<%@ taglib uri="jstl/core" prefix="c"%>
<%@ taglib uri="jstl/fmt" prefix="fmt"%>
<%@ taglib uri="gui" prefix="gui"%>
<gui:docType />
<html>
	<c:set var="title" value="View Genotyping Attachments : ${plate.sheetBarcode}"/>
	<head>
	    <title><c:out value="${title}"/></title>
	    <link type="text/css" href="css/migMain.css" rel="stylesheet">
	    <link type="text/css" href="css/uiTabs.css" rel="stylesheet">
	    <style type="text/css">
	    	.uploadedImage {max-height:500px;}
	    </style>
		<%--
		Assuming that the gel images are large
		- examples to hand are over 1k pixels in each dimension,
		 so restrict the height
		- IE (6,7) is ignoring the max-height, but since we expect the images
		to be large we enforce a constant height for the images
		--%>
		<!--[if IE]>
		<style type="text/css"> .uploadedImage {height:500px;} </style>
		<![endif]-->
	</head>
	<body>
		<gui:page>
			<gui:pageHeader name="${title}" showBackUrl="false"/>

			<c:choose>
			<c:when test="${empty selectedAssay}">No records found</c:when>
			<c:otherwise>

			<img id="spinner" src="images/ajax-loader.gif"/>
			<div id="cloak" style="display: none;">
			<%-- Top level: plate, LacZ nav, Alleles nav--%>
      		<div id="topTabsNav">
				<ul class="ui-tabs-nav">
					<c:forEach items="${alleleAssays}" var="entry">
						<li><a href="#allele-${entry.key.id}">
								<span class="allele">${entry.key.htmlAlleleSymbol}</span>
							</a></li>
					</c:forEach>
					<c:forEach items="${globalAssays}" var="entry">
						<li><a href="#type-${entry.key.id}">
								<span><c:out value="${entry.key.name}"/></span>
						</a></li>
					</c:forEach>
						<li><a href="#plate">
								<span>Plate</span>
						</a></li>
				</ul>
			</div>

			<%-- Second level: plate files, LacZ assay nav, allele type nav --%>
			<div id="plate" class="ui-tabs-panel ui-tabs-hide">
				<gui:fileAttachments files="${plateFiles}"/>
			</div>

			<c:forEach items="${globalAssays}" var="entry">
				<c:set var="type" value="${entry.key}"/>
				<c:set var="assays" value="${entry.value}"/>
				<div id="type-${type.id}" class="ui-tabs-panel ui-tabs-hide">
					<ul class="ui-tabs-nav">
						<c:forEach items="${assays}" var="assay">
							<li><a href="#assay-${assay.id}">
									<span><fmt:formatDate value="${assay.assayDate}" pattern="dd-MMM-yyyy" /></span>
							</a></li>
						</c:forEach>
					</ul>

					<c:forEach items="${assays}" var="assay">
						<c:set var="files" value="${assayFiles[assay]}"/>
						<div id="assay-${assay.id}">
							<gui:fileAttachments files="${files}"/>
						</div>
					</c:forEach>

				</div>
			</c:forEach>

			<c:forEach items="${alleleAssays}" var="entry">
				<c:set var="allele" value="${entry.key}"/>
				<c:set var="assaysByType" value="${entry.value}"/>

				<div id="allele-${allele.id}" class="ui-tabs-panel ui-tabs-hide">
					<ul class="ui-tabs-nav">
						<c:forEach items="${assaysByType}" var="typeEntry">
							<c:set var="type" value="${typeEntry.key}"/>
							<li><a href="#allele-${allele.id}-type-${type.id}">
								<span><c:out value="${type.name}"/></span>
							</a></li>
						</c:forEach>
					</ul>

					<c:forEach items="${assaysByType}" var="typeEntry">
						<c:set var="type" value="${typeEntry.key}"/>
						<c:set var="assays" value="${typeEntry.value}"/>
						<div id="allele-${allele.id}-type-${type.id}" class="ui-tabs-panel ui-tabs-hide">
							<ul class="ui-tabs-nav">
								<c:forEach items="${assays}" var="assay">
									<li><a href="#assay-${assay.id}">
										<span><fmt:formatDate value="${assay.assayDate}" pattern="dd-MMM-yyyy" /></span>
									</a></li>
								</c:forEach>
							</ul>

							<c:forEach items="${assays}" var="assay">
								<c:set var="files" value="${assayFiles[assay]}"/>
								<div id="assay-${assay.id}">
									<gui:fileAttachments files="${files}"/>
								</div>
							</c:forEach>
						</div>
					</c:forEach>
				</div>
			</c:forEach>
			</div>
			</c:otherwise>
			</c:choose>
		</gui:page>
	</body>
	<script type="text/javascript" src="js/jquery.js"></script>
	<script type="text/javascript" src="js/ui.core.packed.js"></script>
	<script type="text/javascript" src="js/ui.tabs.packed.js"></script>
	<script type="text/javascript" src="js/ui.effects.packed.js"></script>
	<script type="text/javascript">
		jQuery.easing.def = "easeInOutQuint";
		$(document).ready(function() {
			var selectedAssayId = ${selectedAssay.id};
			var $tabs = $('ul.ui-tabs-nav').tabs({
		  	fx: { opacity: 'toggle', duration: 'fast' }
			});

			<%--
			Load and prep takes a while on IE, particuarly with big images,
			so use a spinner till it's ready
			--%>
			function reveal() {
				$('#spinner').hide();
				$('#cloak').show();
			}
			<%--
			Traverse up the tabs, making sure that the selected item and it's parent
			menus are all selected.
			Once you get to the top, show the content.
			--%>
			function selectUp(id) {
				$tabs.tabs("select", '#'+ id);
				var container = $('ul.ui-tabs-nav > li > a[href=#'+id+']').parents(".ui-tabs-panel:first");
				if (container.length > 0) {
					selectUp(container.attr("id"));
				}
				else {
					<%-- Everything is now selected, show the content once the animation
					finishes. This removes a nasty flicker caused by the tab selection on load --%>
					setTimeout(reveal,250);
				}
			}

			selectUp("assay-" + selectedAssayId);
		});
	</script>
</html>