<%@ taglib uri="spring/form" prefix="form"%>
<%@ taglib uri="jstl/core" prefix="c"%>
<%@ taglib uri="gui" prefix="gui"%>
<gui:docType />
<html>
	<head>
		<link type="text/css" href="css/migMain.css" rel="stylesheet">
		<link type="text/css" href="css/thickbox.css" rel="stylesheet">
		<link type="text/css" href="css/jquery-calendar.css" rel="stylesheet">
		<c:choose>
			<c:when test="${!empty form.batch.id}">
				<c:set var="title" value="Manage Histology Batch #${form.batch.id}" />
			</c:when>
			<c:otherwise>
				<c:set var="title" value="Create Histology Batch" />
			</c:otherwise>
		</c:choose>
		<title>${title}</title>
		<script src="js/jquery.js"></script>
		<script src="js/jquery-calendar.js"></script>
		<script src="js/validateBarcode.js"></script>
		<script src="js/lookupList.js"></script>
		<script src="js/thickbox.js"></script>
	</head>
	<body onkeydown="if(event.keyCode == 13){return false;}">
		<gui:page>
			<gui:pageHeader name="${title}" />
			<form:form commandName="form" method="post" action="manage_histology_batch.do">
				<gui:mig-box label="Find Mice">
					<table class="migBoxInner">
						<tr>
							<td class="entryLabel" width="220px">
								<label for="barcodeField" class="entryLabel">
									Cage/Mouse Barcode
								</label>
							</td>
							<td class="entryData" style="width: 82px; padding-right: 0px; text-align: right;">
								<%-- Users can scan cage or mouse barcode, or they can pick a cohort --%>
								<input type="text" style="width: 80px;" id="barcodeField" onblur="validateBarcode(this, 'selectorId','cage or mouse','selectorDescription','changeRequest');setTimeout('submitIfValid()' ,500);" />
							</td>
							<td class="entryData" style="width: 230px;">
								<gui:formPopup path="selectorDescription" title="Find Cohort" cssStyle="width: 200px;" onclick="openLookupList('lookup_cohort.do','cohortName=selectorDescription,cohortId=selectorId')" />
								<form:hidden path="selectorId" />
								<form:hidden path="changeRequest" />
							</td>
							<td class="entryLabel" style="text-align: left">
								<label class="entryLabel" for="selectorDescription">
									Choose cohort
								</label>
							</td>
						</tr>
					</table>
				</gui:mig-box>
				<gui:histologyBatchSizeWarning batch="${form.batch}" />
				<c:if test="${!empty form.miceToSelectFrom || !empty form.miceInBatch}">
					<gui:mig-box label="Necropsy Date">
						<table class="migBoxInner">
							<tr>
								<td>
									<form:input path="batch.endDate" onblur="validateDateTime(this, true, false);" cssClass="date" />
									<%-- Quadruple escaping of the . is intentional, to get through jsp engine and javascript escaping --%>
									<gui:dateTimePicker path="batch.endDate" datePicker="true" timePicker="false" autoPopUp="button" />
									<form:errors path="batch.endDate" cssClass="formError" />
								</td>
							</tr>
						</table>
					</gui:mig-box>
				</c:if>

				<c:if test="${!empty form.miceToSelectFrom}">
					<gui:mig-box label="Select Mice">
						<table class="migBoxInner">
							<thead class="listNonPaginatedHeader">
								<tr>
									<th width="43px">
										Include
									</th>
									<th>
										Mouse
									</th>
									<th>
										Gender
									</th>
									<th>
										Ear Mark
									</th>
									<th>
										Age
									</th>
									<th>
										Colony
									</th>
								</tr>
							</thead>
							<tbody class="listNonPaginated">
								<%-- loop through a list of BatchCheckbox objects --%>
								<c:forEach items="${form.miceToSelectFrom}" var="mc" varStatus="loopStat">
									<gui:toggle-row-class />
									<tr class="${rowClass}">
										<c:set value="miceToSelectFrom[${loopStat.index}]" var="rootPath" />
										<c:set value="${mc.mouse}" var="mouse" />
										<td>
											<form:checkbox path="${rootPath}.checked" disabled="${mc.inHistologyBatch}" />
											<form:hidden path="${rootPath}.mouse.id" />
											<span class="formError"><form:errors path="${rootPath}" />
											</span>
										</td>
										<td>
											<c:out value="${mouse.name} (${mouse.barcode})" />
										</td>
										<td>
											<c:out value="${mouse.gender.description}" />
										</td>
										<td>
											<c:out value="${mouse.earmark.description}" />
										</td>
										<td>
											<c:out value="${mouse.ageString}" />
										</td>
										<td>
											<c:if test="${!empty mouse.colonyInfo}">
												<c:out value="${mouse.colonyInfo.colonyName} (${mouse.colonyInfo.colonyPrefix})" />
											</c:if>
										</td>
									</tr>
								</c:forEach>
							</tbody>
						</table>
					</gui:mig-box>
				</c:if>

				<c:if test="${!empty form.miceInBatch}">
					<gui:mig-box label="Mice In Batch">
						<table class="migBoxInner">
							<thead class="listNonPaginatedHeader">
								<tr>
									<th width="43px">
										Include
									</th>
									<th>
										Mouse
									</th>
									<th>
										Gender
									</th>
									<th>
										Ear Mark
									</th>
									<th>
										Age
									</th>
									<th>
										Colony
									</th>
								</tr>
							</thead>
							<tbody class="listNonPaginated">
								<c:forEach items="${form.miceInBatch}" var="mc" varStatus="loopStat">
									<gui:toggle-row-class />
									<tr class="${rowClass}">
										<c:set value="miceInBatch[${loopStat.index}]" var="rootPath" />
										<c:set value="${mc.mouse}" var="mouse" />
										<td>
											<form:checkbox path="${rootPath}.checked" />
											<form:hidden path="${rootPath}.mouse.id" />
											<span class="formError"> <form:errors path="${rootPath}" /> </span>
										</td>
										<td>
											<c:out value="${mouse.name} (${mouse.barcode})" />
										</td>
										<td>
											<c:out value="${mouse.gender.description}" />
										</td>
										<td>
											<c:out value="${mouse.earmark.description}" />
										</td>
										<td>
											<c:out value="${mouse.ageString}" />
										</td>
										<td>
											<c:if test="${!empty mouse.colonyInfo}">
												<c:out value="${mouse.colonyInfo.colonyName} (${mouse.colonyInfo.colonyPrefix})" />
											</c:if>
										</td>
									</tr>
								</c:forEach>
							</tbody>
						</table>
					</gui:mig-box>
				</c:if>

				<gui:error-list commandName="form" />
				<c:if test="${!empty form.miceInBatch || !empty form.miceToSelectFrom}">
					<center>
						<input type="button" value="Update" onclick="submitUpdate()" />
						<input type="submit" value="Save" />
					</center>
				</c:if>

			</form:form>
		</gui:page>
	</body>
	<script type="text/javascript">
		function lookupListPostProcessing() {
			$("#changeRequest").val("cohort");
			$("form").submit();
		}
      
		function submitIfValid() {
	        if($("#selectorId").val() != "") {
	          $("form").submit();
	        }
		}
      
		function submitUpdate() {
			$("#changeRequest").val("update");
			$("form").submit();
		}
	</script>
</html>
