<%--
Copyright (c) 2007 Genome Research Ltd.

Author: Mouse Informatics Group <team110g@sanger.ac.uk>

Redistribution and use in source and binary forms, with or without modification, are permitted
provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this list of conditions
and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright notice, this list of
conditions and the following disclaimer in the documentation and/or other materials provided
with the distribution.
3. The name of the author may not be used to endorse or promote products derived from this software
without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
--%>
<%@ taglib uri="jstl/core" prefix="c"%>
<%@ taglib uri="spring/form" prefix="form"%>
<%@ taglib uri="spring" prefix="spring"%>
<%@ taglib uri="gui" prefix="gui"%>
<gui:docType />
<html>
<head>
<c:set var="title" value="Edit Calorimetry Results" />
<title>${title}</title>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
<link type="text/css" href="css/migMain.css" rel="stylesheet">
<link type="text/css" href="css/thickbox.css" rel="stylesheet">
<script type="text/javascript" src="js/jquery.js"></script>
<script type="text/javascript" src="js/dataCapture.js"></script>
<script type="text/javascript" src="js/thickbox.js"></script>
<script type="text/javascript" src="js/mouse_tracking/printLabels.js"></script>
<script type="text/javascript">
	function updateDiffs() {
		var row = $(this).parents("tr:first");
		var before = row.find(".waterBefore").val();
		var after = row.find(".waterAfter").val();
		var show = row.find(".waterDiff");

		try {
			var diff = before - after;
			if (isNaN(diff) ||  before == "" || after == "") {
				show.val("");
			}
			else {
				diff = Math.round(diff * 10) / 10;
				show.val(diff);
			}
		}catch(e){
			show.val("");
		}
	};

	$(document).ready(function(){
		$(".waterBefore,.waterAfter").blur(updateDiffs);
		$(".waterBefore").each(updateDiffs);
	});
</script>
</head>
<body>
<body>
<gui:page>
  <gui:pageHeader name="${title}" />
  <form:form commandName="form" method="post" action="edit_calorimetry.do">
    <table width="99%" align="center">
    <tr valign="top">
    <td width="70%" >
      <%-- Table for weights --%>

      <table class="listNonPaginated">
        <thead class="listNonPaginatedHeader">
          <tr>
            <th>Box Number</th>
            <th>Mouse</th>
            <th>Status</th>
            <th>Weight Before</th>
            <th>Weight After</th>
            <th>Ignore Food Data</th>
            <th>Water-Bottle Before</th>
          	<th>Water-Bottle After</th>
          	<th>Water-Bottle Difference</th>
          </tr>
        </thead>
        <tbody>
          <c:forEach items="${form.rows}" var="row" varStatus="loopStat">
            <gui:toggle-row-class/>
            <tr class="${rowClass}">
              <td><c:out value="${row.boxNumber.value}" /></td>
              <td><c:out value="${row.mouse.barcode}" /></td>
              <td>
                <c:choose>
                  <c:when test="${row.mouse.alive}">Alive</c:when>
                  <c:otherwise>Deceased</c:otherwise>
                </c:choose>
              </td>
              <td>
                <c:out value="${row.weightBefore.value}" />&nbsp;
                <c:out value="${row.weightBefore.requiredObservation.observationType.units}" />
              </td>
              <td>
                <form:input path="rows[${loopStat.index}].weightAfter.value" size="3"/>&nbsp;
                <c:out value="${row.weightAfter.requiredObservation.observationType.units}" />
                <form:errors path="rows[${loopStat.index}].weightAfter" cssClass="formError"/>
              </td>
              <td>
                <c:forEach items="${row.badFoodData.requiredObservation.observationType.restrictedOptions}" var="option">
                  <label for="rows[${loopStat.index}].badFoodData.value"><c:out value="${option.name}"/></label>
                  <form:radiobutton path="rows[${loopStat.index}].badFoodData.value" value="${option.id}" />
                </c:forEach>&nbsp;
                <form:errors path="rows[${loopStat.index}].badFoodData" cssClass="formError"/>
              </td>
              <td>
                <form:input path="rows[${loopStat.index}].waterBottleWeightBefore.value" size="3" cssClass="waterBefore"/>&nbsp;
                <c:out value="${row.waterBottleWeightBefore.requiredObservation.observationType.units}" />
                <form:errors path="rows[${loopStat.index}].waterBottleWeightBefore" cssClass="formError"/>
              </td>
              <td>
                <form:input path="rows[${loopStat.index}].waterBottleWeightAfter.value" size="3" cssClass="waterAfter"/>&nbsp;
                <c:out value="${row.waterBottleWeightAfter.requiredObservation.observationType.units}" />
                <form:errors path="rows[${loopStat.index}].waterBottleWeightAfter" cssClass="formError"/>
              </td>
              <td>
              	<input type="input" readonly="readonly" class="waterDiff readOnly" size="3"/>
              	<c:out value="${row.waterBottleWeightAfter.requiredObservation.observationType.units}" />
              </td>
            </tr>
          </c:forEach>
        </tbody>
      </table>
      </td>

      <td>
        <%-- Printable cages --%>
        <c:if test="${!empty form.cageIds}">
          <h2>Cages</h2>
          <c:forEach items="${form.cageIds}" var="cageId">
            <gui:link-button text="Print cage card ${cageId}" onclick="printLabels('PRINT_CAGE','${cageId}')" />
          </c:forEach>
        </c:if>
      </td>
      </tr>
    </table>

    <gui:mig-submit-button/>
  </form:form>

</gui:page>
</body>
</html>
