<%--
 - Copyright (c) 2007 Genome Research Ltd.
 -
 - Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 -
 - Redistribution and use in source and binary forms, with or without
 - modification, are permitted provided that the following conditions are
 - met:
 -
 -  1. Redistributions of source code must retain the above copyright notice,
 -     this list of conditions and the following disclaimer.
 -  2. Redistributions in binary form must reproduce the above copyright
 -     notice, this list of conditions and the following disclaimer in the
 -     documentation and/or other materials provided with the distribution.
 -  3. The name of the author may not be used to endorse or promote products
 -     derived from this software without specific prior written permission.
 -
 - THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 - WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 - MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 - EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 - SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 - PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 - OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 - WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 - OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 - ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
--%>

<%@tag description="Render a Mouse Tracking Cage" pageEncoding="UTF-8"%>

<%@ taglib uri="jstl/core" prefix="c"%>
<%@ taglib uri="jstl/fn" prefix="fn"%>
<%@ taglib uri="gui" prefix="gui"%>
<%@ taglib uri="jstl/fmt" prefix="fmt"%>
<%@attribute name="cage" type="uk.ac.sanger.mig.mousetracking.Cage"%>
<%@attribute name="breedings" type="java.util.Collection"%>

<table align="center">
	<c:if test="${!empty breedings}">
		<tr>
			<td>
				<script>
					function jumpToBreeding(field) {
						if(field.value != null) {
							location.href = "view_one_breeding.do?id=" + field.value;
						}
					}
				</script>
				<b>Jump to mating:</b>
				<select name="colonyBreeding" onchange="jumpToBreeding(this)">
					<option value="">&nbsp;</option>
					<c:forEach items="${breedings}" var="breeding">
						<option value="${breeding.id}">${breeding.breedingName}</option>
					</c:forEach>
				</select>
			</td>
		</tr>
	</c:if>
	<c:if test="${cage.populated}">
		<tr>
			<td>
				<h2>
					<u>Tasks</u>
				</h2>
			</td>
		</tr>
		<tr>
			<td>
				<gui:link-button text="print cage card" style="width:250px" onclick="printLabels('PRINT_CAGE','${cage.id}')"/>
			</td>
		</tr>
		<tr>
			<td>
				<gui:link-button text="add 19b / edit / cull mice" style="width:250px" href="edit_mice_by_cage.do?id=${cage.id }"/>
			</td>
		</tr>
		<tr>
			<td>
				<gui:link-button text="clean cage" style="width:250px" href="validate_cage_details.do?id=${cage.id }"/>
			</td>
		</tr>
		<c:if test="${cage.cageType != 'POOL_CAGE'}">
		<tr>
			<td>
				<gui:link-button text="move mice" style="width:250px" href="move_mouse.do?cageId=${cage.id}"/>
			</td>
		</tr>
		</c:if>
	</c:if>
	<c:if test="${!empty cage.previousCages}">
		<tr>
			<td>
				<hr>
				<gui:mig-box>
					<table class="migBoxInner">
						<caption><b>Related Cages</b></caption>
						<thead class="listNonPaginatedHeader">
							<tr>
								<th>Barcode</th>
								<th>Type</th>
								<th>Mice</th>
								<th>
									<c:if test="${fn:length(cage.previousCages) gt 1}">
										<c:set var="cageList" value="${gui:commaSeparate(cage.previousCages,'id')}" />
										<gui:link-button text="print all" style="width:65px" onclick="printLabels('PRINT_CAGE','${cageList}')"/>
									</c:if>
								</th>
							</tr>
						</thead>
						<gui:toggle-row-reset/>
						<c:forEach items="${cage.previousCages}" var="previousCage">
							<gui:toggle-row-class/>
							<tr class="${rowClass}">
								<td>
									<c:out value="${previousCage.barcode}" />
								</td>
								<td>
									<c:out value="${previousCage.cageType.description}" />
								</td>
								<td>
									<c:out value="${previousCage.cageTotals}" />
								</td>
								<td>
									<gui:link-button text="print" style="width:65px" onclick="printLabels('PRINT_CAGE','${previousCage.id}')"/>
									<gui:link-button text="view" style="width:65px" href="view_one_cage.do?id=${previousCage.id}"/>
								</td>
							</tr>
						</c:forEach>
						<tr>
							<td colspan="4" style="font-size:8pt;">
								Mice: f=female, m=male, pw=prewean pups
							</td>
						</tr>
					</table>
				</gui:mig-box>


			</td>
		</tr>
	</c:if>
	<c:if test="${cage.readyToSplit}">
		<tr>
			<td>
				<gui:link-button text="split sexes" style="width:250px" href="edit_litter.do?splitMode=true&id=${cage.contents[0].litterId}"/>
			</td>
		</tr>
	</c:if>
	<c:if test="${cage.cageType eq 'MATING'}">
		<tr>
			<td><hr></td>
		</tr>
		<c:forEach items="${cage.currentBreedings}" var="breeding">
			<tr>
				<td>
					<c:set var="reportUrl"><gui:oracle-report-url parameterString='mating_summary+${breeding.id}' /></c:set>
					<gui:link-button text="mating summary ${breeding.breedingName}" style="width:250px" onclick="window.open('${reportUrl}');"/>
				</td>
			</tr>
			<tr>
				<td>
					<gui:link-button text="add litter to mating ${breeding.breedingName}" style="width:250px" href="edit_litter.do?litter.breedingId=${breeding.id}"/>
				</td>
			</tr>
			<c:if test="${empty breeding.litters}">
				<tr>
					<td>
						<gui:link-button text="delete mating ${breeding.breedingName}" cssClass="smallButtonRed" style="width:250px" onclick="deleteAlert('a mating','delete_breeding.do?id=${breeding.id}')"/>
					</td>
				</tr>
			</c:if>
			<tr>
				<td>
					<gui:link-button text="edit / separate / complete mating ${breeding.breedingName}" style="width:250px" href="edit_breeding.do?id=${breeding.id}"/>
				</td>
			</tr>
		</c:forEach>
	</c:if>
	<c:if test="${cage.cageType eq 'PLUGGED_FEMALE_CAGE'}">
		<tr>
			<td><hr></td>
		</tr>
		<tr>
			<td>
				<gui:link-button text="change required embryo age" style="width:250px" href="edit_stud_breedings.do?cageId=${cage.id}"/>
			</td>
		</tr>
	</c:if>
</table>
