<%--
 - Copyright (c) 2007 Genome Research Ltd.
 -
 - Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 -
 - Redistribution and use in source and binary forms, with or without
 - modification, are permitted provided that the following conditions are
 - met:
 -
 -  1. Redistributions of source code must retain the above copyright notice,
 -     this list of conditions and the following disclaimer.
 -  2. Redistributions in binary form must reproduce the above copyright
 -     notice, this list of conditions and the following disclaimer in the
 -     documentation and/or other materials provided with the distribution.
 -  3. The name of the author may not be used to endorse or promote products
 -     derived from this software without specific prior written permission.
 -
 - THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 - WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 - MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 - EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 - SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 - PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 - OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 - WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 - OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 - ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
--%>
<%@tag description="Render datacapture elements for an experiment" pageEncoding="UTF-8"%>

<%@ taglib uri="http://java.sun.com/jsp/jstl/core" prefix="c"%>
<%@ taglib uri="gui" prefix="gui"%>
<%@ taglib uri="jstl/fmt" prefix="fmt"%>

<%@ attribute name="experiment" type="uk.ac.sanger.mig.phenotyping.datacapture.Experiment" %>
<%@ attribute name="requiredObservations" type="java.util.Collection"%>
<c:set var="recordData" value="${!empty experiment}"/>

<table width="100%" id="expTable${experiment.id}">
<tbody valign="middle">
<gui:toggle-row-class />
<tr class="${rowClass}">
<td>
*
</td>
<td>
Experiment&nbsp;Start
</td>
<td class="expStartRep" id="expStartRep${experiment.id}">
<c:if test="${not empty experiment.procedure.startDate}">
  <img src='images/ticktrans.gif' />
</c:if>
</td>
<td>

<c:choose>
  <c:when test="${recordData}">
    <input id="expStart${experiment.id}" class="dateTime" onblur="validateDateTime(this, true, true);"
      onchange="updateExperimentStart(${experiment.id})"
      value='<fmt:formatDate value="${experiment.procedure.startDate}" pattern="dd-MMM-yyyy HH:mm"/>' />
  </c:when>
  <c:otherwise>
    <input id="expStart${experiment.id}" class="dateTime" onblur="validateDateTime(this, true, true);" />
  </c:otherwise>
</c:choose>

<gui:dateTimePicker path="expStart${experiment.id}" datePicker="true" timePicker="true" autoPopUp="button" />


<c:if test="${empty experiment.procedure}">
  <c:set var="procStyle" value="display: none" />
</c:if>
<span id="procRecorded${experiment.id}" style="${procStyle}">
<em>
Procedure recorded
</em>
<gui:link-button text="Delete" onclick="deleteProcedure(${experiment.id},'${cage.barcode}')" />
</span>
</td>
</tr>

<c:set var="loopItems" value="${experiment.observations}" />
<c:set var="loopItems" value="${experiment.groupedObservations}" />
<c:if test="${!recordData}">
  <c:set var="loopItems" value="${requiredObservations}" />
</c:if>


<c:forEach items="${loopItems}" var="loopItem" varStatus="obvLoopStat">
  <c:choose>
    <c:when test="${recordData}">
      <c:set var="observation" value="${loopItem[0]}" />
      <c:set var="requiredObservation" value="${observation.requiredObservation}" />
    </c:when>
    <c:otherwise>
      <c:set var="requiredObservation" value="${loopItem}" />
    </c:otherwise>
  </c:choose>

  <c:if test="${not empty requiredObservation.sectionTitle}">
    <gui:toggle-row-class />
    <tr class="${rowClass}" valign="middle">
    <td colspan="4">
    <strong>
      <c:out value="${requiredObservation.sectionTitle}" />
    </strong>
    </td>
    </tr>
  </c:if>

  <gui:toggle-row-class />
  <tr class="${rowClass}" id="obsRow${observation.id}" valign="middle">
  <td>
  <c:if test="${requiredObservation.mandatoryObservation}">*</c:if>
  </td>
  <td>
  <c:out value="${requiredObservation.displayName}" />
  </td>
  <c:set var="repCss" value="expRep${experiment.id}" />
  <c:if
    test="${empty observation.valueOrDefault && requiredObservation.mandatoryObservation && requiredObservation.observationType.restrictedOption}">
    <c:set var="repCss" value="emptyOption ${repCss}" />
  </c:if>

  <td id="obvRep${observation.id}" class="${repCss}" width="17px">
  <c:if test="${not empty observation.value}">
    <img src='images/ticktrans.gif' />
  </c:if>
  </td>

  <td nowrap="nowrap" valign="middle">
  <c:choose>
  <c:when test="${requiredObservation.machineData}">
    <em>Recorded separately</em>
  </c:when>
  <c:when test="${recordData}">
    <gui:datacaptureObservation
    observation="${observation}"
    recordFunction="recordObservation('${observation.id}',this)"
    />
  </c:when>
  <c:otherwise>
    <gui:datacaptureObservation requiredObservation="${requiredObservation}" />
  </c:otherwise>
  </c:choose>


  </td>
  </tr>
</c:forEach>
</tbody>
</table>



