<%--
 - Copyright (c) 2007 Genome Research Ltd.
 -
 - Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 -
 - Redistribution and use in source and binary forms, with or without
 - modification, are permitted provided that the following conditions are
 - met:
 -
 -  1. Redistributions of source code must retain the above copyright notice,
 -     this list of conditions and the following disclaimer.
 -  2. Redistributions in binary form must reproduce the above copyright
 -     notice, this list of conditions and the following disclaimer in the
 -     documentation and/or other materials provided with the distribution.
 -  3. The name of the author may not be used to endorse or promote products
 -     derived from this software without specific prior written permission.
 -
 - THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 - WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 - MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 - EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 - SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 - PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 - OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 - WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 - OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 - ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
--%>

<%@tag description="Render an input element for an observation" pageEncoding="UTF-8"%>

<%@ taglib prefix="c" uri="http://java.sun.com/jsp/jstl/core"%>
<%@ taglib uri="gui" prefix="gui"%>

<%@attribute name="observation" type="uk.ac.sanger.mig.phenotyping.datacapture.Observation"%>
<%@attribute name="requiredObservation" type="uk.ac.sanger.mig.phenotyping.datacapture.RequiredObservation"%>
<%@attribute name="recordFunction"%>


<c:choose>
  <c:when test="${not empty observation}">
    <c:set var="requiredObservation" value="${observation.requiredObservation}" />
  </c:when>
  <c:otherwise>
    <jsp:useBean id="observation" class="uk.ac.sanger.mig.phenotyping.datacapture.Observation" />
    <jsp:setProperty name="observation" property="requiredObservation" value="${requiredObservation}" />
    <jsp:setProperty name="observation" property="id" value="${requiredObservation.id}" />
  </c:otherwise>
</c:choose>


<c:set var="obsMarker" value="obv${observation.id}" />
<c:set var="expClass" value="exp${observation.experimentId}" />

<c:set var="cssClasses" value="${obsMarker} ${expClass}" />

<c:if test="${empty observation.value}">
  <c:set var="cssClasses" value="unsubmitted ${cssClasses}"/>
</c:if>

<c:set var="name" value="${obsMarker}" />

<c:set var="events" value=""/>

<c:if test="${not empty recordFunction}">
  <c:choose>
    <c:when test="${requiredObservation.observationType.radioButton}">
      <c:set var="events" value='onclick="toggleRadioLabel(this);${recordFunction}"'/>
    </c:when>
    <c:otherwise>
      <c:set var="events" value='onchange="${recordFunction}"'/>
    </c:otherwise>
  </c:choose>
</c:if>

<%-- Choose input type, depending on the data type expected --%>
<c:choose>
  <%--Data that isn't entered manually --%>
  <c:when test="${requiredObservation.machineData}">

  </c:when>

  <%-- Numeric types --%>
  <c:when
    test="${requiredObservation.observationType.integerNumber || requiredObservation.observationType.floatingPointNumber}">
    <input  id="${name}" size="6" value="${observation.valueOrDefault}"
      class="${cssClasses}"
      ${events} />

    ${requiredObservation.observationType.units}

    <c:choose>
      <c:when test="${!empty requiredObservation.observationType.rangeMin && !empty requiredObservation.observationType.rangeMax}">
        (between ${requiredObservation.observationType.rangeMin} and ${requiredObservation.observationType.rangeMax})
      </c:when>
      <c:when test="${!empty requiredObservation.observationType.rangeMin}">
        (greater than ${requiredObservation.observationType.rangeMin})
      </c:when>
      <c:when test="${!empty requiredObservation.observationType.rangeMax}">
        (less than ${requiredObservation.observationType.rangeMax})
      </c:when>
    </c:choose>

  </c:when>

  <%-- Text type --%>
  <c:when test="${requiredObservation.observationType.freeText}">
    <textarea
	   id="${name}"
	   class="${cssClasses}"
     ${events}
     cols="30"
     rows="3" type="_moz">${observation.valueOrDefault}</textarea>
  </c:when>

  <%-- Select box type --%>
  <c:when test="${requiredObservation.observationType.optionList}">
    <select
      id="${name}"
      ${events}
      class="${cssClasses}">

      <option value="0">
        Please choose...
      </option>

      <c:forEach items="${requiredObservation.observationType.restrictedOptions}" var="opt">
        <c:if test="${opt.active || opt.id == observation.value}">
        <c:choose>
          <c:when test="${opt.id == observation.valueOrDefault}">
            <c:set var="selected" value='selected="selected"' />
          </c:when>
          <c:otherwise>
            <c:set var="selected" value='' />
          </c:otherwise>
        </c:choose>

        <option value="${opt.id}" ${selected}>
          ${opt.name}
        </option>
        </c:if>
      </c:forEach>

    </select>

  </c:when>

  <%--  Radio button type --%>
  <c:when test="${requiredObservation.observationType.radioButton}">
    <c:forEach items="${requiredObservation.observationType.restrictedOptions}" var="option"
      varStatus="optionIterStatus">
      <c:if test="${option.active || option.id == observation.value}">
        <c:choose>
          <c:when test="${option.id == observation.valueOrDefault}">
            <c:set var="checked" value='checked="checked"' />
            <c:set var="radClass" value="enbiggenedInput radio_checked" />
          </c:when>
          <c:otherwise>
            <c:set var="checked" value='' />
            <c:set var="radClass" value="enbiggenedInput radio_unchecked" />
          </c:otherwise>
        </c:choose>

        <c:set var="radioButtonId" value="${name}_${option.id}" />
        <label class="${radClass}" id="obvLabel${observation.id}_${option.id}" for="${radioButtonId}">
        ${option.name}
      </label>
        <input type="radio" value="${option.id}" name="${name}" ${events}
        class="${cssClasses} bigInputHidden"
          ${checked}
        id="${radioButtonId}" />
      </c:if>
    </c:forEach>
  </c:when>

  <%-- Date field --%>
  <c:when test="${requiredObservation.observationType.date}">

    <input
      id="${obsMarker}"
      name="${obsMarker}"
      value="${observation.valueOrDefault}"
      class="${cssClasses} date"
      onblur="validateDateTime(this, true, false)"
      ${events} />
       <gui:dateTimePicker path="${name}" datePicker="true" timePicker="false" defaultDateField="expStart${observation.experimentId}" autoPopUp="button" />
      (dd-mmm-yyyy)
  </c:when>

  <%-- Clock field --%>
  <c:when test="${requiredObservation.observationType.clockTime}">

    <input
      id="${obsMarker}"
      name="${obsMarker}"
      value="${observation.valueOrDefault}"
      class="${cssClasses} time"
      onblur="validateDateTime(this, false, true)"
      ${events} />
      <gui:dateTimePicker path="${name}" datePicker="false" timePicker="true" autoPopUp="button" />
      (hh:mm)
  </c:when>

  <%-- Date time field --%>
  <c:when test="${requiredObservation.observationType.dateTime}">

    <input
      id="${obsMarker}"
      name="${obsMarker}"
      value="${observation.valueOrDefault}"
      class="${cssClasses} calendar${observation.id} dateTime"
      onblur="validateDateTime(this, true, true)"
      ${events}
      />
      <gui:dateTimePicker path="${name}" datePicker="true" timePicker="true" defaultDateField="expStart${observation.experimentId}" autoPopUp="button" />
      (dd-mmm-yyyy hh:mm)

  </c:when>

  <%-- Blood Sample Barcode --%>
  <c:when test="${requiredObservation.observationType.bloodSampleBarcode}">
    <c:if test="${!empty observation.value}">
      <input
        id="${obsMarker}"
        size="8"
        value="${observation.value}"
        class="${cssClasses} readOnly"
        readonly="readonly"
       />
     </c:if>
    <%--  <gui:link-button text="Print label"
        onclick="printLabels('PRINT_ONE_BLOOD_SAMPLE_LABEL','${observation.id}')"
     />
    --%>
  </c:when>

  <c:otherwise>
    Error! ${requiredObservation}, ${requiredObservation.observationType}
  </c:otherwise>

</c:choose>
<input type="hidden" class="metaType" id="${observation.id}" value="${requiredObservation.observationType.observationMetaTypeId}" />