<%--
 - Copyright (c) 2007 Genome Research Ltd.
 -
 - Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 -
 - Redistribution and use in source and binary forms, with or without
 - modification, are permitted provided that the following conditions are
 - met:
 -
 -  1. Redistributions of source code must retain the above copyright notice,
 -     this list of conditions and the following disclaimer.
 -  2. Redistributions in binary form must reproduce the above copyright
 -     notice, this list of conditions and the following disclaimer in the
 -     documentation and/or other materials provided with the distribution.
 -  3. The name of the author may not be used to endorse or promote products
 -     derived from this software without specific prior written permission.
 -
 - THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 - WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 - MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 - EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 - SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 - PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 - OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 - WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 - OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 - ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
--%>

<%@tag description="Render a Mouse Tracking Embryo Transfer Cage" pageEncoding="UTF-8"%>

<%@ taglib uri="jstl/core" prefix="c"%>
<%@ taglib uri="jstl/fn" prefix="fn"%>
<%@ taglib uri="gui" prefix="gui"%>
<%@ taglib uri="jstl/fmt" prefix="fmt"%>

<%@attribute name="cage" type="uk.ac.sanger.mig.mousetracking.Cage"%>
<%@attribute name="readonly" type="java.lang.Boolean"%>

<c:set var="breedings" value="${cage.currentBreedings}" />
<c:forEach items="${breedings}" var="breeding">
	<c:set var="embryoTransfer" value="${breeding.embryoTransfer}" />
	<gui:mig-box>
		<table class="migBoxInner" width="99%">
			<gui:matingCageHeader breeding="${breeding}" />
			<tr>
				<td colspan="2">
					<c:choose>
						<c:when test="${embryoTransfer.fromMicroInjection}">
							<gui:microInjectionDetails embryoTransfer="${embryoTransfer}" />
						</c:when>
						<c:when test="${embryoTransfer.fromThawTest}">
							<gui:thawTestDetails embryoTransfer="${embryoTransfer}" />
						</c:when>
					</c:choose>
				</td>
			</tr>
			<tr>
				<td colspan="2">
					<table class="listNonPaginated" width="100%">
						<thead class="listPaginatedHeader">
							<tr>
								<th>Recipient I.D.</th>
								<th>Earmark</th>
								<th># Embryos</th>
								<th>Due Date</th>
								<th>Plug</th>
								<th>Comments</th>
							</tr>
						</thead>
						<tr class="odd">
							<td>
								<a href="view_one_mouse.do?id=${breeding.female.id}">${breeding.female.name}</a>
								<c:if test="${!readonly}">
									<gui:link-button text="edit" href="edit_mouse.do?id=${breeding.female.id}"/>
								</c:if>
							</td>
							<td>
								${breeding.female.earmark.name}
							</td>
							<td>
								${embryoTransfer.numberLeft}/${embryoTransfer.numberRight}&nbsp;
							</td>
							<td>
								<fmt:formatDate value="${breeding.litters[0].dueDate}" />&nbsp;
							</td>
							<td>
								D${breeding.embryoTransfer.daysFromPlug}
							</td>
							<td width="40%">
								${breeding.comments}
							</td>
						</tr>
						<tr>
							<td colspan="6">
								<gui:litterList list="${breeding.litters}" readonly="${readonly}" />
							</td>
						</tr>
					</table>
				</td>
			</tr>
			<tr valign="top">
				<td colspan="2">
					<gui:cageFooter cage="${cage}" />
				</td>
			</tr>
		</table>
		(Database ID: ${breeding.id})
	</gui:mig-box>
</c:forEach>