<%--
 - Copyright (c) 2007 Genome Research Ltd.
 -
 - Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 -
 - Redistribution and use in source and binary forms, with or without
 - modification, are permitted provided that the following conditions are
 - met:
 -
 -  1. Redistributions of source code must retain the above copyright notice,
 -     this list of conditions and the following disclaimer.
 -  2. Redistributions in binary form must reproduce the above copyright
 -     notice, this list of conditions and the following disclaimer in the
 -     documentation and/or other materials provided with the distribution.
 -  3. The name of the author may not be used to endorse or promote products
 -     derived from this software without specific prior written permission.
 -
 - THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 - WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 - MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 - EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 - SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 - PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 - OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 - WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 - OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 - ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
--%>

<%@tag description="Render a Mouse Tracking Mating Cage" pageEncoding="UTF-8"%>

<%@ taglib uri="jstl/core" prefix="c"%>
<%@ taglib uri="jstl/fn" prefix="fn"%>
<%@ taglib uri="gui" prefix="gui"%>
<%@ taglib uri="jstl/fmt" prefix="fmt"%>

<%@attribute name="cage" type="uk.ac.sanger.mig.mousetracking.Cage"%>
<%@attribute name="readonly" type="java.lang.Boolean"%>

<c:set var="breedings" value="${cage.currentBreedings}" />

<c:forEach items="${breedings}" var="breeding">
	<gui:mig-box>
		<table class="migBoxInner" width="99%">
			<gui:matingCageHeader breeding="${breeding}" />

			<tr valign="top">
				<td>
					<gui:matingCageParents breeding="${breeding}" readonly="${readonly}" />
				</td>
				<td>
					<table width="100%">
						<tr>
							<td>
								<b>Date Paired:</b> <fmt:formatDate value="${breeding.startDate}" pattern="dd-MMM-yyyy"/>
							</td>
						</tr>
						<c:if test="${!empty breeding.endDate}">
							<tr>
								<td>
									<b>Date Completed:</b> <fmt:formatDate value="${breeding.endDate}" pattern="dd-MMM-yyyy"/>
								</td>
							</tr>
						</c:if>
						<c:if test="${!empty breeding.offspringGeneration}">
							<tr>
								<td>
									<b>Offspring Generation:</b> ${breeding.offspringGeneration}
								</td>
							</tr>
						</c:if>
						<c:if test="${breeding.timed}">
							<tr>
								<td>
									<span class="requiredField"><b>Timed Mating</b> <c:out value="${breeding.timedEmbryoAge}" default="?"></c:out>E</span>
								</td>
							</tr>
							<c:set var="harvestDate" value="${breeding.timedHarvestDate}" />
							<c:if test="${!empty harvestDate}">
							<tr>
								<td>
									<b>Harvest Date:</b> <fmt:formatDate value="${harvestDate}" pattern="dd-MMM-yyyy"/>
								</td>
							</tr>
							</c:if>
						</c:if>
					</table>
				</td>
			</tr>
			<c:if test="${! empty breeding.litters}">
				<tr>
					<td colspan="2">
						<gui:litterList list="${breeding.litters}" readonly="${readonly}" />
					</td>
				</tr>
			</c:if>
			<c:if test="${breeding.male.chimera}">
				<tr>
					<td colspan="2">
						<b>ES Cell Line (Clone):</b> ${breeding.male.chimericData.cellLine.cellLineName} (${breeding.male.chimericData.cellLine.cloneName})
					</td>
				</tr>
				<tr>
					<td colspan="2">
						<b>ES Cell Line Background:</b> ${breeding.male.chimericData.cellLineStrain.name}
					</td>
				</tr>
				<tr>
					<td colspan="2">
						<b>ES Cell Line Coat Colour:</b> ${breeding.male.chimericData.expectedCoatColour.name}
					</td>
				</tr>
			</c:if>
			<tr valign="top">
				<td width="50%">
					<gui:cageFooter cage="${cage}" />
				</td>
				<td>
					<c:if test="${!empty breeding.breedingCategory}">
						<b>Mating Category:</b>
						<c:out value="${breeding.breedingCategory.name}" /><br />
					</c:if>
					<c:if test="${!empty breeding.comments}">
						<b>Mating Notes:</b>
						<c:out value="${breeding.comments}" />
					</c:if>
					<c:if test="${breeding.pseudoBreeding}">
						<br /><b>This is a Pseudo-mating</b>
					</c:if>
				</td>
			</tr>
		</table>
		(Database ID: ${breeding.id})
	</gui:mig-box>
</c:forEach>