<%--
 - Copyright (c) 2007 Genome Research Ltd.
 -
 - Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 -
 - Redistribution and use in source and binary forms, with or without
 - modification, are permitted provided that the following conditions are
 - met:
 -
 -  1. Redistributions of source code must retain the above copyright notice,
 -     this list of conditions and the following disclaimer.
 -  2. Redistributions in binary form must reproduce the above copyright
 -     notice, this list of conditions and the following disclaimer in the
 -     documentation and/or other materials provided with the distribution.
 -  3. The name of the author may not be used to endorse or promote products
 -     derived from this software without specific prior written permission.
 -
 - THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 - WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 - MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 - EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 - SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 - PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 - OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 - WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 - OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 - ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
--%>

<%@tag description="Render a Mouse Tracking Plugged Females Cage" pageEncoding="UTF-8"%>

<%@ taglib uri="jstl/core" prefix="c"%>
<%@ taglib uri="jstl/fn" prefix="fn"%>
<%@ taglib uri="gui" prefix="gui"%>
<%@ taglib uri="jstl/fmt" prefix="fmt"%>

<%@attribute name="cage" type="uk.ac.sanger.mig.mousetracking.Cage"%>
<%@attribute name="readonly" type="java.lang.Boolean"%>
<gui:mig-box>
	<table class="migBoxInner" width="99%">
		<gui:stockCageHeader cage="${cage}" />
		<tr>
			<td colspan="3">
				<table class="listNonPaginated" width="100%">
					<c:choose>
						<c:when test="${empty cage.contents}">
							<tr>
								<td colspan="8">
									<h2><span class="formError">There are no mice in this cage</span></h2>
								</td>
							</tr>
						</c:when>
						<c:otherwise>
							<thead class="listNonPaginatedHeader">
								<tr>
									<c:if test="${!readonly eq true}">
										<th>Options</th>
									</c:if>
									<th>I.D.</th>
									<th>D.O.B.</th>
									<th>Earmark</th>
									<th>Genotype</th>
									<th>Set up By</th>
									<th>Plug Check By</th>
									<th>Plug Date</th>
									<th>Required Date (Embryo Age)</th>
									<th>Type</th>
								</tr>
							</thead>
							<c:forEach items="${cage.contents}" var="mouse">
								<c:set var="breeding" value="${mouse.latestStudBreeding}" />
								<gui:toggle-row-class />
								<tr class="${rowClass}">
									<c:if test="${!readonly eq true}">
										<td style="width:50px">
											<gui:link-button text="edit" href="edit_mouse.do?id=${mouse.id}"/>
										</td>
									</c:if>
									<td>
										<a href="view_one_mouse.do?id=${mouse.id}">${mouse.name}</a>
									</td>
									<td>
										<fmt:formatDate value="${mouse.birthDate}" pattern="dd-MMM-yyyy" />&nbsp;
									</td>
									<td>
										${mouse.earmark.name}&nbsp;
									</td>
									<td>
										<gui:mouseGenotype mouse="${mouse}" />
									</td>
									<td>
										<c:out value="${breeding.setupPerson.fullName}" />
									</td>
									<td>
										<c:out value="${breeding.checkPerson.fullName}" />
									</td>
									<td>
										<fmt:formatDate value="${breeding.plugDateTime}" pattern="dd-MMM-yyyy HH:mm"/>
									</td>
									<td>
										<fmt:formatDate value="${breeding.readyDate}" pattern="dd-MMM-yyyy"/>
										(${breeding.timedEmbryoAge}E)
									</td>
									<td>
										<c:choose>
											<c:when test="${breeding.pseudoBreeding}">
												Recipient
											</c:when>
											<c:otherwise>
												Donor
											</c:otherwise>
										</c:choose>
									</td>
								</tr>
							</c:forEach>
						</c:otherwise>
					</c:choose>
				</table>
			</td>
		</tr>
		<tr>
			<td colspan="2">
				<gui:cageFooter />
			</td>
			<td>&nbsp;</td>
		</tr>
	</table>
</gui:mig-box>

