<%--
 - Copyright (c) 2007 Genome Research Ltd.
 -
 - Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 -
 - Redistribution and use in source and binary forms, with or without
 - modification, are permitted provided that the following conditions are
 - met:
 -
 -  1. Redistributions of source code must retain the above copyright notice,
 -     this list of conditions and the following disclaimer.
 -  2. Redistributions in binary form must reproduce the above copyright
 -     notice, this list of conditions and the following disclaimer in the
 -     documentation and/or other materials provided with the distribution.
 -  3. The name of the author may not be used to endorse or promote products
 -     derived from this software without specific prior written permission.
 -
 - THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 - WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 - MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 - EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 - SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 - PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 - OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 - WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 - OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 - ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
--%>

<%@tag description="Render a Mouse Tracking Stud Cage" pageEncoding="UTF-8"%>

<%@ taglib uri="jstl/core" prefix="c"%>
<%@ taglib uri="jstl/fn" prefix="fn"%>
<%@ taglib uri="gui" prefix="gui"%>
<%@ taglib uri="jstl/fmt" prefix="fmt"%>

<%@attribute name="cage" type="uk.ac.sanger.mig.mousetracking.Cage"%>
<%@attribute name="readonly" type="java.lang.Boolean"%>

<c:forEach items="${cage.contents}" var="mouse">
	<c:if test="${mouse.stud}">
		<c:set var="stud" value="${mouse}"/>
	</c:if>
	<c:if test="${mouse.pooled}">
		<c:set var="female" value="${mouse}" />
	</c:if>
</c:forEach>

<gui:mig-box>
	<table class="migBoxInner" width="99%">
		<tr>
			<td>
				<table width="100%">
					<tr valign="top">
						<td width="70%" colspan="3">
							<h1>${stud.colonyInfo.colonyName}</h1>
						</td>
						<td align="right">
							<h1>${stud.colonyInfo.colonyPrefix}</h1>
						</td>
					</tr>
				</table>
			</td>
		</tr>
		<tr>
			<td>
				<table class="listNonPaginated" width="100%">
					<thead class="listPaginatedHeader">
						<tr>
							<th>&nbsp;</th>
							<c:if test="${!readonly eq true}">
								<th>Options</th>
							</c:if>
							<th>I.D.</th>
							<th>D.O.B.</th>
							<th>Age</th>
							<th>&nbsp;</th>
						</tr>
					</thead>
					<tr valign="top" class="odd">
						<td width="5%">
							<img src="images/mouse_tracking/male_gender_symbol.gif" height="25px" />
						</td>
						<c:if test="${!readonly eq true}">
							<td><gui:link-button text="edit" href="edit_mouse.do?id=${stud.id}"/></td>
						</c:if>
						<td>
							<c:out value="${stud.name}" />
						</td>
						<td>
							D.O.B: <fmt:formatDate value="${stud.birthDate}"/>
						</td>
						<td>
							Age: <c:out value="${stud.ageString}" />
						</td>
						<td>
							Proven Stud: <gui:format-boolean booleanValue="${stud.provenStud}"/>
						</td>
					</tr>
					<c:if test="${!empty female}">
						<tr valign="top" class="even">
							<td width="5%">
								<img src="images/mouse_tracking/female_gender_symbol.gif" height="25px" />
							</td>
							<c:if test="${!readonly eq true}">
								<td><gui:link-button text="edit" href="edit_mouse.do?id=${female.id}"/></td>
							</c:if>
							<td>
								<c:out value="${female.name}" />
							</td>
							<td>
								D.O.B: <fmt:formatDate value="${female.birthDate}"/>
							</td>
							<td>
								Age: <c:out value="${female.ageString}" />
							</td>
							<td>
								&nbsp;
							</td>
						</tr>
					</c:if>

				</table>
			</td>
		</tr>
		<tr>
			<td>
				<table>
					<tr valign="top">
						<td>
							<table class="listNonPaginated" style="width:300px">
								<thead class="listPaginatedHeader">
									<tr>
										<c:if test="${!readonly eq true}">
											<th>Options</th>
										</c:if>
										<th>Setup Date</th>
										<th>Plugged</th>
										<th>Female</th>
									</tr>
								</thead>
								<c:set var="successfulPlugs" value="0" />
								<c:set var="unsuccessfulPlugs" value="0" />
								<c:forEach items="${cage.studBreedings}" var="breeding">
									<gui:toggle-row-class/>
									<tr class="${rowClass}">
										<c:if test="${!readonly eq true}">
											<td>
												<gui:link-button text="edit" href="edit_stud_breeding.do?id=${breeding.id}" />
											</td>
										</c:if>
										<td><fmt:formatDate value="${breeding.startDateTime}" pattern="dd-MMM-yyyy HH:mm" /></td>
										<td><gui:format-boolean booleanValue="${breeding.plugged}" /></td>
										<td>
											<a href="view_one_mouse.do?id=${breeding.female.id}"><c:out value="${breeding.female.name}" /></a>
										</td>
									</tr>
									<c:choose>
										<c:when test="${!empty breeding.endDate and breeding.plugged}">
											<c:set var="successfulPlugs" value="${successfulPlugs + 1}" />
										</c:when>
										<c:when test="${!empty breeding.endDate and !breeding.plugged}">
											<c:set var="unsuccessfulPlugs" value="${unsuccessfulPlugs + 1}" />
										</c:when>
									</c:choose>
								</c:forEach>
							</table>
						 </td>
						 <td>
							<c:if test="${!readonly eq true}">
							 	<h2>Plugs: <c:out value="${successfulPlugs}" /></h2>
							 	<h2>Failures: <c:out value="${unsuccessfulPlugs}" /></h2>
							 	<h2>Total: <c:out value="${successfulPlugs + unsuccessfulPlugs}" /></h2>
						 	</c:if>
						 	&nbsp;
						 </td>
					 </tr>
				 </table>
			</td>
		</tr>
	</table>
</gui:mig-box>
