/* jQuery Calendar v2.7
   Written by Marc Grabanski (m@marcgrabanski.com) and enhanced by Keith Wood (kbwood@iprimus.com.au).

   Copyright (c) 2007 Marc Grabanski (http://marcgrabanski.com/code/jquery-calendar)
   Dual licensed under the GPL (http://www.gnu.org/licenses/gpl-3.0.txt) and
   CC (http://creativecommons.org/licenses/by/3.0/) licenses. "Share or Remix it but please Attribute the authors."
   Date: 09-03-2007  */

var arrMonthNames = ["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"];
var monthNumberRegExp = /^\d{1,2}$/;
var monthNameRegExp = /^[a-zA-Z][a-zA-Z][a-zA-Z]$/;
var dateRegExp = /^(([0][1-9])|([1-9])|([1-2][0-9])|([3][01]))(\-)([a-zA-Z][a-zA-Z][a-zA-Z])(\-)\d{4}$/;
var dateTimeRegExp = /^(([0][1-9])|([1-9])|([1-2][0-9])|([3][01]))(\-)([a-zA-Z][a-zA-Z][a-zA-Z])(\-)\d{4}[ ](([0][0])|([0][1-9])|([1-9])|([2][0-3])|([1][0-9]))[:]([0-5][0-9])$/;
var timeRegExp = /^(([0][0])|([0][1-9])|([1-9])|([2][0-3])|([1][0-9]))[:]([0-5][0-9])$/;
var quickDate = /^(([0][1-9])|([1-9])|([1-2][0-9])|([3][01]))(([0][1-9])|([1][0-2]))\d{4}$/;
var quickDateTime = /^(([0][1-9])|([1-9])|([1-2][0-9])|([3][01]))(([0][1-9])|([1][0-2]))\d{4}[ ](([0][0])|([0][1-9])|([1-9])|([2][0-3])|([1][0-9]))[:]([0-5][0-9])$/;
var quickDateTimeCondensed = /^(([0][1-9])|([1-9])|([1-2][0-9])|([3][01]))(([0][1-9])|([1][0-2]))\d{4}(([0][0])|([0][1-9])|([1-9])|([2][0-3])|([1][0-9]))([0-5][0-9])$/;
//thickbox always displays duplicate calendar button, hideButton is used to hide each second button
var hideButton = false;
var arrInputNames = new Array();
var arrIndex = 0;

var bankHolidays = [
"01-Jan-2007",
"06-Apr-2007",
"09-Apr-2007",
"07-May-2007",
"28-May-2007",
"27-Aug-2007",
"25-Dec-2007",
"26-Dec-2007",
"01-Jan-2008",
"21-Mar-2008",
"24-Mar-2008",
"05-May-2008",
"26-May-2008",
"25-Aug-2008",
"25-Dec-2008",
"26-Dec-2008",
"01-Jan-2009",
"10-Apr-2009",
"13-Apr-2009",
"04-May-2009",
"25-May-2009",
"31-Aug-2009",
"25-Dec-2009",
"28-Dec-2009",
"01-Jan-2010",
"02-Apr-2010",
"05-Apr-2010",
"03-May-2010",
"31-May-2010",
"30-Aug-2010",
"28-Dec-2010",
"27-Dec-2010"
];

/* PopUp Calendar manager.
   Use the singleton instance of this class, popUpCal, to interact with the calendar.
   Settings for (groups of) calendars are maintained in an instance object
   (PopUpCalInstance), allowing multiple different settings on the same page. */
function PopUpCal() {
	this._nextId = 0; // Next ID for a calendar instance
	this._inst = []; // List of instances indexed by ID
	this._curInst = null; // The current instance in use
	this._disabledInputs = []; // List of calendar inputs that have been disabled
	this._popUpShowing = false; // True if the popup calendar is showing , false if not
	this._inDialog = false; // True if showing within a "dialog", false if not
	this.regional = []; // Available regional settings, indexed by language code
	this.regional[''] = { // Default regional settings
		clearText: 'Clear', // Display text for clear link
		closeText: 'Close', // Display text for close link
		prevText: '&lt;Prev', // Display text for previous month link
		nextText: 'Next&gt;', // Display text for next month link
		currentText: 'Today', // Display text for current month link
		dayNames: ['Su','Mo','Tu','We','Th','Fr','Sa'], // Names of days starting at Sunday
		monthNames: ['January','February','March','April','May','June',
			'July','August','September','October','November','December'], // Names of months
		currentTime: '',	//To keep track of set time as calendar is redrawn between changing date
		dateFormat: 'DMY-' // First three are day, month, year in the required order,
			// fourth (optional) is the separator, e.g. US would be 'MDY/', ISO would be 'YMD-'
	};
	this._defaults = { // Global defaults for all the calendar instances
		autoPopUp: 'focus', // 'focus' for popup on focus,
			// 'button' for trigger button, or 'both' for either
		appendText: '', // Display text following the input box, e.g. showing the format
		buttonText: '...', // Text for trigger button
		buttonImage: '', // URL for trigger button image
		buttonImageOnly: false, // True if the image appears alone, false if it appears on a button
		closeAtTop: true, // True to have the clear/close at the top,
			// false to have them at the bottom
		hideIfNoPrevNext: false, // True to hide next/previous month links
			// if not applicable, false to just disable them
		changeMonth: true, // True if month can be selected directly, false if only prev/next
		changeYear: true, // True if year can be selected directly, false if only prev/next
		yearRange: '-8:+8', // Range of years to display in drop-down,
			// either relative to current year (-nn:+nn) or absolute (nnnn:nnnn)
		firstDay: 0, // The first day of the week, Sun = 0, Mon = 1, ...
		changeFirstDay: true, // True to click on day name to change, false to remain as set
		showOtherMonths: false, // True to show dates in other months, false to leave blank
		minDate: null, // The earliest selectable date, or null for no limit
		maxDate: null, // The latest selectable date, or null for no limit
		speed: 'fast', // Speed of display/closure (fast,medium, slow)
		customDate: null, // Function that takes a date and returns an array with
			// [0] = true if selectable, false if not,
			// [1] = custom CSS class name(s) or '', e.g. popUpCal.noWeekends
		fieldSettings: null, // Function that takes an input field and
			// returns a set of custom settings for the calendar
		onSelect: null, // Define a callback function when a date is selected
		timePicker: false,	//display the time picker
		datePicker: true, //display the calendar
		defaultDateField: "", //use as a default date
		hoursStart: 8, //timepicker start hour
		hoursEnd: 17, //timepicker end hour
		hourOffset: 0, //use to show coorect hour range
		minuteMarker: 10,	//timepicker interval in minutes. 60/minuteMarker needs to be a whole number
		selectedTime: 0		//time
	};

	$.extend(this._defaults, this.regional['']);
	this._calendarDiv = $('<div id="calendar_div"></div>');
	$(document.body).append(this._calendarDiv);
	$(document.body).mousedown(this._checkExternalClick);
}

$.extend(PopUpCal.prototype, {
	/* Register a new calendar instance - with custom settings. */
	_register: function(inst) {
		var id = this._nextId++;
		this._inst[id] = inst;
		return id;
	},

	/* Retrieve a particular calendar instance based on its ID. */
	_getInst: function(id) {
		return this._inst[id] || id;
	},

	/* Override the default settings for all instances of the calendar.
	   @param  settings  object - the new settings to use as defaults (anonymous object)
	   @return void */
	setDefaults: function(settings) {
		$.extend(this._defaults, settings || {});
	},

	/* Handle keystrokes. */
	_doKeyDown: function(e) {
		var inst = popUpCal._getInst(this._calId);
		if (popUpCal._popUpShowing) {
			switch (e.keyCode) {
				case 9:  popUpCal.hideCalendar(inst, '');
						break; // hide on tab out
				case 13: popUpCal._selectDate(inst);
						break; // select the value on enter
				case 27: popUpCal.hideCalendar(inst, inst._get('speed'));
						break; // hide on escape
				case 33: popUpCal._adjustDate(inst, -1, (e.ctrlKey ? 'Y' : 'M'));
						break; // previous month/year on page up/+ ctrl
				case 34: popUpCal._adjustDate(inst, +1, (e.ctrlKey ? 'Y' : 'M'));
						break; // next month/year on page down/+ ctrl
				case 35: if (e.ctrlKey) popUpCal._clearDate(inst);
						break; // clear on ctrl+end
				case 36: if (e.ctrlKey) popUpCal._gotoToday(inst);
						break; // current on ctrl+home
				case 37: if (e.ctrlKey) popUpCal._adjustDate(inst, -1, 'D');
						break; // -1 day on ctrl+left
				case 38: if (e.ctrlKey) popUpCal._adjustDate(inst, -7, 'D');
						break; // -1 week on ctrl+up
				case 39: if (e.ctrlKey) popUpCal._adjustDate(inst, +1, 'D');
						break; // +1 day on ctrl+right
				case 40: if (e.ctrlKey) popUpCal._adjustDate(inst, +7, 'D');
						break; // +1 week on ctrl+down
			}
		}
		else if (e.keyCode == 36 && e.ctrlKey) { // display the calendar on ctrl+home
			popUpCal.showFor(this);
		}
	},

	/* Filter entered characters. */
	_doKeyPress: function(e) {
		var allowedRegExp = /^[a-zA-Z0-9 :-]$/;

		//var chr = String.fromCharCode(e.charCode == undefined ? e.keyCode : e.charCode);
		if (!e) var e = window.event;
		if (e.keyCode) code = e.keyCode;
		else if (e.which) code = e.which;
		var chr = String.fromCharCode(code);
		if (code == 39 || code == 37 || code == 46) {
			return true;//allow left/right and delete
		} else {
			return  (chr < ' ' || allowedRegExp.test(chr)); // only allow numbers, letters and separator
		}
	},

	/* Filter entered characters. */
	doTimeKeyPress: function(e, id) {
		if (!e) var e = window.event;
		if (e.keyCode) code = e.keyCode;
		else if (e.which) code = e.which;
		var chr = String.fromCharCode(code);

		if (code == 13) {
			popUpCal._setDayTime(id);
		} else {
			return (code == 186 || code == 8 || code == 9 || code == 37 || code == 39 || code == 16 || code == 46 || (code >= 48 && code <= 59) || (code >= 96 && code <= 105));
		}
	},

	/* Attach the calendar to an input field. */
	_connectCalendar: function(target, inst) {
		var $input = $(target);
		var appendText = inst._get('appendText');
		var buttonTitle = "Select date";
		if (appendText) {
			$input.after('<span class="calendar_append">' + appendText + '</span>');
		}
		var autoPopUp = inst._get('autoPopUp');

		if (autoPopUp == 'focus' || autoPopUp == 'both') { // pop-up calendar when in the marked field
			$input.focus(this.showFor);
		}
		if (autoPopUp == 'button' || autoPopUp == 'both') { // pop-up calendar when button clicked
			var buttonText = inst._get('buttonText');
			var buttonImage = inst._get('buttonImage');
			var buttonImageOnly = inst._get('buttonImageOnly');
			//Set hideButton (always false on first use, when inst._id is 0)
			hideButton = (inInputArray($input[0].id) ? true : false);

			if (inst._get('timePicker') && !inst._get('datePicker')) {
				buttonTitle = "Select time";
			} else if (inst._get('timePicker') && inst._get('datePicker')) {
				buttonTitle = "Select date and time";
			}

			var trigger = $(buttonImageOnly ? '<img class="calendar_trigger" src="' +
				buttonImage + '" alt="' + buttonText + '" ' + (hideButton ? 'style="display: none"' : 'style="cursor: pointer"') + ' title="' + buttonTitle + '"/>' :
				'<button type="button" class="calendar_trigger" ' + (hideButton ? 'style="display: none"' : '') + '>' + (buttonImage != '' ?
				//'<button id="button' + $input[0].id + '" type="button" class="calendar_trigger" >' + (buttonImage != '' ?
				'<img src="' + buttonImage + '" alt="' + buttonText + '" title="'+ '"/>' :
				buttonText) + '</button>');
			$input.wrap('<span class="calendar_wrap"></span>').after(trigger);
			trigger.click(this.showFor);
		}
		$input.keydown(this._doKeyDown).keypress(this._doKeyPress);
		$input[0]._calId = inst._id;
		//Build up array of input ids
		arrInputNames[arrIndex] = $input[0].id;
		arrIndex++;
	},

	/* Attach an inline calendar to a div. */
	_inlineCalendar: function(target, inst) {
		$(target).append(inst._calendarDiv);
		target._calId = inst._id;
		var date = new Date();
		inst._selectedDay = date.getDate();
		inst._selectedMonth = date.getMonth();
		inst._selectedYear = date.getFullYear();
		popUpCal._adjustDate(inst);
	},

	/* Pop-up the calendar in a "dialog" box.
	   @param  dateText  string - the initial date to display (in the current format)
	   @param  onSelect  function - the function(dateText) to call when a date is selected
	   @param  settings  object - update the dialog calendar instance's settings (anonymous object)
	   @param  pos       int[2] - coordinates for the dialog's position within the screen
			leave empty for default (screen centre)
	   @return void */
	dialogCalendar: function(dateText, onSelect, settings, pos) {
		var inst = this._dialogInst; // internal instance
		if (!inst) {
			inst = this._dialogInst = new PopUpCalInstance({}, false);
			this._dialogInput = $('<input type="text" size="1" style="position: absolute; top: -100px;"/>');
			this._dialogInput.keydown(this._doKeyDown);
			$('body').append(this._dialogInput);
			this._dialogInput[0]._calId = inst._id;
		}
		$.extend(inst._settings, settings || {});
		this._dialogInput.val(dateText);

		/*	Cross Browser Positioning */
		if (self.innerHeight) { // all except Explorer
			windowWidth = self.innerWidth;
			windowHeight = self.innerHeight;
		} else if (document.documentElement && document.documentElement.clientHeight) { // Explorer 6 Strict Mode
			windowWidth = document.documentElement.clientWidth;
			windowHeight = document.documentElement.clientHeight;
		} else if (document.body) { // other Explorers
			windowWidth = document.body.clientWidth;
			windowHeight = document.body.clientHeight;
		}
		this._pos = pos || // should use actual width/height below
			[(windowWidth / 2) - 100, (windowHeight / 2) - 100];

		// move input on screen for focus, but hidden behind dialog
		this._dialogInput.css('left', this._pos[0] + 'px').css('top', this._pos[1] + 'px');
		inst._settings.onSelect = onSelect;
		this._inDialog = true;
		this._calendarDiv.addClass('calendar_dialog');
		this.showFor(this._dialogInput[0]);
		if ($.blockUI) {
			$.blockUI(this._calendarDiv);
		}
	},

	/* Enable the input field(s) for entry.
	   @param  inputs  element/object - single input field or jQuery collection of input fields
	   @return void */
	enableFor: function(inputs) {
		inputs = (inputs.jquery ? inputs : $(inputs));
		inputs.each(function() {
			this.disabled = false;
			$('../button.calendar_trigger', this).each(function() { this.disabled = false; });
			$('../img.calendar_trigger', this).css({opacity:'1.0',cursor:''});
			var $this = this;
			popUpCal._disabledInputs = $.map(popUpCal._disabledInputs,
				function(value) { return (value == $this ? null : value); }); // delete entry
		});
	},

	/* Disable the input field(s) from entry.
	   @param  inputs  element/object - single input field or jQuery collection of input fields
	   @return void */
	disableFor: function(inputs) {
		inputs = (inputs.jquery ? inputs : $(inputs));
		inputs.each(function() {
			this.disabled = true;
			$('../button.calendar_trigger', this).each(function() { this.disabled = true; });
			$('../img.calendar_trigger', this).css({opacity:'0.5',cursor:'default'});
			var $this = this;
			popUpCal._disabledInputs = $.map(popUpCal._disabledInputs,
				function(value) { return (value == $this ? null : value); }); // delete entry
			popUpCal._disabledInputs[popUpCal._disabledInputs.length] = this;
		});
	},

	/* Update the settings for a calendar attached to an input field or division.
	   @param  control   element - the input field or div/span attached to the calendar
	   @param  settings  object - the new settings to update
	   @return void */
	reconfigureFor: function(control, settings) {
		var inst = this._getInst(control._calId);
		if (inst) {
			$.extend(inst._settings, settings || {});
			this._updateCalendar(inst);
		}
	},

	/* Set the date for a calendar attached to an input field or division.
	   @param  control  element - the input field or div/span attached to the calendar
	   @param  date     Date - the new date
	   @return void */
	setDateFor: function(control, date) {
		var inst = this._getInst(control._calId);
		if (inst) {
			inst._setDate(date);
		}
	},

	/* Retrieve the date for a calendar attached to an input field or division.
	   @param  control  element - the input field or div/span attached to the calendar
	   @return Date - the current date */
	getDateFor: function(control) {
		var inst = this._getInst(control._calId);
		return (inst ? inst._getDate() : null);
	},

	/* Pop-up the calendar for a given input field.
	   @param  target  element - the input field attached to the calendar
	   @return void */
	showFor: function(target) {
		var input = (target.nodeName && target.nodeName.toLowerCase() == 'input' ? target : this);
		if (input.nodeName.toLowerCase() != 'input') { // find from button/image trigger
			input = $('input', input.parentNode)[0];
		}
		if (popUpCal._lastInput == input) { // already here
			return;
		}
		for (var i = 0; i < popUpCal._disabledInputs.length; i++) {  // check not disabled
			if (popUpCal._disabledInputs[i] == input) {
				return;
			}
		}

		var inst = popUpCal._getInst(input._calId);
		popUpCal.hideCalendar(inst, '');
		popUpCal._lastInput = input;
		inst._setDateFromField(input, inst._get('defaultDateField'));
		if (popUpCal._inDialog) { // hide cursor
			input.value = '';
		}
		if (!popUpCal._pos) { // position below input
			popUpCal._pos = popUpCal._findPos(input);
			popUpCal._pos[1] += input.offsetHeight;
		}

		//Find cursor position and place calendar 'on-screen'
		var myWidth = 0, myHeight = 0;
		if( typeof( window.innerWidth ) == 'number' ) {
		//Non-IE
			windowWidth = window.innerWidth;
			windowHeight = window.innerHeight;
		} else if( document.documentElement && ( document.documentElement.clientWidth || document.documentElement.clientHeight ) ) {
			//IE 6+ in 'standards compliant mode'
			windowWidth = document.documentElement.clientWidth;
			windowHeight = document.documentElement.clientHeight;
		} else if( document.body && ( document.body.clientWidth || document.body.clientHeight ) ) {
			//IE 4 compatible
			windowWidth = document.body.clientWidth;
			windowHeight = document.body.clientHeight;
		}

		//Adjust position based on window size
		if (popUpCal._pos[0] + 280 > windowWidth) { popUpCal._pos[0] = windowWidth - 310; };
		if (popUpCal._pos[1] + 260 > windowHeight) { popUpCal._pos[1] = windowHeight - 260; };
		//End of cursor position

		var pos = Position.get(input);
		/*
		inst._calendarDiv.css('position', (popUpCal._inDialog && $.blockUI ? 'static' : 'absolute')).
			css('left', popUpCal._pos[0] + 'px').css('top', popUpCal._pos[1] + 'px');
		*/
		popUpCal._pos[0] = pos.left;
		popUpCal._pos[1] = pos.top;
		//prevent display off edge of screen horizontally

		if (popUpCal._pos[0] + 305 > windowWidth) { popUpCal._pos[0] -= (287 - pos.width); };
		//prevent display off edge of screen vertically, dependent on date/datetime/time only
		if (inst._get('datePicker') && (inst._get('timePicker'))) {
			if (popUpCal._pos[1] + 270 > windowHeight) { popUpCal._pos[1] = windowHeight - 270; };
		} else if (inst._get('datePicker') && (!inst._get('timePicker'))) {
			if (popUpCal._pos[1] + 215 > windowHeight) { popUpCal._pos[1] = windowHeight - 215; };
		} else if (inst._get('timePicker')) {
			if (popUpCal._pos[1] + 120 > windowHeight) { popUpCal._pos[1] = windowHeight - 120; };
		}


		inst._calendarDiv.css('position', (popUpCal._inDialog && $.blockUI ? 'static' : 'absolute')).
			css('left', popUpCal._pos[0] + 'px').css('top', popUpCal._pos[1] + pos.height + 'px');

		popUpCal._pos = null;
		var fieldSettings = inst._get('fieldSettings');
		$.extend(inst._settings, (fieldSettings ? fieldSettings(input) : {}));
		popUpCal._showCalendar(inst);
	},

	/* Construct and display the calendar. */
	_showCalendar: function(id) {
		var inst = this._getInst(id);

		popUpCal._updateCalendar(inst);

		if (!inst._inline) {

			var speed = inst._get('speed');
			inst._calendarDiv.show(speed, function() {
				popUpCal._popUpShowing = true;
				popUpCal._afterShow(inst);
				//set focus on month drop-down to prevent thickbox use re-saving the previous date
				var monthSelect = eval('document.getElementById("month" + inst._id)');
				if (monthSelect) { monthSelect.focus() };
			});
			if (speed == '') {
				popUpCal._popUpShowing = true;
				popUpCal._afterShow(inst);
			}
			if (inst._input[0].type != 'hidden') {
				//inst._input[0].focus();
			}
			this._curInst = inst;
			inst._calendarDiv.css("border", "1px solid #777");
			inst._calendarDiv.css("width", "265px");
			inst._calendarDiv.css("background", "#ddd");
		}
	},

	/* Generate the calendar content. */
	_updateCalendar: function(inst) {
		inst._calendarDiv.empty().append(inst._generateCalendar());
		if (inst._input && inst._input != 'hidden') {
			//inst._input[0].focus();
		}
	},

	/* Tidy up after displaying the calendar. */
	_afterShow: function(inst) {
		if ($.browser.msie) { // fix IE < 7 select problems
			$('#calendar_cover').css({width: inst._calendarDiv[0].offsetWidth + 4,
				height: inst._calendarDiv[0].offsetHeight + 4});
		}
		/*// re-position on screen if necessary
		var calDiv = inst._calendarDiv[0];
		var pos = popUpCal._findPos(inst._input[0]);
		if ((calDiv.offsetLeft + calDiv.offsetWidth) >
				(document.body.clientWidth + document.body.scrollLeft)) {
			inst._calendarDiv.css('left', (pos[0] + inst._input[0].offsetWidth - calDiv.offsetWidth) + 'px');
		}
		if ((calDiv.offsetTop + calDiv.offsetHeight) >
				(document.body.clientHeight + document.body.scrollTop)) {
			inst._calendarDiv.css('top', (pos[1] - calDiv.offsetHeight) + 'px');
		}*/
	},

	/* Hide the calendar from view.
	   @param  id     string/object - the ID of the current calendar instance, or the instance itself
	   @param  speed  string - the speed at which to close the calendar
	   @return void */
	hideCalendar: function(id, speed) {
		var inst = this._getInst(id);
		if (popUpCal._popUpShowing) {
			speed = (speed != null ? speed : inst._get('speed'));
			$("#calendar_div select").css({ visibility: "hidden" });
			inst._calendarDiv.hide(speed, function() {
				popUpCal._tidyDialog(inst);
			});
			if (speed == '') {
				popUpCal._tidyDialog(inst);
			}

			popUpCal._popUpShowing = false;
			popUpCal._lastInput = null;
			inst._settings.prompt = null;

			if (popUpCal._inDialog) {
				popUpCal._dialogInput.css('position', 'absolute').
					css('left', '0px').css('top', '-100px');
				if ($.blockUI) {
					$.unblockUI();
					$('body').append(this._calendarDiv);
				}
			}
			popUpCal._inDialog = false;
		}

		popUpCal._curInst = null;
		try {
			var autoPopUp = inst._get('autoPopUp');

			if ((autoPopUp != 'both')) {
				afterValidateDate(inst._input[0]);
			}
		}
		catch (e) {
			//do nothing
		}
	},

	isBankHoliday: function(testDate) {
		var testDateFormatted = (parseInt(testDate.getDate()) < 10 ? '0' + testDate.getDate().toString() : testDate.getDate()) + '-' + arrMonthNames[testDate.getMonth()] + '-' + testDate.getFullYear();

		for (var i = 0; i < bankHolidays.length; i++) {
			if (testDateFormatted == bankHolidays[i]) {return true}
		}

		return false;
	},
	/* Tidy up after a dialog display. */
	_tidyDialog: function(inst) {
		inst._calendarDiv.removeClass('calendar_dialog');
		$('.calendar_prompt', inst._calendarDiv).remove();
		/*prevent scroll-to-top in firefox and 'hide' from view */
		inst._calendarDiv.empty();
		//inst._calendarDiv.css("border", "0px");
		//inst._calendarDiv.css("background", "transparent");
		//inst._calendarDiv.css("top", "0px");
		//inst._calendarDiv.css("left", "0px");

		//inst._calendarDiv.css("display", "inline");

		/*
		document.getElementById("calendar_div").style.border = '0px';
		document.getElementById("calendar_div").style.background = 'transparent';
		document.getElementById("calendar_div").style.top = '0px';
		document.getElementById("calendar_div").style.left = '0px';
		document.getElementById("calendar_div").innerHTML = '';
		document.getElementById("calendar_div").style.display = 'inline';
		*/
	},

	/* Close calendar if clicked elsewhere. */
	_checkExternalClick: function(event) {
		if (!popUpCal._curInst) {
			return;
		}
		var target = $(event.target);
		if( (target.parents("#calendar_div").length == 0)
			&& (target.attr('class') != 'calendar_trigger')
			&& popUpCal._popUpShowing
			&& !(popUpCal._inDialog && $.blockUI) )
		{
			popUpCal.hideCalendar(popUpCal._curInst, '');
		}
	},

	/* Adjust one of the date sub-fields. */
	_adjustDate: function(id, offset, period) {
		var inst = this._getInst(id);
		inst._adjustDate(offset, period);
		this._updateCalendar(inst);
	},

	_adjustTime: function(id) {
		var inst = this._getInst(id);
		inst._selectedTime = document.getElementById('time').value;
	},

	/* Action for current link. */
	_gotoToday: function(id) {
		var date = new Date();
		var inst = this._getInst(id);
		inst._selectedDay = date.getDate();
		inst._selectedMonth = date.getMonth();
		inst._selectedYear = date.getFullYear();
		if (!inst._get('timePicker')) {
			this._selectDate(id);
		} else {
			this._adjustDate(inst);
		}
	},

	_setSelectedDate: function(id) {
		var date = new Date();
		var inst = this._getInst(id);
		inst._selectedDay = date.getDate();
		inst._selectedMonth = date.getMonth();
		inst._selectedYear = date.getFullYear();
		this._adjustDate(inst);
	},

	/* Action for selecting a new month/year. */
	_selectMonthYear: function(id, select, period) {
		var inst = this._getInst(id);
		inst._selectingMonthYear = false;
		inst[period == 'M' ? '_selectedMonth' : '_selectedYear'] =
			select.options[select.selectedIndex].value - 0;
		this._adjustDate(inst);
	},

	/* Restore input focus after not changing month/year. */
	_clickMonthYear: function(id) {
		var inst = this._getInst(id);
		if (inst._input && inst._selectingMonthYear && !$.browser.msie) {
			inst._input[0].focus();
		}
		inst._selectingMonthYear = !inst._selectingMonthYear;
	},

	/* Action for changing the first week day. */
	_changeFirstDay: function(id, a) {
		var inst = this._getInst(id);
		var dayNames = inst._get('dayNames');
		var value = a.firstChild.nodeValue;
		for (var i = 0; i < 7; i++) {
			if (dayNames[i] == value) {
				inst._settings.firstDay = i;
				break;
			}
		}
		this._updateCalendar(inst);
	},

	/* Action for selecting a day. */
	_selectDay: function(id, td) {
		var inst = this._getInst(id);
		inst._selectedDay = $("a", td).html();
		this._selectDate(id);
	},

	/* Action for selecting a day and time */
	_setDayTime: function(id) {
		var inst = this._getInst(id);
		var dateTime = '';
		var timeArray = $("#time").val().split(':');
		var timeHour = '';
		var time ='';

		if (inst._get('datePicker')) {
			dateTime = inst._formatDate(inst._selectedDay, inst._selectedMonth, inst._selectedYear);
		}
		if (inst._get('timePicker'))
		{
			if (!timeRegExp.test($("#time").val())) {
				alert('The time should be in format hh:mm\n(e.g. 12:30)');
				$("#time").select();
				return false;
			}
			time = (timeArray[0].length == 1 ? '0' + timeArray[0] : timeArray[0]) + ':' + timeArray[1];
			dateTime += (dateTime != '' ? ' ' + time : time);
		}
		inst._input.val(dateTime);
		inst._input.trigger('change');
		hourOffset = 0;
		this.hideCalendar(id, this.speed);
	},


	_setNow: function(id) {
		var today = new Date();
		var inst = this._getInst(id);

		if (inst._get('datePicker')) {
			inst._selectedDay = today.getDate();
			inst._selectedMonth = today.getMonth();
			inst._selectedYear = today.getFullYear();
			this._adjustDate(inst);
		}

		if (!inst._get('timePicker')) {
			this._selectDate(id);
		} else {
			$("#time").val(today.getHours() + ':' + (today.getMinutes() < 10 ? '0' : '') + today.getMinutes());
		}
	},


	/* Erase the input field and hide the calendar. */
	_clearDate: function(id) {
		this._selectDate(id, '');
	},

	/* Update the input field with the selected date. */
	_selectDate: function(id, dateStr) {
		var inst = this._getInst(id);

		if (dateStr == '') {
			inst._input.val(dateStr)
			this.hideCalendar(inst, inst._get('speed'));
			return false;
		}

		dateStr = (dateStr != null ? dateStr : inst._formatDate(inst._selectedDay, inst._selectedMonth, inst._selectedYear));

		if (!inst._get('timePicker')) {
			if (inst._input) {
				inst._input.val(dateStr);
			}
			var onSelect = inst._get('onSelect');
			if (onSelect) {
				onSelect(dateStr);  // trigger custom callback
			}
			else {
				inst._input.trigger('change'); // fire the change event
			}

			if (inst._inline) {
				this._updateCalendar(inst);
			}
			else {
				this.hideCalendar(inst, inst._get('speed'));
			}
		} else {
			this._selectedDay = inst._selectedDay;
			this._selectedMonth = inst._selectedMonth;
			this._selectedYear = inst._selectedYear;
			this._selectedTime = $("#time").val();
			this._updateCalendar(inst);
			setTimeout("$('#time').select()", 100);
		}
	},

	/* Set as customDate function to prevent selection of weekends.
	   @param  date  Date - the date to customise
	   @return [boolean, string] - is this date selectable?, what is its CSS class? */
	noWeekends: function(date) {
		var day = date.getDay();
		return [(day > 0 && day < 6), ''];
	},

	/* Find an object's position on the screen. */
	_findPos: function(obj) {
		if (obj.type == 'hidden') {
			obj = obj.nextSibling;
		}
		var curleft = curtop = 0;
		if (obj.offsetParent) {
			curleft = obj.offsetLeft;
			curtop = obj.offsetTop;
			while (obj = obj.offsetParent) {
				var origcurleft = curleft;
				curleft += obj.offsetLeft;
				if (curleft < 0) {
					curleft = origcurleft;
				}
				curtop += obj.offsetTop;
			}
		}
		return [curleft,curtop];
	}
});

/* Individualised settings for calendars applied to one or more related inputs.
   Instances are managed and manipulated through the PopUpCal manager. */
function PopUpCalInstance(settings, inline) {
	this._id = popUpCal._register(this);
	this._selectedDay = 0;
	this._selectedMonth = 0; // 0-11
	this._selectedYear = 0; // 4-digit year
	this._selectedTime = 0; // time
	this._input = null; // The attached input field
	this._inline = inline; // True if showing inline, false if used in a popup
	this._calendarDiv = (!inline ? popUpCal._calendarDiv :
		$('<div id="calendar_div_' + this._id + '" class="calendar_inline"></div>'));
	if (inline) {
		var date = new Date();
		this._currentDay = date.getDate();
		this._currentMonth = date.getMonth();
		this._currentYear = date.getFullYear();
	}
	// customise the calendar object - uses manager defaults if not overridden
	this._settings = $.extend({}, settings || {}); // clone
}

$.extend(PopUpCalInstance.prototype, {
	/* Get a setting value, defaulting if necessary. */
	_get: function(name) {
		return (this._settings[name] != null ? this._settings[name] : popUpCal._defaults[name]);
	},

	/* Parse existing date and initialise calendar. */
	_setDateFromField: function(input, defaultDateField) {
		this._input = $(input);
		var currentTime = '';
		var currentDate = '';
		var inputField = this._input.val();
		var dateTimeArray = inputField.split(' ');
		var timeArray = '';
		var dateFormat = this._get('dateFormat');
		var defaultDateFormatted = '';

		//Check if defaultDateField is used/exists and get date (not time) from it
		if (defaultDateField != "" && $("#" + defaultDateField).length > 0) {
			defaultDateFormatted = $("#" + defaultDateField).val().substring(0, 11);
		}

		if (this._settings['timePicker'] && !this._settings['datePicker']) {
			if (inputField != '') {
				timeArray = inputField.split(':');
				currentTime = (timeArray[0].length == 1 ? '0' + timeArray[0] : timeArray[0]) + ':' + timeArray[1];
				currentDate = (dateTimeArray[0] ? dateTimeArray[0] : '');
				currentDate = currentDate.split(dateFormat.charAt(3));
			}
		} else if (!this._settings['timePicker'] && this._settings['datePicker']) {
			if (inputField != '') {
				currentDate = inputField.split(dateFormat.charAt(3));
			}
		} else if (this._settings['timePicker'] && this._settings['datePicker']) {
		 	if (inputField != '') {
				currentTime = (dateTimeArray[1] ? dateTimeArray[1] : '');

				timeArray = currentTime.split(':');
				currentTime = (timeArray[0].length == 1 ? '0' + timeArray[0] : timeArray[0]) + ':' + timeArray[1];
				currentDate = (dateTimeArray[0] ? dateTimeArray[0] : '');//this.input.val().substr(0, this.input.val().length - 6);
				currentDate = currentDate.split(dateFormat.charAt(3));
			}
		} else {
			currentDate = inputField.split(dateFormat.charAt(3));
		}

		if (currentDate.length == 0 && defaultDateFormatted != "") {
			currentDate = defaultDateFormatted.split(dateFormat.charAt(3));
		}

		if (currentDate.length == 3) {
			this._currentDay = parseInt(this._trimNumber(currentDate[dateFormat.indexOf('D')]));
			this._currentMonth = parseInt(this._monthNumber((this._trimNumber(currentDate[dateFormat.indexOf('M')]))));
			this._currentYear = parseInt(this._trimNumber(currentDate[dateFormat.indexOf('Y')]));
		} else {
			var date = new Date();
			this._currentDay = date.getDate();
			this._currentMonth = date.getMonth();
			this._currentYear = date.getFullYear();
		}

		this._selectedDay = this._currentDay;
		this._selectedMonth = this._currentMonth;
		this._selectedYear = this._currentYear;
		this._selectedTime = currentTime;
		this._adjustDate();
	},

	/* Ensure numbers are not treated as octal. */
	_trimNumber: function(value) {
		if (value == '')
			return '';
		while (value.charAt(0) == '0') {
			value = value.substring(1);
		}
		return value;
	},

	/* Set the date directly. */
	_setDate: function(date) {
		this._selectedDay = this._currentDay = date.getDate();
		this._selectedMonth = this._currentMonth = date.getMonth();
		this._selectedYear = this._currentYear = date.getFullYear();
		this._adjustDate();
	},

	_monthNumber: function(monthName) {
		for (var i = 0; i < 12; i++) {
			if (arrMonthNames[i].toLowerCase() == monthName.toLowerCase()) {
				return i;
			}
		}
	},

	/* Retrieve the date directly. */
	_getDate: function() {
		return new Date(this._currentYear, this._currentMonth, this._currentDay);
	},

	/* Generate the HTML for the current state of the calendar. */
	_generateCalendar: function() {
		var today = new Date();
		/*ck*/
		var timePickerHtml = '';
		var hourSegments = 60/popUpCal._defaults['minuteMarker'];
		var hourSegmentId = 1;
		var segmentHour = 0;
		var segmentMinute = 0;
		var segmentHourString = '';
		var segmentMinuteString = '';
		var totalHours = popUpCal._defaults['hoursEnd'] - popUpCal._defaults['hoursStart'];
		var controls = '';
		var nowTitle = 'Set to current date and time';

		//Formatting for time picker
		if (this._get('timePicker')) {
			var currentTime = '';
			var inputHour = 0;
			var hourRange = popUpCal._defaults['hoursEnd'] - popUpCal._defaults['hoursStart'];
			var midHour = parseInt((hourRange)/2);
			var hourStart = popUpCal._defaults['hoursStart'];
			var hourEnd = popUpCal._defaults['hoursEnd'];
			var defaultTime = popUpCal._defaults['hoursStart'] + midHour;
			var segmentsHourWidth = 20;
			var segmentLeftPosition = 0;

			if (!this._get('datePicker')) {
				nowTitle = 'Set to current time';
			}

			defaultTime = (defaultTime.length == 1 ? '0' + defaultTime.toString() : defaultTime.toString()) + ':00';
			this._selectedTime = currentTime = (this._selectedTime == '' ? defaultTime : this._selectedTime);
			inputHour = parseInt((currentTime.substr(0,1) == '0' ? currentTime.substr(1,1) : currentTime.substr(0,2)));

			//Check hour range is correct
			if (inputHour < hourStart || inputHour > hourEnd) {
				if (inputHour <= midHour) {
					hourStart = (inputHour - midHour) < 0 ? 0 : inputHour - midHour;
					hourEnd = hourStart + hourRange;
				} else {
					hourEnd = (inputHour + midHour) > 23 ? 23 : inputHour + midHour;
					hourStart = hourEnd - hourRange;
				}
			}

			//default to today if no date in field
			this.date = (!this.date ? this._formatDate(new Date().getDate(), new Date().getMonth(), new Date().getFullYear()) : this.date);

			timePickerHtml = '<div><table class="calendar_time_info" cellpadding=0 cellspacing=0><tr><td>Hover & click range below to pick time (hh:mm)</td></tr></table></div>';
			timePickerHtml += '<div class="calendar_timepick_hours" onMouseout="hideTime()"><table border=0 cellpadding=0 cellspacing=0 width="100%"><tr>';

			//earlier
			timePickerHtml += '<td id="earlierHour" class="moveHour" style="text-align: left;"><a href="javascript:moveHours(-1, ' + hourStart + ', ' + hourEnd + ');" title="earlier">&nbsp;<&nbsp;</a></td>';
			segmentHour += hourStart;

			//hour markers
			timePickerHtml += '<td class="hourMarker">';

			for (var i = hourStart; i <= hourEnd; i++) {
				segmentsHourWidth = (i == hourStart ? 15 : segmentsHourWidth);
				segmentLeftPosition = 0;
				timePickerHtml += '<span>';
				timePickerHtml += '<dl class="hour" style="left: ' + segmentsHourWidth + 'px;"><dt id="hour' + i + '">' + i + '</dt>';
				for (var j = 1; j < hourSegments + 1; j++) {
					segmentMinuteString = (segmentMinute==0)? '00':segmentMinute.toString();
					segmentHourString = (segmentHour<10)? '0' + segmentHour.toString(): segmentHour.toString();
					timePickerHtml += '<img class="segment" src="images/blank.gif" style="left: ' + segmentLeftPosition + 'px;" onclick="javascript: setTime(' + segmentHour + ', ' + segmentMinute + '); popUpCal._adjustTime( ' + this._id + ' );" onmouseover="timeTip(' + segmentHour + ',' + segmentMinute + ');">';
					segmentLeftPosition += 4;
					segmentMinute += popUpCal._defaults['minuteMarker']
					hourSegmentId++;
				}
				timePickerHtml += '</dl></span>';
				segmentMinute = 0;
				segmentHour++;
				segmentsHourWidth += 24;
			}

			//later
			timePickerHtml += '<td id="laterHour" class="moveHour" style="text-align: right;"><a href="javascript:moveHours(1,' + hourStart + ', ' + hourEnd + ');" title="later">&nbsp;>&nbsp;</a></td>';
			timePickerHtml += '</tr></table></div>';
			timePickerHtml += '<div><table class="calendar_time" cellpadding=0 cellspacing=0><tr><td style="width: 45px;"></td><td style="width: 60px;"><a href="javascript:popUpCal._setNow( ' + this._id + ' );popUpCal._setDayTime( ' + this._id + ' );" title="' + nowTitle + '">Now</a></td><td><input class="calendarTime" id="time" maxlength=5 value="' + this._selectedTime + '" type="text" onkeydown="return popUpCal.doTimeKeyPress(event, ' + this._id + ')" onblur="popUpCal._adjustTime( ' + this._id + ' )"></td><td id="hoverTime"></td><td style="width: 45px; text-align: right;"><input class="calendar_set" type="button" value="Set" name="Set" onclick="popUpCal._setDayTime(\'' + this._id + '\');"></td></tr></table></div>';
			timePickerHtml += ''

		} else {
			timePickerHtml = '';
		}
		/*ck*/
		today = new Date(today.getFullYear(), today.getMonth(), today.getDate()); // clear time

		if (this._get('datePicker')) {

			// build the calendar HTML
			controls = '<div id="calendarFrame" class="calendar_control"><table class="calendar_control" cellspacing="0" cellpadding="0" width="100%"><tr>' +
				'<td><a class="calendar_clear" href="#" onclick="popUpCal._clearDate(' + this._id + ');">' +
				this._get('clearText') + '</a></td>' +
				'<td style="text-align: center;">' + (this._isInRange(today) ? '<a class="calendar_current" href="#" ' +
				'onclick="popUpCal._gotoToday(' + this._id + ');">' + this._get('currentText') + '</a>' : '') + '</td>' +
				'<td style="text-align: right;"><a class="calendar_close" href="#" onclick="popUpCal.hideCalendar(' + this._id + ');">' +
				this._get('closeText') + '</a></td></tr></table></div>';
			var prompt = this._get('prompt');
			var closeAtTop = this._get('closeAtTop');
			var hideIfNoPrevNext = this._get('hideIfNoPrevNext');
			var minDate = this._get('minDate');
			var maxDate = this._get('maxDate');

			var html = (prompt ? '<div class="calendar_prompt">' + prompt + '</div>' : '') + (closeAtTop && !this._inline ? controls : '');

			//navigation and month/year
			html += '<div class="calendar_header"><table class="calendar_links" cellspacing="0" cellpadding="0"><tr>'
			//prev month
			html += (this._canAdjustMonth(-1) ? '<td class="calendar_prev"><a id="prev" class="calendar_prev" href="#" ' +
				'onclick="popUpCal._adjustDate(' + this._id + ', -1, \'M\');">' + this._get('prevText') + '</a></td>' :
				(hideIfNoPrevNext ? '' : '<td class="calendar_prev"><label class="calendar_prev">' + this._get('prevText') + '</label></td>')) + '<td>';

			// month selection
			var monthNames = this._get('monthNames');
			if (!this._get('changeMonth')) {
				html += monthNames[this._selectedMonth] + '&nbsp;';
			}
			else {
				var inMinYear = (minDate && minDate.getFullYear() == this._selectedYear);
				var inMaxYear = (maxDate && maxDate.getFullYear() == this._selectedYear);
				html += '<select id="month' + this._id + '" class="calendar_newMonth" ' +
					'onchange="popUpCal._selectMonthYear(' + this._id + ', this, \'M\');" ' +
					'onclick="popUpCal._clickMonthYear(' + this._id + ');">';
				for (var month = 0; month < 12; month++) {
					if ((!inMinYear || month >= minDate.getMonth()) &&
							(!inMaxYear || month <= maxDate.getMonth())) {
						html += '<option value="' + month + '"' +
							(month == this._selectedMonth ? ' selected="selected"' : '') +
							'>' + monthNames[month] + '</option>';
					}
				}
				html += '</select>&nbsp;';
			}
			// year selection
			if (!this._get('changeYear')) {
				html += this._selectedYear;
			}
			else {
				// determine range of years to display
				var years = this._get('yearRange').split(':');
				var year = 0;
				var endYear = 0;
				if (years.length != 2) {
					year = this._selectedYear - 10;
					endYear = this._selectedYear + 10;
				}
				else if (years[0].charAt(0) == '+' || years[0].charAt(0) == '-') {
					year = this._selectedYear + parseInt(years[0], 10);
					endYear = this._selectedYear + parseInt(years[1], 10);
				}
				else {
					year = parseInt(years[0], 10);
					endYear = parseInt(years[1], 10);
				}
				year = (minDate ? Math.max(year, minDate.getFullYear()) : year);
				endYear = (maxDate ? Math.min(endYear, maxDate.getFullYear()) : endYear);
				html += '<select id="year' + this._id + '" class="calendar_newYear" onchange="popUpCal._selectMonthYear(' +
					this._id + ', this, \'Y\');" ' + 'onclick="popUpCal._clickMonthYear(' +
					this._id + ');">';
				for (; year <= endYear; year++) {
					html += '<option value="' + year + '"' +
						(year == this._selectedYear ? ' selected="selected"' : '') +
						'>' + year + '</option>';
				}
				html += '</select>';
			}

			//next month
			html += '</td>' + (this._canAdjustMonth(+1) ? '<td class="calendar_next"><a id="next" class="calendar_next" href="#" ' +
				'onclick="popUpCal._adjustDate(' + this._id + ', +1, \'M\');">' + this._get('nextText') + '</a></td>' :
				(hideIfNoPrevNext ? '' : '<td align="right"><label class="calendar_next">' + this._get('nextText') + '</label></td>'))


			html += '</tr></table></div><table class="calendar" cellpadding="0" cellspacing="0"><thead>' +
				'<tr class="calendar_titleRow">';
			var firstDay = this._get('firstDay');
			var changeFirstDay = this._get('changeFirstDay');
			var dayNames = this._get('dayNames');
			for (var dow = 0; dow < 7; dow++) { // days of the week
				html += '<td>' + (!changeFirstDay ? '' : '<a onclick="popUpCal._changeFirstDay(' +
					this._id + ', this);">') + dayNames[(dow + firstDay) % 7] +
					(changeFirstDay ? '</a>' : '') + '</td>';
			}
			html += '</tr></thead><tbody>';
			var daysInMonth = this._getDaysInMonth(this._selectedYear, this._selectedMonth);
			this._selectedDay = Math.min(this._selectedDay, daysInMonth);
			var leadDays = (this._getFirstDayOfMonth(this._selectedYear, this._selectedMonth) - firstDay + 7) % 7;
			var currentDate = new Date(this._currentYear, this._currentMonth, this._currentDay);
			var selectedDate = new Date(this._selectedYear, this._selectedMonth, this._selectedDay);
			var printDate = new Date(this._selectedYear, this._selectedMonth, 1 - leadDays);
			var numRows = Math.ceil((leadDays + daysInMonth) / 7); // calculate the number of rows to generate
			var customDate = this._get('customDate');
			var showOtherMonths = this._get('showOtherMonths');
			currentDate = selectedDate;
			for (var row = 0; row < numRows; row++) { // create calendar rows
				html += '<tr class="calendar_daysRow">';
				for (var dow = 0; dow < 7; dow++) { // create calendar days
					var customSettings = (customDate ? customDate(printDate) : [true, '']);
					var otherMonth = (printDate.getMonth() != this._selectedMonth);
					var unselectable = otherMonth || !customSettings[0] ||
						(minDate && printDate < minDate) || (maxDate && printDate > maxDate);
					html += '<td class="calendar_daysCell' +
						((dow + firstDay + 6) % 7 >= 5 ? ' calendar_weekEndCell' : '') + // highlight weekends
						(otherMonth ? ' calendar_otherMonth' : '') + // highlight days from other months
						(unselectable ? ' calendar_unselectable' : '') +  // highlight unselectable days
						(!otherMonth || showOtherMonths ? ' ' + customSettings[1] : '') + // highlight custom dates
						(printDate.getTime() == currentDate.getTime() ? ' calendar_currentDay' : // highlight current day
						(printDate.getTime() == today.getTime() ? ' calendar_today' : (popUpCal.isBankHoliday(printDate) ? (otherMonth ? '' : ' calendar_bankHoliday') : ''))) + '"' + // highlight today (if different)
						(unselectable ? '' : ' onmouseover="$(this).addClass(\'calendar_daysCellOver\');"' +
						' onmouseout="$(this).removeClass(\'calendar_daysCellOver\');"' +
						' onclick="popUpCal._selectDay(' + this._id + ', this);"') + '>' + // actions

						(otherMonth ? (showOtherMonths ? printDate.getDate() : '&nbsp;') : // display for other months
						(unselectable ? printDate.getDate() : '<a>' + printDate.getDate() + '</a>')) + '</td>'; // display for this month
					printDate.setDate(printDate.getDate() + 1);

				}
				html += '</tr>';
			}
			html += '</tbody></table>' + timePickerHtml + '' + (!closeAtTop && !this._inline ? controls : '') +
				'<div style="clear: both;"></div>' + (!$.browser.msie ? '' :
				'<!--[if lte IE 6.5]><iframe src="javascript:false;" class="' + (this._get('timePicker') ? 'calendar_cover_datetime' : 'calendar_cover') + '"></iframe><![endif]-->');

		} else {
			controls = '<div class="calendar_control"><table class="calendar_control" cellspacing="0" cellpadding="0" width="100%"><tr>' +
				'<td><a class="calendar_clear" onclick="popUpCal._clearDate(' + this._id + ');">' +
				this._get('clearText') + '</a></td>' +
				'<td align="right"><a class="calendar_close" onclick="popUpCal.hideCalendar(' + this._id + ');">' +
				this._get('closeText') + '</a></td></tr></table></div>';

			html = controls;
			html += '<div>' + timePickerHtml + '</div>' +
			'<div style="clear: both;"></div>' + (!$.browser.msie ? '' :
			'<!--[if lte IE 6.5]><iframe src="javascript:false;" class="calendar_cover_time"></iframe><![endif]-->');
		}

		return html;
	},

	/* Adjust one of the date sub-fields. */
	_adjustDate: function(offset, period) {
		var date = new Date(this._selectedYear + (period == 'Y' ? offset : 0),
			this._selectedMonth + (period == 'M' ? offset : 0),
			this._selectedDay + (period == 'D' ? offset : 0));
		// ensure it is within the bounds set
		var minDate = this._get('minDate');
		var maxDate = this._get('maxDate');
		date = (minDate && date < minDate ? minDate : date);
		date = (maxDate && date > maxDate ? maxDate : date);

		this._selectedDay = date.getDate();
		this._selectedMonth = date.getMonth();
		this._selectedYear = date.getFullYear();
	},

	/* Find the number of days in a given month. */
	_getDaysInMonth: function(year, month) {
		return 32 - new Date(year, month, 32).getDate();
	},

	/* Find the day of the week of the first of a month. */
	_getFirstDayOfMonth: function(year, month) {
		return new Date(year, month, 1).getDay();
	},

	/* Determines if we should allow a "next/prev" month display change. */
	_canAdjustMonth: function(offset) {
		var date = new Date(this._selectedYear, this._selectedMonth + offset, 1);
		if (offset < 0) {
			date.setDate(this._getDaysInMonth(date.getFullYear(), date.getMonth()));
		}
		return this._isInRange(date);
	},

	/* Is the given date in the accepted range? */
	_isInRange: function(date) {
		var minDate = this._get('minDate');
		var maxDate = this._get('maxDate');
		return ((!minDate || date >= minDate) && (!maxDate || date <= maxDate));
	},

	/* Format the given date for display. */
	_formatDate: function(day, month, year) {
		month; // adjust javascript month
		var dateString = '';
		var dateFormat = this._get('dateFormat');
		for (var i = 0; i < 3; i++) {
			dateString += dateFormat.charAt(3) +
				(dateFormat.charAt(i) == 'D' ? (day < 10 ? '0' : '') + day :
				(dateFormat.charAt(i) == 'M' ?  arrMonthNames[month] :
				(dateFormat.charAt(i) == 'Y' ? year : '?')));
		}
		return dateString.substring(dateFormat.charAt(3) ? 1 : 0);
	}
});

/* Attach the calendar to a jQuery selection.
   @param  settings  object - the new settings to use for this calendar instance (anonymous)
   @return jQuery object - for chaining further calls */
$.fn.calendar = function(settings) {
	return this.each(function() {
		// check for settings on the control itself - in namespace 'cal:'
		var inlineSettings = null;
		for (attrName in popUpCal._defaults) {
			var attrValue = this.getAttribute('cal:' + attrName);
			if (attrValue) {
				inlineSettings = inlineSettings || {};
				try {
					inlineSettings[attrName] = eval(attrValue);
				}
				catch (err) {
					inlineSettings[attrName] = attrValue;
				}
			}
		}
		var nodeName = this.nodeName.toLowerCase();
		if (nodeName == 'input') {
			var instSettings = (inlineSettings ? $.extend($.extend({}, settings || {}),
				inlineSettings || {}) : settings); // clone and customise
			var inst = (inst && !inlineSettings ? inst :
				new PopUpCalInstance(instSettings, false));
			popUpCal._connectCalendar(this, inst);
		}
		else if (nodeName == 'div' || nodeName == 'span') {
			var instSettings = $.extend($.extend({}, settings || {}),
				inlineSettings || {}); // clone and customise
			var inst = new PopUpCalInstance(instSettings, true);
			popUpCal._inlineCalendar(this, inst);
		}
	});
};

/* Initialise the calendar. */
$(document).ready(function() {
	popUpCal = new PopUpCal(); // singleton instance
	//Allow change month with mouse wheel
	popUpCal._calendarDiv.mousewheel(function(event, delta) {
		if (popUpCal._popUpShowing) {
			var inst = popUpCal._curInst;
			if (delta > 0)
				popUpCal._adjustDate(inst, (delta < 0 ? 1 : -1), 'M');
			else if (delta < 0)
				popUpCal._adjustDate(inst, (delta < 0 ? 1 : -1), 'M');

			event.stopPropagation();
			event.preventDefault();
		}
	});
});

var hourOffset = 0;

function setTime(hour, minute) {
	//Pad
	minute = (minute==0)? '00':minute.toString();
	hour = parseInt(hour+hourOffset);
	hour = (hour<10)? '0' + hour:hour.toString();
	document.getElementById('time').value = hour + ':' + minute;
}

function moveHours(moveHours, hourStart, hourEnd) {

	if ((hourStart + hourOffset + moveHours) >= 0 && (hourEnd + hourOffset + moveHours) < 24) {
		hourOffset += moveHours;
		currentHour = hourStart + hourOffset;
		hourMarkers = hourEnd - hourStart;
		//change hour display
		for (var i = 0; i <= hourMarkers; i++) {
			document.getElementById('hour' + (hourStart + i)).innerHTML = currentHour;
			currentHour++;
		}
	}
}

function monthToNumber(sMM)
{
  switch(sMM.toUpperCase())
  {
    case 'JAN':
      sMM = '01';
      break;
    case 'FEB':
      sMM = '02';
      break;
    case 'MAR':
      sMM = '03';
      break;
    case 'APR':
      sMM = '04';
      break;
    case 'MAY':
      sMM = '05';
      break;
    case 'JUN':
      sMM = '06';
      break;
    case 'JUL':
      sMM = '07';
      break;
    case 'AUG':
      sMM = '08';
      break;
    case 'SEP':
      sMM = '09';
      break;
    case 'OCT':
      sMM = '10';
      break;
    case 'NOV':
      sMM = '11';
      break;
    case 'DEC':
      sMM = '12';
      break;
  }
  return sMM;
}

function getTodaysDate(controlName, withTime){

	today = new Date();
	todayDay = today.getDate();
	todayMon = today.getMonth();
	todayYear = today.getYear();
	todayHour = today.getHours();
	todayMinute = today.getMinutes();
	if (todayYear < 2000)
		todayYear += 1900;

	if (todayMon == 0) { todayMonth = "Jan"; }
	else if (todayMon == 1) { todayMonth = "Feb"; }
	else if (todayMon == 2) { todayMonth = "Mar"; }
	else if (todayMon == 3) { todayMonth = "Apr"; }
	else if (todayMon == 4) { todayMonth = "May"; }
	else if (todayMon == 5) { todayMonth = "Jun"; }
	else if (todayMon == 6) { todayMonth = "Jul"; }
	else if (todayMon == 7) { todayMonth = "Aug"; }
	else if (todayMon == 8) { todayMonth = "Sep"; }
	else if (todayMon == 9) { todayMonth = "Oct"; }
	else if (todayMon == 10) { todayMonth = "Nov"; }
	else if (todayMon == 11) { todayMonth = "Dec"; }
	else { todayMonth = todayMon; }

	if(todayDay < 10) {
		todayDay = "0" + todayDay;
	}

	if(todayHour < 10) {
		todayHour = "0" + todayHour;
	}

	if(todayMinute < 10) {
		todayMinute = "0" + todayMinute;
	}

	var field = document.getElementById(controlName);
	dateString = todayDay + "-" + todayMonth + "-" + todayYear;
	if(withTime) {
		dateString += " " + todayHour + ":" + todayMinute;
	}
	field.value = dateString;
	try {
		afterValidateDate(field);
	}
	catch(e) {
	}
}

function checkDateTimeFormat(field, isDate, isTime) {
	var testDate = new Date();
	if (isDate && !isTime) {
		//Format dd-mmm-yyyy\n(e.g. 05-Jan-2008)
		if (testDateTime.length == 8) {
			//quick format, convert to full
			if (quickDate.test(field.value)) {
				//Check if date exists
				testDate.setFullYear(field.value.substring(4), field.value.substring(2,4) - 1, field.value.substring(0,2));
				if (parseInt(field.value.substring(0,2)) == testDate.getDate()) {
					//Convert to correct format
					field.value = field.value.substring(0,2) + '-' + arrMonthNames[field.value.substring(2,4)-1] + '-' + field.value.substring(4);
					return true;
				}
			}
		} else {
			if (dateRegExp.test(field.value)) {
				//Check if date exists
				testDate.setFullYear(field.value.substring(7,11), monthToNumber(field.value.substring(3,6)) - 1, field.value.substring(0,2));
				if (parseInt(field.value.substring(0,2),10) == testDate.getDate()) {
					return true;
				}
			}
		}
	} else if (isDate && isTime) {
		//Format dd-mmm-yyyy hh:mm\n(e.g. 05-Jan-2008 12:30)
		if (testDateTime.length == 12) {
			//quick format ddmmyyyymmhh, convert to full
			if (quickDateTimeCondensed.test(field.value)) {
				testDate.setFullYear(field.value.substring(4,8), monthToNumber(field.value.substring(2,4)) - 1, field.value.substring(0,2));
				if (parseInt(field.value.substring(0,2),10) == testDate.getDate()) {
					//Convert to correct format
					field.value = field.value.substring(0,2) + '-' + arrMonthNames[field.value.substring(2,4)-1] + '-' + field.value.substring(4,8) + ' ' + field.value.substring(8,10) + ':' + field.value.substring(10,12);
					return true;
				}
			}
		}
		if (testDateTime.length == 14) {
			//quick format ddmmyyyy mm:hh, convert to full
			if (quickDateTime.test(field.value)) {
				testDate.setFullYear(field.value.substring(4,8), monthToNumber(field.value.substring(2,4)) - 1, field.value.substring(0,2));
				if (parseInt(field.value.substring(0,2),10) == testDate.getDate()) {
					//Convert to correct format
					field.value = field.value.substring(0,2) + '-' + arrMonthNames[field.value.substring(2,4)-1] + '-' + field.value.substring(4,8) + field.value.substring(8);
					return true;
				}
			}
		}
		if (dateTimeRegExp.test(field.value)) {
			testDate.setFullYear(field.value.substring(7,11), monthToNumber(field.value.substring(3,6)) - 1, field.value.substring(0,2));
			if (parseInt(field.value.substring(0,2),10) == testDate.getDate()) {
				return true;
			} else {
				return false;
			}
		}
	} else if (isTime) {
		return timeRegExp.test(field.value);
	}
	return false
}

function validateDateTime(field, date, time) {
	testDateTime = rtrim(field.value);

	var returnValue = false;
	var correctFormat = '';
	var day = '';
	var month = '';
	var year = '';

	//if field is empty do nothing...
	if(testDateTime == "") {
		returnValue = true;
	} else {
		if (date && !time) {
			correctFormat = "dd-mmm-yyyy\n(e.g. 05-Jan-2008)";
			returnValue = checkDateTimeFormat(field, true, false);
		} else if (date && time) {
			correctFormat = "dd-mmm-yyyy hh:mm\n(e.g. 05-Jan-2008 12:30)";
			returnValue = checkDateTimeFormat(field, true, true);
		} else if (!date && time) {
			correctFormat = "hh:mm\n(e.g. 12:30)";
			returnValue = checkDateTimeFormat(field, false, true);
		}

		if (!returnValue) {
			field.value = '';
			alert('Date/Time should be in format ' + correctFormat);
			setTimeout("document.getElementById('" + field.id + "').focus()", 100);
		}
	}

	//call to custom post-processing function in opener window
	if(returnValue == true) {
		try {
			afterValidateDate(field);
		}
		catch(e) {
			//do nothing with exception
		}
	}
	return returnValue;
}

function validateMonth(month) {
	//Returns formated month (e.g. "Jan") or blank string if not a month
	var formattedMonth = '';

	if (monthNumberRegExp.test(month)) {
		formattedMonth = arrMonthNames[month];
	} else if (monthNameRegExp.test(month)) {
		for (var i = 0; i < 12; i++) {
			if (month.toUpperCase() == arrMonthNames[i].toUpperCase()) {
				formattedMonth = arrMonthNames[month];
			}
		}
	}
	return formattedMonth;
}

function timeTip(hour, minute) {
	//Pad
	minute = (minute==0)? '00':minute.toString();
	hour = parseInt(hour+hourOffset);
	hour = (hour<10)? '0' + hour:hour.toString();
	document.getElementById('hoverTime').innerHTML = hour + ':' + minute;
	return false
}

function hideTime() {
	document.getElementById('hoverTime').innerHTML = '';
}

function inInputArray(inputId) {
	//Checked whether input id has already been used
	//To allow duplicate calendar butons to be hidden
	for (var i = 0; i < arrInputNames.length; i++) {
		if (inputId == arrInputNames[i]) {
			return true;
		}
	}
	return false;
}
function rtrim(s)
{
	var r = s.length -1;
	while(r > 0 && s.substr(r,1) == ' ')
	{
		r-=1;
	}
	return s.substring(0, r+1);
}

var Position = (function() {
	// Resolve a string identifier to an object
	// ========================================
	function resolveObject(s) {
		if (document.getElementById && document.getElementById(s)!=null) {
			return document.getElementById(s);
		}
		else if (document.all && document.all[s]!=null) {
			return document.all[s];
		}
		else if (document.anchors && document.anchors.length && document.anchors.length>0 && document.anchors[0].x) {
			for (var i=0; i<document.anchors.length; i++) {
				if (document.anchors[i].name==s) {
					return document.anchors[i]
				}
			}
		}
	}

	var pos = {};
	pos.$VERSION = 1.0;

	// Set the position of an object
	// =============================
	pos.set = function(o,left,top) {
		if (typeof(o)=="string") {
			o = resolveObject(o);
		}
		if (o==null || !o.style) {
			return false;
		}

		// If the second parameter is an object, it is assumed to be the result of getPosition()
		if (typeof(left)=="object") {
			var pos = left;
			left = pos.left;
			top = pos.top;
		}

		o.style.left = left + "px";
		o.style.top = top + "px";
		return true;
  	};

	// Retrieve the position and size of an object
	// ===========================================
	pos.get = function(o) {
		var fixBrowserQuirks = true;
		// If a string is passed in instead of an object ref, resolve it
		if (typeof(o)=="string") {
			o = resolveObject(o);
		}

		if (o==null) {
			return null;
		}

		var left = 0;
		var top = 0;
		var width = 0;
		var height = 0;
		var parentNode = null;
		var offsetParent = null;


		offsetParent = o.offsetParent;
		var originalObject = o;
		var el = o; // "el" will be nodes as we walk up, "o" will be saved for offsetParent references
		while (el.parentNode!=null) {
			el = el.parentNode;
			if (el.offsetParent==null) {
			}
			else {
				var considerScroll = true;
				/*
				In Opera, if parentNode of the first object is scrollable, then offsetLeft/offsetTop already
				take its scroll position into account. If elements further up the chain are scrollable, their
				scroll offsets still need to be added in. And for some reason, TR nodes have a scrolltop value
				which must be ignored.
				*/
				if (fixBrowserQuirks && window.opera) {
					if (el==originalObject.parentNode || el.nodeName=="TR") {
						considerScroll = false;
					}
				}
				if (considerScroll) {
					if (el.scrollTop && el.scrollTop>0) {
						top -= el.scrollTop;
					}
					if (el.scrollLeft && el.scrollLeft>0) {
						left -= el.scrollLeft;
					}
				}
			}
			// If this node is also the offsetParent, add on the offsets and reset to the new offsetParent
			if (el == offsetParent) {
				left += o.offsetLeft;
				if (el.clientLeft && el.nodeName!="TABLE") {
					left += el.clientLeft;
				}
				top += o.offsetTop;
				if (el.clientTop && el.nodeName!="TABLE") {
					top += el.clientTop;
				}
				o = el;
				if (o.offsetParent==null) {
					if (o.offsetLeft) {
						left += o.offsetLeft;
					}
					if (o.offsetTop) {
						top += o.offsetTop;
					}
				}
				offsetParent = o.offsetParent;
			}
    	}

		if (originalObject.offsetWidth) {
			width = originalObject.offsetWidth;
		}
		if (originalObject.offsetHeight) {
			height = originalObject.offsetHeight;
		}

		return {'left':left, 'top':top, 'width':width, 'height':height };
	};

	// Retrieve the position of an object's center point
	// =================================================
	pos.getCenter = function(o) {
		var c = this.get(o);
		if (c==null) { return null; }
			c.left = c.left + (c.width/2);
			c.top = c.top + (c.height/2);
			return c;
		};

		return pos;
	})();





/* Copyright (c) 2006 Brandon Aaron (brandon.aaron@gmail.com || http://brandonaaron.net)
 * Dual licensed under the MIT (http://www.opensource.org/licenses/mit-license.php)
 * and GPL (http://www.opensource.org/licenses/gpl-license.php) licenses.
 * Thanks to: http://adomas.org/javascript-mouse-wheel/ for some pointers.
 * Thanks to: Mathias Bank(http://www.mathias-bank.de) for a scope bug fix.
 *
 * $LastChangedDate: 2007-12-20 09:02:08 -0600 (Thu, 20 Dec 2007) $
 * $Rev: 4265 $
 *
 * Version: 3.0
 *
 * Requires: $ 1.2.2+
 */

(function($) {

$.event.special.mousewheel = {
	setup: function() {
		var handler = $.event.special.mousewheel.handler;

		// Fix pageX, pageY, clientX and clientY for mozilla
		if ( $.browser.mozilla )
			$(this).bind('mousemove.mousewheel', function(event) {
				$.data(this, 'mwcursorposdata', {
					pageX: event.pageX,
					pageY: event.pageY,
					clientX: event.clientX,
					clientY: event.clientY
				});
			});

		if ( this.addEventListener )
			this.addEventListener( ($.browser.mozilla ? 'DOMMouseScroll' : 'mousewheel'), handler, false);
		else
			this.onmousewheel = handler;
	},

	teardown: function() {
		var handler = $.event.special.mousewheel.handler;

		$(this).unbind('mousemove.mousewheel');

		if ( this.removeEventListener )
			this.removeEventListener( ($.browser.mozilla ? 'DOMMouseScroll' : 'mousewheel'), handler, false);
		else
			this.onmousewheel = function(){};

		$.removeData(this, 'mwcursorposdata');
	},

	handler: function(event) {
		var args = Array.prototype.slice.call( arguments, 1 );

		event = $.event.fix(event || window.event);
		// Get correct pageX, pageY, clientX and clientY for mozilla
		$.extend( event, $.data(this, 'mwcursorposdata') || {} );
		var delta = 0, returnValue = true;

		if ( event.wheelDelta ) delta = event.wheelDelta/120;
		if ( event.detail     ) delta = -event.detail/3;
		if ( $.browser.opera  ) delta = -event.wheelDelta;

		event.data  = event.data || {};
		event.type  = "mousewheel";

		// Add delta to the front of the arguments
		args.unshift(delta);
		// Add event to the front of the arguments
		args.unshift(event);

		return $.event.handle.apply(this, args);
	}
};

$.fn.extend({
	mousewheel: function(fn) {
		return fn ? this.bind("mousewheel", fn) : this.trigger("mousewheel");
	},

	unmousewheel: function(fn) {
		return this.unbind("mousewheel", fn);
	}
});

})(jQuery);