
/*
Linked Select boxes.

The contents of one select box depends on what is selected in another.

first arg: url for the json call
second arg: jQuery selector string. Should find select box. This is where the retrieved elements will be placed.
third arg: optional params:
	firstOption - ?
	loadingText - text displayed in the destination while data is loaded
	noResultsText - text displayed in the destination if no data is returned
	dependents - jQuery selector string. Identifies select boxes that depend on this one. Their initial state will be capture when this is initialized and will be restored when this select boxs onchange event
	queryParams - a callback that returns parameters to pass to the json query, or a map of those params
*/
(function($){

   $.fn.linkedSelect = function(url,destination,params) {

      var params = $.extend({
         firstOption : '-- Please Select',
         loadingText : 'Loading...',
         noResultsText : 'No data found',
         dependents : null,
         queryParams : null // can either be a map of params, or a callback that returns a map of params
      },params);


      var $dest = $(destination);
			if (params.dependents != null){
				$(params.dependents).each(function(){
					$(this).data('linkedSelect-initialContents',$(this).html());
				});
			}

      return this.each(function(){
         $(this).bind('change', function() {
            var $$ = $(this);

						if (params.dependents != null) {
							$(params.dependents).attr('disabled','disabled').each(function(){
								$(this).html($(this).data("linkedSelect-initialContents"));
							});
            }

            $dest.find('option:first').remove();
            $dest.attr('disabled','false')
                 .append('<option value="">' +params.loadingText+ '</option>')
                 .ajaxStart(function(){
                    $$.show();
            });

            var queryParams = {};
            if (params.queryParams != null && $.isFunction(params.queryParams)) {
            	queryParams = params.queryParams();
            }
            if (params.queryParams != null && !$.isFunction(params.queryParams)) {
            	queryParams = params.queryParams;
            }

            $.getJSON(url,queryParams, function(j){
	        		var options = '';
	  					for(p in j.data) {
	  						options += '<option value="' + p + '">' + j.data[p] + '</option>';
	  					}
	  					if (options.length > 0) {
	          		$dest.removeAttr('disabled').html(options);
	          	}
	            else {
	            	$dest.html('<option>' + params.noResultsText + '</option>')
	            }
            }); // end getJSON
         });  // end change
      }); // end return each
   };  // end function

})(jQuery);