/*
	Changes the style for the current row to highlight
*/
function rowHighlight(row) {
    row.style.background = "#CCCCCC";
    row.style.cursor = "pointer";
}

/*
	Reverts the style for the current to the default
*/
function rowLowlight(row) {
    row.style.background = "#FFFFFF";
    row.style.cursor = "pointer";
}

/*
	Returns true if current page has previous page to go back to 
	-- eg on history.go(-1) or history.back()
*/
function hasBackPage () {	
	/* changed test to work with iframe instead of popup
	  the rationale is that if the parent URL is the same as the referrer URL,
	  the iframe has only just been opened, and doesn't have it's own history	 
	  can't use history.length, as it always seem to give the history of the main window	 
	 */
	
	return document.referrer != parent.document.URL;
}

/**
 * Just takes the value supplied in controlValue and assigns it to the element in the window that 
 * opened the popup that has the name supplied in controlName. 
 */
function updateControl(controlName, controlValue, destinationWindow) {

	//controlName = formatString(controlName);
    if (controlValue == "null") {
        controlValue = "";
    }
    try {
        var x = destinationWindow.document.getElementById(controlName);
        x.value = controlValue;
    }
    catch (e) {
		//alert(controlName + ":" + e);
    }
}
/**
 * This method receives a compound string of fieldname-fieldvalue pairs delimited by appropriate tags.
 * It parses the string and isolates individual fieldNames and fieldValues, and uses the updateControl 
 * method with each name-value pair to set the appropriate form elements in the form that opened the popup. 
 */
function assignStrings(inString, destinationWindow) {
    var nameEnd = "</fieldName>";
    var valueEnd = "</fieldValue>";
    var currentName = "";
    var currentValue = "";
    var nameTagLength = 12;
    var valueTagLength = 13;
    var nameTagIndex = -1;
    var valueTagIndex = -1;
    var lookupListCustomMapping = destinationWindow.lookupListCustomMapping;

    while (inString.indexOf(valueEnd) != -1) {
		// find the next positions of the name and value delimiters
        nameTagIndex = inString.indexOf(nameEnd);
        valueTagIndex = inString.indexOf(valueEnd);
		
		// isolate the next fieldName - it goes from the start of the string to the start of the
		// nameEnd tag
        currentName = inString.substring(0, nameTagIndex);
        if(lookupListCustomMapping) {
	        for(i=0; i < lookupListCustomMapping.length; i++) {
	        	if(lookupListCustomMapping[i][0] == currentName) {
	        		currentName = lookupListCustomMapping[i][1];
	        		break;
	        	}
	        }
        }
		
		// isolate the next fieldValue - goes from the end of the nameEnd tag to the start of the
		// valueEnd tag
        currentValue = inString.substring(nameTagIndex + nameTagLength, valueTagIndex);
        updateControl(currentName, currentValue, destinationWindow);

		// excise the substrings that have been processed
        inString = inString.substring(valueTagIndex + valueTagLength);
    }
}

/*
	This function should be called when a user selects a row in the lookup list.
	It fetches the data from the selected element and passes it back to the opener window
*/
function processSelection(rowId) {
    var elementData = document.getElementById("elementData" + rowId).value;
    var returnObject = new Object();
    returnObject.elementData = elementData;
	  
	// switched from window.opener to window.parent, as we're now using an iframe instead of a popup
	assignStrings(returnObject.elementData, window.parent);
	
	self.parent.tb_remove();
	
	// attempt to call additional processing function in opener window
	try {
		self.parent.lookupListPostProcessing();
	}
	catch(e) {
		//do nothing if function not found/fails
	}	
}


function clearFilterText() {
	document.getElementById("filterText").value = '';
	filterList();
}

function closeTb(caller) {
	self.parent.tb_remove();
}

var rows = [];

function initFilterList() {
	var tbody = document.getElementById("lookupListTBody");

	for( var i = 0; i < tbody.rows.length; i++ ) {
		var row = tbody.rows[i];
		var col = row.getElementsByTagName("td")[0];		
		rows.push({ row:row, col:col, style:row.style, visible:true });
	}
	setTimeout(function(){document.getElementById("filterText").focus();},100);
	//to prevent firefox and safari from showing unnecessary scroll bars
	$("html").css("overflow","hidden");
}

function filterList(filterText) {
	//var rows = [];
	var quickLink = false;

	if (filterText) {
		document.getElementById("filterText").value = '';
		quickLink = true;
	} else {
		filterText = document.getElementById("filterText").value;
	}
	filterText = filterText.toLowerCase();
	
	for(var i=0; i<rows.length; i++) {			
		var row = rows[i];
		if(row == null) alert(i);
		var rowText = row.col.innerHTML.toLowerCase();
		if((!quickLink && rowText.indexOf(filterText) != -1) || (quickLink && rowText.indexOf(filterText) == 0)) {
			if(!row.visible) {
				row.visible = true;
				row.style.display = "";
			}
		}
		else {
			if(row.visible) {
				row.visible = false;
				row.style.display = "none";
			}
		}
	}
}

function showAll() {
	for(var i=0; i<rows.length; i++) {
		rows[i].visible = true;
		rows[i].style.display = "";
	}
}