// Boolean value to show the action being executed, see the lookupPerson() method.
var isLookingUpPerson = false;

/**
 * Called in the edit_reservation.jsp code when the user clicks on the microscope or entry text
 * field to lookup and select a user. This method sets the boolean isLookingUpPerson to show that
 * this action is taking place. The boolean value us read in the generic lookupListPostProcessing()
 * so that the default team is only looked up when this action is being executed.
 */
function lookupPerson() {
	isLookingUpPerson = true;
	openLookupList('lookup_person.do?recordType=person&bypassForm=true',
			'personId=reservation.reserverId,personName=reservation.reserverName');
}

/**
 * Generic method called from within the lookupListPopup.js files processSelection() method that is
 * triggered by a click event within a thickbox window list of options.
 */
function lookupListPostProcessing() {
	if (isLookingUpPerson) {
		isLookingUpPerson = false;
		updateDefaultTeam('reservation.reserverId');
	}
}

/**
 * Performs an ajax lookup on the selected person (held within the reserverElementId element) to
 * find their default team from within the database. The results are inserted into the team text
 * entry field and the team id is entered into the hidden field of the form.
 *
 * @param reserverElementId - the id of the element holding the person id making the reservation.
 */
function updateDefaultTeam(reserverElementId) {
	var reserverId = document.getElementById(reserverElementId).value;
	$.ajax({
		type: "POST",
		url: "reserver_team.do",
		data:{
			reserverId: reserverId
		},
		cache: false,
		success: function (data) {
			try {
				var teamId = "";
				var teamName = "";
				var hasTeam = data.getElementsByTagName("hasTeam")[0].firstChild.nodeValue;
				if (hasTeam == "true") {
					teamId = data.getElementsByTagName("teamId")[0].firstChild.nodeValue;
					teamName = data.getElementsByTagName("teamNumber")[0].firstChild.nodeValue
							+ " - " +
							   data.getElementsByTagName("teamName")[0].firstChild.nodeValue;
				}
				document.getElementById('reservation.teamId').value = teamId;
				document.getElementById('reservation.teamName').value = teamName;
			} catch(e) {
				defaultTeamSettingError();
			}
		},
		error: function (XMLHttpRequest, textStatus, errorThrown) {
			defaultTeamSettingError();
		}
	});
}

/**
 * Method called within ajax sucess and error callback methods. Called from the success method if
 * passing the resulting XML data fails or setting the element attributes fails for some reason.
 * Called from the error callback if an internal error ocurrs.
 */
function defaultTeamSettingError() {
	alert('Error: setting the default team has failed, this should ' +
		  'not stop you from working, please select your team manually ' +
		  'and continue your submission');
}

/**
 * Clears the reservation purpose field and hidden id form element. Called when the category is changed.
 */
function clearReservationPurpose() {
	document.getElementById('reservation.purposeId').value = "";
	document.getElementById('reservation.purposeName').value = "";
}