CREATE OR REPLACE VIEW REP_PHENOTYPE_COHORTS
(ID, COHORT_NAME, REASON, CREATED_DATE, COLONY_PREFIX,
 COLONY_NAME, TOTAL_MICE, LIVE_MICE, DEAD_MICE, PIPELINE,
 PIPELINE_DICT_ID)
AS
select
  c.id,
  c.cohort_name,
  c.reason,
  c.created_date,
  l.colony_prefix,
  l.colony_name,
  l.total_mice,
  l.live_mice,
  l.dead_mice,
  p.name pipeline,
  c.pipeline_dict_id
from
  mts_cohort c,
  (select
    i.colony_prefix,
    i.colony_name,
    l.cohort_id,
    count(m.id) total_mice,
    count(decode(m.death_date,null,1,null)) live_mice,
    count(decode(m.death_date,null,null,1)) dead_mice
   from
    mts_colony_info i,
    mts_mouse m,
    mts_cohort_mouse l
   where
     m.id = l.mouse_id and
     i.id = m.colony_info_id
   group by
     i.colony_prefix,
     i.colony_name,
     l.cohort_id
  ) l,
  mts_cohort_pipeline_dict p
where
  c.id = l.cohort_id(+)
  and c.pipeline_dict_id = p.id(+) and
  c.cohort_type_id = 1
order by c.created_date desc;

alter table app_custom_query_column add (actual_query_column varchar2(30), list_query varchar2(512), is_display_column number(1), is_filter_column number(1));

CREATE OR REPLACE VIEW APP_CUSTOM_QUERY_COL_PREF_VW
(ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
 DATATYPE_FORMAT, DATATYPE_FORMAT_2, IS_DISPLAY_COLUMN, IS_FILTER_COLUMN, LIST_QUERY, ACTUAL_QUERY_COLUMN, ORDER_BY, PERSON_ID)
AS
select
  c.id,
  c.custom_query_id,
  c.column_name,
  c.column_title,
  c.datatype,
  c.datatype_format,
  c.datatype_format_2,
  c.is_display_column,
  c.is_filter_column,
  c.list_query,
  c.actual_query_column,
  p.order_by,
  p.person_id
from
  app_custom_query_person_pref p,
  app_custom_query_column c
where
  c.id = p.query_column_id
union
select
  c.id,
  c.custom_query_id,
  c.column_name,
  c.column_title,
  c.datatype,
  c.datatype_format,
  c.datatype_format_2,
  c.is_display_column,
  c.is_filter_column,
  c.list_query,
  c.actual_query_column,
  c.order_by,
  p.person_id
from
  per_person p,
  app_custom_query_column c
where
  not exists (select null from app_custom_query_person_pref x, app_custom_query_column y where x.person_id = p.person_id and x.query_column_id = y.id and y.custom_query_id = c.custom_query_id);

