create or replace view mts_cage_procedure_list_vw
(last_date, procedure_dict_id, procedure, cage_id, pil_number)
as
select
   max(p.start_date) last_date,
   p.procedure_dict_id,
   d.name procedure,
   c.id cage_id,
   l.pil_number
from
  mts_mouse_procedure p,
  mts_mouse m,
  mts_cage c,
  mts_procedure_dict d,
  lic_personal_licence l
where
  m.cage_id = c.id and
  p.mouse_id = m.id and
  p.procedure_dict_id = d.id and
  p.personal_licence_id = l.personal_licence_id and
  p.procedure_dict_id not in (21,36) -- breeding and maintenance
group by
  p.procedure_dict_id,
  d.name,
  c.id,
  l.pil_number
order by
  last_date;

alter table mts_colony_info add is_poolable number(1) default '0';

alter table mts_mouse add is_pooled number(1) default '0';

alter table mts_mouse drop column earmark_left;

alter table mts_mouse drop column earmark_right;

alter table mts_mouse drop column supplier_dict_id;

CREATE OR REPLACE VIEW MTS_MOUSE_VW
(ID, LITTER_ID, NAME, RFID_TAG, EDIT_DATE,
 COAT_COLOUR_DICT_ID, COAT_COLOUR, EYE_COLOUR_DICT_ID, EYE_COLOUR, EARMARK_DICT_ID,
 EARMARK, BIRTH_DATE, AGE_IN_WEEKS,
 DEATH_DATE, AGE_AT_DEATH, CAUSE_OF_DEATH_DICT_ID, CAUSE_OF_DEATH, EDITED_BY,
 WEAN_DATE, CAGE_ID, CAGE_NAME, CAGE_BARCODE, RACK_ID,
 RACK_NAME, ROOM_ID, ROOM_NAME, CURRENT_OWNER_ID, CURRENT_OWNER,
 CURRENT_PROJECT_LICENCE_ID, CURRENT_PROJECT_LICENCE, CURRENT_PROTOCOL_ID, CURRENT_PROTOCOL_CODE, CHECK_NUMBER,
 GENDER_DICT_ID, GENDER, MOUSE_STRAIN_DICT_ID, STRAIN, STATUS,
 CREATOR_ID, CREATED_DATE, BARCODE, COMMENTS, IS_NON_BREEDER,
 IS_SENTINEL, GENERATION, COLONY_NAME, COLONY_PREFIX, COLONY_INFO_ID,
 ARRIVAL_DATE, LATEST_PLUG_DATE, BREEDING_NAME, GENOTYPE, FATHER_NAME,
 FATHER_GENOTYPE, MOTHER_NAME, MOTHER_GENOTYPE, COHORTS, PIPELINES)
AS
select
  m.id,
  m.litter_id,
  m.name,
  m.rfid_tag,
  m.edit_date,
  m.coat_colour_dict_id,
  c.name||decode(chim.percent_chimeric,null,null,' ('||chim.percent_chimeric||'%)') coat_colour,
  m.eye_colour_dict_id,
  e.name eye_colour,
  m.earmark_dict_id,
  ear.name earmark,
  m.birth_date,
  round((nvl(m.death_date,sysdate) - m.birth_date)/7,1) age_in_weeks,
  m.death_date,
  round((m.death_date - m.birth_date)/7,1) age_at_death,
  m.cause_of_death_dict_id,
  d.name cause_of_death,
  m.edited_by,
  m.wean_date,
  m.cage_id,
  l.cage_name,
  l.cage_barcode,
  l.rack_id,
  l.rack_name,
  l.room_id,
  l.room_name,
  m.current_owner_id,
  owner.first_name||' '||owner.last_name current_owner,
  b.project_licence_id current_project_licence_id,
  b.licence_number current_project_licence,
  b.protocol_id current_protocol_id,
  b.protocol_code current_protocol_code,
  m.check_number,
  m.gender_dict_id,
  s.name gender,
  m.mouse_strain_dict_id,
  t.name strain,
  decode(m.death_date,null,'Alive','Deceased') status,
  m.creator_id,
  m.created_date,
  m.barcode,
  m.comments,
  m.is_non_breeder,
  m.is_sentinel,
  m.generation,
  colony.colony_name,
  colony.colony_prefix,
  m.colony_info_id,
  m.arrival_date,
  m.latest_plug_date,
  breeding.breeding_name,
  mts.fetch_genotype(m.id) genotype,
  p.father_name,
  decode(m.generation,'F0',null,decode(p.male_id,null,null,mts.fetch_genotype(p.male_id))) father_genotype,
  p.mother_name,
  decode(m.generation,'F0',null,decode(p.female_id,null,null,mts.fetch_genotype(p.female_id))) mother_genotype,
  mts.fetch_cohort(m.id,', ') cohorts,
  mts.fetch_pipelines(m.id,', ') pipelines
from
  mts_mouse m,
  mts_coat_colour_dict c,
  mts_eye_colour_dict e,
  mts_earmark_dict ear,
  mts_cause_of_death_dict d,
  per_person owner,
  mts_gender_dict s,
  mts_cage_vw l,
  mts_mouse_current_19b_mv b,
  typ_strain t,
  mts_colony_info colony,
  mts_current_breeding_mv breeding,
  mts_chimeric_mouse_data chim,
  (select b.male_id, b.female_id, l.id litter_id, decode(b.embryo_transfer_id,null,sire.name, null) father_name, decode(b.embryo_transfer_id,null,dam.name,null) mother_name
   from
    mts_litter l,
    mts_breeding b,
 mts_mouse sire,
 mts_mouse dam
   where
    l.breeding_id = b.id and
 b.male_id = sire.id and
 b.female_id = dam.id
  ) p
where
  m.coat_colour_dict_id = c.id(+) and
  m.eye_colour_dict_id = e.id(+) and
  m.earmark_dict_id = ear.id(+) and
  m.cause_of_death_dict_id = d.id(+) and
  m.current_owner_id = owner.person_id(+) and
  m.gender_dict_id = s.id(+) and
  m.cage_id = l.cage_id(+) and
  m.mouse_strain_dict_id = t.id(+) and
  m.colony_info_id = colony.id(+) and
  m.id = b.mouse_id(+) and
  m.id = breeding.mouse_id(+) and
  m.id = chim.mouse_id(+) and
  m.litter_id = p.litter_id(+);

/* formatted on 2008/06/23 10:50 (formatter plus v4.8.8) */
create or replace view rep_all_mice
as
select
  id,
  litter_id,
  name,
  rfid_tag,
  edit_date,
  coat_colour_dict_id,
  coat_colour,
  eye_colour_dict_id,
  eye_colour,
  earmark_dict_id,
  earmark,
  birth_date,
  age_in_weeks,
  death_date,
  age_at_death,
  cause_of_death_dict_id,
  cause_of_death,
  edited_by,
  wean_date,
  cage_id,
  cage_name,
  cage_barcode,
  rack_id,
  rack_name,
  room_id,
  room_name,
  current_owner_id,
  current_owner,
  current_project_licence_id,
  current_project_licence,
  current_protocol_id,
  current_protocol_code,
  check_number,
  gender_dict_id,
  gender,
  mouse_strain_dict_id,
  strain,
  status,
  creator_id,
  created_date,
  barcode,
  comments,
  is_non_breeder,
  is_sentinel,
  generation,
  colony_name,
  colony_prefix,
  colony_info_id,
  arrival_date,
  latest_plug_date,
  breeding_name,
  genotype,
  father_name,
  father_genotype,
  mother_name,
  mother_genotype,
  cohorts,
  pipelines
from
  mts_mouse_vw;

  CREATE OR REPLACE FORCE VIEW REP_MOUSE_HEADER_VW AS
WITH colony_gene AS
(SELECT a.colony_id, g.primary_name gene_name
   FROM mts_colony_allele a
   JOIN typ_modified_allele t ON a.modified_allele_id = t.id
   JOIN gnm_gene g ON t.gene_id = g.id
)
select
  t.name strain, m.mouse_strain_dict_id strain_id,
  c.cohort_name, cpd.name pipeline,
  c.id cohort_id, c.pipeline_dict_id pipeline_id,
  cg.gene_name,
  m.name mouse_name,
  m.barcode mouse,
  m.id mouse_id,
  mts.fetch_genotype(m.id) AS genotype,
  gd.name gender, m.gender_dict_id gender_id,
  m.birth_date
from mts_mouse m
JOIN mts_cohort_mouse cm ON m.id = cm.mouse_id
JOIN mts_cohort c ON cm.cohort_id = c.id AND c.cohort_type_id = 1
LEFT OUTER JOIN colony_gene cg ON m.colony_info_id = cg.colony_id
LEFT OUTER JOIN mts_cohort_pipeline_dict cpd ON cpd.id = c.pipeline_dict_id
JOIN typ_strain t ON m.mouse_strain_dict_id = t.id
JOIN mts_gender_dict gd ON m.gender_dict_id = gd.id;


CREATE OR REPLACE FORCE VIEW PHN_EXPERIMENT_SUMMARY_VW AS
  SELECT
  m.*,
  to_char(mp.start_date, 'dd-mm-yyyy') assay_date,
  ROUND((mp.start_date -m.birth_date) / 7,   1) age_in_weeks,
  per.first_name || ' ' || per.last_name pil_holder,
  e.sop_id,
  e.is_complete,
  e.id
FROM phn_experiment e
JOIN rep_mouse_header_vw m on m.mouse_id = e.mouse_id
JOIN mts_mouse_procedure mp ON e.id = mp.foreign_key_id AND mp.foreign_table_name = 'PHN_EXPERIMENT'
JOIN lic_personal_licence pil ON mp.personal_licence_id = pil.personal_licence_id
JOIN per_person per ON pil.person_id = per.person_id;
