CREATE TABLE PHN_UPLOAD_MAPPING (
ID NUMBER NOT NULL ENABLE,
REQUIRED_OBSERVATION_ID NUMBER NOT NULL ENABLE,
FIELD_NAME VARCHAR2(255 CHAR) NOT NULL ENABLE,
NAME VARCHAR2(255 CHAR) NOT NULL ENABLE,
CREATED_DATE DATE,
CREATOR_ID NUMBER,
EDIT_DATE DATE,
EDITED_BY VARCHAR2(255 CHAR),
CHECK_NUMBER NUMBER,
CONSTRAINT PHN_UPLOAD_MAPPING_PK PRIMARY KEY (ID),
CONSTRAINT PHN_UPLOAD_MAPPING_FK1 FOREIGN KEY (REQUIRED_OBSERVATION_ID) REFERENCES PHN_REQUIRED_OBSERVATION(ID)
);

CREATE SEQUENCE  PHN_UPLOAD_MAPPING_SEQ  MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 NOCACHE  NOORDER  NOCYCLE;

create table phn_calorimetry_data (
ID NUMBER NOT NULL,
EXPERIMENT_ID NUMBER NOT NULL,
SAMPLE_TIME TIMESTAMP NOT NULL,
MINUTES_ELAPSED NUMBER NOT NULL,
CO2 NUMBER,
O2 NUMBER,
REF_CO2 NUMBER,
REF_O2 NUMBER,
CO2_DIFFERENCE NUMBER,
O2_DIFFERENCE NUMBER,
CUMULATIVE_FOOD_INTAKE NUMBER,
FLOW_RATE_IN NUMBER,
SAMPLE_FLOW_RATE_OUT NUMBER,
TEMPERATURE NUMBER,
RESPIRATORY_EXCHANGE_RATIO NUMBER,
VCO2_BODYWEIGHT NUMBER,
VCO2_LEAN_MASS NUMBER,
VCO2_ANIMAL NUMBER,
VO2_BODYWEIGHT NUMBER,
VO2_LEAN_MASS NUMBER,
VO2_ANIMAL NUMBER,
ENERGY_EXPEND_BODYWEIGHT NUMBER,
ENERGY_EXPEND_LEAN_MASS NUMBER,
ENERGY_EXPEND_ANIMAL NUMBER,
HEAT_BODYWEIGHT NUMBER,
HEAT_LEAN_MASS NUMBER,
HEAT_ANIMAL NUMBER,
XAXIS_ACTIVITY_COUNT NUMBER,
XAXIS_ACTIVITY_COUNT_TOTAL NUMBER,
YAXIS_ACTIVITY_COUNT NUMBER,
YAXIS_ACTIVITY_COUNT_TOTAL NUMBER,
CREATED_DATE DATE,
CREATOR_ID NUMBER,
EDIT_DATE DATE,
EDITED_BY VARCHAR2(255 CHAR),
CHECK_NUMBER NUMBER,
CONSTRAINT phn_calorimetry_data_pk PRIMARY KEY (id),
CONSTRAINT phn_calorimetry_data_fk1 FOREIGN KEY (EXPERIMENT_ID) REFERENCES PHN_EXPERIMENT(ID)
);


CREATE SEQUENCE  PHN_CALORIMETRY_DATA_SEQ MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 NOCACHE  NOORDER  NOCYCLE ;

CREATE OR REPLACE FORCE VIEW PHN_CALORIMETRY_DATA_BINNED_VW  AS
  SELECT experiment_id,
  round(sample_time, 'hh') time,
  avg(minutes_elapsed) avg_minutes_elapsed,
  count(id) samples,
  AVG(co2) co2,
  AVG(o2) o2,
  AVG(ref_co2) ref_co2,
  AVG(ref_o2) ref_o2,
  AVG(co2_difference) co2_difference,
  AVG(o2_difference) o2_difference,
  AVG(cumulative_food_intake) cumulative_food_intake,
  AVG(flow_rate_in) flow_rate_in,
  AVG(sample_flow_rate_out) sample_flow_rate_out,
  AVG(temperature) temperature,
  AVG(respiratory_exchange_ratio) respiratory_exchange_ratio,
  AVG(vco2_bodyweight) vco2_bodyweight,
  AVG(vco2_lean_mass) vco2_lean_mass,
  AVG(vco2_animal) vco2_animal,
  AVG(vo2_bodyweight) vo2_bodyweight,
  AVG(vo2_lean_mass) vo2_lean_mass,
  AVG(vo2_animal) vo2_animal,
  AVG(energy_expend_bodyweight) energy_expend_bodyweight,
  AVG(energy_expend_lean_mass) energy_expend_lean_mass,
  AVG(energy_expend_animal) energy_expend_animal,
  AVG(heat_bodyweight) heat_bodyweight,
  AVG(heat_lean_mass) heat_lean_mass,
  AVG(heat_animal) heat_animal,
  AVG(xaxis_activity_count) xaxis_activity_count,
  AVG(xaxis_activity_count_total) xaxis_activity_count_total,
  AVG(yaxis_activity_count) yaxis_activity_count,
  AVG(yaxis_activity_count_total) yaxis_activity_count_total
FROM phn_calorimetry_data
GROUP BY experiment_id,
  round(sample_time, 'hh');

create or replace view rep_calorimetry_binned_vw as
  select
e.*,
c.TIME,
c.SAMPLES,
c.CO2,
c.O2,
c.REF_CO2,
c.REF_O2,
c.CO2_DIFFERENCE,
c.O2_DIFFERENCE,
c.CUMULATIVE_FOOD_INTAKE,
c.FLOW_RATE_IN,
c.SAMPLE_FLOW_RATE_OUT,
c.TEMPERATURE,
c.RESPIRATORY_EXCHANGE_RATIO,
c.VCO2_BODYWEIGHT,
c.VCO2_LEAN_MASS,
c.VCO2_ANIMAL,
c.VO2_BODYWEIGHT,
c.VO2_LEAN_MASS,
c.VO2_ANIMAL,
c.ENERGY_EXPEND_BODYWEIGHT,
c.ENERGY_EXPEND_LEAN_MASS,
c.ENERGY_EXPEND_ANIMAL,
c.HEAT_BODYWEIGHT,
c.HEAT_LEAN_MASS,
c.HEAT_ANIMAL,
c.XAXIS_ACTIVITY_COUNT,
c.XAXIS_ACTIVITY_COUNT_TOTAL,
c.YAXIS_ACTIVITY_COUNT,
c.YAXIS_ACTIVITY_COUNT_TOTAL,
(e.experiment_id * 1e2) + (e.cohort_id * 1e9) + c.avg_minutes_elapsed as id
from PHN_EXPERIMENT_SUMMARY_VW e
join PHN_CALORIMETRY_DATA_BINNED_VW c on e.experiment_id = c.experiment_id;

create or replace view REP_CALORIMETRY_RAW_VW as
select
e.*,
c.SAMPLE_TIME,
c.MINUTES_ELAPSED,
c.CO2,
c.O2,
c.REF_CO2,
c.REF_O2,
c.CO2_DIFFERENCE,
c.O2_DIFFERENCE,
c.CUMULATIVE_FOOD_INTAKE,
c.FLOW_RATE_IN,
c.SAMPLE_FLOW_RATE_OUT,
c.TEMPERATURE,
c.RESPIRATORY_EXCHANGE_RATIO,
c.VCO2_BODYWEIGHT,
c.VCO2_LEAN_MASS,
c.VCO2_ANIMAL,
c.VO2_BODYWEIGHT,
c.VO2_LEAN_MASS,
c.VO2_ANIMAL,
c.ENERGY_EXPEND_BODYWEIGHT,
c.ENERGY_EXPEND_LEAN_MASS,
c.ENERGY_EXPEND_ANIMAL,
c.HEAT_BODYWEIGHT,
c.HEAT_LEAN_MASS,
c.HEAT_ANIMAL,
c.XAXIS_ACTIVITY_COUNT,
c.XAXIS_ACTIVITY_COUNT_TOTAL,
c.YAXIS_ACTIVITY_COUNT,
c.YAXIS_ACTIVITY_COUNT_TOTAL,
(e.experiment_id * 1e4) + (e.cohort_id * 1e9) + c.id as id
from PHN_CALORIMETRY_DATA c
join PHN_EXPERIMENT_SUMMARY_VW e
on c.experiment_id = e.experiment_id;

alter table phn_required_observation add IS_MACHINE_DATA number(1) default '0';
alter table app_custom_query add IS_SERIES_DATA number(1) default '0';