create table res_category_dict (
ID NUMBER,
NAME VARCHAR2(1024 CHAR),
DESCRIPTION VARCHAR2(2048 CHAR),
ACTIVE NUMBER(1,0) DEFAULT 1 NOT NULL ENABLE,
ORDER_BY NUMBER,
constraint res_category_dict_pk primary key (id)
);

create table res_purpose (
id number,
name varchar2(1024 char) not null,
category_id number not null,
edit_date DATE DEFAULT sysdate,
edited_by VARCHAR2(128 BYTE),
created_date DATE DEFAULT sysdate,
creator_id NUMBER,
check_number NUMBER,
constraint res_purpose_pk primary key (id),
constraint res_purpose_fk1 foreign key (category_id) references res_category_dict(id),
constraint res_purpose_fk2 foreign key (creator_id) references per_person(person_id)
);

CREATE SEQUENCE  RES_PURPOSE_SEQ  MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1;


create table res_reservation (
id number not null ,
purpose_id not null,
reserver_id not null,
team_id not null,
edit_date DATE DEFAULT sysdate,
edited_by VARCHAR2(128 BYTE),
created_date DATE DEFAULT sysdate,
creator_id NUMBER,
check_number NUMBER,
notify number(1) not null,
constraint res_reservation_pk primary key (id),
constraint res_reservation_fk1 foreign key (purpose_id) references res_purpose(id),
constraint res_reservation_fk2 foreign key (reserver_id) references per_person(person_id),
constraint res_reservation_fk3 foreign key (team_id) references per_team(id),
constraint res_reservation_fk4 foreign key (creator_id) references per_person(person_id)
);

CREATE SEQUENCE  RES_RESERVATION_SEQ  MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1;

create table res_mouse_reservation (
id number,
mouse_id number not null,
reservation_id number not null,
notification_sent number(1) not null,
edit_date DATE DEFAULT sysdate,
edited_by VARCHAR2(128 BYTE),
created_date DATE DEFAULT sysdate,
creator_id NUMBER,
check_number NUMBER,
constraint res_mouse_reservation_pk primary key (id),
constraint res_mouse_reservation_fk1 foreign key (mouse_id) references mts_mouse(id),
constraint res_mouse_reservation_fk2 foreign key (reservation_id) references res_reservation(id)
);

CREATE SEQUENCE  res_mouse_reservation_seq  MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1;

CREATE OR REPLACE VIEW MTS_MOUSE_VW as
 select
  m.id,
  m.litter_id,
  m.name,
  m.rfid_tag,
  m.edit_date,
  m.coat_colour_dict_id,
  c.name||decode(chim.percent_chimeric,null,null,' ('||chim.percent_chimeric||'%)') coat_colour,
  m.eye_colour_dict_id,
  e.name eye_colour,
  m.earmark_dict_id,
  ear.name earmark,
  m.birth_date,
  round((nvl(m.death_date,sysdate) - m.birth_date)/7,1) age_in_weeks,
  m.death_date,
  round((m.death_date - m.birth_date)/7,1) age_at_death,
  m.cause_of_death_dict_id,
  d.name cause_of_death,
  m.edited_by,
  m.wean_date,
  m.cage_id,
  l.cage_name,
  l.cage_barcode,
  l.rack_id,
  l.rack_name,
  l.room_id,
  l.room_name,
  m.current_owner_id,
  owner.first_name||' '||owner.last_name current_owner,
  b.project_licence_id current_project_licence_id,
  b.licence_number current_project_licence,
  b.protocol_id current_protocol_id,
  b.protocol_code current_protocol_code,
  m.check_number,
  m.gender_dict_id,
  s.name gender,
  m.mouse_strain_dict_id,
  t.name strain,
  decode(m.death_date,null,'Alive','Deceased') status,
  m.creator_id,
  m.created_date,
  m.barcode,
  m.comments,
  m.is_non_breeder,
  m.is_sentinel,
  m.generation,
  colony.colony_name,
  colony.colony_prefix,
  m.colony_info_id,
  m.arrival_date,
  m.latest_plug_date,
  breeding.breeding_name,
  mts.fetch_genotype(m.id) genotype,
  p.father_name,
  decode(m.generation,'F0',null,decode(p.male_id,null,null,mts.fetch_genotype(p.male_id))) father_genotype,
  p.mother_name,
  decode(m.generation,'F0',null,decode(p.female_id,null,null,mts.fetch_genotype(p.female_id))) mother_genotype,
  mts.fetch_cohort(m.id,', ') cohorts,
  mts.fetch_pipelines(m.id,', ') pipelines,
  decode(r.id,
    null, null,
    rc.name ||':' || p.name
  ) reservation,
  rc.name category,
  rc.id category_id,
  p.id purpose_id,
  r.reserver_id,
  r.team_id,
  p.name purpose,
  decode(rp.person_id,
    null, null,
    rp.first_name || ' ' || rp.last_name
  ) reserver,
  decode(rt.id,
    null,null,
    rt.team_number || ' - ' || rt.team_name
  ) reservation_team
from
  mts_mouse m,
  mts_coat_colour_dict c,
  mts_eye_colour_dict e,
  mts_earmark_dict ear,
  mts_cause_of_death_dict d,
  per_person owner,
  mts_gender_dict s,
  mts_cage_vw l,
  mts_mouse_current_19b_mv b,
  typ_strain t,
  mts_colony_info colony,
  mts_current_breeding_mv breeding,
  mts_chimeric_mouse_data chim,
  res_mouse_reservation mr,
  res_reservation r,
  res_purpose p,
  res_category_dict rc,
  per_team rt,
  per_person rp,
  (select b.male_id, b.female_id, l.id litter_id, decode(b.embryo_transfer_id,null,sire.name, null) father_name, decode(b.embryo_transfer_id,null,dam.name,null) mother_name
   from
    mts_litter l,
    mts_breeding b,
 mts_mouse sire,
 mts_mouse dam
   where
    l.breeding_id = b.id and
 b.male_id = sire.id and
 b.female_id = dam.id
  ) p
where
  m.coat_colour_dict_id = c.id(+) and
  m.eye_colour_dict_id = e.id(+) and
  m.earmark_dict_id = ear.id(+) and
  m.cause_of_death_dict_id = d.id(+) and
  m.current_owner_id = owner.person_id(+) and
  m.gender_dict_id = s.id(+) and
  m.cage_id = l.cage_id(+) and
  m.mouse_strain_dict_id = t.id(+) and
  m.colony_info_id = colony.id(+) and
  m.id = b.mouse_id(+) and
  m.id = breeding.mouse_id(+) and
  m.id = chim.mouse_id(+) and
  m.litter_id = p.litter_id(+) and
  m.id = mr.mouse_id(+) and
  mr.reservation_id = r.id(+) and
  r.purpose_id = p.id (+) and
  p.CATEGORY_ID = rc.id (+) and
  r.reserver_id = rp.person_id(+) and
  r.team_id = rt.id(+);

CREATE OR REPLACE VIEW REP_ALL_MICE AS
  select
  id,
  litter_id,
  name,
  rfid_tag,
  edit_date,
  coat_colour_dict_id,
  coat_colour,
  eye_colour_dict_id,
  eye_colour,
  earmark_dict_id,
  earmark,
  birth_date,
  age_in_weeks,
  death_date,
  age_at_death,
  cause_of_death_dict_id,
  cause_of_death,
  edited_by,
  wean_date,
  cage_id,
  cage_name,
  cage_barcode,
  rack_id,
  rack_name,
  room_id,
  room_name,
  current_owner_id,
  current_owner,
  current_project_licence_id,
  current_project_licence,
  current_protocol_id,
  current_protocol_code,
  check_number,
  gender_dict_id,
  gender,
  mouse_strain_dict_id,
  strain,
  status,
  creator_id,
  created_date,
  barcode,
  comments,
  is_non_breeder,
  is_sentinel,
  generation,
  colony_name,
  colony_prefix,
  colony_info_id,
  arrival_date,
  latest_plug_date,
  breeding_name,
  genotype,
  father_name,
  father_genotype,
  mother_name,
  mother_genotype,
  cohorts,
  pipelines,
  reservation,
  category,
  category_id,
  purpose_id,
  reserver_id,
  team_id,
  purpose,
  reserver,
  reservation_team
from
  mts_mouse_vw;

CREATE INDEX RES_MOUSE_RESERVATION_IND1 ON RES_MOUSE_RESERVATION (RESERVATION_ID);
CREATE INDEX RES_MOUSE_RESERVATION_IND2 ON RES_MOUSE_RESERVATION (MOUSE_ID);

CREATE INDEX RES_RESERVATION_IND1 ON RES_RESERVATION (PURPOSE_ID);
CREATE INDEX RES_RESERVATION_IND2 ON RES_RESERVATION (RESERVER_ID);
CREATE INDEX RES_RESERVATION_IND3 ON RES_RESERVATION (TEAM_ID);

alter table RES_MOUSE_RESERVATION add
CONSTRAINT RES_MOUSE_RESERVATION_U1 unique (mouse_id);