CREATE TABLE APP_CUSTOM_QUERY_RSET_ACTION (
	ID NUMBER(*,0),
	CUSTOM_QUERY_ID NUMBER(*,0),
	ACTION_TITLE VARCHAR2(32 BYTE),
	ACTION_URL VARCHAR2(4000 BYTE),
	ORDER_BY NUMBER(*,0),
	CONSTRAINT APP_CUSTOM_QUERY_RSET_ACTIO_PK PRIMARY KEY (ID),
 	CONSTRAINT APP_CUSTOM_QUERY_RSET_ACTI_R01 FOREIGN KEY (CUSTOM_QUERY_ID)
	  REFERENCES APP_CUSTOM_QUERY (ID)
);

alter table app_custom_query add (selectable_records number(1) default '0', unique_name varchar2(64));

alter table app_user_searches modify query_name varchar2(64);

create unique index app_custom_query_u01 on app_custom_query (unique_name);

create sequence app_custom_query_rset_act_seq
  start with 6
  maxvalue 999999999999999999999999999
  minvalue 1
  nocycle
  nocache
  noorder;

create or replace trigger app_custom_query_rset_act_ts
before insert on app_custom_query_rset_action for each row
begin
  if :new.id is null then
    select app_custom_query_rset_act_seq.nextval into :new.id from dual;
  end if;
end;
/

create or replace procedure app_sync_custom_query(in_unique_name varchar2, origin_dblink varchar2) is

type ref_cursor is ref cursor;
c_ref_cursor ref_cursor;

r_custom_query app_custom_query%rowtype;

r_custom_query_column app_custom_query_column%rowtype;

r_custom_query_rset_action app_custom_query_rset_action%rowtype;

n_new_id number;


begin

   execute immediate 'select * from app_custom_query@'||origin_dblink||' where unique_name = :1'
   into r_custom_query using in_unique_name;

   select app_custom_query_seq.nextval into n_new_id from dual ;

   insert into app_custom_query
    (id,
    query_title,
    query_view_name,
    description,
    system_query,
    category,
    start_with_filter,
    selectable_records,
    unique_name)
   values
    (n_new_id,
    r_custom_query.query_title,
    r_custom_query.query_view_name,
    r_custom_query.description,
    r_custom_query.system_query,
    r_custom_query.category,
    r_custom_query.start_with_filter,
    r_custom_query.selectable_records,
    r_custom_query.unique_name
    );

    open c_ref_cursor for 'select * from app_custom_query_column@'||origin_dblink||' where custom_query_id = '||r_custom_query.id;
        loop
            fetch c_ref_cursor into r_custom_query_column;
            exit when c_ref_cursor%notfound;
            insert into app_custom_query_column
            (id,
            custom_query_id,
            column_name,
            column_title,
            datatype,
            order_by,
            datatype_format,
            datatype_format_2,
            actual_query_column,
            list_query,
            is_display_column,
            is_filter_column)
            values (
            app_custom_query_col_seq.nextval,
            n_new_id,
            r_custom_query_column.column_name,
            r_custom_query_column.column_title,
            r_custom_query_column.datatype,
            r_custom_query_column.order_by,
            r_custom_query_column.datatype_format,
            r_custom_query_column.datatype_format_2,
            r_custom_query_column.actual_query_column,
            r_custom_query_column.list_query,
            r_custom_query_column.is_display_column,
            r_custom_query_column.is_filter_column
            );
        end loop;
    close c_ref_cursor;

    open c_ref_cursor for 'select * from app_custom_query_rset_action@'||origin_dblink||' where custom_query_id = '||r_custom_query.id;
        loop
            fetch c_ref_cursor into r_custom_query_rset_action;
            exit when c_ref_cursor%notfound;
            insert into app_custom_query_rset_action
            (id,
            custom_query_id,
            action_title,
            action_url,
            order_by)
            values (
            app_custom_query_col_seq.nextval,
            n_new_id,
            r_custom_query_rset_action.action_title,
            r_custom_query_rset_action.action_url,
            r_custom_query_rset_action.order_by
            );
        end loop;
    close c_ref_cursor;

end app_sync_custom_query;
/

alter table mts_stud_breeding add (pseudo_breeding number(1) default '0');

CREATE OR REPLACE VIEW MTS_LATEST_STUD_BREEDING_VW
(BREEDING_ID, MOUSE_ID)
AS
select
  max(id) breeding_id,
  b.female_id mouse_id
  from mts_stud_breeding b,
 (select
 max(start_date) max_start_date,
 female_id
  from
 mts_stud_breeding
  group by
 female_id
  ) x
where
  b.female_id = x.female_id and
  b.start_date = x.max_start_date
group by b.female_id
union
select
  max(id) breeding_id,
  b.male_id mouse_id
  from mts_stud_breeding b,
 (select
 max(start_date) max_start_date,
 male_id
  from
 mts_stud_breeding
  group by
 male_id
  ) x
where
  b.male_id = x.male_id and
  b.start_date = x.max_start_date
group by b.male_id;


CREATE OR REPLACE VIEW REP_MOUSE_POOLS
(ID, COLONY_PREFIX, COLONY_NAME, POOL_DATE, CAGE_ID,
 CAGE_BARCODE, RACK_NAME, ROOM_NAME, TOTAL_FEMALES, AVAILABLE_FEMALES,
 PAIRED_FEMALES, PLUGGED_FEMALES)
AS
select
  p.id,
  i.colony_prefix,
  i.colony_name,
  p.pool_date,
  c.cage_id,
  c.cage_barcode,
  c.rack_name,
  c.room_name,
  count(distinct m.id) total_females,
  count(distinct decode(m.cage_id,p.cage_id,m.id,null)) available_females,
  count(distinct decode(b.id,null,null,decode(b.end_date,null,b.id,null))) paired_females,
  count(distinct decode(b.id,null,null,decode(b.end_date,null,null,decode(b.plug_date,null,null,b.id)))) plugged_females
from
  mts_mouse_pool p,
  mts_cage_vw c,
  mts_mouse m,
  mts_stud_breeding b,
  mts_colony_info i
where
  p.cage_id = c.cage_id and
  p.pool_date = m.birth_date(+) and
  p.colony_info_id = m.colony_info_id(+) and
  m.is_pooled(+) = 1 and
  m.id = b.female_id(+) and
  p.colony_info_id = i.id
group by
  p.id,
  i.colony_prefix,
  i.colony_name,
  p.pool_date,
  c.cage_id,
  c.cage_barcode,
  c.rack_name,
  c.room_name;


CREATE OR REPLACE VIEW REP_MOUSE_POOL_PLUGGED_FEMALES
(ID, CAGE_BARCODE, RACK_NAME, ROOM_NAME, COLONY_NAME,
 COLONY_PREFIX, FEMALE_TYPE, FEMALES_IN_CAGE, PLUG_DATE)
AS
select
  c.cage_id id,
  c.cage_barcode,
  c.rack_name,
  c.room_name,
  i.colony_name,
  i.colony_prefix,
  decode(b.pseudo_breeding,1,'Recipients','Donors') female_type,
  count(distinct m.id) females_in_cage,
  max(b.plug_date) plug_date
from
  mts_cage_vw c,
  mts_mouse m,
  mts_mouse f,
  mts_colony_info i,
  mts_stud_breeding b
where
  b.male_id = m.id and
  b.female_id = f.id and
  b.plug_date is not null and
  f.cage_id != nvl(m.cage_id,0) and
  f.cage_id = c.cage_id and
  f.colony_info_id = i.id and
  not exists (select null from mts_breeding b2 where b2.female_id = f.id)
group by
  c.cage_id,
  c.cage_barcode,
  c.rack_name,
  c.room_name,
  i.colony_name,
  i.colony_prefix,
  decode(b.pseudo_breeding,1,'Recipients','Donors')
order by c.cage_id;


CREATE OR REPLACE VIEW REP_STUD_BANKS
(ID, STUD_BANK, COLONY_PREFIX, LIVE_MICE, BREEDING_MICE,
 LATEST_SETUP)
AS
select
  c.id,
  c.cohort_name stud_bank,
  l.colony_prefix,
  l.live_mice,
  l.breeding_mice,
  l.latest_setup
from
  mts_cohort c,
  (select
    l.cohort_id,
    i.colony_prefix,
    count(distinct decode(m.death_date,null,m.id,null)) live_mice,
    count(distinct decode(b.id,null,null,decode(b.end_date,null,b.id,null))) breeding_mice,
    max(b.start_date) latest_setup
   from
    mts_mouse m,
    mts_cohort_mouse l,
    mts_colony_info i,
    mts_stud_breeding b
   where
     m.id = l.mouse_id and
     i.id = m.colony_info_id and
     m.id = b.male_id(+)
   group by
     l.cohort_id,
     i.colony_prefix
  ) l
where
  c.id = l.cohort_id(+) and
  c.cohort_type_id = 3;


CREATE OR REPLACE VIEW REP_PRODUCTION_STUDS
(ID, NAME, IS_PROVEN_STUD_BOOLEAN, IS_PROVEN_STUD_TEXT, BIRTH_DATE,
 DEATH_DATE, COLONY_PREFIX, COLONY_NAME, ROOM_NAME, RACK_NAME,
 CAGE_ID, CAGE_BARCODE, LAST_BREEDING, TOTAL_BREEDINGS, PLUGGED_BREEDINGS)
AS
select
  m.id,
  m.name,
  m.is_proven_stud is_proven_stud_boolean,
  decode(m.is_proven_stud,1,'Yes','No') is_proven_stud_text,
  m.birth_date,
  m.death_date,
  i.colony_prefix,
  i.colony_name,
  c.room_name,
  c.rack_name,
  c.cage_id,
  c.cage_barcode,
  max(b.start_date) last_breeding,
  count(b.start_date) total_breedings,
  count(decode(b.end_date,null,null,decode(b.plug_date,null,null,1))) plugged_breedings
from
  mts_mouse m,
  mts_stud_breeding b,
  mts_cage_vw c,
  mts_colony_info i
where
  m.id = b.male_id(+) and
  c.cage_id(+) = m.cage_id and
  m.colony_info_id = i.id and
  m.is_stud = 1
group by
  m.id,
  m.name,
  m.is_proven_stud,
  m.birth_date,
  m.death_date,
  i.colony_prefix,
  i.colony_name,
  c.room_name,
  c.rack_name,
  c.cage_id,
  c.cage_barcode
order by
  m.death_date nulls first,m.birth_date;

create or replace view rep_stud_breedings
as
select
  b.id,
  i.colony_prefix,
  i.colony_name,
  decode(b.end_date,null,'Mating',decode(b.plug_date,null,'Failed','Plugged')) status,
  decode(b.pseudo_breeding,1,'Recipient','Donor') breeding_type,
  b.start_date,
  p1.first_name||' '||p1.last_name setup_by,
  b.plug_date,
  p2.first_name||' '||p2.last_name check_by,
  b.end_date,
  m.name male_name,
  m.id male_id,
  f.name female_name,
  f.id female_id,
  c1.cage_id male_cage_id,
  c1.cage_barcode male_cage_barcode,
  c1.rack_name male_rack_name,
  c1.room_name male_room_name,
  c2.cage_id female_cage_id,
  c2.cage_barcode female_cage_barcode,
  c2.rack_name female_rack_name,
  c2.room_name female_room_name
from
  mts_cage_vw c1,
  mts_cage_vw c2,
  mts_mouse m,
  mts_mouse f,
  mts_stud_breeding b,
  per_person p1,
  per_person p2,
  mts_colony_info i
where
  c1.cage_id(+) = m.cage_id and
  c2.cage_id(+) = f.cage_id and
  m.id = b.male_id and
  f.id = b.female_id and
  p1.person_id = b.setup_person_id and
  p2.person_id(+) = b.check_person_id and
  i.id = f.colony_info_id;


CREATE OR REPLACE PACKAGE     MTS AS
/******************************************************************************
   NAME:       MTS
   PURPOSE:

   REVISIONS:
   Ver        Date        Author           Description
   ---------  ----------  ---------------  ------------------------------------
   V3.0.39       18/04/2008             wl1 Created this package.
******************************************************************************/


  PROCEDURE mts_delete_colony(in_colony_id number);
  PROCEDURE mts_delete_mouse(in_mouse_id number);
  PROCEDURE mts_genotype_import;
  PROCEDURE MTS_MIR_MOVE_COLONY(IN_MIR_ID number, IN_COLONY_ID number);
  FUNCTION  MTS_NEXT_BREEDING_NUMBERS (in_colony_id number) return integer_list;
  FUNCTION fetch_cohort (in_mouse_id in number, in_delimiter in varchar2) return varchar2;
  FUNCTION fetch_genotype (in_mouse_id number) return varchar2;
  FUNCTION fetch_pipelines (in_mouse_id in number, in_delimiter in varchar2) return varchar2;
  FUNCTION fetch_simple_genotype (in_mouse_id number) return varchar2;
  FUNCTION FETCH_GENOTYPE_BY_ALLELE(in_mouse_id number, in_allele_id number) RETURN NUMBER;
  FUNCTION FETCH_COHORT_GENOTYPE(in_cohort_id number, in_allele_id number) RETURN NUMBER;
  FUNCTION FETCH_CAGE_TYPE(in_cage_id number) RETURN varchar2;

END MTS;
/



CREATE OR REPLACE PACKAGE BODY     mts as


/* ====================================

  mts_delete_colony(in_colony_id number)

 ==================================== */

PROCEDURE mts_delete_colony(in_colony_id number) IS
BEGIN
  delete mts_colony_allele where colony_id = in_colony_id;
  delete mts_colony_behaviour where colony_id = in_colony_id;
  delete mts_colony_coat_colour where colony_id = in_colony_id;
  delete mts_colony_contact where colony_id = in_colony_id;
  delete mts_colony_cross where colony_id = in_colony_id;
  delete mts_colony_room where colony_id = in_colony_id;
  delete mts_colony_strain where colony_id = in_colony_id;
  delete mts_colony_info where id = in_colony_id;

END mts_delete_colony;

/* ====================================

  MTS_DELETE_MOUSE(IN_MOUSE_ID number)

 ==================================== */
PROCEDURE MTS_DELETE_MOUSE(IN_MOUSE_ID number) IS

BEGIN

  delete mts_mouse_procedure where mouse_id = in_mouse_id;

  delete mts_chimeric_mouse_data where mouse_id = in_mouse_id;

  delete mts_mouse_cage_history where mouse_id = in_mouse_id;

  delete mts_mouse_allele where mouse_id = in_mouse_id;

  delete mts_mouse where id = in_mouse_id;

END MTS_DELETE_MOUSE;


/* ====================================

  MTS_GENOTYPE_IMPORT

 ==================================== */

PROCEDURE MTS_GENOTYPE_IMPORT IS

cursor c_mice_to_genotype is
select *
from mts_genotype_import_data
where status is null
for update of status, status_date
;

cursor c_fetch_mouse_by_name(in_name varchar2) is
select *
from mts_mouse
where name = in_name;

v_mouse mts_mouse%rowtype;

v_status varchar2(4000);
BEGIN

  for i in c_mice_to_genotype loop
    v_status := '';
    open c_fetch_mouse_by_name(i.mouse_name);
 fetch c_fetch_mouse_by_name into v_mouse;

 if c_fetch_mouse_by_name%found then

     if i.genotype = '+/+' then
     delete mts_mouse_allele where mouse_id = v_mouse.id;
  v_status := 'Wildtype: mts_mouse_allele records deleted:'||sql%rowcount;
   elsif i.genotype = '-/-' then
     update mts_mouse_allele set genotype_dict_id = 3, edit_date = sysdate, edited_by = sys_context('USERENV','OS_USER') where mouse_id = v_mouse.id;
     if sql%rowcount = 0 then
       v_status := 'Hom: Allele not found';
     else
       v_status := 'Hom: mts_mouse_allele records updated:'||sql%rowcount;
     end if;
   elsif i.genotype = '-/+' or i.genotype = '+/-' then
     update mts_mouse_allele set genotype_dict_id = 2, edit_date = sysdate, edited_by = sys_context('USERENV','OS_USER') where mouse_id = v_mouse.id;
     if sql%rowcount = 0 then
       v_status := 'Het: Allele not found';
     else
       v_status := 'Het: mts_mouse_allele records updated:'||sql%rowcount;
     end if;
   else
     v_status := 'Unknown genotype code';
   end if;
 else
   v_status := 'Mouse not found';
 end if;

 close c_fetch_mouse_by_name;

    update mts_genotype_import_data
 set status_date = systimestamp, status = v_status
 where current of c_mice_to_genotype;
  end loop;

END mts_genotype_import;


/* ====================================

  MTS_MIR_MOVE_COLONY(IN_MIR_ID number, IN_COLONY_ID number)

 ==================================== */
PROCEDURE MTS_MIR_MOVE_COLONY(IN_MIR_ID number, IN_COLONY_ID number) IS

cursor c_colony_info is
select * from mts_colony_info where id = in_colony_id;

t_colony_info mts_colony_info%rowtype;

cursor c_embryo_transfer_breedings is
select b.*
from
  mts_breeding b,
  mir_embryo_transfer_procedure et,
  mir_scheduled_micro_injection smi,
  mir_micro_injection_request mir
where
  b.embryo_transfer_id = et.id and
  et.scheduled_micro_injection_id = smi.id and
  smi.micro_injection_request_id = mir.id and
  mir.id = in_mir_id
order by b.id
for update of b.name_prefix,b.offspring_colony_id,b.breeding_number;

cursor c_embryo_transfer_recipients is
select m.*
from
  mts_mouse m,
  mts_breeding b,
  mir_embryo_transfer_procedure et,
  mir_scheduled_micro_injection smi,
  mir_micro_injection_request mir
where
  b.female_id = m.id and
  b.embryo_transfer_id = et.id and
  et.scheduled_micro_injection_id = smi.id and
  smi.micro_injection_request_id = mir.id and
  mir.id = in_mir_id
order by m.id
for update of m.colony_info_id;

cursor c_next_breeding_number is
select 1 + max(breeding_number)
from
  mts_breeding
where
  offspring_colony_id = in_colony_id;

t_next_breeding_number number;

t_old_offspring_colony_id number;

cursor c_embryo_transfer_litters is
select l.*, b.name_prefix||b.breeding_number||'.' new_prefix
from
  mts_litter l,
  mts_breeding b,
  mir_embryo_transfer_procedure et,
  mir_scheduled_micro_injection smi,
  mir_micro_injection_request mir
where
  l.breeding_id = b.id and
  b.embryo_transfer_id = et.id and
  et.scheduled_micro_injection_id = smi.id and
  smi.micro_injection_request_id = mir.id and
  mir.id = in_mir_id
order by l.id
for update of l.name_prefix;

cursor c_chimeras is
select m.*, l.name_prefix||l.litter_number||lower(substr(m.name,length(m.name))) new_name
from
  mts_mouse m,
  mts_litter l,
  mts_breeding b,
  mir_embryo_transfer_procedure et,
  mir_scheduled_micro_injection smi,
  mir_micro_injection_request mir
where
  m.litter_id = l.id and
  l.breeding_id = b.id and
  b.embryo_transfer_id = et.id and
  et.scheduled_micro_injection_id = smi.id and
  smi.micro_injection_request_id = mir.id and
  mir.id = in_mir_id
order by l.id
for update of m.colony_info_id, m.name;

cursor c_chimera_matings is
select cb.*
from
  mts_breeding cb,
  mts_mouse m,
  mts_litter l,
  mts_breeding b,
  mir_embryo_transfer_procedure et,
  mir_scheduled_micro_injection smi,
  mir_micro_injection_request mir
where
  cb.male_id = m.id and
  m.litter_id = l.id and
  l.breeding_id = b.id and
  b.embryo_transfer_id = et.id and
  et.scheduled_micro_injection_id = smi.id and
  smi.micro_injection_request_id = mir.id and
  mir.id = in_mir_id
order by cb.id
for update of cb.name_prefix,cb.offspring_colony_id,cb.breeding_number;

cursor c_chimera_mates is
select f.*
from
  mts_mouse f,
  mts_breeding cb,
  mts_mouse m,
  mts_litter l,
  mts_breeding b,
  mir_embryo_transfer_procedure et,
  mir_scheduled_micro_injection smi,
  mir_micro_injection_request mir
where
  cb.female_id = f.id and
  cb.male_id = m.id and
  m.litter_id = l.id and
  l.breeding_id = b.id and
  b.embryo_transfer_id = et.id and
  et.scheduled_micro_injection_id = smi.id and
  smi.micro_injection_request_id = mir.id and
  mir.id = in_mir_id
order by f.id
for update of f.colony_info_id;

cursor c_chimera_litters is
select cl.*,cb.name_prefix||cb.breeding_number||'.' new_prefix
from
  mts_litter cl,
  mts_breeding cb,
  mts_mouse m,
  mts_litter l,
  mts_breeding b,
  mir_embryo_transfer_procedure et,
  mir_scheduled_micro_injection smi,
  mir_micro_injection_request mir
where
  cl.breeding_id = cb.id and
  cb.male_id = m.id and
  m.litter_id = l.id and
  l.breeding_id = b.id and
  b.embryo_transfer_id = et.id and
  et.scheduled_micro_injection_id = smi.id and
  smi.micro_injection_request_id = mir.id and
  mir.id = in_mir_id
order by cl.id
for update of cl.name_prefix;

cursor c_chimera_offspring is
select co.*,cl.name_prefix||cl.litter_number||lower(substr(co.name,length(co.name))) new_name
from
  mts_mouse co,
  mts_litter cl,
  mts_breeding cb,
  mts_mouse m,
  mts_litter l,
  mts_breeding b,
  mir_embryo_transfer_procedure et,
  mir_scheduled_micro_injection smi,
  mir_micro_injection_request mir
where
  co.litter_id = cl.id and
  cl.breeding_id = cb.id and
  cb.male_id = m.id and
  m.litter_id = l.id and
  l.breeding_id = b.id and
  b.embryo_transfer_id = et.id and
  et.scheduled_micro_injection_id = smi.id and
  smi.micro_injection_request_id = mir.id and
  mir.id = in_mir_id
order by co.id
for update of co.colony_info_id, co.name;

BEGIN

     open c_colony_info;
  fetch c_colony_info into t_colony_info;
  close c_colony_info;

  --update colony for MIR
  dbms_output.put_line('updating mir '||in_mir_id||' to new colony id '||in_colony_id);

  update mir_micro_injection_request
  set colony_info_id = in_colony_id
  where id = in_mir_id;
  dbms_output.put_line('rows affected: '||sql%rowcount);

  -- update embryo transfer matings (colony, name and number)
  for b in c_embryo_transfer_breedings loop

   t_old_offspring_colony_id := b.offspring_colony_id;

   if nvl(t_old_offspring_colony_id,-1) != in_colony_id then

     open c_next_breeding_number;
     fetch c_next_breeding_number into t_next_breeding_number;
     close c_next_breeding_number;

     if t_next_breeding_number is null then
        t_next_breeding_number := 1;
     end if;

     dbms_output.put_line('updating breeding '||b.id||'('||b.breeding_number||')'||' setting breeding number, colony and name prefix  from '||b.breeding_number||','||b.offspring_colony_id||','||b.name_prefix||' to '||t_next_breeding_number||','||in_colony_id||','||t_colony_info.colony_prefix);
     update mts_breeding
     set
       offspring_colony_id = in_colony_id,
       name_prefix = t_colony_info.colony_prefix,
       breeding_number = t_next_breeding_number
     where current of c_embryo_transfer_breedings;
     dbms_output.put_line('rows affected: '||sql%rowcount);
      else
     dbms_output.put_line('updating breeding '||b.id||'('||b.breeding_number||')'||' setting colony and name prefix from '||b.offspring_colony_id||','||b.name_prefix||' to '||in_colony_id||','||t_colony_info.colony_prefix);
     update mts_breeding
    set
      offspring_colony_id = in_colony_id,
      name_prefix = t_colony_info.colony_prefix
    where current of c_embryo_transfer_breedings;
    dbms_output.put_line('rows affected: '||sql%rowcount);
   end if;

  end loop;

  -- update embryo transfer recipients
  for m in c_embryo_transfer_recipients loop
    dbms_output.put_line('updating et recipient '||m.id||'('||m.name||') setting colony '||in_colony_id);
   update mts_mouse
   set
     colony_info_id = in_colony_id
   where current of c_embryo_transfer_recipients;
   dbms_output.put_line('rows affected: '||sql%rowcount);
  end loop;

  -- update embryo transfer litters
  for l in c_embryo_transfer_litters loop
    dbms_output.put_line('updating et litter '||l.id||' seting name prefix from '||l.name_prefix||' to '||l.new_prefix);
    update mts_litter
   set
     name_prefix = l.new_prefix
   where current of c_embryo_transfer_litters;
   dbms_output.put_line('rows affected: '||sql%rowcount);
  end loop;

  -- update chimeras
  for m in c_chimeras loop
    dbms_output.put_line('updating chimera '||m.id||'('||m.name||') setting colony_id, name from '||m.colony_info_id||','||m.name||' to '||in_colony_id||','||m.new_name);
    update mts_mouse
   set
     colony_info_id = in_colony_id,
     name = m.new_name
   where current of c_chimeras;
   dbms_output.put_line('rows affected: '||sql%rowcount);
  end loop;

  -- update chimera matings
  for cm in c_chimera_matings loop

   t_old_offspring_colony_id := cm.offspring_colony_id;

   if nvl(t_old_offspring_colony_id,-1) != in_colony_id then

     open c_next_breeding_number;
     fetch c_next_breeding_number into t_next_breeding_number;
     close c_next_breeding_number;

     if t_next_breeding_number is null then
        t_next_breeding_number := 1;
     end if;

     dbms_output.put_line('updating chimera breeding '||cm.id||'('||cm.breeding_number||')'||' setting breeding number, colony and name prefix  from '||cm.breeding_number||','||cm.offspring_colony_id||','||cm.name_prefix||' to '||t_next_breeding_number||','||in_colony_id||','||t_colony_info.colony_prefix);
     update mts_breeding
     set
       offspring_colony_id = in_colony_id,
       name_prefix = t_colony_info.colony_prefix,
       breeding_number = t_next_breeding_number
     where current of c_chimera_matings;
     dbms_output.put_line('rows affected: '||sql%rowcount);
      else
     dbms_output.put_line('updating chimera breeding '||cm.id||'('||cm.breeding_number||')'||' setting colony and name prefix from '||cm.offspring_colony_id||','||cm.name_prefix||' to '||in_colony_id||','||t_colony_info.colony_prefix);
     update mts_breeding
    set
      offspring_colony_id = in_colony_id,
      name_prefix = t_colony_info.colony_prefix
    where current of c_chimera_matings;
    dbms_output.put_line('rows affected: '||sql%rowcount);
   end if;

  end loop;

  -- update chimera mates
  for m in c_chimera_mates loop
    dbms_output.put_line('updating chimera mate '||m.id||'('||m.name||') setting colony '||in_colony_id);
   update mts_mouse
   set
     colony_info_id = in_colony_id
   where current of c_chimera_mates;
   dbms_output.put_line('rows affected: '||sql%rowcount);
  end loop;

  -- update chimera litters
  for l in c_chimera_litters loop
    dbms_output.put_line('updating chimera litter '||l.id||' seting name prefix from '||l.name_prefix||' to '||l.new_prefix);
    update mts_litter
   set
     name_prefix = l.new_prefix
   where current of c_chimera_litters;
   dbms_output.put_line('rows affected: '||sql%rowcount);
  end loop;

  -- update chimera offspring
  for m in c_chimera_offspring loop
    dbms_output.put_line('updating F1 '||m.id||'('||m.name||') setting colony_id, name from '||m.colony_info_id||','||m.name||' to '||in_colony_id||','||m.new_name);
    update mts_mouse
   set
     colony_info_id = in_colony_id,
     name = m.new_name
   where current of c_chimera_offspring;
   dbms_output.put_line('rows affected: '||sql%rowcount);
  end loop;


END MTS_MIR_MOVE_COLONY;

/* ====================================

MTS_NEXT_BREEDING_NUMBERS (in_colony_id number) return integer_list

 ==================================== */


FUNCTION MTS_NEXT_BREEDING_NUMBERS (in_colony_id number) return integer_list IS

output_list integer_list := integer_list();

cursor c_colony_exists is
select count(*)
from mts_colony_info
where id = in_colony_id;

cursor c_last_breeding_number is
select max(breeding_number) max_number
from mts_breeding
where offspring_colony_id = in_colony_id;

cursor c_breeding_number_used(in_number number) is
select count(*) in_use
from mts_breeding
where offspring_colony_id = in_colony_id
and breeding_number = in_number;

cursor c_breeding_number_offset is
select offset
from mts_breeding_offset
where colony_info_id = in_colony_id;

n_colony_exists number;

n_last_breeding_number number;

n_breeding_number_used number;

n_breeding_number_offset number;

n_index number := 1;

BEGIN
     if in_colony_id is null then return null;
     end if;

     open c_colony_exists;
	 fetch c_colony_exists into n_colony_exists;
	 close c_colony_exists;
	 if n_colony_exists = 0 then return null;
	 end if;

	 open c_last_breeding_number;
	 fetch c_last_breeding_number into n_last_breeding_number;
	 close c_last_breeding_number;

	 if n_last_breeding_number is null then
	   n_last_breeding_number := 1;
	 end if;

	 if n_last_breeding_number = 1 then
	   open c_breeding_number_offset;
	   fetch  c_breeding_number_offset into n_breeding_number_offset;
	   close c_breeding_number_offset;
	 end if;

	 if n_breeding_number_offset is not null then
	   n_last_breeding_number := n_breeding_number_offset + n_last_breeding_number;
	 else
	   n_breeding_number_offset := 1;
	 end if;

	 for n in n_breeding_number_offset .. (n_last_breeding_number + 100) loop
	 	 open c_breeding_number_used(n);
		 fetch c_breeding_number_used into n_breeding_number_used;
		 close c_breeding_number_used;
		 if n_breeding_number_used = 0 then
		   output_list.extend;
		   output_list(n_index) := n;
		   n_index := n_index + 1;
		 end if;
	 end loop;

	 return output_list;
END mts_next_breeding_numbers;

/******************************************************************************
  fetch_pipelines (in_mouse_id in number, in_delimiter in varchar2) return varchar2
******************************************************************************/
function fetch_pipelines (in_mouse_id in number, in_delimiter in varchar2) return varchar2
is
  t_pipelines varchar2(2000);
begin
for i in (
  select distinct
    p.name pipeline
  from
    mts_cohort_pipeline_dict p,
    mts_cohort_mouse m,
	mts_cohort c
  where
    c.pipeline_dict_id = p.id and
    m.cohort_id = c.id and
	m.mouse_id = in_mouse_id
) loop
    t_pipelines := t_pipelines || i.pipeline || in_delimiter;
  end loop;
  return substr(t_pipelines, 1, length(t_pipelines)-length(in_delimiter));
end;

/******************************************************************************
function fetch_cohort (in_mouse_id in number, in_delimiter in varchar2) return varchar2
******************************************************************************/

function fetch_cohort (in_mouse_id in number, in_delimiter in varchar2) return varchar2
is
  t_cohorts varchar2(2000);
begin

for i in (
  select
    c.cohort_name
  from
    mts_cohort_mouse m,
	mts_cohort c
  where
    m.cohort_id = c.id and
	m.mouse_id = in_mouse_id
) loop
    t_cohorts := t_cohorts || i.cohort_name || in_delimiter;
  end loop;

  return substr(t_cohorts, 1, length(t_cohorts)-length(in_delimiter));
end;

/******************************************************************************
fetch_genotype (in_mouse_id number) return varchar2
******************************************************************************/
function fetch_genotype (in_mouse_id number) return varchar2 is

cursor c_alleles is
select
  decode(c.percent_chimeric,
  null,
	  decode(m.genotype_dict_id,
	    1, '+/+', --wildtype
	 	2, decode(a.inheritance_mode_id, -- heterozygous
		   		1,a.short_allele_symbol||'/+', -- dominant
				3,a.short_allele_symbol||'/+', -- semi-dominant
				'+/'||a.short_allele_symbol),
	 	3, a.short_allele_symbol||'/'||a.short_allele_symbol, --homozygous
	 	4, a.short_allele_symbol||'-?'),
   0, '+/+', -- zero percent chimera
   c.percent_chimeric||'% '||a.short_allele_symbol --chimera
  ) genotype -- unknown
from
  mts_mouse_allele m,
  typ_modified_allele a,
  mts_chimeric_mouse_data c
where
  m.mouse_id = in_mouse_id and
  m.allele_id = a.id and
  m.mouse_id = c.mouse_id(+);

v_genotype varchar2(4000) := '';

begin

  for a in c_alleles loop
    v_genotype := v_genotype||a.genotype||' ';
  end loop;

  return trim(nvl(v_genotype,'+/+'));

end fetch_genotype;

/******************************************************************************
   fetch_simple_genotype (in_mouse_id number) return varchar2
******************************************************************************/


function fetch_simple_genotype (in_mouse_id number) return varchar2 is

cursor c_alleles is
select
  decode(c.percent_chimeric,
  null,
	  decode(m.genotype_dict_id,
	    1, '+/+', --wildtype
	 	2, decode(a.inheritance_mode_id, -- heterozygous
		   		1,'-/+', -- dominant
				3,'-/+', -- semi-dominant
				'+/-'),
	 	3, '-/-', --homozygous
	 	4, '?'),
   0, '+/+', -- zero percent chimera
   c.percent_chimeric||'%' --chimera
  ) genotype -- unknown
from
  mts_mouse_allele m,
  typ_modified_allele a,
  mts_chimeric_mouse_data c
where
  m.mouse_id = in_mouse_id and
  m.allele_id = a.id and
  m.mouse_id = c.mouse_id(+);

v_genotype varchar2(4000) := '';

begin

  -- just return the first allele found (for now)
  open c_alleles;
  fetch c_alleles into v_genotype;
  close c_alleles;

  return trim(nvl(v_genotype,'+/+'));

end fetch_simple_genotype;


/******************************************************************************
   FETCH_GENOTYPE_BY_ALLELE(in_mouse_id number, in_allele_id number)
******************************************************************************/
FUNCTION FETCH_GENOTYPE_BY_ALLELE(in_mouse_id number, in_allele_id number) RETURN NUMBER IS

cursor c_has_allele is
select genotype_dict_id
from
  mts_mouse_allele a
where
  a.mouse_id = in_mouse_id and
  a.allele_id = in_allele_id
;

t_genotype number;


BEGIN

  open c_has_allele;
  fetch c_has_allele into t_genotype;
  if c_has_allele%NOTFOUND then
    t_genotype := 1; --wildtype
  end if;
  close c_has_allele;

  return t_genotype;

END FETCH_GENOTYPE_BY_ALLELE;

/******************************************************************************
   FETCH_FETCH_COHORT_GENOTYPE(in_cohort_id number, in_allele_id number) RETURN NUMBER
******************************************************************************/

FUNCTION FETCH_COHORT_GENOTYPE(in_cohort_id number, in_allele_id number) RETURN NUMBER IS

cursor c_has_allele is
select distinct genotype_dict_id
from
  mts_mouse_allele a,
  mts_cohort_mouse c
where
  c.cohort_id = in_cohort_id and
  a.allele_id = in_allele_id and
  a.mouse_id = c.mouse_id
;

t_genotype number;

t_loop_index number := 1;

BEGIN

  for a in c_has_allele loop
    if t_loop_index > 1 then
	  t_genotype := -1;
	  exit;
	end if;
    t_genotype := a.genotype_dict_id;
	t_loop_index := t_loop_index + 1;
  end loop;

  if t_genotype is null then
    t_genotype := 1; --wildtype
  end if;

  return t_genotype;

END FETCH_COHORT_GENOTYPE;

function fetch_cage_type(in_cage_id number) return varchar2 is

cursor is_embryo_transfer is
select
  decode(count(b.id),0,0,null,0,1) is_embryo_transfer,
  decode(count(smi.id),0,0,null,0,1) is_from_smi
from
  mts_breeding b,
  mts_mouse m,
  mir_embryo_transfer_procedure et,
  mir_scheduled_micro_injection smi
where
  m.id = b.female_id and
  b.embryo_transfer_id = et.id and
  et.scheduled_micro_injection_id = smi.id(+)
  and m.cage_id = in_cage_id;

n_is_embryo_transfer number := 0;
n_is_from_smi number := 0;

cursor is_mating is
select decode(decode(count(m.id),0,0,1,1,2)||decode(count(b.id),0,null,count(b.end_date)),
    '10',1,
    '11',1,
    '20',1,
    0) is_mating
from
  mts_breeding b,
  mts_latest_breeding_vw l,
  mts_mouse m
where
  m.id = l.mouse_id(+) and
  l.mouse_id = b.female_id(+) and
  l.breeding_id = b.id(+) and
  m.cage_id = in_cage_id and
  (m.litter_id is null or m.wean_date is not null) and
  b.embryo_transfer_id is null;

n_is_mating number := 0;

cursor is_pool_cage is
select decode(count(p.id),1,1,0) is_pool
from
  mts_mouse_pool p
where
  p.cage_id = in_cage_id;

n_is_pool_cage number := 0;

cursor is_stud_cage is
select
  decode(count(m.id),1,1,0) is_stud
from
  mts_mouse m
where
  m.wean_date is not null and
  m.is_stud = 1 and
  m.cage_id = in_cage_id;

n_is_stud_cage number := 0;

/**
    PLUGGED_FEMALE_CAGE if the female(s) has a plugged stud breeding,
    is not in the stud cage, and has not had a subsequent normal breeding
    (embryo transfer) record.
*/
cursor is_plugged_female_cage is
select decode(count(f.id),0,0,1) is_plugged
from
  mts_mouse f,
  mts_mouse m,
  mts_stud_breeding b
where
  f.id = b.female_id and
  m.id = b.male_id and
  f.cage_id != nvl(m.cage_id,0) and
  b.plug_date is not null and
  f.cage_id = in_cage_id and
  not exists (select null from mts_breeding b2 where b2.female_id = f.id);

n_is_plugged_female_cage number := 0;

cage_type varchar2(30);

begin

  if cage_type is null then
    open is_pool_cage;
    fetch is_pool_cage into n_is_pool_cage;
    close is_pool_cage;

    if n_is_pool_cage = 1 then
      cage_type := 'POOL_CAGE';
    end if;
  end if;

  if cage_type is null then
    open is_stud_cage;
    fetch is_stud_cage into n_is_stud_cage;
    close is_stud_cage;

    if n_is_stud_cage = 1 then
      cage_type := 'STUD_CAGE';
    end if;
  end if;

  if cage_type is null then
    open is_plugged_female_cage;
    fetch is_plugged_female_cage into n_is_plugged_female_cage;
    close is_plugged_female_cage;

    if n_is_plugged_female_cage = 1 then
      cage_type := 'PLUGGED_FEMALE_CAGE';
    end if;
  end if;


  if cage_type is null then
    open is_embryo_transfer;
    fetch is_embryo_transfer into n_is_embryo_transfer, n_is_from_smi;
    close is_embryo_transfer;

    if n_is_embryo_transfer = 1 then
      if n_is_from_smi = 1 then
        cage_type := 'EMBRYO_TRANSFER';
      else
        cage_type := 'CRYO_EMBRYO_TRANSFER';
      end if;
    end if;
  end if;

  if cage_type is null then
    open is_mating;
    fetch is_mating into n_is_mating;
    close is_mating;

    if n_is_mating = 1 then
      cage_type := 'MATING';
    end if;
  end if;

  if cage_type is null then
    cage_type := 'STOCK';
  end if;

  return cage_type;


end fetch_cage_type;

end mts;
/


