CREATE OR REPLACE VIEW HTL_CROP_VW
AS 
SELECT 
m.ID mouse_id, 
g.primary_name gene_name, 
Mts.Fetch_Genotype(m.ID) allele, 
gt.id genotype_dict_id, 
gt.name genotype_name, 
tma.id allele_id, 
tma.official_name_superscript allele_name, 
MTS.fetch_pipelines(m.ID,',') pipeline, 
m.barcode mouse_barcode, 
m.gender_dict_id, 
mg.NAME gender, 
c.ID ID, 
c.width width, 
c.height height, 
c.resized_image_path, 
c.created_date, 
c.edit_date, 
c.full_image_path, 
c.qc_pass qc_pass, 
c.tiled tiled, 
c.comments comments, 
t.NAME tissue_name, 
t.ID tissue_id, 
s.ID scan_id, 
bt.ID source_block_id, 
bt.description source_block_description, 
sl.ID slide_id, 
sl.barcode slide_barcode, 
st.NAME staining, 
st.ID staining_dict_id 
FROM 
HTL_CROP c, 
HTL_TISSUE t, 
HTL_CROP_JOB cj, 
HTL_SCAN s, 
HTL_SLIDE sl, 
HTL_STAINING_TYPE_DICT st, 
HTL_BLOCK b, 
HTL_BLOCK_TYPE bt, 
HTL_FIXATION f, 
HTL_NECROPSY n, 
MTS_MOUSE m, 
MTS_GENDER_DICT mg,
MTS_MOUSE_ALLELE ma, 
MTS_GENOTYPE_DICT gt, 
TYP_MODIFIED_ALLELE tma, 
GNM_GENE g 
WHERE 
c.crop_job_id = cj.ID
AND c.full_image_path is not null
AND c.tissue_id = t.ID(+)
AND cj.scan_id = s.ID
AND s.slide_id = sl.ID
AND sl.staining_type_dict_id = st.ID
AND sl.block_id = b.ID
AND b.block_type_id = bt.ID
AND b.fixation_id = f.ID
AND f.necropsy_id = n.ID
AND n.mouse_id = m.ID
AND m.gender_dict_id = mg.ID
AND ma.mouse_id(+) = m.id 
AND ma.allele_id = tma.id(+)
AND ma.genotype_dict_id = gt.id(+)
AND tma.gene_id = g.id(+);

CREATE OR REPLACE VIEW REP_HISTOLOGY_MOUSE_VW
AS 
SELECT 
m.ID id, 
g.primary_name gene_name, 
gt.id genotype_dict_id, 
gt.name genotype_name, 
tma.id allele_id, 
tma.official_name_superscript allele_name, 
MTS.fetch_pipelines(m.ID,',') pipeline, 
m.barcode mouse_barcode, 
m.gender_dict_id, 
mg.NAME gender,
b.count block_count,
sl.count slide_count,
sc.count scan_count,
crtot.count crop_count_total,
crpass.count crop_count_pass,
crfail.count crop_count_fail,
crawait.count crop_count_await
FROM 
MTS_MOUSE m, 
MTS_GENDER_DICT mg,
MTS_MOUSE_ALLELE ma, 
MTS_GENOTYPE_DICT gt, 
TYP_MODIFIED_ALLELE tma,
GNM_GENE g,
(
select n.mouse_id, count(*) count from htl_block b, htl_fixation f, htl_necropsy n
where
b.fixation_id = f.id
AND f.necropsy_id = n.id
group by
n.mouse_id
) b,
(
select n.mouse_id, count(*) count from htl_slide sl, htl_block b, htl_fixation f, htl_necropsy n
where
sl.block_id = b.id
AND b.fixation_id = f.id
AND f.necropsy_id = n.id
group by
n.mouse_id
) sl,

(
select n.mouse_id, count(*) count from htl_scan sc, htl_slide sl, htl_block b, htl_fixation f, htl_necropsy n
where
sc.slide_id = sl.id
AND sl.block_id = b.id
AND b.fixation_id = f.id
AND f.necropsy_id = n.id
group by
n.mouse_id
) sc,

(
select n.mouse_id, count(*) count from htl_crop cr, htl_crop_job cj, htl_scan sc, htl_slide sl, htl_block b, htl_fixation f, htl_necropsy n
where
cr.crop_job_id = cj.id
AND cj.scan_id = sc.id
AND sc.slide_id = sl.id
AND sl.block_id = b.id
AND b.fixation_id = f.id
AND f.necropsy_id = n.id
group by
n.mouse_id
) crtot,


(
select n.mouse_id, count(*) count from htl_crop cr, htl_crop_job cj, htl_scan sc, htl_slide sl, htl_block b, htl_fixation f, htl_necropsy n
where
cr.qc_pass = 1
AND cr.crop_job_id = cj.id
AND cj.scan_id = sc.id
AND sc.slide_id = sl.id
AND sl.block_id = b.id
AND b.fixation_id = f.id
AND f.necropsy_id = n.id
group by
n.mouse_id
) crpass,

(
select n.mouse_id, count(*) count from htl_crop cr, htl_crop_job cj, htl_scan sc, htl_slide sl, htl_block b, htl_fixation f, htl_necropsy n
where
cr.qc_pass = 0
AND cr.crop_job_id = cj.id
AND cj.scan_id = sc.id
AND sc.slide_id = sl.id
AND sl.block_id = b.id
AND b.fixation_id = f.id
AND f.necropsy_id = n.id
group by
n.mouse_id
) crfail,

(
select n.mouse_id, count(*) count from htl_crop cr, htl_crop_job cj, htl_scan sc, htl_slide sl, htl_block b, htl_fixation f, htl_necropsy n
where
cr.qc_pass is null
AND cr.crop_job_id = cj.id
AND cj.scan_id = sc.id
AND sc.slide_id = sl.id
AND sl.block_id = b.id
AND b.fixation_id = f.id
AND f.necropsy_id = n.id
group by
n.mouse_id
) crawait


WHERE 
m.gender_dict_id = mg.ID
AND ma.mouse_id(+) = m.id 
AND ma.allele_id = tma.id(+)
AND tma.gene_id = g.id(+)
AND ma.genotype_dict_id = gt.id(+)
AND b.mouse_id = m.id
AND sl.mouse_id(+) = m.id
AND sc.mouse_id(+) = m.id
AND crtot.mouse_id(+) = m.id
AND crpass.mouse_id(+) = m.id
AND crfail.mouse_id(+) = m.id
AND crawait.mouse_id(+) = m.id
ORDER BY
crtot.count DESC NULLS LAST;