CREATE TABLE APP_BINARY_FILE_TYPE_DICT
(
  ID           NUMBER,
  NAME         VARCHAR2(256 CHAR),
  ORDER_BY     INTEGER,
  DESCRIPTION  VARCHAR2(2048 CHAR),
  ACTIVE       NUMBER
);

ALTER TABLE APP_BINARY_FILES
 ADD (CONTENT_TYPE_DICT_ID  INTEGER);

CREATE TABLE AUD_FREQ_EXPERIMENT
(
  ID                 INTEGER,
  CREATOR_ID         INTEGER,
  CREATED_DATE       DATE,
  EDITED_BY          VARCHAR2(32 BYTE),
  EDIT_DATE          DATE,
  CHECK_NUMBER       INTEGER,
  PHN_EXPERIMENT_ID  INTEGER,
  FREQUENCE          INTEGER,
  THRESHOLD          INTEGER
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;

ALTER TABLE APP_BINARY_FILE_TYPE_DICT
 ADD CONSTRAINT APP_BINARY_FILE_TYPE_DICT_PK
 PRIMARY KEY
 (ID);


ALTER TABLE APP_BINARY_FILES
 ADD CONSTRAINT APP_BINARY_FILES_R01
 FOREIGN KEY (CONTENT_TYPE_DICT_ID)
 REFERENCES APP_BINARY_FILE_TYPE_DICT (ID);

ALTER TABLE AUD_FREQ_EXPERIMENT
 ADD CONSTRAINT AUD_FEQ_EXPERIMENT_PK
 PRIMARY KEY
 (ID);



CREATE SEQUENCE AUD_FREQ_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;


/* This object may not be sorted properly in the script due to cirular references */
CREATE OR REPLACE FORCE VIEW PHN_ABR_EXPERIMENT_VW
(ID, MOUSE_ID, MOUSE_CHART_ID, MOUSE_CALI_CHART_ID, MOUSE_CLICK_CHART_ID,
 MOUSE_FILE_ID, SIMPLE_GENOTYPE, MOUSE_NAME, ANAESTHETIC, ANAESTHETIC_DOSE,
 ANAESTHETIC_ROUTE, INDUCTION_TIME, EXPERIMENT_DATE, WEIGHT, INCLUDE_EXPERIMENT,
 COMMENTS, USER_COMMENTS, MOUSE_BARCODE, MOUSE_BIRTH_DATE, RFID_TAG,
 MOUSE_GENDER, EAR_CLIP, GENOTYPE, SHORT_ALLELE_SYMBOL, OFFICIAL_NAME_SUPERSCRIPT,
 COLONY_PREFIX, GENE_PRIMARY_NAME, PERSONAL_LICENCE_ID, PIL_NUMBER, USER_ID,
 USER_NAME, PROJECT_LICENCE_ID, PPL_NUMBER, PROTOCOL_CODE, PROCESS_STATUS)
AS
select
e.id id,
e.MOUSE_ID mouse_id,
bmouseC2.ID mouse_chart_id,
bcaliC4.ID mouse_cali_chart_id,
bclickC3.ID mouse_click_chart_id,
bfile1.ID mouse_file_id,
mts.fetch_simple_genotype(e.MOUSE_ID) simple_genotype,
m.NAME mouse_name,
o1.value anaesthetic,
TO_NUMBER(o2.value) anaesthetic_dose,
o3.value anaesthetic_route,
o4.value induction_time,
TO_DATE(o5.value,'dd/mm/yyyy') experiment_date,
TO_NUMBER(o6.value) weight,
TO_NUMBER(o7.value) include_experiment,
o8.value comments,
o9.value user_comments,
m.BARCODE mouse_barcode,
m.BIRTH_DATE mouse_birth_date,
m.RFID_TAG,
gd.NAME mouse_gender,
ed.name ear_clip,
mts.fetch_genotype(e.MOUSE_ID) genotype,
typall.SHORT_ALLELE_SYMBOL,
typall.OFFICIAL_NAME_SUPERSCRIPT,
ci.COLONY_PREFIX,
g.PRIMARY_NAME gene_primary_name,
mp.PERSONAL_LICENCE_ID,
pil.PIL_NUMBER,
pil.PERSON_ID user_id,
p.FIRST_NAME||' '||p.LAST_NAME user_name,
p19b.PROJECT_LICENCE_ID,
ppl.LICENCE_NUMBER PPL_NUMBER,
p19b.PROTOCOL_CODE,
decode(PHN.FETCH_ABR_STATUS(e.id), 1, 'Completed',0,'In Process') process_status
from
PHN_EXPERIMENT e,
MTS_MOUSE m,
MTS_EARMARK_DICT ed,
mts_mouse_allele mall,
TYP_MODIFIED_ALLELE typall,
gnm_gene g,
MTS_COLONY_INFO ci,
MTS_GENDER_DICT gd,
PHN_OBSERVATION o1,
PHN_OBSERVATION o2,
PHN_OBSERVATION o3,
PHN_OBSERVATION o4,
PHN_OBSERVATION o5,
PHN_OBSERVATION o6,
PHN_OBSERVATION o7,
PHN_OBSERVATION o8,
PHN_OBSERVATION o9,
APP_BINARY_FILES bfile1,
APP_BINARY_FILES bmouseC2,
APP_BINARY_FILES bclickC3,
APP_BINARY_FILES bcaliC4,
mts_mouse_procedure mp,
LIC_PERSONAL_LICENCE pil,
LIC_PROTOCOL_19B p19b,
LIC_PROJECT_LICENCE ppl,
per_person p
where e.id = o1.EXPERIMENT_ID(+) and o1.required_observation_id(+)=825
and e.id = o2.EXPERIMENT_ID(+) and o2.required_observation_id(+)=826
and e.id = o3.EXPERIMENT_ID(+) and o3.required_observation_id(+)=827
and e.id = o4.EXPERIMENT_ID(+) and o4.required_observation_id(+)=828
and e.id = o5.EXPERIMENT_ID(+) and o5.required_observation_id(+)=824
and e.id = o6.EXPERIMENT_ID(+) and o6.required_observation_id(+)=823
and e.id = o7.EXPERIMENT_ID(+) and o7.REQUIRED_OBSERVATION_ID(+)=831
and e.id = o8.EXPERIMENT_ID(+) and o8.REQUIRED_OBSERVATION_ID(+)=829
and e.id = o9.EXPERIMENT_ID(+) and o9.REQUIRED_OBSERVATION_ID(+)=830
and e.SOP_ID=149
and e.MOUSE_ID = m.id
and m.EARMARK_DICT_ID=ed.id(+)
and bfile1.FOREIGN_KEY_ID(+)=e.id and bfile1.CONTENT_TYPE_DICT_ID=1
and bmouseC2.FOREIGN_KEY_ID(+)=e.id and bmouseC2.CONTENT_TYPE_DICT_ID=2
and bclickC3.FOREIGN_KEY_ID(+)=e.id and bclickC3.CONTENT_TYPE_DICT_ID=3
and bcaliC4.FOREIGN_KEY_ID(+)=e.id and bcaliC4.CONTENT_TYPE_DICT_ID=4
and m.GENDER_DICT_ID=gd.ID
and e.mouse_id=mall.MOUSE_ID(+) and mall.ALLELE_ID = typall.id(+)
and typall.GENE_ID=g.id(+)
and m.COLONY_INFO_ID =ci.id(+)
and mp.MOUSE_ID=e.MOUSE_ID and mp.PROCEDURE_DICT_ID=25 and mp.FOREIGN_KEY_ID=e.id
and mp.PERSONAL_LICENCE_ID = pil.PERSONAL_LICENCE_ID
and pil.PERSON_ID(+)=p.PERSON_ID
and mp.PROTOCOL_ID=p19b.ID
and p19b.PROJECT_LICENCE_ID = ppl.PROJECT_LICENCE_ID;

CREATE OR REPLACE PACKAGE "PHN" AS
/******************************************************************************
   NAME:       PHN
   PURPOSE:

   REVISIONS:
   Ver        Date        Author           Description
   ---------  ----------  ---------------  ------------------------------------
    V3.0.39       18/04/2008             wl1 Created this package.
******************************************************************************/

PROCEDURE PHN_DELETE_EXPERIMENT_SET (IN_SET_ID number);
FUNCTION FETCH_ABR_STATUS(EXPERIMENT_ID number) RETURN integer;


END PHN;
/

CREATE OR REPLACE PACKAGE BODY "PHN" AS
/******************************************************************************
   PHN_DELETE_EXPERIMENT_SET (IN_SET_ID number)
******************************************************************************/


PROCEDURE PHN_DELETE_EXPERIMENT_SET (IN_SET_ID number) IS

BEGIN

  delete from MTS_MOUSE_PROCEDURE where id in (
    select mp.id from phn_experiment e
    join MTS_MOUSE_PROCEDURE mp on e.ID = mp.FOREIGN_KEY_ID and mp.FOREIGN_TABLE_NAME = 'PHN_EXPERIMENT'
    where e.EXPERIMENT_SET_ID = IN_SET_ID
  );

  delete from PHN_OBSERVATION where id in (
    select o.id from PHN_EXPERIMENT e
    join PHN_OBSERVATION o on e.ID = o.EXPERIMENT_ID
    where e.EXPERIMENT_SET_ID = IN_SET_ID
  );

  delete from PHN_EXPERIMENT where EXPERIMENT_SET_ID = IN_SET_ID;

  delete from PHN_EXPERIMENT_SET where id = IN_SET_ID;

END;

FUNCTION FETCH_ABR_STATUS(EXPERIMENT_ID number) RETURN INTEGER IS

STATUS INTEGER:=0;
CURSOR ABR_CUR IS
   SELECT E.THRESHOLD FROM AUD_FREQ_EXPERIMENT E WHERE E.PHN_EXPERIMENT_ID=EXPERIMENT_ID;
ABR_rec ABR_CUR%ROWTYPE;

BEGIN
OPEN ABR_CUR;

LOOP
	FETCH ABR_CUR INTO ABR_rec;
	EXIT WHEN NOT ABR_CUR%FOUND;
	STATUS :=1;
    IF(ABR_REC.THRESHOLD IS NULL) THEN
    STATUS :=0;EXIT;
    END IF;
END LOOP;

CLOSE ABR_CUR;

RETURN STATUS;
END;

END PHN;
/


