CREATE OR REPLACE VIEW PHN_EXPERIMENT_SET_VIEW as
with
exp_total as (
    select experiment_set_id, count(id) as EXP_COUNT
    from PHN_EXPERIMENT group by experiment_set_id
),
exp_completed as (
    select experiment_set_id, count(id) as COMP_EXP_COUNT
    from PHN_EXPERIMENT where IS_COMPLETE = 1 group by experiment_set_id
),
work_start as (
    select pe.EXPERIMENT_SET_ID, min(mp.START_DATE) as PROCEDURE_DATE
    from MTS_MOUSE_PROCEDURE mp
    join PHN_EXPERIMENT pe on mp.FOREIGN_KEY_ID = pe.ID
    WHERE mp.FOREIGN_TABLE_NAME = 'PHN_EXPERIMENT'
    group by pe.EXPERIMENT_SET_ID
),
obs_count as (
    select e.EXPERIMENT_SET_ID, count(o.id) as obs_count
    from phn_experiment e
    join phn_observation o on e.id = o.EXPERIMENT_ID
    where LENGTH(o.value) > 0
    group by e.EXPERIMENT_SET_ID
),
cname as (select e.experiment_set_id group_key, c.cohort_name val
    from PHN_EXPERIMENT e
    join MTS_COHORT_MOUSE cm on cm.mouse_id = e.mouse_id
    join MTS_COHORT c on cm.cohort_id = c.id
    where c.cohort_type_id = 1 -- phenotyping cohorts
    and e.experiment_set_id is not null
    group by e.experiment_set_id, c.cohort_name
    order by e.experiment_set_id, c.cohort_name),
cnameagg as ( --http://www.sqlsnippets.com/en/topic-11592.html
select tb.group_key as experiment_set_id,  substr( sys_connect_by_path( tb.val, ', ' ) ,2) as cohort_names
from
( select group_key, val , row_number() over (
    partition by group_key
    order by val
  )  as val_index
 from cname
  ) tb
where connect_by_isleaf = 1
connect by
  val_index = prior val_index + 1 and
  group_key = prior group_key
start with val_index = 1
)
select es.id, es.IS_COMPLETE, ca.COHORT_NAMES, sop.NAME as SOP_NAME, es.sop_id, es.PPL_ID, es.PIL_ID, es.CREATOR_ID,
perl.LAST_NAME || ', ' || perl.FIRST_NAME || ' (' || pil.PIL_NUMBER || ')' as PERSONAL_LICENCE,
ppl.LICENCE_NUMBER || ' ' || ppl.TITLE as PROJECT_LICENCE,
per.LAST_NAME || ', ' || per.FIRST_NAME  as CREATOR_NAME,
nvl(et.EXP_COUNT,0) as EXP_COUNT,
nvl(ec.COMP_EXP_COUNT, 0) as COMP_EXP_COUNT,
nvl(ec.COMP_EXP_COUNT, 0) / et.EXP_COUNT as COMPLETION,
es.created_date,
ws.PROCEDURE_DATE,
sop.procedure_id,
oc.obs_count,
es.scheduled_date
from PHN_EXPERIMENT_SET es
join PHN_STD_OPERATING_PROCEDURE sop on es.SOP_ID = sop.ID
join LIC_PERSONAL_LICENCE pil on es.PIL_ID = pil.PERSONAL_LICENCE_ID
join LIC_PROJECT_LICENCE ppl on es.PPL_ID = ppl.PROJECT_LICENCE_ID
join PER_PERSON per on es.CREATOR_ID = per.PERSON_ID
join PER_PERSON perl on pil.PERSON_ID = perl.PERSON_ID
left outer join cnameagg ca on ca.experiment_set_id = es.ID
left outer join work_start ws on ws.EXPERIMENT_SET_ID = es.ID
left outer join obs_count oc on oc.EXPERIMENT_SET_ID = es.id
left outer join exp_total et on es.id = et.experiment_set_id
left outer join exp_completed ec on es.id = ec.experiment_set_id
order by length(ca.cohort_names) desc;