alter table mts_mouse_allele add (is_qc_locked number(1));

create table gtp_well_type_dict
(id integer not null,
 name varchar2(64 char) not null,
 description varchar2(512 char),
 order_by integer,
 active number(1) not null);

alter table gtp_well_type_dict add (
  constraint gtp_well_type_dict_pk primary key(id) using index tablespace index_02
);

create table gtp_assay_type_dict
(id integer not null,
 name varchar2(64 char) not null,
 description varchar2(512 char),
 order_by integer,
 active number(1) not null,
 scope varchar2(8 char) not null);

alter table gtp_assay_type_dict add (
  constraint gtp_assay_type_dict_pk primary key(id) using index tablespace index_02
);

create table gtp_assay_result_dict
(id integer not null,
 name varchar2(64 char) not null,
 description varchar2(512 char),
 order_by integer,
 active number(1) not null);

alter table gtp_assay_result_dict add (
  constraint gtp_assay_result_dict_pk primary key(id) using index tablespace index_02
);

create table gtp_assay_plate
(id integer not null,
 cohort_id integer,
 sheet_barcode varchar2(64 char),
 plate_barcode varchar2(64 char),
 is_auto_populated number(1) not null,
 creator_id integer not null,
 created_date date not null,
 edited_by varchar2(32 char) not null,
 edit_date date not null,
 check_number integer,
 rows_on_plate integer,
 columns_on_plate integer)
tablespace data_02;

alter table gtp_assay_plate add (
  constraint gtp_assay_plate_pk primary key(id) using index tablespace index_02,
  constraint gtp_assay_plate_r01 foreign key (creator_id) references per_person (person_id),
  constraint gtp_assay_plate_r02 foreign key (cohort_id) references mts_cohort (id)
);

create index gtp_assay_plate_ind01 on gtp_assay_plate(creator_id) logging tablespace index_02;

create index gtp_assay_plate_ind02 on gtp_assay_plate(cohort_id) logging tablespace index_02;

create index gtp_assay_plate_ind03 on gtp_assay_plate(plate_barcode) logging tablespace index_02;

create index gtp_assay_plate_ind04 on gtp_assay_plate(sheet_barcode) logging tablespace index_02;

create table gtp_assay_plate_well
(id integer not null,
 assay_plate_id integer not null,
 mouse_id integer,
 plate_row integer not null,
 plate_column integer not null,
 well_type_dict_id integer not null,
 earmark_dict_id integer,
 is_locked number(1) not null,
 is_sample_collected number(1),
 creator_id integer not null,
 created_date date not null,
 edited_by varchar2(32 char) not null,
 edit_date date not null,
 check_number integer)
tablespace data_02;

alter table gtp_assay_plate_well add (
  constraint gtp_assay_plate_well_pk primary key(id) using index tablespace index_02,
  constraint gtp_assay_plate_well_r01 foreign key (creator_id) references per_person (person_id),
  constraint gtp_assay_plate_well_r02 foreign key (assay_plate_id) references gtp_assay_plate (id),
  constraint gtp_assay_plate_well_r03 foreign key (mouse_id) references mts_mouse (id),
  constraint gtp_assay_plate_well_r04 foreign key (earmark_dict_id) references mts_earmark_dict(id),
  constraint gtp_assay_plate_well_r05 foreign key (well_type_dict_id) references gtp_well_type_dict (id)
);

create index gtp_assay_plate_well_ind01 on gtp_assay_plate_well(creator_id) logging tablespace index_02;

create index gtp_assay_plate_well_ind02 on gtp_assay_plate_well(assay_plate_id) logging tablespace index_02;

create index gtp_assay_plate_well_ind03 on gtp_assay_plate_well(mouse_id) logging tablespace index_02;

create index gtp_assay_plate_well_ind04 on gtp_assay_plate_well(earmark_dict_id) logging tablespace index_02;

create index gtp_assay_plate_well_ind05 on gtp_assay_plate_well(well_type_dict_id) logging tablespace index_02;

create table gtp_assay
(id integer not null,
 assay_type_dict_id integer not null,
 assay_date date not null,
 allele_id integer,
 assay_plate_id integer not null,
 creator_id integer not null,
 created_date date not null,
 edited_by varchar2(32 char) not null,
 edit_date date not null,
 check_number integer,
 comments varchar2(4000 char))
tablespace data_02;

alter table gtp_assay add (
  constraint gtp_assay_pk primary key(id) using index tablespace index_02,
  constraint gtp_assay_r01 foreign key (creator_id) references per_person (person_id),
  constraint gtp_assay_r02 foreign key (assay_type_dict_id) references gtp_assay_type_dict (id),
  constraint gtp_assay_r03 foreign key (allele_id) references typ_modified_allele(id),
  constraint gtp_assay_r04 foreign key (assay_plate_id) references gtp_assay_plate(id)
);

create index gtp_assay_ind01 on gtp_assay(creator_id) logging tablespace index_02;

create index gtp_assay_ind02 on gtp_assay(assay_type_dict_id) logging tablespace index_02;

create index gtp_assay_ind03 on gtp_assay(allele_id) logging tablespace index_02;

create index gtp_assay_ind04 on gtp_assay(assay_plate_id) logging tablespace index_02;

create table gtp_assay_result
(id integer not null,
 assay_result_dict_id integer not null,
 assay_id integer not null,
 assay_plate_well_id integer not null,
 creator_id integer not null,
 created_date date not null,
 edited_by varchar2(32 char) not null,
 edit_date date not null,
 check_number integer,
 comments varchar2(4000 char))
tablespace data_02;

alter table gtp_assay_result add (
  constraint gtp_assay_result_pk primary key(id) using index tablespace index_02,
  constraint gtp_assay_result_r01 foreign key (creator_id) references per_person (person_id),
  constraint gtp_assay_result_r02 foreign key (assay_result_dict_id) references gtp_assay_result_dict (id),
  constraint gtp_assay_result_r03 foreign key (assay_id) references gtp_assay(id),
  constraint gtp_assay_result_r04 foreign key (assay_plate_well_id) references gtp_assay_plate_well(id)
);

create index gtp_assay_result_ind01 on gtp_assay_result(creator_id) logging tablespace index_02;

create index gtp_assay_result_ind02 on gtp_assay_result(assay_result_dict_id) logging tablespace index_02;

create index gtp_assay_result_ind03 on gtp_assay_result(assay_id) logging tablespace index_02;

create index gtp_assay_result_ind04 on gtp_assay_result(assay_plate_well_id) logging tablespace index_02;

create table mts_geno_history_source_dict
(id integer not null,
 name varchar2(64 char) not null,
 description varchar2(512 char),
 order_by integer,
 active number(1) not null);

alter table mts_geno_history_source_dict add (
  constraint mts_geno_hist_source_dict_pk primary key(id) using index tablespace index_02
);

create table mts_genotype_history
(id integer not null,
 mouse_allele_id integer not null,
 assignment_date date not null,
 genotype_dict_id integer not null,
 creator_id integer not null,
 created_date date not null,
 edited_by varchar2(32 char) not null,
 edit_date date not null,
 check_number integer,
 source_dict_id integer)
tablespace data_02;

alter table mts_genotype_history add (
  constraint mts_genotype_history_pk primary key(id) using index tablespace index_02,
  constraint mts_genotype_history_r01 foreign key (creator_id) references per_person (person_id),
  constraint mts_genotype_history_r02 foreign key (mouse_allele_id) references mts_mouse_allele (id),
  constraint mts_genotype_history_r03 foreign key (genotype_dict_id) references mts_genotype_dict(id),
  constraint mts_geno_hist_source_r04 foreign key (source_dict_id) references mts_geno_history_source_dict (id)
);

create index mts_genotype_history_ind01 on mts_genotype_history(creator_id) logging tablespace index_02;

create index mts_genotype_history_ind02 on mts_genotype_history(mouse_allele_id) logging tablespace index_02;

create index mts_genotype_history_ind03 on mts_genotype_history(genotype_dict_id) logging tablespace index_02;

create sequence gtp_assay_seq
  start with 1
  minvalue 1
  nocycle
  nocache
  noorder;

create sequence gtp_assay_plate_seq
  start with 1
  minvalue 1
  nocycle
  nocache
  noorder;

create sequence gtp_assay_plate_well_seq
  start with 1
  minvalue 1
  nocycle
  nocache
  noorder;

create sequence gtp_assay_result_seq
  start with 1
  minvalue 1
  nocycle
  nocache
  noorder;

create sequence mts_genotype_history_seq
  start with 1
  minvalue 1
  nocycle
  nocache
  noorder;

create index mts_litter_fn1 on mts_litter( name_prefix || litter_number) tablespace index_02;


CREATE OR REPLACE function mts_fetch_genotype (in_mouse_id number) return varchar2 is

cursor c_alleles is
select
  m.genotype_dict_id,
  nvl(a.short_allele_symbol,'ERROR') short_allele_symbol,
  a.inheritance_mode_id,
  c.percent_chimeric
from
  mts_mouse_allele m,
  typ_modified_allele a,
  mts_chimeric_mouse_data c
where
  m.mouse_id = in_mouse_id and
  m.allele_id = a.id and
  m.mouse_id = c.mouse_id(+);

v_genotype varchar2(4000) := '';

chromosome1 typ_modified_allele.short_allele_symbol%type;
chromosome2 typ_modified_allele.short_allele_symbol%type;
is_exception integer(1);
genotype_string varchar2(32);

begin

  for a in c_alleles loop

    chromosome1 := '+';
    chromosome2 := '+';
    is_exception := 0;
    genotype_string := '';

    if a.genotype_dict_id = 2 then --heterozygous
      chromosome1 := a.short_allele_symbol;
    elsif a.genotype_dict_id = 3 then --homozygous
      chromosome1 := a.short_allele_symbol;
      chromosome2 := a.short_allele_symbol;
    elsif a.genotype_dict_id = 6 then --hemizygous
      chromosome1 := a.short_allele_symbol;
      chromosome2 := 'Y';
    elsif a.genotype_dict_id = 4 then --untested
      is_exception := 1;
      genotype_string := 'untested';
    elsif a.genotype_dict_id = 5 then --failed
      is_exception := 1;
      genotype_string := 'failed';
    elsif a.genotype_dict_id = 10 then --chimera
      is_exception := 1;
      genotype_string := 'chimera';
    elsif a.genotype_dict_id = 7 then --conditional het
      is_exception := 1;
      genotype_string := 'c/+';
    elsif a.genotype_dict_id = 7 then --conditional hom
      is_exception := 1;
      genotype_string := 'c/-';
    elsif a.genotype_dict_id = 7 then --conditional
      is_exception := 1;
      genotype_string := 'c/c';
    end if;

    if is_exception = 1 then
      genotype_string := a.short_allele_symbol||':'||genotype_string;
    else
      if a.inheritance_mode_id = 2 then --recessive allele
        genotype_string := chromosome2||'/'||chromosome1;
      else
        genotype_string := chromosome1||'/'||chromosome2;
      end if;
    end if;
    v_genotype := v_genotype||genotype_string||' ';
  end loop;

  return trim(nvl(v_genotype,'+/+'));

end mts_fetch_genotype;
/

create or replace view mts_latest_mouse_cage_vw as
select
  mouse_id,
  cage_id
from
  mts_mouse_cage_history
where
  (mouse_id,id) in (
    select mouse_id,max(id)
    from mts_mouse_cage_history
    group by mouse_id
  )
/

CREATE OR REPLACE FORCE VIEW GTP_ALL_PLATES_VW
AS
SELECT   p.ID, p.created_date, p.sheet_barcode, p.plate_barcode,
            DECODE (p.plate_barcode, NULL, 0, 1) plate_barcode_exists,
            c.ID cohort_id, c.cohort_name,
            rowtocol
               (   'select distinct c.room_name from mts_cage_vw c,mts_latest_mouse_cage_vw m,gtp_assay_plate_well w where c.cage_id = m.cage_id and m.mouse_id = w.mouse_id and w.assay_plate_id ='
                || p.ID
                || ' order by c.room_name'
               ) room_list,
            COUNT (m.ID) mouse_count,
            COUNT (DISTINCT DECODE (w.earmark_dict_id,
                                    NULL, NULL,
                                    1, NULL,
                                    w.ID
                                   )
                  ) earclip_count,
            rowtocol
               (   'select distinct r.corridor from mts_room r, mts_cage_vw c,mts_latest_mouse_cage_vw m,gtp_assay_plate_well w where c.cage_id = m.cage_id and c.room_id = r.id and m.mouse_id = w.mouse_id and w.assay_plate_id ='
                || p.ID
                || ' order by r.corridor'
               ) suite
       FROM gtp_assay_plate p,
            mts_cohort c,
            gtp_assay_plate_well w,
            mts_mouse m,
            mts_cage_vw l,
            mts_latest_mouse_cage_vw ca
      WHERE c.ID = p.cohort_id
        AND p.ID = w.assay_plate_id
        AND m.ID = w.mouse_id
        AND m.ID = ca.mouse_id
        AND ca.cage_id = l.cage_id
   GROUP BY p.ID,
            p.created_date,
            p.sheet_barcode,
            p.plate_barcode,
            c.ID,
            c.cohort_name
   ORDER BY p.created_date DESC;

CREATE OR REPLACE FORCE VIEW GTP_ASSAY_RESULTS_VW
AS
select
  w.mouse_id,
  w.id as assay_plate_well_id,
  p.sheet_barcode,
  p.plate_barcode,
  w.plate_row,
  w.plate_column,
  at.name assay_type,
  at.scope,
  a.id assay_id,
  a.allele_id,
  rd.name assay_result,
  r.created_date result_date,
  a.created_date assay_date,
  r.comments||decode(a.comments,null,null,'.'||a.comments) assay_result_comments
from
  gtp_assay_plate_well w
  join gtp_assay_result r on w.id = r.assay_plate_well_id
  join gtp_assay_result_dict rd on r.assay_result_dict_id = rd.id
  join gtp_assay a on a.id = r.assay_id
  join gtp_assay_plate p on w.assay_plate_id = p.id
  join gtp_assay_type_dict at on a.assay_type_dict_id = at.id;


CREATE OR REPLACE FORCE VIEW GTP_ASSAY_RESULT_SUMMARY_VW
AS
select
  p.id plate_id,
  decode (a.allele_id,
    null, 'N/A',
    nvl (g.primary_name, '(no gene)')|| '<'||nvl (t.official_name_superscript, 'unknown')|| '>') allele,
  ad.name assay,
  a.assay_date,
  count (rd.name) assay_result_count
from
  gtp_assay_plate p,
  gtp_assay_plate_well w,
  mts_mouse m,
  mts_mouse_allele ma,
  typ_modified_allele t,
  gnm_gene g,
  gtp_assay_result r,
  gtp_assay_result_dict rd,
  gtp_assay a,
  gtp_assay_type_dict ad
where
  p.id = w.assay_plate_id
  and w.mouse_id = m.id
  and m.id = ma.mouse_id(+)
  and ma.allele_id = t.id
  and t.gene_id = g.id(+)
  and w.id = r.assay_plate_well_id
  and rd.id = r.assay_result_dict_id
  and r.assay_id = a.id
  and ad.id = a.assay_type_dict_id
group by p.id,
decode
  (a.allele_id,
    null, 'N/A',
    nvl (g.primary_name,'(no gene)')|| '<'|| nvl (t.official_name_superscript, 'unknown')||'>'),
   ad.name,
   a.assay_date
order by allele, assay;


CREATE OR REPLACE FORCE VIEW GTP_GENOTYPE_HISTORY_TODAY_VW
AS
select
  w.assay_plate_id,
  t.id allele_id,
  nvl(g.primary_name, '(no gene)')|| '<'||nvl (t.official_name_superscript, 'unknown')|| '>' allele,
  count(distinct w.id) total_samples,
  count(distinct decode(trunc(h.assignment_date), trunc(sysdate), w.id, null)) todays_samples
from
  typ_modified_allele t,
  gnm_gene g,
  mts_mouse_allele a,
  gtp_assay_plate_well w,
  mts_genotype_history h
where
  t.gene_id = g.id(+) and
  a.allele_id = t.id and
  a.mouse_id = w.mouse_id and
  h.mouse_allele_id(+) = a.id and
  h.source_dict_id(+) = 1
group by
  w.assay_plate_id,
  t.id,
  nvl(g.primary_name, '(no gene)')|| '<'||nvl (t.official_name_superscript, 'unknown')|| '>';


CREATE OR REPLACE FORCE VIEW GTP_GENOTYPE_LIST_VW
AS
select
  c.id,
  c.cohort_name,
  c.created_date,
  count(distinct cm.id) num_mice,
  count(distinct ma.allele_id) num_alleles,
  count(distinct ap.id) num_assay_plates,
  p.first_name||' '||p.last_name creator,
  rowtocol('select distinct id from gtp_assay_plate where cohort_id='||c.id,',') plate_ids
from
  mts_cohort c,
  mts_cohort_mouse cm,
  mts_mouse_allele ma,
  per_person p,
  gtp_assay_plate ap
where
  c.id = cm.cohort_id(+) and
  cm.mouse_id = ma.mouse_id(+) and
  c.creator_id = p.person_id and
  c.id = ap.cohort_id(+) and
  c.cohort_type_id = 4
group by
  c.id,
  c.cohort_name,
  c.created_date,
  p.first_name || ' ' || p.last_name
order by c.created_date desc;

alter table app_custom_query_column add (conditional  varchar2(32 char));

alter table app_custom_query_column add (conditional_value  varchar2(32 char));

alter table app_custom_query_column add (query_param  varchar2(512 byte));

alter table app_custom_query_column add (col_attr  varchar2(32 char));

alter table app_custom_query_column add (col_attr_value  varchar2(512 char));

create table app_custom_query_action
(
  id                 integer                    not null,
  custom_query_id    integer,
  action_title       varchar2(32 char),
  action_url         varchar2(4000 char),
  action_param       varchar2(512 char),
  order_by           integer,
  permitted_roles    varchar2(512 char),
  href_target        varchar2(64 char),
  conditional        varchar2(32 char),
  query_param        varchar2(512 char),
  conditional_value  varchar2(32 char)
);

alter table app_custom_query_action add constraint app_custom_query_action_pk primary key (id) using index tablespace index_02;

alter table app_custom_query_action add constraint app_custom_query_action_fk1 foreign key (custom_query_id) references app_custom_query (id);

create sequence app_custom_query_act_seq
  start with 1
  maxvalue 9999999999
  minvalue 1
  nocycle
  nocache
  noorder;

CREATE OR REPLACE PROCEDURE app_sync_custom_query(in_unique_name varchar2, origin_dblink varchar2) IS

type ref_cursor is ref cursor;
c_ref_cursor ref_cursor;

r_custom_query app_custom_query%rowtype;

r_custom_query_column app_custom_query_column%rowtype;

r_custom_query_rset_action app_custom_query_rset_action%rowtype;

r_custom_query_action app_custom_query_action%rowtype;

n_new_id number;


BEGIN

   execute immediate 'select * from app_custom_query@'||origin_dblink||' where unique_name = :1'
   into r_custom_query using in_unique_name;

   select app_custom_query_seq.nextval into n_new_id from dual ;

   insert into app_custom_query
    (id,
    query_title,
    query_view_name,
    description,
    system_query,
    category,
    start_with_filter,
    selectable_records,
    unique_name)
   values
    (n_new_id,
    r_custom_query.query_title,
    r_custom_query.query_view_name,
    r_custom_query.description,
    r_custom_query.system_query,
    r_custom_query.category,
    r_custom_query.start_with_filter,
    r_custom_query.selectable_records,
    r_custom_query.unique_name
    );

    open c_ref_cursor for 'select * from app_custom_query_column@'||origin_dblink||' where custom_query_id = '||r_custom_query.id;
        loop
            fetch c_ref_cursor into r_custom_query_column;
            exit when c_ref_cursor%NOTFOUND;
            insert into app_custom_query_column
            (id,
            custom_query_id,
            column_name,
            column_title,
            datatype,
            order_by,
            datatype_format,
            datatype_format_2,
            actual_query_column,
            list_query,
            is_display_column,
            is_filter_column,
            conditional,
            conditional_value,
            query_param,
            col_attr,
            col_attr_value)
            values (
            app_custom_query_col_seq.nextval,
            n_new_id,
            r_custom_query_column.column_name,
            r_custom_query_column.column_title,
            r_custom_query_column.datatype,
            r_custom_query_column.order_by,
            r_custom_query_column.datatype_format,
            r_custom_query_column.datatype_format_2,
            r_custom_query_column.actual_query_column,
            r_custom_query_column.list_query,
            r_custom_query_column.is_display_column,
            r_custom_query_column.is_filter_column,
            r_custom_query_column.conditional,
            r_custom_query_column.conditional_value,
            r_custom_query_column.query_param,
            r_custom_query_column.col_attr,
            r_custom_query_column.col_attr_value
            );
        end loop;
    close c_ref_cursor;

    open c_ref_cursor for 'select * from app_custom_query_rset_action@'||origin_dblink||' where custom_query_id = '||r_custom_query.id;
        loop
            fetch c_ref_cursor into r_custom_query_rset_action;
            exit when c_ref_cursor%NOTFOUND;
            insert into app_custom_query_rset_action
            (id,
            custom_query_id,
            action_title,
            action_url,
            order_by,
            permitted_roles)
            values (
            app_custom_query_col_seq.nextval,
            n_new_id,
            r_custom_query_rset_action.action_title,
            r_custom_query_rset_action.action_url,
            r_custom_query_rset_action.order_by,
            r_custom_query_rset_action.permitted_roles
            );
        end loop;
    close c_ref_cursor;


    open c_ref_cursor for 'select * from app_custom_query_action@'||origin_dblink||' where custom_query_id = '||r_custom_query.id;
        loop
            fetch c_ref_cursor into r_custom_query_action;
            exit when c_ref_cursor%NOTFOUND;
            insert into app_custom_query_action
            (id,
            custom_query_id,
            action_title,
            action_url,
            action_param,
            order_by,
            permitted_roles,
            href_target,
            conditional,
            query_param,
            conditional_value)
            values (
            app_custom_query_col_seq.nextval,
            n_new_id,
            r_custom_query_action.action_title,
            r_custom_query_action.action_url,
            r_custom_query_action.action_param,
            r_custom_query_action.order_by,
            r_custom_query_action.permitted_roles,
            r_custom_query_action.href_target,
            r_custom_query_action.conditional,
            r_custom_query_action.query_param,
            r_custom_query_action.conditional_value
            );
        end loop;
    close c_ref_cursor;

END app_sync_custom_query;
/

CREATE OR REPLACE FORCE VIEW APP_CUSTOM_QUERY_COL_PREF_VW
AS
SELECT c.ID, c.custom_query_id, c.column_name, c.column_title, c.datatype,
          c.datatype_format, c.datatype_format_2, c.is_display_column,
          c.is_filter_column, c.list_query, c.actual_query_column, p.order_by,
          p.person_id, c.conditional, c.conditional_value, c.query_param, c.col_attr, c.col_attr_value
     FROM app_custom_query_person_pref p, app_custom_query_column c
    WHERE c.ID = p.query_column_id
   UNION
   SELECT c.ID, c.custom_query_id, c.column_name, c.column_title, c.datatype,
          c.datatype_format, c.datatype_format_2, c.is_display_column,
          c.is_filter_column, c.list_query, c.actual_query_column, c.order_by,
          p.person_id, c.conditional, c.conditional_value, c.query_param, c.col_attr, c.col_attr_value
     FROM per_person p, app_custom_query_column c
    WHERE NOT EXISTS (
             SELECT NULL
               FROM app_custom_query_person_pref x, app_custom_query_column y
              WHERE x.person_id = p.person_id
                AND x.query_column_id = y.ID
                AND y.custom_query_id = c.custom_query_id);

create or replace view mts_first_and_final_genotype as
with final_genotype as (
  select
    a.mouse_id,
    a.id mouse_allele_id,
    a.genotype_dict_id
  from
    mts_mouse_allele a
  where
    a.is_qc_locked = 1
),
first_genotype_assignment as (
  select
    h.mouse_allele_id,
    min(h.assignment_date) assignment_date
  from
    mts_genotype_history h,
    mts_genotype_dict d
  where
    d.id = h.genotype_dict_id and
    d.description not in ('?','FAIL')
  group by
    h.mouse_allele_id
)
select
  f.mouse_id,
  f.mouse_allele_id,
  h.genotype_dict_id first_genotype,
  f.genotype_dict_id final_genotype
from
  final_genotype f,
  first_genotype_assignment a,
  mts_genotype_history h
where
  a.mouse_allele_id = h.mouse_allele_id and
  a.assignment_date = h.assignment_date and
  a.mouse_allele_id = f.mouse_allele_id and
  h.genotype_dict_id != f.genotype_dict_id;

CREATE OR REPLACE FORCE VIEW REP_PHENOTYPING_PIPELINE_COUNT AS
with changed_genotype as (
  select distinct mouse_id
  from mts_first_and_final_genotype
  where first_genotype != final_genotype
)
select
  ((p.id * 10e9) + i.id) id,
  p.id pipeline_id,
  p.name pipeline,
  i.colony_prefix,
  max(t.short_allele_symbol) genotype_symbol,
  count(m.id) total_mice,
  count(decode(m.gender_dict_id,2,decode(a.genotype_dict_id,null,1,null),null)) wt_male,
  count(decode(m.gender_dict_id,2,decode(a.genotype_dict_id,2,1,null),null)) het_male,
  count(decode(m.gender_dict_id,2,decode(a.genotype_dict_id,3,1,null),null)) hom_male,
  count(decode(m.gender_dict_id,2,decode(a.genotype_dict_id,4,1,null),null)) unknown_male,
  count(decode(m.gender_dict_id,1,decode(a.genotype_dict_id,null,1,null),null)) wt_female,
  count(decode(m.gender_dict_id,1,decode(a.genotype_dict_id,2,1,null),null)) het_female,
  count(decode(m.gender_dict_id,1,decode(a.genotype_dict_id,3,1,null),null)) hom_female,
  count(decode(m.gender_dict_id,1,decode(a.genotype_dict_id,4,1,null),null)) unknown_female,
  count(distinct g.mouse_id) changed_genotypes,
  count(distinct decode(a.is_qc_locked,1,a.mouse_id,null)) final_genotypes
from
  mts_mouse m,
  mts_colony_info i,
  mts_cohort_mouse cm,
  mts_cohort c,
  mts_cohort_pipeline_dict p,
  mts_mouse_allele a,
  typ_modified_allele t,
  changed_genotype g
where
  m.id = cm.mouse_id and
  m.id = a.mouse_id(+) and
  cm.cohort_id = c.id and
  c.pipeline_dict_id = p.id and
  i.id = m.colony_info_id and
  a.allele_id = t.id(+) and
  m.id = g.mouse_id(+)
group by
  ((p.id * 10e9) + i.id),
  p.id,
  p.name,
  i.colony_prefix
order by
  p.name,
  i.colony_prefix;

CREATE OR REPLACE FORCE VIEW REP_GENOTYPE_HISTORY_VW
AS
select
  h.id,
  m.name mouse_name,
  i.colony_prefix,
  i.colony_name,
  m.birth_date,
  m.death_date,
  t.short_allele_symbol,
  d2.name latest_genotype,
  d2.id latest_genotype_dict_id,
  a.is_qc_locked,
  decode(a.is_qc_locked,1,'Yes','No') genotype_locked,
  h.assignment_date,
  d1.name assigned_genotype,
  d1.id assigned_genotype_dict_id,
  h.edited_by assigned_by
from
  mts_genotype_history h,
  mts_geno_history_source_dict s,
  mts_genotype_dict d1,
  mts_genotype_dict d2,
  mts_mouse_allele a,
  typ_modified_allele t,
  mts_mouse m,
  mts_colony_info i
where
  h.mouse_allele_id = a.id and
  a.mouse_id = m.id and
  m.colony_info_id = i.id and
  h.source_dict_id = s.id and
  h.genotype_dict_id = d1.id and
  a.genotype_dict_id = d2.id and
  a.allele_id = t.id
order by m.name, h.assignment_date;

create or replace view rep_ungenotyped_pups as
select
  m.id,
  m.name mouse_name,
  m.gender_dict_id,
  g.name gender,
  m.birth_date,
  m.death_date,
  m.earmark_dict_id,
  e.name earclip,
  c.room_id,
  c.room_name,
  i.colony_prefix,
  i.colony_name
from
  mts_mouse m,
  mts_latest_mouse_cage_vw l,
  mts_cage_vw c,
  mts_colony_info i,
  mts_gender_dict g,
  mts_earmark_dict e
where
  c.cage_id = l.cage_id and
  m.id = l.mouse_id and
  i.id = m.colony_info_id and
  g.id = m.gender_dict_id and
  e.id(+) = m.earmark_dict_id and
  m.birth_date between sysdate - 28 and sysdate - 10 and
  exists (select null from mts_mouse_allele a where a.mouse_id = m.id) and
  not exists (select null
              from mts_cohort_mouse cm, mts_cohort co
              where cm.cohort_id = co.id and co.cohort_type_id = 4 and cm.mouse_id = m.id);

CREATE OR REPLACE FORCE VIEW MTS_LITTER_LIST_VW
AS
select
  l.id,
  b.id breeding_id,
  b.name_prefix breeding_name_prefix,
  b.breeding_number,
  l.litter_number,
  l.name_prefix||l.litter_number litter_name,
  b.offspring_colony_id,
  male.id father_id,
  male.name father_name,
  female.id mother_id,
  female.name mother_name,
  et.micro_injection_request_id,
  l.plug_check_date plug_date,
  l.birth_date,
  min(pups.wean_date) wean_date,
  l.not_pregnant,
  count(pups.id) number_pups,
  l.number_born number_born,
  decode(l.number_born,null,null,count(decode(pups.gender_dict_id,1,1,null))) number_born_female,
  decode(l.number_born,null,null,count(decode(pups.gender_dict_id,2,1,null))) number_born_male,
  decode(l.number_born,null,null,count(decode(pups.wean_date,null,null,1))) number_weaned,
  decode(l.number_born,null,null,count(decode(pups.gender_dict_id,1,(decode(pups.wean_date,null,null,1)),null))) number_weaned_female,
  decode(l.number_born,null,null,count(decode(pups.gender_dict_id,2,(decode(pups.wean_date,null,null,1)),null))) number_weaned_male,
  l.number_harvested number_embryos,
  decode(l.number_born||l.number_harvested,null,null,count(decode(pups.wean_date,null,(decode(pups.death_date,null,null,1)),null))) number_used,
  l.comments
from
  mts_litter l,
  mts_breeding b,
  mts_mouse male,
  mts_mouse female,
  mts_mouse pups,
  (select et.id,smi.micro_injection_request_id
   from
     mir_embryo_transfer_procedure et,
  mir_scheduled_micro_injection smi
   where
     et.scheduled_micro_injection_id = smi.id) et
where
  l.breeding_id = b.id and
  b.male_id = male.id and
  b.female_id = female.id and
  pups.litter_id(+) = l.id and
  b.embryo_transfer_id = et.id(+)
group by
  l.id,
  b.id,
  b.name_prefix,
  b.breeding_number,
  l.litter_number,
  l.name_prefix||l.litter_number,
  b.offspring_colony_id,
  male.id,
  male.name,
  female.id,
  female.name,
  et.micro_injection_request_id,
  l.plug_check_date,
  l.birth_date,
  l.not_pregnant,
  l.number_born,
  l.number_harvested,
  l.comments;

