CREATE OR REPLACE FUNCTION ROWTOCOL ( p_slct in varchar2, p_dlmtr in varchar2 default ',' ) return varchar2 authid current_user as

type c_refcur is ref cursor;

lc_str varchar2(4000);

lc_colval varchar2(4000);

c_dummy c_refcur;

length_exceeded number;


begin

  open c_dummy for p_slct;

  length_exceeded := 0;

  loop
    fetch c_dummy into lc_colval;
    exit when c_dummy%notfound or length_exceeded = 1;

    if length(lc_str || p_dlmtr || lc_colval) <= 4000 then
      lc_str := lc_str || p_dlmtr || lc_colval;
    else
      length_exceeded := 1;
      lc_str := substr(lc_str,1,4000-3)||'...';
    end if;

  end loop;

  close c_dummy;
  return substr(lc_str,2);

exception
  when others then
    lc_str := sqlerrm;
    if c_dummy%isopen then
      close c_dummy;
    end if;

  return lc_str;
end;
/

alter table gtp_assay_plate add plate_category_dict_id integer;

alter table gtp_assay_plate add sample_type_dict_id integer;

alter table gtp_assay_plate add is_post_mortem number(1);

alter table mts_procedure_dict add is_allowable_postmortem number(1);

CREATE TABLE GTP_SAMPLE_TYPE_DICT
(
  ID           INTEGER,
  NAME         VARCHAR2(64 CHAR),
  DESCRIPTION  VARCHAR2(512 CHAR),
  ORDER_BY     INTEGER,
  ACTIVE       NUMBER(1)
)
TABLESPACE DATA_02
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE UNIQUE INDEX GTP_SAMPLE_TYPE_DICT_PK ON GTP_SAMPLE_TYPE_DICT
(ID)
LOGGING
TABLESPACE INDEX_02
NOPARALLEL;


ALTER TABLE GTP_SAMPLE_TYPE_DICT ADD (
  CONSTRAINT GTP_SAMPLE_TYPE_DICT_PK
 PRIMARY KEY
 (ID)
    USING INDEX
    TABLESPACE INDEX_02);

CREATE TABLE GTP_ASSAY_PLATE_CATEGORY
(
  ID           NUMBER                           NOT NULL,
  NAME         VARCHAR2(256 CHAR)               NOT NULL,
  ORDER_BY     INTEGER,
  DESCRIPTION  VARCHAR2(2048 CHAR),
  ACTIVE       NUMBER(1)                        NOT NULL
)
TABLESPACE DATA_02
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE UNIQUE INDEX GTP_ASSAY_PLATE_CATEGORY_PK ON GTP_ASSAY_PLATE_CATEGORY
(ID)
LOGGING
TABLESPACE INDEX_02
NOPARALLEL;


ALTER TABLE GTP_ASSAY_PLATE_CATEGORY ADD (
  CONSTRAINT GTP_ASSAY_PLATE_CATEGORY_PK
 PRIMARY KEY
 (ID)
    USING INDEX
    TABLESPACE INDEX_02);


CREATE OR REPLACE function mts_fetch_genotype (in_mouse_id number) return varchar2 is

cursor c_alleles is
select
  m.genotype_dict_id,
  nvl(a.short_allele_symbol,'ERROR') short_allele_symbol,
  a.inheritance_mode_id,
  c.percent_chimeric
from
  mts_mouse_allele m,
  typ_modified_allele a,
  mts_chimeric_mouse_data c
where
  m.mouse_id = in_mouse_id and
  m.allele_id = a.id and
  m.mouse_id = c.mouse_id(+);

v_genotype varchar2(4000) := '';

chromosome1 typ_modified_allele.short_allele_symbol%type;
chromosome2 typ_modified_allele.short_allele_symbol%type;
is_exception integer(1);
genotype_string varchar2(32);

begin

  for a in c_alleles loop

    chromosome1 := '+';
    chromosome2 := '+';
    is_exception := 0;
    genotype_string := '';

    if a.genotype_dict_id = 2 then --heterozygous
      chromosome1 := a.short_allele_symbol;
    elsif a.genotype_dict_id = 3 then --homozygous
      chromosome1 := a.short_allele_symbol;
      chromosome2 := a.short_allele_symbol;
    elsif a.genotype_dict_id = 6 then --hemizygous
      chromosome1 := a.short_allele_symbol;
      chromosome2 := 'Y';
    elsif a.genotype_dict_id = 4 then --untested
      is_exception := 1;
      genotype_string := 'untested';
    elsif a.genotype_dict_id = 5 then --failed
      is_exception := 1;
      genotype_string := 'failed';
    elsif a.genotype_dict_id = 10 then --chimera
      is_exception := 1;
      genotype_string := 'chimera';
      if a.percent_chimeric is not null then
        genotype_string := genotype_string||' '||a.percent_chimeric||'%';
      end if;
    elsif a.genotype_dict_id = 7 then --conditional het
      is_exception := 1;
      genotype_string := 'c/+';
    elsif a.genotype_dict_id = 7 then --conditional hom
      is_exception := 1;
      genotype_string := 'c/-';
    elsif a.genotype_dict_id = 7 then --conditional
      is_exception := 1;
      genotype_string := 'c/c';
    end if;

    if is_exception = 1 then
      genotype_string := a.short_allele_symbol||':'||genotype_string;
    else
      if a.inheritance_mode_id = 2 then --recessive allele
        genotype_string := chromosome2||'/'||chromosome1;
      else
        genotype_string := chromosome1||'/'||chromosome2;
      end if;
    end if;
    v_genotype := v_genotype||genotype_string||' ';
  end loop;

  return trim(nvl(v_genotype,'+/+'));

end mts_fetch_genotype;
/

CREATE OR REPLACE VIEW PER_PERSON_VW
AS
select
  p.person_id id,
  p.user_name,
  p.first_name,
  p.last_name,
  p.email,
  p.phone_number,
  p.room,
  decode(t.id,null,null,t.team_number||' - '||t.team_name) team,
  l.pil_number,
  decode(p.active,1,'Yes','No') active,
  decode(p.hidden,1,'Yes','No') hidden
from
  per_person p,
  per_team t,
  lic_personal_licence l
where
  p.team_id = t.id(+) and
  p.person_id = l.person_id(+)
order by p.last_name;

CREATE OR REPLACE VIEW APP_CUSTOM_QUERY_VW
AS
select
  c.id,
  c.query_title,
  c.query_view_name,
  c.description,
  c.system_query,
  c.category,
  c.start_with_filter,
  c.selectable_records,
  c.unique_name,
  s.last_refresh
from
  app_custom_query c,
  user_snapshots s
where
  upper(c.query_view_name) = s.name(+);

CREATE OR REPLACE VIEW GTP_ALL_PLATES_VW
AS
SELECT   p.ID, p.created_date, p.sheet_barcode, p.plate_barcode,
            DECODE (p.plate_barcode, NULL, 0, 1) plate_barcode_exists,
            pc.name category,
            c.ID cohort_id, c.cohort_name,
            rowtocol
               (   'select distinct c.room_name from mts_cage_vw c,mts_latest_mouse_cage_vw m,gtp_assay_plate_well w where c.cage_id = m.cage_id and m.mouse_id = w.mouse_id and w.assay_plate_id ='
                || p.ID
                || ' order by c.room_name'
               ) room_list,
            COUNT (m.ID) mouse_count,
            COUNT (DISTINCT DECODE (w.is_sample_collected, NULL, NULL, w.ID)
                  ) earclip_count,
            rowtocol
               (   'select distinct r.corridor from mts_room r, mts_cage_vw c,mts_latest_mouse_cage_vw m,gtp_assay_plate_well w where c.cage_id = m.cage_id and c.room_id = r.id and m.mouse_id = w.mouse_id and w.assay_plate_id ='
                || p.ID
                || ' order by r.corridor'
               ) suite
       FROM gtp_assay_plate p,
            mts_cohort c,
            gtp_assay_plate_well w,
            mts_mouse m,
            mts_cage_vw l,
            mts_latest_mouse_cage_vw ca,
            gtp_assay_plate_category pc
      WHERE c.ID = p.cohort_id
        AND p.ID = w.assay_plate_id
        AND m.ID = w.mouse_id
        AND m.ID = ca.mouse_id
        AND ca.cage_id = l.cage_id
        and P.PLATE_CATEGORY_DICT_ID = pc.id(+)
   GROUP BY p.ID,
            p.created_date,
            p.sheet_barcode,
            p.plate_barcode,
            pc.name,
            c.ID,
            c.cohort_name
   ORDER BY p.created_date DESC;
