CREATE OR REPLACE procedure app_ftr_on_insert(in_foreign_table_name varchar2, in_foreign_key_id number) is

cursor get_table_metadata(in_table_name varchar2) is
select
  *
from
  app_table_metadata
where
  table_name = in_table_name;

user_exception exception;
exception_message varchar2(4000);

type fk_lookup is record(row_count number);
fklp fk_lookup;

v_table_metadata app_table_metadata%rowtype;

begin

if in_foreign_table_name is null and in_foreign_key_id is not null then
  exception_message := 'FOREIGN_TABLE_NAME is null but a foreign key has been supplied';
  raise user_exception;
end if;

-- inserted record must contain a valid table name
if in_foreign_table_name is not null then
  open get_table_metadata(in_foreign_table_name);
  fetch get_table_metadata into v_table_metadata;
  if get_table_metadata%notfound then
    close get_table_metadata;
    exception_message := 'FOREIGN_TABLE_NAME ('||in_foreign_table_name||') is not a valid reference';
    raise user_exception;
  end if;
  execute immediate 'select count(*) row_count from '||v_table_metadata.table_name||' where '||v_table_metadata.primary_key_column||'=:1' into fklp using in_foreign_key_id ;
  if fklp.row_count < 1 then
    close get_table_metadata;
    exception_message := 'Foreign key '||in_foreign_key_id||' does not exist in '|| in_foreign_table_name;
    raise user_exception;
  end if;
  close get_table_metadata;
end if;

exception
  when user_exception then raise_application_error(-20001, exception_message);

end;
/

CREATE OR REPLACE procedure app_ftr_on_update(in_old_foreign_table_name varchar2, in_new_foreign_table_name varchar2, in_new_foreign_key_id number) is

user_exception exception;
exception_message varchar2(4000);

begin

if ((in_old_foreign_table_name is not null and in_new_foreign_table_name is null) or
   (in_old_foreign_table_name is null and in_new_foreign_table_name is not null) or
   in_new_foreign_table_name != in_old_foreign_table_name) then
 exception_message := 'FOREIGN_TABLE_NAME reference cannot be changed';
raise user_exception;
end if;


-- on_insert already does the checks required on table name  and id
app_ftr_on_insert(
  in_foreign_table_name => in_new_foreign_table_name,
  in_foreign_key_id => in_new_foreign_key_id
);

exception
  when user_exception then raise_application_error(-20001, exception_message);

end;
/

CREATE OR REPLACE TRIGGER EUR_DATA_EXPORTED_T1
 before insert or update or delete on EUR_DATA_EXPORTED
for each row

begin

  if updating then
    app_ftr_on_update(
        in_old_foreign_table_name => :old.foreign_table_name,
        in_new_foreign_table_name => :new.foreign_table_name,
        in_new_foreign_key_id => :new.foreign_key_id
    );
  end if;

  if inserting then
    app_ftr_on_insert(
        in_foreign_table_name => :new.foreign_table_name,
        in_foreign_key_id => :new.foreign_key_id
    );
  end if;


end;
/

CREATE OR REPLACE TRIGGER MTS_MOUSE_PROCEDURE_T1
 before insert or update or delete ON MTS_MOUSE_PROCEDURE for each row
begin

  if updating then
    app_ftr_on_update(
        in_old_foreign_table_name => :old.foreign_table_name,
        in_new_foreign_table_name => :new.foreign_table_name,
        in_new_foreign_key_id => :new.foreign_key_id
    );
  end if;

  if inserting then
    app_ftr_on_insert(
        in_foreign_table_name => :new.foreign_table_name,
        in_foreign_key_id => :new.foreign_key_id
    );
  end if;


end;
/


CREATE OR REPLACE TRIGGER APP_BINARY_FILES_T1
 before insert or update or delete ON APP_BINARY_FILES for each row
begin

  if updating then
    app_ftr_on_update(
        in_old_foreign_table_name => :old.foreign_table_name,
        in_new_foreign_table_name => :new.foreign_table_name,
        in_new_foreign_key_id => :new.foreign_key_id
    );
  end if;

  if inserting then
    app_ftr_on_insert(
        in_foreign_table_name => :new.foreign_table_name,
        in_foreign_key_id => :new.foreign_key_id
    );
  end if;


end;
/
