create or replace view EUR_HAEMATOLGY_EXP_VW as
with bdata as ( --bloods data
select r.id run_id,
max(cast (decode(d.parameter_id,2,d.value,null) as NUMBER)) WBC_count,
max(cast (decode(d.parameter_id,3,d.value,null) as NUMBER)) RBC_count,
max(cast (decode(d.parameter_id,4,d.value,null) as NUMBER)) HGB,
max(cast (decode(d.parameter_id,5,d.value,null) as NUMBER)) HCT,
max(cast (decode(d.parameter_id,7,d.value,null) as NUMBER)) MCV,
max(cast (decode(d.parameter_id,8,d.value,null) as NUMBER)) MCH,
max(cast (decode(d.parameter_id,9,d.value,null) as NUMBER)) MCHC,
max(cast (decode(d.parameter_id,6,d.value,null) as NUMBER)) PLT
from phn_bloods_run r
join phn_bloods_data d on r.id = d.run_id
group by r.id
),
cdata as ( -- collection data
select e.id, e.mouse_id,
min(mp.start_date) blood_collection_date,
max(decode(o.required_observation_id,
  663,opt.name,
  205,opt.name,
  null)) bleed_type,
max(decode(o.required_observation_id,
  713,opt.name,
  714,opt.name,
  null)) anaesthesia
from phn_experiment e
join phn_observation o on e.id = o.experiment_id
join phn_restricted_option opt on o.value = to_char(opt.id)
join mts_mouse_procedure mp on e.id = mp.foreign_key_id and mp.foreign_table_name = 'PHN_EXPERIMENT'
where e.sop_id in (120,144)
and o.required_observation_id in (713,714,205,663)
group by e.id, e.mouse_id
)
select
m.barcode mouse_barcode, r.mouse_id, r.run_date, r.id run_id, r.failed,
b.wbc_count, b.rbc_count, b.hgb, b.hct, b.mcv, b.mch, b.mchc, b.plt,
c.blood_collection_date, c.bleed_type, c.anaesthesia
from phn_bloods_run r
join bdata b on r.id = b.run_id
join cdata c on r.mouse_id = c.mouse_id
join mts_mouse m on r.mouse_id = m.id
where r.instrument_id = 1;

create or replace view EUR_CLINICAL_CHEM_P1_EXP_VW as
with bdata as ( --bloods data
select r.id run_id,
max(cast (decode(d.parameter_id,33,d.value,51,d.value,null) as NUMBER)) glucose,
max(cast (decode(d.parameter_id,36,d.value,53,d.value,null) as NUMBER)) total_cholesterol,
max(cast (decode(d.parameter_id,24,d.value,52,d.value,null) as NUMBER)) triglycerides,
max(cast (decode(d.parameter_id,49,d.value,55,d.value,null) as NUMBER))	Free_fatty_acid,
max(cast (decode(d.parameter_id,38,d.value,71,d.value,null) as NUMBER)) hdl_cholesterol,
max(cast (decode(d.parameter_id,72,d.value,null) as NUMBER)) ldl_cholesterol
from phn_bloods_run r
join phn_bloods_data d on r.id = d.run_id
group by r.id
),
cdata as ( -- collection data
select e.id, e.mouse_id,
min(mp.start_date) blood_collection_date,
max(decode(o.required_observation_id,
  663,opt.name,
  205,opt.name,
  null)) bleed_type,
max(decode(o.required_observation_id,
  713,opt.name,
  714,opt.name,
  null)) anaesthesia,
max(ofa.start_date) overnight_fast_start_date
from phn_experiment e
join phn_observation o on e.id = o.experiment_id
join phn_restricted_option opt on o.value = to_char(opt.id)
join mts_mouse_procedure mp on e.id = mp.foreign_key_id and mp.foreign_table_name = 'PHN_EXPERIMENT'
left outer join mts_mouse_procedure ofa on e.mouse_id = ofa.mouse_id and ofa.protocol_id = 43 and trunc(ofa.start_date) <= trunc(mp.start_date)
where e.sop_id in (120,144)
and o.required_observation_id in (713,714,205,663)
group by e.id, e.mouse_id
)
select
m.barcode mouse_barcode, r.mouse_id, r.run_date, r.id run_id, r.failed,
b.glucose, b.total_cholesterol, b.triglycerides, b.free_fatty_acid, b.hdl_cholesterol, b.ldl_cholesterol,
c.blood_collection_date, c.bleed_type, c.anaesthesia, c.overnight_fast_start_date
from phn_bloods_run r
join bdata b on r.id = b.run_id
join cdata c on r.mouse_id = c.mouse_id
join mts_mouse m on r.mouse_id = m.id
where r.instrument_id = 2;

create or replace view EUR_CLINICAL_CHEM_P2_EXP_VW as
with bdata as ( --bloods data
select r.id run_id,
max(cast (decode(d.parameter_id,33,d.value,51,d.value,null) as NUMBER)) Glucose,
max(cast (decode(d.parameter_id,25,d.value,66,d.value,null) as NUMBER)) Urea,
max(cast (decode(d.parameter_id,26,d.value,64,d.value,null) as NUMBER)) Creatinine,
max(cast (decode(d.parameter_id,46,d.value,null) as NUMBER)) Sodium,
max(cast (decode(d.parameter_id,47,d.value,null) as NUMBER)) Potassium,
max(cast (decode(d.parameter_id,48,d.value,null) as NUMBER)) Chloride,
max(cast (decode(d.parameter_id,30,d.value,56,d.value,null) as NUMBER))	Total_protein ,
max(cast (decode(d.parameter_id,31,d.value,57,d.value,null) as NUMBER)) Albumin,
max(cast (decode(d.parameter_id,58,d.value,null) as NUMBER)) Calcium,
max(cast (decode(d.parameter_id,59,d.value,null) as NUMBER)) Phosphorus,
max(cast (decode(d.parameter_id,60,d.value,null) as NUMBER)) Iron,
max(cast (decode(d.parameter_id,35,d.value,65,d.value,null) as NUMBER)) Lactate_dehydrogenase,
max(cast (decode(d.parameter_id,22,d.value,61,d.value,null) as NUMBER)) Aspartate_aminotransferase,
max(cast (decode(d.parameter_id,23,d.value,63,d.value,null) as NUMBER)) Alanine_aminotransferase,
max(cast (decode(d.parameter_id,29,d.value,null) as NUMBER)) Alkaline_phosphatase,
max(cast (decode(d.parameter_id,37,d.value,54,d.value,null) as NUMBER)) Alpha_amylase,
max(cast (decode(d.parameter_id,36,d.value,53,d.value,null) as NUMBER)) Total_cholesterol,
max(cast (decode(d.parameter_id,24,d.value,52,d.value,null) as NUMBER)) Triglyceride,
max(cast (decode(d.parameter_id,49,d.value,55,d.value,null) as NUMBER))	Free_fatty_acid,
max(cast (decode(d.parameter_id,42,d.value,69,d.value,null) as NUMBER)) Creatine_kinase,
max(cast (decode(d.parameter_id,73,d.value,null) as NUMBER)) Uric_acid,
max(cast (decode(d.parameter_id,32,d.value,67,d.value,null) as NUMBER)) Total_bilirubin,
max(cast (decode(d.parameter_id,38,d.value,71,d.value,null) as NUMBER)) HDL_cholesterol,
max(cast (decode(d.parameter_id,72,d.value,null) as NUMBER)) LDL_cholesterol,
null Ferretin,
null Transferrin,
null C_Reactive_protein
from phn_bloods_run r
join phn_bloods_data d on r.id = d.run_id
group by r.id
),
cdata as ( -- collection data
select e.id, e.mouse_id,
min(mp.start_date) blood_collection_date,
max(decode(o.required_observation_id,
  663,opt.name,
  205,opt.name,
  null)) bleed_type,
max(decode(o.required_observation_id,
  713,opt.name,
  714,opt.name,
  null)) anaesthesia,
max(ofa.start_date) overnight_fast_start_date
from phn_experiment e
join phn_observation o on e.id = o.experiment_id
join phn_restricted_option opt on o.value = to_char(opt.id)
join mts_mouse_procedure mp on e.id = mp.foreign_key_id and mp.foreign_table_name = 'PHN_EXPERIMENT'
left outer join mts_mouse_procedure ofa on e.mouse_id = ofa.mouse_id and ofa.protocol_id = 43 and trunc(ofa.start_date) <= trunc(mp.start_date)
where e.sop_id in (120,144)
and o.required_observation_id in (713,714,205,663)
group by e.id, e.mouse_id
)
select
m.barcode mouse_barcode, r.mouse_id, r.run_date, r.id run_id, r.failed,
b.GLUCOSE,
b.UREA,
b.CREATININE,
b.SODIUM,
b.POTASSIUM,
b.CHLORIDE,
b.TOTAL_PROTEIN,
b.ALBUMIN,
b.CALCIUM,
b.PHOSPHORUS,
b.IRON,
b.LACTATE_DEHYDROGENASE,
b.ASPARTATE_AMINOTRANSFERASE,
b.ALANINE_AMINOTRANSFERASE,
b.ALKALINE_PHOSPHATASE,
b.ALPHA_AMYLASE,
b.TOTAL_CHOLESTEROL,
b.TRIGLYCERIDE,
b.FREE_FATTY_ACID,
b.CREATINE_KINASE,
b.URIC_ACID,
b.TOTAL_BILIRUBIN,
b.HDL_CHOLESTEROL,
b.LDL_CHOLESTEROL,
b.FERRETIN,
b.TRANSFERRIN,
b.C_REACTIVE_PROTEIN,
c.blood_collection_date, c.bleed_type, c.anaesthesia, c.overnight_fast_start_date
from phn_bloods_run r
join bdata b on r.id = b.run_id
join cdata c on r.mouse_id = c.mouse_id
join mts_mouse m on r.mouse_id = m.id
where r.instrument_id = 2;

CREATE OR REPLACE VIEW EUR_COHORT_CRITERIA_VW as
with mouse_name_matches as (
select
  cm.cohort_id,
  case
    when m.name like ci.colony_prefix || '%' then 1
    else 0
  end name_matches_colony
from mts_cohort_mouse cm
join mts_mouse m on m.id = cm.mouse_id
join mts_colony_info ci on m.colony_info_id = ci.id
),
cohort_name_matches as (
select nm.cohort_id, min(nm.name_matches_colony) all_names_match_colony
from mouse_name_matches nm
group by nm.cohort_id
),
alleles as (
select cm.cohort_id, count(distinct ma.allele_id) allele_count
from mts_cohort_mouse cm
join mts_mouse_allele ma on cm.mouse_id = ma.mouse_id
group by cm.cohort_id
),
cell_lines as (
select cm.cohort_id, count(distinct mir.cell_line_id) cell_line_count, max(mir.cell_line_id) cell_line_id
from mts_cohort_mouse cm
join mts_mouse m on cm.mouse_id = m.id
join mir_micro_injection_request mir on m.colony_info_id = mir.colony_info_id
group by cm.cohort_id
),
strains as (
select cm.cohort_id, count(distinct m.mouse_strain_dict_id) strain_count
from mts_cohort_mouse cm
join mts_mouse m on cm.mouse_id = m.id
group by cm.cohort_id
),
alleles_and_wt_count as (
SELECT
cm.cohort_id, COUNT (DISTINCT nvl(ma.allele_id,-1)) alleles_and_wt_count
FROM mts_cohort_mouse cm
LEFT OUTER JOIN mts_mouse_allele ma
ON cm.mouse_id = ma.mouse_id
GROUP BY cm.cohort_id
),
odd_genotypes as (
SELECT
cm.cohort_id, 1 has_odd_genotypes
FROM mts_cohort_mouse cm
JOIN mts_mouse_allele ma ON cm.mouse_id = ma.mouse_id
where ma.genotype_dict_id not in (6,2,3)
GROUP BY cm.cohort_id
),
unlocked_genotypes as (
SELECT
cm.cohort_id, 1 has_unlocked_genotypes
FROM mts_cohort_mouse cm
JOIN mts_mouse_allele ma ON cm.mouse_id = ma.mouse_id
where ma.is_qc_locked = 0
GROUP BY cm.cohort_id
)
select
  c.id cohort_id, c.cohort_name, c.pipeline_dict_id, p.name pipeline,
  nm.all_names_match_colony,
  s.strain_count,
  nvl(a.allele_count,0) allele_count,
  nvl(cls.cell_line_count,0) cell_line_count,
  nvl(aw.alleles_and_wt_count,0) alleles_and_wt_count,
  nvl(og.has_odd_genotypes,0) has_odd_genotypes,
  case
    when cl.clone_name like 'EPD%' then 1
    else 0
  end have_epd
from mts_cohort c
join cohort_name_matches nm on c.id = nm.cohort_id
left outer join alleles a on c.id = a.cohort_id
left outer join cell_lines cls on c.id = cls.cohort_id
left outer join mir_cell_line cl on cl.id = cls.cell_line_id
left outer join alleles_and_wt_count aw on c.id = aw.cohort_id
left outer join odd_genotypes og on c.id = og.cohort_id
left outer join unlocked_genotypes ug on c.id = ug.cohort_id
join mts_cohort_pipeline_dict p on c.pipeline_dict_id = p.id
join strains s on c.id = s.cohort_id
where c.cohort_type_id = 1;

alter table EUR_DATA_EXPORTED drop constraint EUR_DATA_EXPORTED_PHN_EXP_FK1;
alter table EUR_DATA_EXPORTED rename column experiment_id to FOREIGN_KEY_ID;
alter table EUR_DATA_EXPORTED add FOREIGN_TABLE_NAME varchar2(30);

alter table eur_sop_2_procedure add min_date date;

create table temp_cohorts_to_export(cohort_name varchar2(128));
