CREATE OR REPLACE FORCE VIEW REP_CALORIMETRY_BINNED_VW as
with observations as (
select e.id experiment_id,
max(decode(o.required_observation_id,807,opt.name,null)) bad_food_data,
max(decode(o.required_observation_id,878,cast(o.value as number),null)) water_bottle_before,
max(decode(o.required_observation_id,879,cast(o.value as number),null)) water_bottle_after,
max(decode(o.required_observation_id,739,o.value,null)) box
from phn_experiment e
join phn_observation o on e.id = o.experiment_id
left join phn_restricted_option opt on o.value = to_char(opt.id)
group by e.id
)
select
e.*,
c.TIME,
c.SAMPLES,
c.CO2,
c.O2,
c.REF_CO2,
c.REF_O2,
c.CO2_DIFFERENCE,
c.O2_DIFFERENCE,
c.CUMULATIVE_FOOD_INTAKE,
c.FLOW_RATE_IN,
c.SAMPLE_FLOW_RATE_OUT,
c.TEMPERATURE,
c.RESPIRATORY_EXCHANGE_RATIO,
c.VCO2_BODYWEIGHT,
c.VCO2_LEAN_MASS,
c.VCO2_ANIMAL,
c.VO2_BODYWEIGHT,
c.VO2_LEAN_MASS,
c.VO2_ANIMAL,
c.ENERGY_EXPEND_BODYWEIGHT,
c.ENERGY_EXPEND_LEAN_MASS,
c.ENERGY_EXPEND_ANIMAL,
c.HEAT_BODYWEIGHT,
c.HEAT_LEAN_MASS,
c.HEAT_ANIMAL,
c.XAXIS_ACTIVITY_COUNT,
c.XAXIS_ACTIVITY_COUNT_TOTAL,
c.YAXIS_ACTIVITY_COUNT,
c.YAXIS_ACTIVITY_COUNT_TOTAL,
c.XAXIS_ACTIVITY_RATE,
c.YAXIS_ACTIVITY_RATE,
c.XAXIS_ACTIVITY_TOTAL_RATE,
c.YAXIS_ACTIVITY_TOTAL_RATE,
c.FOOD_INTAKE_RATE,
(e.experiment_id * 1e9) + (e.cohort_id * 1e2) + trunc(c.avg_minutes_elapsed) as id,
o.box,
o.bad_food_data,
o.water_bottle_before,
o.water_bottle_after,
o.water_bottle_before - o.water_bottle_after water_bottle_change
from PHN_EXPERIMENT_SUMMARY_VW e
join PHN_CALORIMETRY_DATA_BINNED_VW c on e.experiment_id = c.experiment_id
join observations o on e.experiment_id = o.experiment_id
where e.is_complete = 1 ;

CREATE OR REPLACE VIEW REP_CALORIMETRY_RAW_VW as
with observations as (
select e.id experiment_id,
max(decode(o.required_observation_id,807,opt.name,null)) bad_food_data,
max(decode(o.required_observation_id,878,cast(o.value as number),null)) water_bottle_before,
max(decode(o.required_observation_id,879,cast(o.value as number),null)) water_bottle_after,
max(decode(o.required_observation_id,739,o.value,null)) box
from phn_experiment e
join phn_observation o on e.id = o.experiment_id
left join phn_restricted_option opt on o.value = to_char(opt.id)
group by e.id
)
select
e.*,
c.SAMPLE_TIME,
c.MINUTES_ELAPSED,
c.CO2,
c.O2,
c.REF_CO2,
c.REF_O2,
c.CO2_DIFFERENCE,
c.O2_DIFFERENCE,
c.CUMULATIVE_FOOD_INTAKE,
c.FLOW_RATE_IN,
c.SAMPLE_FLOW_RATE_OUT,
c.TEMPERATURE,
c.RESPIRATORY_EXCHANGE_RATIO,
c.VCO2_BODYWEIGHT,
c.VCO2_LEAN_MASS,
c.VCO2_ANIMAL,
c.VO2_BODYWEIGHT,
c.VO2_LEAN_MASS,
c.VO2_ANIMAL,
c.ENERGY_EXPEND_BODYWEIGHT,
c.ENERGY_EXPEND_LEAN_MASS,
c.ENERGY_EXPEND_ANIMAL,
c.HEAT_BODYWEIGHT,
c.HEAT_LEAN_MASS,
c.HEAT_ANIMAL,
c.XAXIS_ACTIVITY_COUNT,
c.XAXIS_ACTIVITY_COUNT_TOTAL,
c.YAXIS_ACTIVITY_COUNT,
c.YAXIS_ACTIVITY_COUNT_TOTAL,
c.RATE_XA,
c.RATE_XT,
c.RATE_YA,
c.RATE_YT,
c.RATE_FEED,
(e.experiment_id * 1e4) + (e.cohort_id * 1e9) + c.id as id,
o.box,
o.bad_food_data,
o.water_bottle_before,
o.water_bottle_after,
o.water_bottle_before - o.water_bottle_after water_bottle_change
from PHN_CALORIMETRY_DATA c
join PHN_EXPERIMENT_SUMMARY_VW e
join PHN_OBSERVATION box on e.experiment_id = box.experiment_id and box.required_observation_id = 739
join observations o on e.experiment_id = o.experiment_id
on c.experiment_id = e.experiment_id
where e.is_complete = 1 ;