CREATE TABLE ANN_ONTOLOGY_DICT
(
  ID           INTEGER,
  NAME         VARCHAR2(256 CHAR)               NOT NULL,
  DESCRIPTION  VARCHAR2(2048 CHAR),
  ACTIVE       NUMBER(1)                        DEFAULT 1                     NOT NULL,
  ORDER_BY     NUMBER                           NOT NULL
);


CREATE TABLE ANN_ANNOTATION
(
  ID                  INTEGER,
  TERM_NAME           VARCHAR2(256 BYTE),
  TERM_ID             VARCHAR2(128 BYTE),
  ONTOLOGY_DICT_ID    INTEGER,
  EDIT_DATE           DATE,
  EDITED_BY           VARCHAR2(128 BYTE),
  CREATED_DATE        DATE,
  CREATOR_ID          INTEGER,
  CHECK_NUMBER        INTEGER,
  FOREIGN_TABLE_NAME  VARCHAR2(30 BYTE),
  FOREIGN_KEY_ID      INTEGER
);


CREATE OR REPLACE function ann_fetch_annotations (c_foreign_table_name varchar2, c_foreign_key_id number) return varchar2 is

v_annotations varchar2(4000) := '';
v_separator varchar2(2) := '; ';

cursor c_annotation is
select
   ANN.TERM_ID,
   ANN.TERM_NAME
from
   ann_annotation ann
where
    ANN.FOREIGN_TABLE_NAME = c_foreign_table_name
    AND ANN.FOREIGN_KEY_ID = c_foreign_key_id;

begin

  for a in c_annotation loop


    if A.TERM_ID is not null then
            v_annotations := v_annotations||v_separator||A.TERM_ID||' '||A.TERM_NAME;
    else
            v_annotations := v_annotations||v_separator||A.TERM_NAME;
    end if;



  end loop;

  return ltrim(v_annotations,v_separator);


end ann_fetch_annotations;
/

CREATE OR REPLACE TRIGGER ANN_ANNOTATION_T1
 before insert or update or delete on ANN_ANNOTATION
for each row
begin

  if updating then
    app_ftr_on_update(
        in_old_foreign_table_name => :old.foreign_table_name,
        in_new_foreign_table_name => :new.foreign_table_name,
        in_new_foreign_key_id => :new.foreign_key_id
    );
  end if;

  if inserting then
    app_ftr_on_insert(
        in_foreign_table_name => :new.foreign_table_name,
        in_foreign_key_id => :new.foreign_key_id
    );
  end if;


end;
/


CREATE OR REPLACE FORCE VIEW htl_crop_vw (mouse_id,
                                          gene_name,
                                          allele,
                                          genotype_dict_id,
                                          genotype_name,
                                          allele_id,
                                          allele_name,
                                          pipeline,
                                          mouse_barcode,
                                          gender_dict_id,
                                          gender,
                                          ID,
                                          width,
                                          height,
                                          resized_image_path,
                                          created_date,
                                          edit_date,
                                          full_image_path,
                                          qc_pass,
                                          tiled,
                                          comments,
                                          tissue_name,
                                          tissue_id,
                                          scan_id,
                                          source_block_id,
                                          source_block_description,
                                          slide_id,
                                          slide_barcode,
                                          staining,
                                          staining_dict_id,
                                          annotations
                                         )
AS
   SELECT   m.ID mouse_id, g.primary_name gene_name,
            mts.fetch_genotype (m.ID) allele, gt.ID genotype_dict_id,
            gt.NAME genotype_name, tma.ID allele_id,
            tma.official_name_superscript allele_name,
            mts.fetch_pipelines (m.ID, ',') pipeline, m.barcode mouse_barcode,
            m.gender_dict_id, mg.NAME gender, c.ID ID, c.width width,
            c.height height, c.resized_image_path, c.created_date,
            c.edit_date, c.full_image_path, c.qc_pass qc_pass, c.tiled tiled,
            c.comments comments, t.NAME tissue_name, t.ID tissue_id,
            s.ID scan_id, bt.ID source_block_id,
            bt.description source_block_description, sl.ID slide_id,
            sl.barcode slide_barcode, st.NAME staining,
            st.ID staining_dict_id,
            ann_fetch_annotations ('HTL_CROP', c.ID) annotations
       FROM htl_crop c,
            htl_tissue t,
            htl_crop_job cj,
            htl_scan s,
            htl_slide sl,
            htl_staining_type_dict st,
            htl_block b,
            htl_block_type bt,
            htl_fixation f,
            htl_necropsy n,
            mts_mouse m,
            mts_gender_dict mg,
            mts_mouse_allele ma,
            mts_genotype_dict gt,
            typ_modified_allele tma,
            gnm_gene g
      WHERE c.crop_job_id = cj.ID
        AND c.resized_image_path IS NOT NULL
        AND c.tissue_id = t.ID(+)
        AND cj.scan_id = s.ID
        AND s.slide_id = sl.ID
        AND sl.staining_type_dict_id = st.ID
        AND sl.block_id = b.ID
        AND b.block_type_id = bt.ID
        AND b.fixation_id = f.ID
        AND f.necropsy_id = n.ID
        AND n.mouse_id = m.ID
        AND m.gender_dict_id = mg.ID
        AND ma.mouse_id(+) = m.ID
        AND ma.allele_id = tma.ID(+)
        AND ma.genotype_dict_id = gt.ID(+)
        AND tma.gene_id = g.ID(+)
   ORDER BY gene_name;
