CREATE TABLE REP_GRAPH_DATA_AVAILABLE
(
  ID              INTEGER                       NOT NULL,
  GENE_ID         INTEGER                       NOT NULL,
  GENE_NAME       VARCHAR2(256 CHAR)            NOT NULL,
  ALLELE_ID       INTEGER                       NOT NULL,
  ALLELE_NAME     VARCHAR2(256 CHAR)            NOT NULL,
  PIPELINE_ID     INTEGER                       NOT NULL,
  PIPELINE_NAME   VARCHAR2(256 CHAR)            NOT NULL,
  REPORTING_TEST  VARCHAR2(256 CHAR)            NOT NULL,
  PAGE_TYPE_ID    INTEGER                       NOT NULL,
  DATA_AVAILABLE  NUMBER(1)                     NOT NULL,
  RECORD_COUNT    INTEGER                       NOT NULL,
  COLONY_ID       INTEGER,
  COLONY_PREFIX   VARCHAR2(256 CHAR),
  COLONY_NAME     VARCHAR2(256 CHAR)
)
TABLESPACE DATA_02
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE REP_PAGE_TYPE
(
  ID            INTEGER                         NOT NULL,
  NAME          VARCHAR2(4000 CHAR)             NOT NULL,
  DESCRIPTION   VARCHAR2(4000 CHAR),
  CHECK_NUMBER  INTEGER,
  EDITED_BY     VARCHAR2(128 CHAR),
  EDIT_DATE     DATE,
  CREATOR_ID    INTEGER,
  CREATED_DATE  DATE
)
TABLESPACE DATA_02;


CREATE UNIQUE INDEX REP_PAGE_TYPE_PK ON MIG.REP_PAGE_TYPE
(ID)
TABLESPACE INDEX_02;

ALTER TABLE REP_PAGE_TYPE ADD (
  CONSTRAINT REP_PAGE_TYPE_PK
 PRIMARY KEY
 (ID)
    USING INDEX
    TABLESPACE INDEX_02
 );

CREATE sequence REP_GRAPH_DATA_AVAILABLE_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE UNIQUE INDEX REP_GRAPH_DATA_AVAILABLE_PK ON MIG.REP_GRAPH_DATA_AVAILABLE
(ID)
LOGGING
TABLESPACE INDEX_02
NOPARALLEL;

ALTER TABLE REP_GRAPH_DATA_AVAILABLE ADD (
  CONSTRAINT REP_GRAPH_DATA_AVAILABLE_PK
 PRIMARY KEY
 (ID)
    USING INDEX
    TABLESPACE INDEX_02
 );

ALTER TABLE REP_GRAPH_DATA_AVAILABLE ADD (
  CONSTRAINT REP_GRAPH_DATA_AVAILABLE_R01
 FOREIGN KEY (GENE_ID)
 REFERENCES GNM_GENE (ID),
  CONSTRAINT REP_GRAPH_DATA_AVAILABLE_R02
 FOREIGN KEY (ALLELE_ID)
 REFERENCES TYP_MODIFIED_ALLELE (ID),
  CONSTRAINT REP_GRAPH_DATA_AVAILABLE_R03
 FOREIGN KEY (PIPELINE_ID)
 REFERENCES MTS_COHORT_PIPELINE_DICT (ID),
  CONSTRAINT REP_GRAPH_DATA_AVAILABLE_R04
 FOREIGN KEY (PAGE_TYPE_ID)
 REFERENCES REP_PAGE_TYPE (ID));

 alter table REP_GRAPH_METADATA add (SCIENTIFIC_Y_AXIS number(1));
 alter table REP_GRAPH_METADATA add (TIME_AXIS number(1));
 alter table REP_GRAPH_METADATA add (X_PADDING number(1));
 alter table REP_GRAPH_METADATA add (XAXIS_AS_LABELS number(1));
 alter table REP_GRAPH_METADATA add (XAXIS_COLUMN varchar2(256 char));

CREATE TABLE REP_LINE_RANGE
(
  ID                 NUMBER                     NOT NULL,
  GRAPH_METADATA_ID  NUMBER                     NOT NULL,
  XLABEL             VARCHAR2(128 BYTE)         NOT NULL,
  MINUS_2_SD         NUMBER,
  MINUS_1_SD         NUMBER,
  MEAN               NUMBER,
  PLUS_1_SD          NUMBER,
  PLUS_2_SD          NUMBER,
  GENDER_ID          NUMBER,
  STRAIN_ID          NUMBER,
  PCT_25             NUMBER,
  PCT_975            NUMBER,
  MEDIAN             NUMBER,
  NUM_ROWS           NUMBER,
  PIPELINE_DICT_ID   NUMBER
)
TABLESPACE DATA_02
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;

ALTER TABLE REP_LINE_RANGE ADD (
  PRIMARY KEY
 (ID, GRAPH_METADATA_ID, XLABEL)
    USING INDEX
    TABLESPACE INDEX_02
);

CREATE OR REPLACE PACKAGE BODY "MAKE_REFRANGES_NEW" as

/* ====================================

   Load table that lists which genes/alleles have data
   available for graphing.

 ==================================== */

procedure load_graph_data_available is



plsql_block VARCHAR2(10000);

cursor view_new_cur is
select
  m.ID,m.VIEW_NAME, m.PLOT_COLUMN
from
 REP_GRAPH_METADATA m;

begin

execute immediate 'truncate table REP_GRAPH_DATA_AVAILABLE';

for view_rec in view_new_cur
 loop
         plsql_block := 'insert into REP_GRAPH_DATA_AVAILABLE (
            gene_id,
            gene_name,
            allele_id,
            allele_name,
            pipeline_id,
            pipeline_name,
            reporting_test,
            page_type_id,
            data_available,
            record_count,
            colony_id,
            colony_prefix,
            colony_name)
            select
            g.id gene_id,
            g.primary_name gene_name,
            a.id allele_id,
            A.internal_name allele_name,
            v.pipeline_id pipeline_id,
            d.name pipeline_name,
            t.description test,
            T.PAGE_TYPE_ID page_type_id,
            decode(count(v.'||view_rec.plot_column||'),0,0,1) data_available,
            count(v.'||view_rec.plot_column||') record_count,
            ci.id,
            ci.colony_prefix,
            ci.colony_name
            from '||view_rec.view_name||' v,
            mts_cohort_set_element cs,
            mts_cohort_set s,
            typ_modified_allele a,
            gnm_gene g,
            rep_pipeline_tests t,
            mts_cohort_pipeline_dict d,
            rep_page_type pt,
            rep_page_subgroup sg,
            rep_graph rg,
            rep_graph_metadata gm,
            mts_colony_allele ca,
            mts_colony_info ci
            where v.cohort_id = cs.cohort_id
            and cs.set_id = s.id
            and s.allele_id = a.id
            and a.id = ca.modified_allele_id(+)
            and ca.colony_id = ci.id(+)
            and a.gene_id = g.id
            and v.pipeline_id = t.pipeleine_id
            and v.pipeline_id = d.id
            and RG.GRAPH_METADATA_ID = gm.id
            and RG.REP_SUBGROUP_ID = sg.id
            and SG.REP_PAGE_TYPE_ID = pt.id
            and pt.id = T.PAGE_TYPE_ID
            and gm.id = '||view_rec.id||'
            group by g.id,g.primary_name,a.id,a.internal_name,v.pipeline_id, d.name,t.description,t.page_type_id,ci.id,ci.colony_prefix,ci.colony_name';
         dbms_output.put_line(plsql_block);
         begin
             execute immediate plsql_block;
         exception when others then dbms_output.put_line('Failed insert REP_GRAPH_DATA_AVAILABLE:'||view_rec.view_name);
         end;
  commit;
 end loop;

 end load_graph_data_available;



/* ====================================

   make_refranges_inserts(gender in varchar2)
   gender specific for line charts.

 ==================================== */
procedure make_line_range_inserts(gender in number) is

plsql_block VARCHAR2(1000);

cursor view_new_cur is
select
  m.ID,replace(m.VIEW_NAME,'_VW','_MV') view_name, m.PLOT_COLUMN, M.XAXIS_COLUMN
from
 REP_GRAPH_METADATA m
 where compute_ref_range=1
 and graph_type_id = 3
 order by m.id
 ;

type query_curtype is ref cursor;
strains_cur query_curtype;

type query_curtype2 is ref cursor;
pipeline_cur query_curtype2;

type query_curtype3 is ref cursor;
xlabel_cur query_curtype3;

temp_strain_id number;
temp_pipeline_id number;
temp_xlabel varchar2(512);



begin
for view_rec in view_new_cur
 loop
 open pipeline_cur for 'select distinct pipeline_id from '||view_rec.view_name;
     loop
     exit when pipeline_cur%notfound;
     fetch pipeline_cur into temp_pipeline_id;
     open strains_cur for 'select distinct strain_id from '||view_rec.view_name;
     loop
     exit when strains_cur%notfound;
     fetch strains_cur into temp_strain_id;

         open xlabel_cur for 'select distinct '||view_rec.xaxis_column||' from '|| view_rec.view_name;
         loop
         exit when xlabel_cur%notfound;
         fetch xlabel_cur into temp_xlabel;

             plsql_block := 'insert into REP_LINE_RANGE (GRAPH_METADATA_ID,XLABEL,STRAIN_ID,NUM_ROWS,PCT_25,MEDIAN,PCT_975,MINUS_2_SD, MINUS_1_SD, MEAN, PLUS_1_SD, PLUS_2_SD,gender_id,pipeline_dict_id) '
                  ||'select '||view_rec.ID||','||temp_xlabel||','||temp_strain_id||','
                             ||'COUNT('||view_rec.PLOT_COLUMN||'),'
                  ||'PERCENTILE_CONT(0.975) WITHIN GROUP (ORDER BY to_number('||view_rec.PLOT_COLUMN||') DESC),'
                         ||'PERCENTILE_CONT(0.5) WITHIN GROUP (ORDER BY to_number('||view_rec.PLOT_COLUMN||') DESC),'
                         ||'PERCENTILE_CONT(0.025) WITHIN GROUP (ORDER BY to_number('||view_rec.PLOT_COLUMN||') DESC),'
                         ||'AVG('||view_rec.PLOT_COLUMN||')-2*STDDEV('||view_rec.PLOT_COLUMN||'),'
                         ||'AVG('||view_rec.PLOT_COLUMN||')-STDDEV('||view_rec.PLOT_COLUMN||'),'
                         ||'AVG('||view_rec.PLOT_COLUMN||'),'
                         ||'AVG('||view_rec.PLOT_COLUMN||')+STDDEV('||view_rec.PLOT_COLUMN||'),'
                         ||'AVG('||view_rec.PLOT_COLUMN||')+2*STDDEV('||view_rec.PLOT_COLUMN||'),'
                  ||gender||','||temp_pipeline_id|| ' from '||view_rec.view_name||' where gender_id='||gender||' and genotype= ''+/+'' and strain_id='||temp_strain_id||'and pipeline_id='||temp_pipeline_id||' and '||view_rec.xaxis_column||' = '||temp_xlabel ;
             dbms_output.put_line(plsql_block);
                 begin
                     delete REP_LINE_RANGE where graph_metadata_id = view_rec.ID and gender_id = gender and strain_id = temp_strain_id and xlabel = temp_xlabel and pipeline_dict_id = temp_pipeline_id;
                     execute immediate plsql_block;

                 exception when others then dbms_output.put_line('Failed Line Reference Range Calc:'||view_rec.view_name);
                 end;

             end loop;
           close xlabel_cur;
         end loop;
    close strains_cur;
     end loop;
     close pipeline_cur;
     commit;
 end loop;

end make_line_range_inserts;



/* ====================================

   make_refranges_inserts(gender in varchar2)
   gender specific

 ==================================== */
procedure make_scatter_range_inserts(gender in number) is

plsql_block VARCHAR2(1000);

cursor view_new_cur is
select
  m.ID,replace(m.VIEW_NAME,'_VW','_MV') view_name, m.PLOT_COLUMN
from
 REP_GRAPH_METADATA m
 where compute_ref_range=1
 and graph_type_id = 1
 order by m.id
 ;

type query_curtype is ref cursor;
strains_cur query_curtype;

type query_curtype2 is ref cursor;
pipeline_cur query_curtype2;

temp_strain_id number;
temp_pipeline_id number;

begin
for view_rec in view_new_cur
 loop
 open pipeline_cur for 'select distinct pipeline_id from '||view_rec.view_name;
     loop
     exit when pipeline_cur%notfound;
     fetch pipeline_cur into temp_pipeline_id;
     open strains_cur for 'select distinct strain_id from '||view_rec.view_name;
     loop
     exit when strains_cur%notfound;
     fetch strains_cur into temp_strain_id;
         plsql_block := 'insert into REP_SCATTER_RANGE (GRAPH_METADATA_ID,STRAIN_ID,NUM_ROWS,PCT_25,MEDIAN,PCT_975,MINUS_2_SD, MINUS_1_SD, MEAN, PLUS_1_SD, PLUS_2_SD,gender_id,pipeline_dict_id) '
              ||'select '||view_rec.ID||','||temp_strain_id||','
                         ||'COUNT('||view_rec.PLOT_COLUMN||'),'
              ||'PERCENTILE_CONT(0.975) WITHIN GROUP (ORDER BY to_number('||view_rec.PLOT_COLUMN||') DESC),'
                     ||'PERCENTILE_CONT(0.5) WITHIN GROUP (ORDER BY to_number('||view_rec.PLOT_COLUMN||') DESC),'
                     ||'PERCENTILE_CONT(0.025) WITHIN GROUP (ORDER BY to_number('||view_rec.PLOT_COLUMN||') DESC),'
                     ||'AVG('||view_rec.PLOT_COLUMN||')-2*STDDEV('||view_rec.PLOT_COLUMN||'),'
                         ||'AVG('||view_rec.PLOT_COLUMN||')-STDDEV('||view_rec.PLOT_COLUMN||'),'
                         ||'AVG('||view_rec.PLOT_COLUMN||'),'
                     ||'AVG('||view_rec.PLOT_COLUMN||')+STDDEV('||view_rec.PLOT_COLUMN||'),'
                         ||'AVG('||view_rec.PLOT_COLUMN||')+2*STDDEV('||view_rec.PLOT_COLUMN||'),'
              ||gender||','
                         ||temp_pipeline_id||' from '||view_rec.view_name||' where gender_id='||gender||' and genotype= ''+/+'' and strain_id='||temp_strain_id||' and pipeline_id='||temp_pipeline_id;
         dbms_output.put_line(plsql_block);
         begin
             delete REP_SCATTER_RANGE where graph_metadata_id = view_rec.ID and gender_id = gender and strain_id = temp_strain_id and pipeline_dict_id = temp_pipeline_id;
             execute immediate plsql_block;
         exception when others then dbms_output.put_line('Failed Scatter Reference Range Calc:'||view_rec.view_name);
         end;
     end loop;
     close strains_cur;
     end loop;
     close pipeline_cur;
    commit;
 end loop;

end make_scatter_range_inserts;


/* ====================================

   make_refranges_inserts(gender in varchar2)
   gender specific

 ==================================== */
procedure make_bar_range_inserts(gender in number) is

plsql_block VARCHAR2(1000);

cursor view_new_cur is
select
  m.ID,replace(m.VIEW_NAME,'_VW','_MV') view_name, m.PLOT_COLUMN
from
 REP_GRAPH_METADATA m
 where compute_ref_range=1
 and graph_type_id = 2
 order by m.id
 ;

type query_curtype is ref cursor;
strains_cur query_curtype;

temp_strain_id number;

type query_curtype2 is ref cursor;
pipeline_cur query_curtype2;

temp_pipeline_id number;

begin
for view_rec in view_new_cur
 loop
 open pipeline_cur for 'select distinct pipeline_id from '||view_rec.view_name;
     loop
     exit when pipeline_cur%notfound;
     fetch pipeline_cur into temp_pipeline_id;
 open strains_cur for 'select distinct strain_id from '||view_rec.view_name;
     loop
     exit when strains_cur%notfound;
     fetch strains_cur into temp_strain_id;
         plsql_block := 'insert into REP_BAR_RANGE (GRAPH_METADATA_ID,STRAIN_ID,GENDER_ID,COLUMN_PARAMETER,PARAMETER_COUNT,pipeline_dict_id) '
              ||'select '||view_rec.ID||','
                         ||temp_strain_id||','
                         ||gender||','
                         ||'nvl('||view_rec.PLOT_COLUMN||',''0''),'
                         ||'COUNT(nvl('||view_rec.PLOT_COLUMN||',''0'')),'
                         ||temp_pipeline_id
              ||' from '||view_rec.view_name||' where gender_id='||gender||' and genotype= ''+/+'' and strain_id='||temp_strain_id||'and pipeline_id='||temp_pipeline_id||' group by '||view_rec.PLOT_COLUMN;
         dbms_output.put_line(plsql_block);
         begin
             delete REP_BAR_RANGE where graph_metadata_id = view_rec.ID and gender_id = gender and strain_id = temp_strain_id and pipeline_dict_id = temp_pipeline_id;
             execute immediate plsql_block;
         exception when others then dbms_output.put_line('Failed Bar Reference Range Calc:'||view_rec.view_name);
         end;
     end loop;
    close strains_cur;
    end loop;
     close pipeline_cur;
    commit;
 end loop;

end make_bar_range_inserts;



/* ====================================

    make_all_refranges_inserts
    for male, female and all

 ==================================== */
procedure make_all_refranges_inserts is

begin

    make_scatter_range_inserts(1);
    make_scatter_range_inserts(2);

    make_bar_range_inserts(1);
    make_bar_range_inserts(2);

    make_line_range_inserts(1);
    make_line_range_inserts(2);

  	load_graph_data_available();

end make_all_refranges_inserts;

/* ====================================

    make_refranges_values

    male, female and all

 ==================================== */
procedure make_refranges_values is

begin
  make_all_refranges_inserts;
end make_refranges_values;

end make_refranges_new;
/

CREATE OR REPLACE PACKAGE MIG."MAKE_REFRANGES_NEW" as

  procedure make_scatter_range_inserts(gender in number);
  procedure make_bar_range_inserts(gender in number);
  procedure make_all_refranges_inserts;
  procedure make_refranges_values;
  procedure load_graph_data_available;

end make_refranges_new;
/


