 CREATE OR REPLACE FORCE VIEW PHN_ABR_EXPERIMENT_VW ("ID", "MOUSE_ID", "MOUSE_CALI_CHART_ID", "MOUSE_CLICK_CHART_ID", "MOUSE_FILE_ID", "SIMPLE_GENOTYPE", "GENOTYPE_ID", "MOUSE_NAME", "ANAESTHETIC", "ANAESTHETIC_DOSE", "ANAESTHETIC_ROUTE", "INDUCTION_TIME", "EXPERIMENT_DATE", "WEIGHT", "AGE_IN_WEEKS", "INCLUDE_EXPERIMENT", "COMMENTS", "USER_COMMENTS", "MOUSE_BARCODE", "MOUSE_BIRTH_DATE", "RFID_TAG", "MOUSE_GENDER", "EAR_CLIP", "GENOTYPE", "ALLELE_ID", "SHORT_ALLELE_SYMBOL", "OFFICIAL_NAME_SUPERSCRIPT", "COLONY_PREFIX", "GENE_PRIMARY_NAME", "PERSONAL_LICENCE_ID", "PIL_NUMBER", "USER_ID", "USER_NAME", "PROJECT_LICENCE_ID", "PPL_NUMBER", "PROTOCOL_CODE", "PROCESS_STATUS") AS
  SELECT e.ID ID, e.mouse_id mouse_id, bcalic4.ID mouse_cali_chart_id,
       bclickc3.ID mouse_click_chart_id, bfile1.ID mouse_file_id,
       mts.fetch_simple_genotype (e.mouse_id) simple_genotype,
       nvl(mall.genotype_dict_id,1) genotype_id,
       m.NAME mouse_name, o1.VALUE anaesthetic,
       TO_NUMBER (o2.VALUE) anaesthetic_dose, o3.VALUE anaesthetic_route,
       o4.VALUE induction_time,
       TO_DATE (o5.VALUE, 'dd/mm/yyyy') experiment_date,
       TO_NUMBER (o6.VALUE) weight,
       ROUND ((TO_DATE (o5.VALUE, 'dd/mm/yyyy') - m.birth_date) / 7,
              1
             ) age_in_weeks,
       DECODE (NVL (TO_NUMBER (o7.VALUE), 0),
               0, 'No',
               1, 'Yes'
              ) include_experiment,
       o8.VALUE comments, o9.VALUE user_comments, m.barcode mouse_barcode,
       m.birth_date mouse_birth_date, m.rfid_tag, gd.NAME mouse_gender,
       ed.NAME ear_clip, mts.fetch_genotype (e.mouse_id) genotype,
       typall.ID allele_id, typall.short_allele_symbol,
       typall.official_name_superscript, ci.colony_prefix,
       g.primary_name gene_primary_name, mp.personal_licence_id,
       pil.pil_number, pil.person_id user_id,
       p.first_name || ' ' || p.last_name user_name, p19b.project_licence_id,
       ppl.licence_number ppl_number, p19b.protocol_code,
       DECODE (phn.fetch_abr_status (e.ID),
               1, 'Completed',
               0, 'In Process'
              ) process_status
  FROM phn_experiment e,
       mts_mouse m,
       mts_earmark_dict ed,
       mts_mouse_allele mall,
       typ_modified_allele typall,
       gnm_gene g,
       mts_colony_info ci,
       mts_gender_dict gd,
       phn_observation o1,
       phn_observation o2,
       phn_observation o3,
       phn_observation o4,
       phn_observation o5,
       phn_observation o6,
       phn_observation o7,
       phn_observation o8,
       phn_observation o9,
       app_binary_files bfile1,
       app_binary_files bclickc3,
       app_binary_files bcalic4,
       mts_mouse_procedure mp,
       lic_personal_licence pil,
       lic_protocol_19b p19b,
       lic_project_licence ppl,
       per_person p
 WHERE e.ID = o1.experiment_id(+)
   AND o1.required_observation_id(+) = 825
   AND e.ID = o2.experiment_id(+)
   AND o2.required_observation_id(+) = 826
   AND e.ID = o3.experiment_id(+)
   AND o3.required_observation_id(+) = 827
   AND e.ID = o4.experiment_id(+)
   AND o4.required_observation_id(+) = 828
   AND e.ID = o5.experiment_id(+)
   AND o5.required_observation_id(+) = 824
   AND e.ID = o6.experiment_id(+)
   AND o6.required_observation_id(+) = 823
   AND e.ID = o7.experiment_id(+)
   AND o7.required_observation_id(+) = 831
   AND e.ID = o8.experiment_id(+)
   AND o8.required_observation_id(+) = 829
   AND e.ID = o9.experiment_id(+)
   AND o9.required_observation_id(+) = 830
   AND e.sop_id = 149
   AND e.mouse_id = m.ID
   AND m.earmark_dict_id = ed.ID(+)
   AND bfile1.foreign_key_id(+) = e.ID
   AND bfile1.content_type_dict_id = 1
   AND bclickc3.foreign_key_id(+) = e.ID
   AND bclickc3.content_type_dict_id = 3
   AND bcalic4.foreign_key_id(+) = e.ID
   AND bcalic4.content_type_dict_id = 4
   AND m.gender_dict_id = gd.ID
   AND e.mouse_id = mall.mouse_id(+)
   AND mall.allele_id = typall.ID(+)
   AND typall.gene_id = g.ID(+)
   AND m.colony_info_id = ci.ID(+)
   AND mp.mouse_id = e.mouse_id
   AND mp.procedure_dict_id = 25
   AND mp.foreign_key_id = e.ID
   AND mp.personal_licence_id = pil.personal_licence_id
   AND pil.person_id(+) = p.person_id
   AND mp.protocol_id = p19b.ID
   AND p19b.project_licence_id = ppl.project_licence_id ;


CREATE OR REPLACE FORCE VIEW phn_line_graph_abr_vw (cohort_set_id,
                                                        strain_id,
                                                        strain,
                                                        mouse_id,
                                                        mouse_name,
                                                        barcode,
                                                        genotype_id,
                                                        genotype,
                                                        age_in_weeks,
                                                        gender,
                                                        gender_id,
                                                        gene_name,
                                                        allele_superscript,
                                                        allele_id,
                                                        html_allele_symbol,
                                                        cohort_id,
                                                        cohort_name,
                                                        pipeline,
                                                        pipeline_id,
                                                        experiment_id,
                                                        assay_date,
                                                        x_label,
                                                        plot_column,
                                                        include,
                                                        process_status
                                                       )
AS
   SELECT csl.ID cohort_set_id, mv.mouse_strain_dict_id strain_id, mv.strain,
          m.mouse_id, mv.NAME mouse_name, mv.barcode,
          NVL (ma.genotype_dict_id, 1) genotype_id, mv.genotype,
          abrm.age_in_weeks, mv.gender, mv.gender_dict_id gender_id,
          csl.gene_name, csl.allele_superscript, csl.allele_id,
          csl.html_allele_symbol, e.cohort_id, c.cohort_name, c.pipeline,
          c.pipeline_dict_id pipeline_id, abrm.ID experiment_id,
          abrm.experiment_date assay_date, f.frequence x_label,
          f.threshold plot_column, abrm.include_experiment include,
          abrm.process_status
     FROM mts_cohort_set_list_vw csl,
          mts_cohort_set_element e,
          mts_cohort_list_vw c,
          mts_cohort_mouse m,
          mts_mouse_vw mv,
          mts_mouse_allele ma,
          phn_abr_experiment_vw abrm,
          aud_freq_experiment f
    WHERE csl.ID = e.set_id
      AND e.wt_only = 0
      AND e.cohort_id = c.ID
      AND c.pipeline_dict_id IN (2, 14)
      AND m.cohort_id = c.ID
      AND abrm.mouse_id = m.mouse_id
      AND m.mouse_id = mv.ID
      AND m.mouse_id = ma.mouse_id(+)
      AND f.phn_experiment_id = abrm.ID
      AND f.threshold IS NOT NULL
   UNION
   SELECT csl.ID cohort_set_id, mv.mouse_strain_dict_id strain_id, mv.strain,
          m.mouse_id, mv.NAME mouse_name, mv.barcode,
          NVL (ma.genotype_dict_id, 1) genotype_id, mv.genotype,
          abrm.age_in_weeks, mv.gender, mv.gender_dict_id gender_id,
          csl.gene_name, csl.allele_superscript, csl.allele_id,
          csl.html_allele_symbol, e.cohort_id, c.cohort_name, c.pipeline,
          c.pipeline_dict_id pipeline_id, abrm.ID experiment_id,
          abrm.experiment_date assay_date, f.frequence x_label,
          f.threshold plot_column, abrm.include_experiment include,
          abrm.process_status
     FROM mts_cohort_set_list_vw csl,
          mts_cohort_set_element e,
          mts_cohort_list_vw c,
          mts_cohort_mouse m,
          mts_mouse_vw mv,
          mts_mouse_allele ma,
          phn_abr_experiment_vw abrm,
          aud_freq_experiment f
    WHERE csl.ID = e.set_id
      AND e.wt_only = 1
      AND e.cohort_id = c.ID
      AND c.pipeline_dict_id IN (2, 14)
      AND m.cohort_id = c.ID
      AND abrm.mouse_id = m.mouse_id
      AND m.ID = ma.mouse_id(+)
      AND NVL (ma.genotype_dict_id, 1) = 1
      AND m.mouse_id = mv.ID
      AND f.phn_experiment_id = abrm.ID
      AND f.threshold IS NOT NULL;

CREATE MATERIALIZED VIEW PHN_LINE_GRAPH_ABR_MV
TABLESPACE DATA_02
PCTUSED    0
PCTFREE    10
INITRANS   2
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       UNLIMITED
            PCTINCREASE      0
            BUFFER_POOL      DEFAULT
           )
NOCACHE
LOGGING
NOCOMPRESS
NOPARALLEL
BUILD IMMEDIATE
REFRESH FORCE
START WITH TO_DATE('11-Feb-2009 03:00:00','dd-mon-yyyy hh24:mi:ss')
NEXT trunc(sysdate) + 1 + (3/24)
WITH PRIMARY KEY
AS
  SELECT p.*
  FROM phn_line_graph_abr_vw p
 WHERE p.include = 'Yes' AND p.process_status = 'Completed';


CREATE OR REPLACE FUNCTION AUD_FETCH_MICE_COUNT_INCLUDE(p_cohortset_ID number) RETURN INTEGER IS

micecount INTEGER:=0;
CURSOR ABR_CUR IS
   select count(distinct(w.MOUSE_ID)) micecount from phn_line_graph_abr_mv w where w.COHORT_SET_ID=p_cohortset_ID;


BEGIN
OPEN ABR_CUR;

 FETCH ABR_CUR INTO micecount;
 CLOSE ABR_CUR;

RETURN micecount;

END AUD_FETCH_MICE_COUNT_INCLUDE;
/




