CREATE OR REPLACE VIEW rep_mouse_header_vw AS
   WITH colony_gene AS
        (SELECT a.colony_id, g.primary_name gene_name
           FROM mts_colony_allele a JOIN typ_modified_allele t
                ON a.modified_allele_id = t.ID
                JOIN gnm_gene g ON t.gene_id = g.ID
                )
   SELECT ci.colony_prefix, ci.colony_name, t.NAME strain,
          m.mouse_strain_dict_id strain_id, c.cohort_name, cpd.NAME pipeline,
          c.ID cohort_id, c.pipeline_dict_id pipeline_id, cg.gene_name,
          m.NAME mouse_name, m.barcode mouse, m.ID mouse_id,
          mts.fetch_genotype (m.ID) AS genotype, gd.NAME gender,
          m.gender_dict_id gender_id, m.birth_date
     FROM mts_mouse m JOIN mts_cohort_mouse cm ON m.ID = cm.mouse_id
          JOIN mts_cohort c ON cm.cohort_id = c.ID AND c.cohort_type_id = 1
          LEFT OUTER JOIN colony_gene cg ON m.colony_info_id = cg.colony_id
          LEFT OUTER JOIN mts_cohort_pipeline_dict cpd
          ON cpd.ID = c.pipeline_dict_id
          JOIN typ_strain t ON m.mouse_strain_dict_id = t.ID
          JOIN mts_gender_dict gd ON m.gender_dict_id = gd.ID
          LEFT OUTER JOIN mts_colony_info ci ON m.colony_info_id = ci.ID;

CREATE OR REPLACE VIEW phn_experiment_summary_vw AS
   SELECT m.*, TO_CHAR (mp.start_date, 'dd-mm-yyyy') assay_date,
          ROUND ((mp.start_date - m.birth_date) / 7, 1) age_in_weeks,
          per.first_name || ' ' || per.last_name pil_holder, e.sop_id,
          e.is_complete, e.ID experiment_id
     FROM phn_experiment e JOIN rep_mouse_header_vw m ON m.mouse_id =
                                                                    e.mouse_id
          JOIN mts_mouse_procedure mp
          ON e.ID = mp.foreign_key_id
        AND mp.foreign_table_name = 'PHN_EXPERIMENT'
          JOIN lic_personal_licence pil
          ON mp.personal_licence_id = pil.personal_licence_id
          JOIN per_person per ON pil.person_id = per.person_id;

CREATE OR REPLACE VIEW phn_weights_bin_mouse_week_vw
AS
   SELECT   w.mouse_id, AVG (w.weight_value) avg_weight, w.weight_units,
            ROUND ((w.sample_date - m.birth_date) / 7) week,
            COUNT (*) sample_count
       FROM mts_all_mouse_weight_vw w JOIN mts_mouse m ON m.ID = w.mouse_id
      WHERE m.birth_date IS NOT NULL
   GROUP BY w.mouse_id,
            w.weight_units,
            ROUND ((w.sample_date - m.birth_date) / 7);


CREATE OR REPLACE VIEW phn_mouse_weights_binned_vw
AS
   SELECT m.*, w.avg_weight, w.weight_units, w.week, w.sample_count
     FROM rep_mouse_header_vw m JOIN phn_weights_bin_mouse_week_vw w
          ON m.mouse_id = w.mouse_id
          ;


CREATE OR REPLACE VIEW phn_ipgtt_time_series_vw
AS
   SELECT e.cohort_id + (o.ID * 1e9) ID, e.*,
          CASE
             WHEN o.required_observation_id = 152
                THEN 0
             WHEN o.required_observation_id = 153
                THEN 15
             WHEN o.required_observation_id = 154
                THEN 30
             WHEN o.required_observation_id = 155
                THEN 60
             WHEN o.required_observation_id = 156
                THEN 120
             ELSE -1
          END AS TIME,
          TO_NUMBER (o.VALUE) blood_glucose_conc
     FROM phn_experiment_summary_vw e JOIN phn_observation o
          ON e.experiment_id = o.experiment_id
    WHERE e.sop_id = 10
      AND e.is_complete = 1
      AND o.required_observation_id IN (152, 153, 154, 155, 156);


CREATE OR REPLACE VIEW phn_calorimetry_time_series_vw
AS   SELECT e.*, c."TIME", c."AVG_MINUTES_ELAPSED", c."SAMPLES",
c."CO2",
          c."O2", c."REF_CO2", c."REF_O2", c."CO2_DIFFERENCE",
          c."O2_DIFFERENCE", c."CUMULATIVE_FOOD_INTAKE",
c."FLOW_RATE_IN",
          c."SAMPLE_FLOW_RATE_OUT", c."TEMPERATURE",
          c."RESPIRATORY_EXCHANGE_RATIO", c."VCO2_BODYWEIGHT",
          c."VCO2_LEAN_MASS", c."VCO2_ANIMAL", c."VO2_BODYWEIGHT",
          c."VO2_LEAN_MASS", c."VO2_ANIMAL",
c."ENERGY_EXPEND_BODYWEIGHT",
          c."ENERGY_EXPEND_LEAN_MASS", c."ENERGY_EXPEND_ANIMAL",
          c."HEAT_BODYWEIGHT", c."HEAT_LEAN_MASS", c."HEAT_ANIMAL",
          c."XAXIS_ACTIVITY_COUNT", c."XAXIS_ACTIVITY_COUNT_TOTAL",
          c."YAXIS_ACTIVITY_COUNT", c."YAXIS_ACTIVITY_COUNT_TOTAL",
             TRUNC (c.TIME)
          -  TRUNC (mp.start_date)
          || TO_CHAR (c.TIME, ' HH24:MI') x_label
     FROM phn_calorimetry_data_binned_vw c
     JOIN phn_experiment_summary_vw e on e.experiment_id =
c.experiment_id
     JOIN mts_mouse_procedure mp on e.experiment_id = mp.foreign_key_id
and mp.foreign_table_name = 'PHN_EXPERIMENT';


CREATE MATERIALIZED VIEW PHN_WEIGHTS_BIN_MOUSE_WEEK_MV
REFRESH FORCE
START WITH TO_DATE('13-Feb-2009 03:00:00','dd-mon-yyyy hh24:mi:ss')
NEXT trunc(sysdate) + 1 + (3/24)
AS
SELECT
R.MOUSE_ID, R.AVG_WEIGHT, R.WEIGHT_UNITS,
   R.WEEK, R.SAMPLE_COUNT
FROM PHN_WEIGHTS_BIN_MOUSE_WEEK_VW R;


CREATE MATERIALIZED VIEW PHN_IPGTT_TIME_SERIES_MV
REFRESH FORCE
START WITH TO_DATE('13-Feb-2009 03:00:00','dd-mon-yyyy hh24:mi:ss')
NEXT trunc(sysdate) + 1 + (3/24)
AS
SELECT
P.ID, P.COLONY_PREFIX, P.COLONY_NAME,
   P.STRAIN, P.STRAIN_ID, P.COHORT_NAME,
   P.PIPELINE, P.COHORT_ID, P.PIPELINE_ID,
   P.GENE_NAME, P.MOUSE_NAME, P.MOUSE,
   P.MOUSE_ID, P.GENOTYPE, P.GENDER,
   P.GENDER_ID, P.BIRTH_DATE, P.ASSAY_DATE,
   P.AGE_IN_WEEKS, P.PIL_HOLDER, P.SOP_ID,
   P.IS_COMPLETE, P.EXPERIMENT_ID, P.TIME,
   P.BLOOD_GLUCOSE_CONC
FROM PHN_IPGTT_TIME_SERIES_VW P;


CREATE MATERIALIZED VIEW PHN_CALORIMETRY_TIME_SERIES_MV
REFRESH FORCE
START WITH TO_DATE('13-Feb-2009 03:00:00','dd-mon-yyyy hh24:mi:ss')
NEXT trunc(sysdate) + 1 + (3/24)
AS
SELECT
P.COLONY_PREFIX, P.COLONY_NAME, P.STRAIN,
   P.STRAIN_ID, P.COHORT_NAME, P.PIPELINE,
   P.COHORT_ID, P.PIPELINE_ID, P.GENE_NAME,
   P.MOUSE_NAME, P.MOUSE, P.MOUSE_ID,
   P.GENOTYPE, P.GENDER, P.GENDER_ID,
   P.BIRTH_DATE, P.ASSAY_DATE, P.AGE_IN_WEEKS,
   P.PIL_HOLDER, P.SOP_ID, P.IS_COMPLETE,
   P.EXPERIMENT_ID, P.TIME, P.AVG_MINUTES_ELAPSED,
   P.SAMPLES, P.CO2, P.O2,
   P.REF_CO2, P.REF_O2, P.CO2_DIFFERENCE,
   P.O2_DIFFERENCE, P.CUMULATIVE_FOOD_INTAKE, P.FLOW_RATE_IN,
   P.SAMPLE_FLOW_RATE_OUT, P.TEMPERATURE, P.RESPIRATORY_EXCHANGE_RATIO,
   P.VCO2_BODYWEIGHT, P.VCO2_LEAN_MASS, P.VCO2_ANIMAL,
   P.VO2_BODYWEIGHT, P.VO2_LEAN_MASS, P.VO2_ANIMAL,
   P.ENERGY_EXPEND_BODYWEIGHT, P.ENERGY_EXPEND_LEAN_MASS, P.ENERGY_EXPEND_ANIMAL,
   P.HEAT_BODYWEIGHT, P.HEAT_LEAN_MASS, P.HEAT_ANIMAL,
   P.XAXIS_ACTIVITY_COUNT, P.XAXIS_ACTIVITY_COUNT_TOTAL, P.YAXIS_ACTIVITY_COUNT,
   P.YAXIS_ACTIVITY_COUNT_TOTAL, P.X_LABEL
FROM PHN_CALORIMETRY_TIME_SERIES_VW P;