CREATE OR REPLACE procedure MIG.gra_ref_ranges_bar is

plsql_block VARCHAR2(1000);

cursor view_new_cur is
select
  m.ID,m.VIEW_NAME view_name, m.PLOT_COLUMN
from
 REP_GRAPH_METADATA m
 where compute_ref_range=1
 and graph_type_id = 2
 order by m.id
 ;

begin
for view_rec in view_new_cur
 loop
         plsql_block := 'insert into REP_BAR_RANGE (GRAPH_METADATA_ID,STRAIN_ID,GENDER_ID,COLUMN_PARAMETER,PARAMETER_COUNT,pipeline_dict_id) '
              ||'select '||view_rec.ID||',strain_id, gender_id,'
              ||'nvl('||view_rec.PLOT_COLUMN||',''0''),'
              ||'COUNT(nvl('||view_rec.PLOT_COLUMN||',''0'')),'
              ||' pipeline_id '
              ||' from '||view_rec.view_name||' where genotype= ''+/+'''
              ||' group by '||view_rec.plot_column||',strain_id,gender_id,pipeline_id';
        --dbms_output.put_line(plsql_block);
         begin
             delete REP_BAR_RANGE where graph_metadata_id = view_rec.ID;
             execute immediate plsql_block;
         exception when others then dbms_output.put_line('Failed Bar Reference Range Calc:'||view_rec.view_name);
         end;
  end loop;

end gra_ref_ranges_bar;
/

CREATE OR REPLACE procedure MIG.gra_ref_ranges_scatter is

plsql_block VARCHAR2(1000);

cursor view_new_cur is
select
  m.ID,m.VIEW_NAME view_name, m.PLOT_COLUMN
from
 REP_GRAPH_METADATA m
 where compute_ref_range=1
 and graph_type_id = 1
 order by m.id
 ;


begin
for view_rec in view_new_cur loop
         plsql_block := 'insert into REP_SCATTER_RANGE (GRAPH_METADATA_ID,STRAIN_ID,NUM_ROWS,PCT_25,MEDIAN,PCT_975,MINUS_2_SD, MINUS_1_SD, MEAN, PLUS_1_SD, PLUS_2_SD,gender_id,pipeline_dict_id) '
              ||'select '||view_rec.ID||',strain_id,'
              ||'COUNT('||view_rec.PLOT_COLUMN||'),'
              ||'PERCENTILE_CONT(0.975) WITHIN GROUP (ORDER BY to_number('||view_rec.PLOT_COLUMN||') DESC),'
              ||'PERCENTILE_CONT(0.5) WITHIN GROUP (ORDER BY to_number('||view_rec.PLOT_COLUMN||') DESC),'
              ||'PERCENTILE_CONT(0.025) WITHIN GROUP (ORDER BY to_number('||view_rec.PLOT_COLUMN||') DESC),'
              ||'AVG('||view_rec.PLOT_COLUMN||')-2*STDDEV('||view_rec.PLOT_COLUMN||'),'
              ||'AVG('||view_rec.PLOT_COLUMN||')-STDDEV('||view_rec.PLOT_COLUMN||'),'
              ||'AVG('||view_rec.PLOT_COLUMN||'),'
              ||'AVG('||view_rec.PLOT_COLUMN||')+STDDEV('||view_rec.PLOT_COLUMN||'),'
              ||'AVG('||view_rec.PLOT_COLUMN||')+2*STDDEV('||view_rec.PLOT_COLUMN||'),'
              ||' gender_id, pipeline_id'
              ||' from '||view_rec.view_name||' where genotype= ''+/+'''
              ||' group by strain_id,gender_id,pipeline_id';
         --dbms_output.put_line(plsql_block);
         begin
             delete REP_SCATTER_RANGE where graph_metadata_id = view_rec.ID;
             execute immediate plsql_block;
         exception when others then dbms_output.put_line('Failed Scatter Reference Range Calc:'||view_rec.view_name);
         end;
 end loop;

end gra_ref_ranges_scatter;
/

CREATE OR REPLACE procedure MIG.gra_ref_ranges_line(combine_genders in varchar2) is

insert_sql varchar2(1000);

cursor view_new_cur is
select
  m.id,m.view_name view_name, m.plot_column, m.xaxis_column
from
 rep_graph_metadata m
 where compute_ref_range=1
 and graph_type_id = 3
 order by m.id
;

begin
  for view_rec in view_new_cur loop
    insert_sql := 'insert into REP_LINE_RANGE (GRAPH_METADATA_ID,XLABEL,STRAIN_ID,NUM_ROWS,PCT_25,MEDIAN,PCT_975,MINUS_2_SD, MINUS_1_SD, MEAN, PLUS_1_SD, PLUS_2_SD,gender_id,pipeline_dict_id) '
                  ||'select '||view_rec.id||','||view_rec.xaxis_column||',strain_id,COUNT('||view_rec.plot_column||'),'
                  ||'PERCENTILE_CONT(0.975) WITHIN GROUP (ORDER BY to_number('||view_rec.plot_column||') DESC),'
                  ||'PERCENTILE_CONT(0.5) WITHIN GROUP (ORDER BY to_number('||view_rec.plot_column||') DESC),'
                  ||'PERCENTILE_CONT(0.025) WITHIN GROUP (ORDER BY to_number('||view_rec.plot_column||') DESC),'
                  ||'AVG('||view_rec.plot_column||')-2*STDDEV('||view_rec.plot_column||'),'
                  ||'AVG('||view_rec.plot_column||')-STDDEV('||view_rec.plot_column||'),'
                  ||'AVG('||view_rec.plot_column||'),'
                  ||'AVG('||view_rec.plot_column||')+STDDEV('||view_rec.plot_column||'),'
                  ||'AVG('||view_rec.plot_column||')+2*STDDEV('||view_rec.plot_column||'),'
                  ||'gender_id,pipeline_id'
                  ||' from '||view_rec.view_name||' where genotype= ''+/+'''
                  ||' group by '||view_rec.xaxis_column||',strain_id,gender_id,pipeline_id';
                  --dbms_output.put_line(insert_sql);

                  if upper(combine_genders) = 'COMBINE' then
                    insert_sql := replace(insert_sql,'gender_id,','');
                    delete rep_line_range where graph_metadata_id = view_rec.id and gender_id is null;
                  else
                     delete rep_line_range where graph_metadata_id = view_rec.id and gender_id is not null;
                  end if;

                 begin

                  execute immediate insert_sql;

                 exception when others then
                    dbms_output.put_line('Failed Line Reference Range Calc:'||view_rec.view_name);
                 end;

 end loop;

end gra_ref_ranges_line;
/

CREATE OR REPLACE procedure MIG.gra_load_data_available is

plsql_block VARCHAR2(10000);

cursor view_new_cur is
select
  m.ID,m.VIEW_NAME, m.PLOT_COLUMN
from
 REP_GRAPH_METADATA m;

begin

execute immediate 'truncate table REP_GRAPH_DATA_AVAILABLE';

for view_rec in view_new_cur
 loop
         plsql_block := 'insert into REP_GRAPH_DATA_AVAILABLE (
            gene_id,
            gene_name,
            allele_id,
            allele_name,
            pipeline_id,
            pipeline_name,
            reporting_test,
            page_type_id,
            data_available,
            record_count,
            colony_id,
            colony_prefix,
            colony_name)
            select
            g.id gene_id,
            g.primary_name gene_name,
            a.id allele_id,
            A.internal_name allele_name,
            v.pipeline_id pipeline_id,
            d.name pipeline_name,
            t.description test,
            T.PAGE_TYPE_ID page_type_id,
            decode(count(v.'||view_rec.plot_column||'),0,0,1) data_available,
            count(v.'||view_rec.plot_column||') record_count,
            ci.id,
            ci.colony_prefix,
            ci.colony_name
            from '||view_rec.view_name||' v,
            mts_cohort_set_element cs,
            mts_cohort_set s,
            typ_modified_allele a,
            gnm_gene g,
            rep_pipeline_tests t,
            mts_cohort_pipeline_dict d,
            rep_page_type pt,
            rep_page_subgroup sg,
            rep_graph rg,
            rep_graph_metadata gm,
            mts_colony_allele ca,
            mts_colony_info ci
            where v.cohort_id = cs.cohort_id
            and cs.set_id = s.id
            and s.allele_id = a.id
            and a.id = ca.modified_allele_id(+)
            and ca.colony_id = ci.id(+)
            and a.gene_id = g.id
            and v.pipeline_id = t.pipeleine_id
            and v.pipeline_id = d.id
            and RG.GRAPH_METADATA_ID = gm.id
            and RG.REP_SUBGROUP_ID = sg.id
            and SG.REP_PAGE_TYPE_ID = pt.id
            and pt.id = T.PAGE_TYPE_ID
            and gm.id = '||view_rec.id||'
            group by g.id,g.primary_name,a.id,a.internal_name,v.pipeline_id, d.name,t.description,t.page_type_id,ci.id,ci.colony_prefix,ci.colony_name';
         --dbms_output.put_line(plsql_block);
         begin
             execute immediate plsql_block;
         exception when others then dbms_output.put_line('Failed insert REP_GRAPH_DATA_AVAILABLE:'||view_rec.view_name);
         end;
  commit;
 end loop;

 end gra_load_data_available;
 /


CREATE OR REPLACE procedure MIG.gra_run_all_refranges is

begin

    gra_ref_ranges_bar;

    gra_ref_ranges_scatter;

    gra_ref_ranges_line('');

    gra_ref_ranges_line('COMBINE');

 end gra_run_all_refranges;
 /

