CREATE OR REPLACE function MIG.mts_fetch_age(in_mouse_id number) return varchar2 is

cursor mouse_details is
select
  l.plug_check_date,
  m.birth_date,
  m.death_date
from
  mts_mouse m,
  mts_litter l
where
  m.id = in_mouse_id and
  m.litter_id = l.id(+);

t_plug_date date;
t_birth_date date;
t_death_date date;

age_string varchar2(320);

is_embryo number;

age_in_days number;

begin

  open mouse_details;
  fetch mouse_details into t_plug_date,t_birth_date,t_death_date;
  close mouse_details;

  if t_plug_date is not null and t_birth_date is null and t_death_date is not null then is_embryo := 1; end if;

  if is_embryo is not null then
    age_in_days := nvl(t_death_date,sysdate) - t_plug_date;
    age_string := to_char((0.5 + age_in_days),'FM9990.0')||'E';
  elsif t_birth_date is null then
    age_string := 'unknown';
  else
    age_in_days := nvl(t_death_date,sysdate) - t_birth_date;
    age_string := to_char(((0.5 + age_in_days)/7),'FM9990.0')||'w';
  end if;

  if t_death_date is not null then
    age_string := age_string||' (at death)';
  end if;

  return age_string;
end;
/

CREATE OR REPLACE VIEW MTS_MOUSE_CURRENT_19B_VW
AS
with max_id as (
  select
    p.*,
    row_number() over (partition by mouse_id order by start_date desc, id desc) row_number
  from
    mts_mouse_procedure p
  where
    protocol_id is not null
  )
select
  m.id,
  m.mouse_id,
  m.protocol_id,
  m.personal_licence_id,
  m.start_date,
  m.end_date,
  m.foreign_key_id,
  m.foreign_table_name,
  m.procedure_dict_id,
  d.name procedure,
  ppl.project_licence_id,
  ppl.licence_number,
  b.protocol_code,
  pil.pil_number,
  m.edited_by
from
  lic_project_licence ppl,
  lic_protocol_19b b,
  lic_personal_licence pil,
  mts_procedure_dict d,
  max_id m
where
  m.row_number = 1 and
  m.protocol_id = b.id and
  b.project_licence_id = ppl.project_licence_id and
  m.personal_licence_id = pil.personal_licence_id(+) and
  m.procedure_dict_id = d.id;

CREATE OR REPLACE VIEW MTS_LITTER_DETAIL_VW
AS
select
  m.id,
  m.litter_id,
  m.name mouse_name,
  mts_fetch_age(m.id) age,
  e.name earmark,
  g.name gender,
  c.name coat_colour,
  mts_fetch_genotype(m.id) genotype,
  m.wean_date,
  m.generation,
  decode(l.protocol_id,null,null,l.licence_number||':'||l.protocol_code) ppl_19b,
  decode(l.protocol_id,null,null,l.procedure||' '||to_char(start_date,'DD-Mon-YYYY')||' '||l.pil_number||' '||l.edited_by) latest_procedure,
  cg.cage_id,
  decode(m.death_date,null,cg.room_name||' Rack '||cg.rack_name||' ('||cg.cage_barcode||')',d.name||' '||m.death_date) location,
  m.comments
from
  mts_mouse m,
  mts_earmark_dict e,
  mts_gender_dict g,
  mts_coat_colour_dict c,
  mts_cause_of_death_dict d,
  mts_cage_vw cg,
  mts_mouse_current_19b_vw l
where
  m.litter_id is not null and
  m.earmark_dict_id = e.id(+) and
  m.gender_dict_id = g.id and
  m.coat_colour_dict_id = c.id(+) and
  m.cause_of_death_dict_id = d.id(+) and
  m.cage_id = cg.cage_id(+) and
  m.id = l.mouse_id(+);


