CREATE OR REPLACE function mts_fetch_genotype (in_mouse_id number) return varchar2 is

cursor c_alleles is
select
  m.genotype_dict_id,
  nvl(a.short_allele_symbol,'ERROR') short_allele_symbol,
  a.inheritance_mode_id,
  c.percent_chimeric
from
  mts_mouse_allele m,
  typ_modified_allele a,
  mts_chimeric_mouse_data c
where
  m.mouse_id = in_mouse_id and
  m.allele_id = a.id and
  m.mouse_id = c.mouse_id(+);

cursor c_allele_count is
select
count(*)
from
  mts_mouse_allele m,
  typ_modified_allele a,
  mts_chimeric_mouse_data c
where
  m.mouse_id = in_mouse_id and
  m.allele_id = a.id and
  m.mouse_id = c.mouse_id(+);


allele_count INTEGER:=0;

v_genotype varchar2(4000) := '';

chromosome1 typ_modified_allele.short_allele_symbol%type;
chromosome2 typ_modified_allele.short_allele_symbol%type;
is_exception integer(1);
genotype_string varchar2(32);

begin
  open c_allele_count;
  fetch c_allele_count into allele_count;
  close c_allele_count;

  for a in c_alleles loop

    chromosome1 := '+';
    chromosome2 := '+';
    is_exception := 0;
    genotype_string := '';

    if a.genotype_dict_id = 1 and allele_count > 1 then -- wildtype with multiple alleles
      is_exception := 1;
      genotype_string := '+/+';
    elsif a.genotype_dict_id = 2 then --heterozygous
      chromosome1 := a.short_allele_symbol;
    elsif a.genotype_dict_id = 3 then --homozygous
      chromosome1 := a.short_allele_symbol;
      chromosome2 := a.short_allele_symbol;
    elsif a.genotype_dict_id = 6 then --hemizygous
      chromosome1 := a.short_allele_symbol;
      chromosome2 := 'Y';
    elsif a.genotype_dict_id = 4 then --untested
      is_exception := 1;
      genotype_string := 'untested';
    elsif a.genotype_dict_id = 5 then --failed
      is_exception := 1;
      genotype_string := 'failed';
    elsif a.genotype_dict_id = 10 then --chimera
      is_exception := 1;
      genotype_string := 'chimera';
      if a.percent_chimeric is not null then
        genotype_string := genotype_string||' '||a.percent_chimeric||'%';
      end if;
    elsif a.genotype_dict_id = 7 then --conditional het
      is_exception := 1;
      genotype_string := 'c/+';
    elsif a.genotype_dict_id = 7 then --conditional hom
      is_exception := 1;
      genotype_string := 'c/-';
    elsif a.genotype_dict_id = 7 then --conditional
      is_exception := 1;
      genotype_string := 'c/c';
    end if;

    if is_exception = 1 then
      genotype_string := a.short_allele_symbol||':'||genotype_string;
    else
      if a.inheritance_mode_id = 2 then --recessive allele
        genotype_string := chromosome2||'/'||chromosome1;
      else
        genotype_string := chromosome1||'/'||chromosome2;
      end if;
    end if;
    v_genotype := v_genotype||genotype_string||' ';
  end loop;

  return trim(nvl(v_genotype,'+/+'));

end mts_fetch_genotype;
/

CREATE OR REPLACE procedure gra_ref_ranges_bar is

plsql_block VARCHAR2(1000);

cursor view_new_cur is
select
  m.ID,m.VIEW_NAME view_name, m.PLOT_COLUMN
from
 REP_GRAPH_METADATA m
 where compute_ref_range=1
 and graph_type_id = 2
 order by m.id
 ;

begin
for view_rec in view_new_cur
 loop
         plsql_block := 'insert into REP_BAR_RANGE (GRAPH_METADATA_ID,STRAIN_ID,GENDER_ID,COLUMN_PARAMETER,PARAMETER_COUNT,pipeline_dict_id) '
              ||'select '||view_rec.ID||',strain_id, gender_id,'
              ||'nvl('||view_rec.PLOT_COLUMN||',''0''),'
              ||'COUNT(nvl('||view_rec.PLOT_COLUMN||',''0'')),'
              ||' pipeline_id '
              ||' from '||view_rec.view_name||' g where not exists (select null from mts_mouse_allele ma where g.mouse_id = ma.mouse_id and ma.genotype_dict_id <> 1)'
              ||' group by '||view_rec.plot_column||',strain_id,gender_id,pipeline_id';
        --dbms_output.put_line(plsql_block);
         begin
             delete REP_BAR_RANGE where graph_metadata_id = view_rec.ID;
             execute immediate plsql_block;
         exception when others then dbms_output.put_line('Failed Bar Reference Range Calc:'||view_rec.view_name);
         end;
  end loop;

end gra_ref_ranges_bar;
/

CREATE OR REPLACE procedure gra_ref_ranges_line(combine_genders in varchar2) is

insert_sql varchar2(1500);

cursor view_new_cur is
select
  m.id,m.view_name view_name, m.plot_column, m.xaxis_column
from
 rep_graph_metadata m
 where compute_ref_range=1
 and graph_type_id = 3
 order by m.id
;

begin
  for view_rec in view_new_cur loop
    insert_sql := 'insert into REP_LINE_RANGE (GRAPH_METADATA_ID,XLABEL,STRAIN_ID,NUM_ROWS,PCT_25,MEDIAN,PCT_975,MINUS_2_SD, MINUS_1_SD, MEAN, PLUS_1_SD, PLUS_2_SD,gender_id,pipeline_dict_id) '
                  ||'select '||view_rec.id||','||view_rec.xaxis_column||',strain_id,COUNT('||view_rec.plot_column||'),'
                  ||'PERCENTILE_CONT(0.975) WITHIN GROUP (ORDER BY to_number('||view_rec.plot_column||') DESC),'
                  ||'PERCENTILE_CONT(0.5) WITHIN GROUP (ORDER BY to_number('||view_rec.plot_column||') DESC),'
                  ||'PERCENTILE_CONT(0.025) WITHIN GROUP (ORDER BY to_number('||view_rec.plot_column||') DESC),'
                  ||'AVG('||view_rec.plot_column||')-2*STDDEV('||view_rec.plot_column||'),'
                  ||'AVG('||view_rec.plot_column||')-STDDEV('||view_rec.plot_column||'),'
                  ||'AVG('||view_rec.plot_column||'),'
                  ||'AVG('||view_rec.plot_column||')+STDDEV('||view_rec.plot_column||'),'
                  ||'AVG('||view_rec.plot_column||')+2*STDDEV('||view_rec.plot_column||'),'
                  ||'gender_id,pipeline_id'
                  ||' from '||view_rec.view_name||' g where not exists (select null from mts_mouse_allele ma where g.mouse_id = ma.mouse_id and ma.genotype_dict_id <> 1)'
                  ||' group by '||view_rec.xaxis_column||',strain_id,gender_id,pipeline_id';
                  --dbms_output.put_line(insert_sql);

                  if upper(combine_genders) = 'COMBINE' then
                    insert_sql := replace(insert_sql,'gender_id,','');
                    delete rep_line_range where graph_metadata_id = view_rec.id and gender_id is null;
                  else
                     delete rep_line_range where graph_metadata_id = view_rec.id and gender_id is not null;
                  end if;

                 begin

                  execute immediate insert_sql;

                 exception when others then
                    dbms_output.put_line('Failed Line Reference Range Calc:'||view_rec.view_name);
                 end;

 end loop;

end gra_ref_ranges_line;
/

CREATE OR REPLACE procedure gra_ref_ranges_scatter is

plsql_block VARCHAR2(1500);

cursor view_new_cur is
select
  m.ID,m.VIEW_NAME view_name, m.PLOT_COLUMN
from
 REP_GRAPH_METADATA m
 where compute_ref_range=1
 and graph_type_id = 1
 order by m.id
 ;


begin
for view_rec in view_new_cur loop
         plsql_block := 'insert into REP_SCATTER_RANGE (GRAPH_METADATA_ID,STRAIN_ID,NUM_ROWS,PCT_25,MEDIAN,PCT_975,MINUS_2_SD, MINUS_1_SD, MEAN, PLUS_1_SD, PLUS_2_SD,gender_id,pipeline_dict_id) '
              ||'select '||view_rec.ID||',strain_id,'
              ||'COUNT('||view_rec.PLOT_COLUMN||'),'
              ||'PERCENTILE_CONT(0.975) WITHIN GROUP (ORDER BY to_number('||view_rec.PLOT_COLUMN||') DESC),'
              ||'PERCENTILE_CONT(0.5) WITHIN GROUP (ORDER BY to_number('||view_rec.PLOT_COLUMN||') DESC),'
              ||'PERCENTILE_CONT(0.025) WITHIN GROUP (ORDER BY to_number('||view_rec.PLOT_COLUMN||') DESC),'
              ||'AVG('||view_rec.PLOT_COLUMN||')-2*STDDEV('||view_rec.PLOT_COLUMN||'),'
              ||'AVG('||view_rec.PLOT_COLUMN||')-STDDEV('||view_rec.PLOT_COLUMN||'),'
              ||'AVG('||view_rec.PLOT_COLUMN||'),'
              ||'AVG('||view_rec.PLOT_COLUMN||')+STDDEV('||view_rec.PLOT_COLUMN||'),'
              ||'AVG('||view_rec.PLOT_COLUMN||')+2*STDDEV('||view_rec.PLOT_COLUMN||'),'
              ||' gender_id, pipeline_id'
              ||' from '||view_rec.view_name||' g where not exists (select null from mts_mouse_allele ma where g.mouse_id = ma.mouse_id and ma.genotype_dict_id <> 1)'
              ||' group by strain_id,gender_id,pipeline_id';
         --dbms_output.put_line(plsql_block);
         begin
             delete REP_SCATTER_RANGE where graph_metadata_id = view_rec.ID;
             execute immediate plsql_block;
         exception when others then dbms_output.put_line('Failed Scatter Reference Range Calc:'||view_rec.view_name);
         end;
 end loop;

end gra_ref_ranges_scatter;
/

CREATE INDEX MTS_MOUSE_ALLELE_IND3 ON MTS_MOUSE_ALLELE (MOUSE_ID, GENOTYPE_DICT_ID) TABLESPACE INDEX_02;
