CREATE MATERIALIZED VIEW REP_ALL_MICE_WITH_GENE_MV
TABLESPACE DATA_02
NOCACHE
LOGGING
NOCOMPRESS
NOPARALLEL
BUILD IMMEDIATE
REFRESH FORCE
NEXT sysdate + (1/24)
WITH PRIMARY KEY
AS
with colony_allele_count as (
    select
      colony_id,count(modified_allele_id) colony_allele_count
    from
      mts_colony_allele
    group by
      colony_id
),
single_gene_colony as (
    select
      c.colony_id,
      g.id gene_id,
      g.primary_name,
      a.id allele_id,
      a.official_name_superscript allele_name
    from
      colony_allele_count t,
      typ_modified_allele a,
      mts_colony_allele c,
      gnm_gene g
    where
      t.colony_allele_count = 1 and
      t.colony_id = c.colony_id and
      c.modified_allele_id = a.id and
      a.gene_id = g.id(+)
)
select
  id,
  litter_id,
  name,
  rfid_tag,
  edit_date,
  coat_colour_dict_id,
  coat_colour,
  eye_colour_dict_id,
  eye_colour,
  earmark_dict_id,
  earmark,
  birth_date,
  age_in_weeks,
  death_date,
  age_at_death,
  cause_of_death_dict_id,
  cause_of_death,
  edited_by,
  wean_date,
  cage_id,
  cage_name,
  cage_barcode,
  rack_id,
  rack_name,
  room_id,
  room_name,
  current_owner_id,
  current_owner,
  current_project_licence_id,
  current_project_licence,
  current_protocol_id,
  current_protocol_code,
  check_number,
  gender_dict_id,
  gender,
  mouse_strain_dict_id,
  strain,
  status,
  creator_id,
  created_date,
  barcode,
  comments,
  is_non_breeder,
  is_sentinel,
  generation,
  colony_name,
  colony_prefix,
  colony_info_id,
  decode(cc.colony_allele_count,0,null,null,null,1,c.primary_name,'Multi Gene') colony_gene,
  c.gene_id colony_gene_id,
  decode(cc.colony_allele_count,0,null,null,null,1,c.allele_name,'Multi Allele') colony_allele,
  c.allele_id colony_allele_id,
  arrival_date,
  latest_plug_date,
  breeding_name,
  genotype,
  father_name,
  father_genotype,
  mother_name,
  mother_genotype,
  cohorts,
  pipelines,
  reservation,
  category,
  category_id,
  purpose_id,
  reserver_id,
  team_id,
  purpose,
  reserver,
  reservation_team
from
  mts_mouse_vw m,
  single_gene_colony c,
  colony_allele_count cc
where
  m.colony_info_id = c.colony_id(+) and
  m.colony_info_id = cc.colony_id(+);