--drop  table MIC_TISSUE_DICT;

CREATE TABLE MIC_TISSUE_DICT
(
  ID           INTEGER                          NOT NULL,
  NAME         VARCHAR2(256 CHAR)               NOT NULL,
  DESCRIPTION  VARCHAR2(2048 CHAR),
  ACTIVE       NUMBER(1)                        DEFAULT 1                     NOT NULL,
  ORDER_BY     NUMBER
);

ALTER TABLE MIC_TISSUE_DICT ADD (
  CONSTRAINT MIC_TISSUE_DICT_PK
 PRIMARY KEY
 (ID),
  CONSTRAINT MIC_TISSUE_DICT_U01
 UNIQUE (NAME));

--drop TABLE MIC_DESCRIPTION_DICT;

CREATE TABLE MIC_DESCRIPTION_DICT
(
  ID           INTEGER                          NOT NULL,
  NAME         VARCHAR2(256 CHAR)               NOT NULL,
  DESCRIPTION  VARCHAR2(2048 CHAR),
  ACTIVE       NUMBER(1)                        DEFAULT 1                     NOT NULL,
  ORDER_BY     NUMBER
);

ALTER TABLE MIC_DESCRIPTION_DICT ADD (
  CONSTRAINT MIC_DESCRIPTION_DICT_PK
 PRIMARY KEY
 (ID),
  CONSTRAINT MIC_DESCRIPTION_DICT_U01
 UNIQUE (NAME));

CREATE TABLE MIC_META_DATA
(
  ID                          NUMBER,
  READ_ONLY_META_DATA_ID      NUMBER,
  URL                         VARCHAR2(2048 BYTE),
  IS_PRIMARY_FOR_TISSUE_TYPE  NUMBER,
  EDIT_DATE                   DATE              DEFAULT SYSDATE,
  EDITED_BY                   VARCHAR2(128 BYTE),
  CREATED_DATE                DATE              DEFAULT SYSDATE,
  CREATOR_ID                  NUMBER,
  CHECK_NUMBER                NUMBER,
  QC_PASS                     NUMBER(1),
  TISSUE_DICT_ID              NUMBER,
  DESCRIPTION_DICT_ID         NUMBER,
  FILE_PATH                   VARCHAR2(2048 BYTE),
  IMAGE_WIDTH                 INTEGER,
  IMAGE_HEIGHT                INTEGER,
  COMMENTS                    VARCHAR2(2048 BYTE)
);


ALTER TABLE MIC_META_DATA ADD (
  CONSTRAINT MIC_PUBLICATION_PK
 PRIMARY KEY
 (ID));

ALTER TABLE MIC_META_DATA ADD (
  CONSTRAINT MIC_META_DATA_R01
 FOREIGN KEY (TISSUE_DICT_ID)
 REFERENCES MIC_TISSUE_DICT (ID));

alter table mic_meta_data add (

    constraint mic_meta_data_r02 foreign key (description_dict_id) references mic_description_dict(id)

);


CREATE SEQUENCE MIC_META_DATA_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

--DROP VIEW MTS_COHORT_SET_ELEMENT_LIST_VW;

CREATE OR REPLACE FORCE VIEW mts_cohort_set_element_list_vw (ID,
                                                             set_id,
                                                             cohort_id,
                                                             cohort_name,
                                                             wt_dict_id,
                                                             wt_dict_name,
                                                             reason,
                                                             created_date,
                                                             pipeline,
                                                             pipeline_id,
                                                             cohort_strain,
                                                             cohort_allele_id
                                                            )
AS
   SELECT e.ID, e.set_id, cl.ID cohort_id, cl.cohort_name, e.wt_dict_id,
          d.NAME wt_dict_name, cl.reason, cl.created_date, cl.pipeline, CL.PIPELINE_DICT_ID,
          cl.cohort_strain, cl.cohort_allele_id
     FROM mts_cohort_set_element e,
          mts_cohort_list_vw cl,
          mts_cohort_set_wt_dict d
    WHERE e.cohort_id = cl.ID AND e.wt_dict_id = d.ID(+);


CREATE OR REPLACE TRIGGER mic_meta_data_t1
BEFORE INSERT OR UPDATE ON mic_meta_data
FOR EACH ROW
DECLARE
  e EXCEPTION;
  PRAGMA EXCEPTION_INIT(e,-20001);
  valid_id NUMBER;
  CURSOR c (id_in NUMBER) IS
    SELECT   id
    FROM     mic_read_only_meta_data_vw@mimp.world
    WHERE     id = id_in;
BEGIN
  OPEN c(:NEW.read_only_meta_data_id);
  FETCH c INTO valid_id;
  CLOSE c;
  IF valid_id IS NULL THEN
    RAISE_APPLICATION_ERROR(-20001,'Invalid read_only_meta_data_id foreign key.');
  END IF;
END;
/


/* Formatted on 2009/03/10 14:29 (Formatter Plus v4.8.8) */
CREATE OR REPLACE FORCE VIEW mic_meta_data_vw (ID,
                                               read_only_meta_data_id,
                                               url,
                                               is_primary_for_tissue_type,
                                               edit_date,
                                               edited_by,
                                               created_date,
                                               creator_id,
                                               check_number,
                                               qc_pass,
                                               tissue_dict_id,
                                               description_dict_id,
                                               file_path,
                                               image_width,
                                               image_height,
                                               comments,
                                               img_wme,
                                               img_faxitron,
                                               img_slit_lamp,
                                               img_skin_screen,
                                               img_video,
                                               genotype_locked,
                                               pipeline_id,
                                               pipeline,
                                               allele_id,
                                               allele_superscript,
                                               gene_id,
                                               gene_name,
                                               genotype_id,
                                               genotype,
                                               gender,
                                               gender_dict_id,
                                               age_at_death
                                              )
AS
   SELECT   md."ID", md."READ_ONLY_META_DATA_ID", md."URL",
            md."IS_PRIMARY_FOR_TISSUE_TYPE", md."EDIT_DATE", md."EDITED_BY",
            md."CREATED_DATE", md."CREATOR_ID", md."CHECK_NUMBER",
            md."QC_PASS", md."TISSUE_DICT_ID", md."DESCRIPTION_DICT_ID",
            md."FILE_PATH", md."IMAGE_WIDTH", md."IMAGE_HEIGHT",
            md."COMMENTS", mdro.img_wme, mdro.img_faxitron,
            mdro.img_slit_lamp, mdro.img_skin_screen, mdro.img_video,
            ma.is_qc_locked genotype_locked, cp.ID pipeline_id,
            cp.NAME pipeline, a.ID allele_id,
            a.official_name_superscript allele_superscript, g.ID gene_id,
            g.primary_name gene_name, gd.ID genotype_id, gd.NAME genotype,
            gnd.NAME gender, gnd.ID gender_dict_id,
            ROUND ((m.death_date - m.birth_date) / 7, 1) age_at_death
       FROM mic_meta_data md,
            mic_read_only_meta_data_vw@mimp.world mdro,
            mts_mouse m,
            mts_gender_dict gnd,
            mts_mouse_allele ma,
            typ_modified_allele a,
            gnm_gene g,
            mts_genotype_dict gd,
            mts_cohort_mouse cm,
            mts_cohort c,
            mts_cohort_pipeline_dict cp
           -- mts_cohort_set_element cse,
            --mts_cohort_set cs
      WHERE (m.NAME = mdro.sample_name OR m.barcode = mdro.sample_name)
        AND m.ID = cm.mouse_id(+)
        AND m.ID = ma.mouse_id(+)
        AND ma.genotype_dict_id = gd.ID(+)
        AND ma.allele_id = a.ID(+)
        AND a.gene_id = g.ID(+)
        AND cm.cohort_id = c.ID(+)
        --AND c.ID = cse.cohort_id(+)
        AND c.pipeline_dict_id = cp.ID(+)
        --AND cse.set_id = cs.ID(+)
        AND c.cohort_type_id = 1
        AND mdro.ID = md.read_only_meta_data_id
        AND m.gender_dict_id = gnd.ID(+)
        and ma.genotype_dict_id != 4
        and ma.genotype_dict_id != 5
   ORDER BY md.ID;


