CREATE OR REPLACE FORCE VIEW mig.phn_abr_experiment_vw (ID,
                                                        mouse_id,
                                                        mouse_cali_chart_id,
                                                        mouse_click_chart_id,
                                                        mouse_file_id,
                                                        simple_genotype,
                                                        genotype_id,
                                                        mouse_name,
                                                        anaesthetic,
                                                        anaesthetic_dose,
                                                        anaesthetic_route,
                                                        induction_time,
                                                        experiment_date,
                                                        weight,
                                                        age_in_weeks,
                                                        include_experiment,
                                                        comments,
                                                        user_comments,
                                                        mouse_barcode,
                                                        mouse_birth_date,
                                                        rfid_tag,
                                                        mouse_gender,
                                                        ear_clip,
                                                        genotype,
                                                        allele_id,
                                                        short_allele_symbol,
                                                        official_name_superscript,
                                                        colony_prefix,
                                                        gene_primary_name,
                                                        personal_licence_id,
                                                        pil_number,
                                                        user_id,
                                                        user_name,
                                                        project_licence_id,
                                                        ppl_number,
                                                        protocol_code,
                                                        process_status,
                                                        binary_file_id
                                                       )
AS
   SELECT e.ID ID, e.mouse_id mouse_id, bcalic4.ID mouse_cali_chart_id,
          bclickc3.ID mouse_click_chart_id, bfile1.ID mouse_file_id,
          mts.fetch_simple_genotype (e.mouse_id) simple_genotype,
          NVL (mall.genotype_dict_id, 1) genotype_id, m.NAME mouse_name,
          o1.VALUE anaesthetic, TO_NUMBER (o2.VALUE) anaesthetic_dose,
          o3.VALUE anaesthetic_route, o4.VALUE induction_time,
          TO_DATE (o5.VALUE, 'dd/mm/yyyy') experiment_date,
          TO_NUMBER (o6.VALUE) weight,
          ROUND ((TO_DATE (o5.VALUE, 'dd/mm/yyyy') - m.birth_date) / 7,
                 1
                ) age_in_weeks,
          DECODE (NVL (TO_NUMBER (o7.VALUE), 0),
                  0, 'No',
                  1, 'Yes'
                 ) include_experiment,
          o8.VALUE comments, o9.VALUE user_comments, m.barcode mouse_barcode,
          m.birth_date mouse_birth_date, m.rfid_tag, gd.NAME mouse_gender,
          ed.NAME ear_clip, mts.fetch_genotype (e.mouse_id) genotype,
          typall.ID allele_id, typall.short_allele_symbol,
          typall.official_name_superscript, ci.colony_prefix,
          g.primary_name gene_primary_name, mp.personal_licence_id,
          pil.pil_number, pil.person_id user_id,
          p.first_name || ' ' || p.last_name user_name,
          p19b.project_licence_id, ppl.licence_number ppl_number,
          p19b.protocol_code,
          DECODE (phn.fetch_abr_status (e.ID),
                  1, 'Completed',
                  0, 'In Process'
                 ) process_status,
          bf.ID AS binary_file_id
     FROM phn_experiment e,
          mts_mouse m,
          mts_earmark_dict ed,
          mts_mouse_allele mall,
          typ_modified_allele typall,
          gnm_gene g,
          mts_colony_info ci,
          mts_gender_dict gd,
          phn_observation o1,
          phn_observation o2,
          phn_observation o3,
          phn_observation o4,
          phn_observation o5,
          phn_observation o6,
          phn_observation o7,
          phn_observation o8,
          phn_observation o9,
          app_binary_files bfile1,
          app_binary_files bclickc3,
          app_binary_files bcalic4,
          mts_mouse_procedure mp,
          lic_personal_licence pil,
          lic_protocol_19b p19b,
          lic_project_licence ppl,
          per_person p,
          app_binary_files bf
    WHERE e.ID = o1.experiment_id(+)
      AND o1.experiment_id = bf.foreign_key_id
      AND bf.foreign_table_name = 'PHN_EXPERIMENT'
      AND bf.CONTENT_TYPE_DICT_ID = 1
      AND o1.required_observation_id(+) = 825
      AND e.ID = o2.experiment_id(+)
      AND o2.required_observation_id(+) = 826
      AND e.ID = o3.experiment_id(+)
      AND o3.required_observation_id(+) = 827
      AND e.ID = o4.experiment_id(+)
      AND o4.required_observation_id(+) = 828
      AND e.ID = o5.experiment_id(+)
      AND o5.required_observation_id(+) = 824
      AND e.ID = o6.experiment_id(+)
      AND o6.required_observation_id(+) = 823
      AND e.ID = o7.experiment_id(+)
      AND o7.required_observation_id(+) = 831
      AND e.ID = o8.experiment_id(+)
      AND o8.required_observation_id(+) = 829
      AND e.ID = o9.experiment_id(+)
      AND o9.required_observation_id(+) = 830
      AND e.sop_id = 149
      AND e.mouse_id = m.ID
      AND m.earmark_dict_id = ed.ID(+)
      AND bfile1.foreign_key_id(+) = e.ID
      AND bfile1.content_type_dict_id = 1
      AND bclickc3.foreign_key_id(+) = e.ID
      AND bclickc3.content_type_dict_id = 3
      AND bcalic4.foreign_key_id(+) = e.ID
      AND bcalic4.content_type_dict_id = 4
      AND m.gender_dict_id = gd.ID
      AND e.mouse_id = mall.mouse_id(+)
      AND mall.allele_id = typall.ID(+)
      AND typall.gene_id = g.ID(+)
      AND m.colony_info_id = ci.ID(+)
      AND mp.mouse_id = e.mouse_id
      AND mp.procedure_dict_id = 25
      AND mp.foreign_key_id = e.ID
      AND mp.personal_licence_id = pil.personal_licence_id
      AND pil.person_id(+) = p.person_id
      AND mp.protocol_id = p19b.ID
      AND p19b.project_licence_id = ppl.project_licence_id;