create or replace view rep_mating_summary_vw as
with
colony_count as (
select
ca.colony_id,
count (distinct ca.modified_allele_id) colony_allele_count,
count(distinct a.gene_id) colony_gene_count
from mts_colony_allele ca,
typ_modified_allele a
where ca.modified_allele_id = a.id
group by colony_id
),
single_gene_colony as (
select c.colony_id, g.id gene_id, g.primary_name, a.id allele_id, a.official_name_superscript allele_name
from colony_count t,
typ_modified_allele a,
mts_colony_allele c,
gnm_gene g
where t.colony_allele_count = 1
and t.colony_id = c.colony_id
and c.modified_allele_id = a.id
and a.gene_id = g.id(+)
)
select
b.id,
min(B.NAME_PREFIX || B.BREEDING_NUMBER) mating,
min(decode (cc.colony_gene_count,
               0, null,
               null, null,
               1, c.primary_name,
               'Multi Gene'
              )) gene,
min(c.gene_id) gene_id,
min(decode (cc.colony_allele_count,
               0, null,
               null, null,
               1, c.allele_name,
               'Multi Allele'
              )) allele,
min(c.allele_id) allele_id,
min(ci.colony_prefix) colony_prefix,
min(ci.id) colony_id,
min(mm.name) father,
min(decode(mm.id,99900002,null,99900001,null,mm.id)) father_id,
min(fm.name) mother,
min(fm.id) mother_id,
nvl(min(mgd.name),'Wildtype') father_genotype_status,
min(mgd.id) father_genotype_id,
nvl(min(fgd.name),'Wildtype') mother_genotype_status,
min(fgd.id) mother_genotype_id,
min(b.start_date) setup_date,
min(b.end_date) separation_date,
min(decode(b.end_date,null,null, round((b.end_date - b.start_date)/7,1) )) length_of_mating_weeks,
count(distinct om.id) number_of_pups_born,
count(distinct decode(om.wean_date,null,null,om.id) ) number_of_pups_weaned,
count(distinct l.id) total_number_of_litters_born
from mts_breeding b,
mts_colony_info ci,
colony_count cc,
single_gene_colony c,
mts_mouse mm,
mts_mouse fm,
mts_mouse_allele mma,
mts_mouse_allele fma,
mts_genotype_dict mgd,
mts_genotype_dict fgd,
mts_litter l,
mts_mouse om
where b.offspring_colony_id = ci.id
and ci.id = cc.colony_id(+)
and ci.id = c.colony_id(+)
and b.male_id = mm.id
and b.female_id = fm.id
and mm.id = mma.mouse_id(+)
and fm.id = fma.mouse_id(+)
and mma.genotype_dict_id = mgd.id(+)
and fma.genotype_dict_id = fgd.id(+)
and b.id = l.breeding_id(+)
and l.id = om.litter_id(+)
and b.embryo_transfer_id is null
group by b.id
order by min(b.start_date) desc;
