create or replace view mts_mouse_current_19b_vw as
with procs as (
select
  p.id,
  p.mouse_id,
  p.protocol_id,
  p.personal_licence_id,
  p.start_date,
  p.end_date,
  p.foreign_key_id,
  p.foreign_table_name,
  p.procedure_dict_id,
  pro.name procedure,
  ppl.project_licence_id,
  ppl.licence_number,
  p19.protocol_code,
  pil.pil_number,
  p.edited_by,
  row_number() over (partition by p.mouse_id order by p.start_date desc, p.id desc) row_number
from
  mts_mouse_procedure p,
  lic_protocol_19b p19,
  lic_personal_licence pil,
  lic_project_licence ppl,
  mts_procedure_dict pro
where
  p.protocol_id = p19.id and
  p19.project_licence_id = ppl.project_licence_id and
  p.personal_licence_id = pil.personal_licence_id and
  p.procedure_dict_id = pro.id
)
select
  id,
  mouse_id,
  protocol_id,
  personal_licence_id,
  start_date,
  end_date,
  foreign_key_id,
  foreign_table_name,
  procedure_dict_id,
  procedure,
  project_licence_id,
  licence_number,
  protocol_code,
  pil_number,
  edited_by
from
  procs
where
  row_number = 1;

DROP MATERIALIZED VIEW MTS_MOUSE_CURRENT_19B_MV;

CREATE MATERIALIZED VIEW MTS_MOUSE_CURRENT_19B_MV
TABLESPACE DATA_02
NOCACHE
LOGGING
NOCOMPRESS
NOPARALLEL
BUILD IMMEDIATE
REFRESH FORCE
START WITH TO_DATE('04-Mar-2009 14:16:07','dd-mon-yyyy hh24:mi:ss')
NEXT sysdate + (1/24/6)
WITH PRIMARY KEY
AS
/* Formatted on 2009/03/04 14:16 (Formatter Plus v4.8.8) */
SELECT m.ID, m.mouse_id, m.protocol_id, m.personal_licence_id, m.start_date,
       m.end_date, m.foreign_key_id, m.foreign_table_name,
       m.procedure_dict_id, m.PROCEDURE, m.project_licence_id,
       m.licence_number, m.protocol_code, m.pil_number, m.edited_by
  FROM mts_mouse_current_19b_vw m;

CREATE INDEX MTS_MOUSE_CURRENT_19B_IND1 ON MTS_MOUSE_CURRENT_19B_MV
(MOUSE_ID)
LOGGING
TABLESPACE INDEX_02
NOPARALLEL;

create or replace view mts_cage_header_vw as
with procs as (
select
  m.cage_id,
  p.protocol_id,
  p.edited_by,
  p.start_date,
  p19.protocol_code,
  p19.project_licence_id,
  ppl.licence_number,
  p.procedure_dict_id,
  pro.name||' '||to_char(p.start_date,'DD-Mon-YYYY') procedure,
  p.personal_licence_id,
  pil.pil_number,
  row_number() over (partition by m.cage_id order by p.start_date desc, p.id desc) row_number
from
  mts_mouse m,
  mts_mouse_procedure p,
  lic_protocol_19b p19,
  lic_personal_licence pil,
  lic_project_licence ppl,
  per_person per,
  mts_procedure_dict pro
where
  m.id = p.mouse_id and
  p.protocol_id = p19.id and
  p19.project_licence_id = ppl.project_licence_id and
  p.personal_licence_id = pil.personal_licence_id and
  pil.person_id = per.person_id and
  p.procedure_dict_id = pro.id
)
select distinct
  c.cage_id,
  c.cage_barcode,
  c.rack_id,
  c.rack_name,
  c.rack_barcode,
  c.room_id,
  c.room_name,
  o.person_id owner_id,
  o.first_name||' '||o.last_name owner_name,
  o.phone_number owner_phone_number,
  o.email owner_email,
  i.id colony_info_id,
  i.colony_name,
  i.colony_prefix,
  b.protocol_id,
  b.protocol_code,
  b.project_licence_id,
  b.licence_number,
  b.procedure_dict_id,
  b.procedure,
  b.personal_licence_id,
  b.pil_number
from
  mts_mouse m,
  mts_cage_vw c,
  per_person o,
  mts_colony_info i,
  procs b
where
  m.cage_id = c.cage_id and
  m.current_owner_id = o.person_id and
  m.colony_info_id = i.id(+) and
  m.cage_id = b.cage_id(+) and
  b.row_number(+) = 1
;

create or replace view mtl_mating_card_wv as
with procs as (
select
  m.cage_id,
  p.protocol_id,
  p.edited_by,
  p.start_date,
  p19.protocol_code,
  p19.project_licence_id,
  ppl.licence_number,
  p.procedure_dict_id,
  pro.name||' '||to_char(p.start_date,'DD-Mon-YYYY') procedure,
  p.personal_licence_id,
  pil.pil_number,
  row_number() over (partition by m.cage_id order by p.start_date desc, p.id desc) row_number
from
  mts_mouse m,
  mts_mouse_procedure p,
  lic_protocol_19b p19,
  lic_personal_licence pil,
  lic_project_licence ppl,
  per_person per,
  mts_procedure_dict pro
where
  m.id = p.mouse_id and
  p.protocol_id = p19.id and
  p19.project_licence_id = ppl.project_licence_id and
  p.personal_licence_id = pil.personal_licence_id and
  pil.person_id = per.person_id and
  p.procedure_dict_id = pro.id
)
select distinct
  c.cage_id,
  c.cage_barcode,
  c.room_name||' Rack '||c.rack_name cage_location,
  o.licence_number project_licence_number,
  o.protocol_code protocol_19b,
  p.first_name||' '||p.last_name owner,
  p.phone_number owner_phone_number,
  p.email owner_email,
  b.id breeding_id,
  b.start_date date_paired,
  b.name_prefix,
  b.breeding_number,
  i.colony_name,
  i.colony_prefix
from
  mts_breeding b,
  mts_mouse m,
  mts_cage_vw c,
  mts_colony_info i,
  per_person p,
  procs o
where
  b.female_id = m.id and
  m.cage_id = c.cage_id and
  m.current_owner_id = p.person_id(+) and
  b.offspring_colony_id = i.id and
  m.cage_id = o.cage_id(+)
;

CREATE OR REPLACE VIEW MTL_STOCK_CARD_VW
AS
with procs as (
select
  m.cage_id,
  p.protocol_id,
  p.edited_by,
  p.start_date,
  p19.protocol_code,
  p19.project_licence_id,
  ppl.licence_number,
  p.procedure_dict_id,
  pro.name||' '||to_char(p.start_date,'DD-Mon-YYYY') procedure,
  p.personal_licence_id,
  pil.pil_number,
  row_number() over (partition by m.cage_id order by p.start_date desc, p.id desc) row_number
from
  mts_mouse m,
  mts_mouse_procedure p,
  lic_protocol_19b p19,
  lic_personal_licence pil,
  lic_project_licence ppl,
  per_person per,
  mts_procedure_dict pro
where
  m.id = p.mouse_id and
  p.protocol_id = p19.id and
  p19.project_licence_id = ppl.project_licence_id and
  p.personal_licence_id = pil.personal_licence_id and
  pil.person_id = per.person_id and
  p.procedure_dict_id = pro.id
)
select distinct
  c.cage_id,
  c.cage_barcode,
  c.room_name||' Rack '||c.rack_name cage_location,
  o.licence_number project_licence_number,
  o.protocol_code protocol_19b,
  p.first_name||' '||p.last_name owner,
  p.phone_number owner_phone_number,
  p.email owner_email,
  p.email,
  i.colony_name,
  i.colony_prefix
from
  mts_mouse m,
  mts_cage_vw c,
  mts_colony_info i,
  per_person p,
  procs o
where
  m.cage_id = c.cage_id and
  m.current_owner_id = p.person_id(+) and
  m.colony_info_id = i.id(+) and
  m.cage_id = o.cage_id(+)
;
