-- set the webserver port for XE to something less obnoxious, create users and fill in dependencies for test script


EXEC DBMS_XDB.SETHTTPPORT(9090);

create user mig identified by mig;
create user mig_audit identified by mig_audit;
create user eucomm_vector identified by eucomm_vector;

grant CONNECT to MIG, MIG_AUDIT, EUCOMM_VECTOR;
grant RESOURCE to MIG, MIG_AUDIT, EUCOMM_VECTOR;
grant SELECT ANY TABLE to MIG, EUCOMM_VECTOR;
grant CREATE VIEW, CREATE MATERIALIZED VIEW to MIG;

CREATE TABLE MIG.DBMAINTAIN_SCRIPTS
(
  FILE_NAME              VARCHAR2(150 BYTE),
  VERSION                VARCHAR2(25 BYTE),
  FILE_LAST_MODIFIED_AT  INTEGER,
  CHECKSUM               VARCHAR2(50 BYTE),
  EXECUTED_AT            VARCHAR2(20 BYTE),
  SUCCEEDED              INTEGER
);


CREATE TABLE MIG_AUDIT.ARQ_HAVANA_REQUEST
(
  ID                            NUMBER,
  ALLELE_REQUEST_ID             NUMBER,
  STATUS_DICT_ID                NUMBER,
  CREATED_DATE                  DATE,
  EDITED_BY                     VARCHAR2(256 CHAR),
  EDITED_DATE                   DATE,
  COMMENTS                      VARCHAR2(4000 CHAR),
  VEGA_ID                       VARCHAR2(128 CHAR),
  UPDATED_GENE_NAME             VARCHAR2(128 CHAR),
  UPDATED_CHROMOSOME_NAME       VARCHAR2(128 CHAR),
  START_NOT_FOUND               NUMBER(1),
  END_NOT_FOUND                 NUMBER(1),
  CRITICAL_EXON_ID              VARCHAR2(128 CHAR),
  PSEUDOGENE                    NUMBER(1),
  ASSEMBLY_ERROR                NUMBER(1),
  CREATED_BY                    INTEGER,
  SMALL_INTRONS                 NUMBER(1),
  MULTIPLE_CODING_TRANSCRIPTS   NUMBER(1),
  SYMMETRICAL_EXON              NUMBER(1),
  LARGE_CODING_EXON             NUMBER(1),
  LESS_THAN_THREE_CODING_EXONS  NUMBER(1),
  NO_NMD_INDUCED                NUMBER(1),
  POSSIBLE_REINITIATION         NUMBER(1),
  CONTAINS_HYDROPHOBIC_REGION   NUMBER(1),
  CRITICAL_EXON_CONTAINS_ATG    NUMBER(1),
  HAS_TRANSMEMBRANE_DOMAIN      NUMBER(1),
  HAS_SIGNAL_PEPTIDE            NUMBER(1),
  AUDIT_TIMESTAMP               TIMESTAMP(6)    DEFAULT SYSTIMESTAMP,
  OS_USER                       VARCHAR2(30 BYTE) DEFAULT sys_context('USERENV','OS_USER'),
  AUDIT_ACTION                  VARCHAR2(10 BYTE),
  CRITICAL_EXON_TOO_3_PRIME     NUMBER(1),
  GENE_CLUSTER                  NUMBER(1),
  OVERLAPPING_LOCI              NUMBER(1),
  REPEAT_REGION                 NUMBER(1)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;

--
-- Create Schema Script
--   Database Version   : 10.2.0.2.0
--   TOAD Version       : 8.6.1.0
--   DB Connect String  : MIGT.WORLD
--   Schema             : EUCOMM_VECTOR
--   Script Created by  : MIG
--   Script Created at  : 12/05/2008 16:37:04
--   Physical Location  :
--   Notes              :
--

-- Object Counts:
--   Tables: 71         Columns: 537
--   Views: 1


CREATE TABLE EUCOMM_VECTOR.SEQUENCE_TAG
(
  SEQUENCE_NAME    VARCHAR2(255 BYTE),
  SOURCE_ID        NUMBER(10),
  ACCESSION_ID     VARCHAR2(255 BYTE),
  SEQUENCE         CLOB,
  SEQUENCE_TYPE    VARCHAR2(255 BYTE),
  SUBMISSION_DATE  DATE,
  VECTOR           VARCHAR2(255 BYTE),
  SOURCE           VARCHAR2(255 BYTE),
  SEQ_ID           NUMBER(10)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.DESIGN_USER_COMMENTS
(
  DESIGN_COMMENT_ID  NUMBER(10),
  DESIGN_ID          NUMBER(10),
  DESIGN_COMMENT     VARCHAR2(400 BYTE),
  VISIBILITY         VARCHAR2(10 BYTE),
  EDITED_USER        VARCHAR2(30 BYTE),
  EDITED_DATE        DATE
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.MGI_TO_VEGA
(
  MGI_TO_VEGA_ID  NUMBER(10),
  MGI_GENE_ID     VARCHAR2(128 BYTE),
  MGI_SYMBOL      VARCHAR2(128 BYTE),
  DESCRIPTION     VARCHAR2(4000 BYTE),
  VEGA_ID         VARCHAR2(30 BYTE),
  BATCH           NUMBER(2),
  BATCH_DATE      DATE                          DEFAULT sysdate
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.MGI_TO_ENSEMBL
(
  MGI_TO_ENSEMBL_ID  NUMBER(10),
  MGI_GENE_ID        VARCHAR2(128 BYTE),
  MGI_SYMBOL         VARCHAR2(128 BYTE),
  DESCRIPTION        VARCHAR2(4000 BYTE),
  ENSEMBL_ID         VARCHAR2(30 BYTE),
  BATCH              NUMBER(2),
  BATCH_DATE         DATE                       DEFAULT sysdate
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.TOAD_PLAN_TABLE
(
  STATEMENT_ID     VARCHAR2(32 CHAR),
  TIMESTAMP        DATE,
  REMARKS          VARCHAR2(80 CHAR),
  OPERATION        VARCHAR2(30 CHAR),
  OPTIONS          VARCHAR2(30 CHAR),
  OBJECT_NODE      VARCHAR2(128 CHAR),
  OBJECT_OWNER     VARCHAR2(30 CHAR),
  OBJECT_NAME      VARCHAR2(30 CHAR),
  OBJECT_INSTANCE  NUMBER,
  OBJECT_TYPE      VARCHAR2(30 CHAR),
  SEARCH_COLUMNS   NUMBER,
  ID               NUMBER,
  COST             NUMBER,
  PARENT_ID        NUMBER,
  POSITION         NUMBER,
  CARDINALITY      NUMBER,
  OPTIMIZER        VARCHAR2(255 CHAR),
  BYTES            NUMBER,
  OTHER_TAG        VARCHAR2(255 CHAR),
  PARTITION_ID     NUMBER,
  PARTITION_START  VARCHAR2(255 CHAR),
  PARTITION_STOP   VARCHAR2(255 CHAR),
  DISTRIBUTION     VARCHAR2(30 CHAR),
  OTHER            LONG
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.HTGT_STATUS_MSGS
(
  ID         NUMBER,
  MSG        VARCHAR2(4000 BYTE),
  IS_ACTIVE  INTEGER,
  THE_DATE   TIMESTAMP(6) WITH LOCAL TIME ZONE  DEFAULT SYSDATE,
  IS_EUCOMM  INTEGER
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.GENE_INFO_BACKUP_JAN_21_2008
(
  GENE_INFO_ID        NUMBER(10),
  GENE_ID             NUMBER,
  SP                  NUMBER(1),
  TM                  NUMBER(1),
  ENSEMBL_ID          VARCHAR2(100 BYTE),
  OTTER_ID            VARCHAR2(100 BYTE),
  MGI_SYMBOL          VARCHAR2(100 BYTE),
  MGI_SYMBOL_SOURCE   VARCHAR2(100 BYTE),
  OTTER_ID_SOURCE     VARCHAR2(100 BYTE),
  ENSEMBL_ID_SOURCE   VARCHAR2(100 BYTE),
  OTTER_MATCH_METHOD  VARCHAR2(100 BYTE),
  ARQ_SOURCES         VARCHAR2(4000 BYTE),
  BATCH               NUMBER(10),
  FOR_EUCOMM_MOUSE    NUMBER(1),
  FOR_RECOVERY        NUMBER(1),
  RECOVERY_COMMENT    VARCHAR2(400 BYTE),
  IGTC_HITS           NUMBER(10),
  OB_HITS             NUMBER(10),
  FOR_EUMODIC         NUMBER(1),
  EUCOMM_COMMENT      VARCHAR2(400 BYTE),
  HOMOZYGOUS_LETHAL   NUMBER(1),
  STATUS_EDIT_USER    VARCHAR2(100 BYTE),
  STATUS_EDIT_DATE    DATE,
  ICS_STATUS          VARCHAR2(100 BYTE),
  MRC_STATUS          VARCHAR2(100 BYTE),
  SNG_STATUS          VARCHAR2(100 BYTE),
  GSF_STATUS          VARCHAR2(100 BYTE),
  CNR_STATUS          VARCHAR2(100 BYTE)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.DCC_MASTER_GENE_LIST
(
  MGI_ID                   VARCHAR2(100 BYTE),
  SYMBOL                   VARCHAR2(100 BYTE),
  CHR                      VARCHAR2(100 BYTE),
  CHR_START                NUMBER(10),
  CHR_END                  NUMBER(10),
  STRAND                   NUMBER(1),
  KOMP_TARGET              VARCHAR2(1 BYTE),
  IMSR                     NUMBER(10),
  IGTC                     NUMBER(10),
  TARGETED_MUTANTS         NUMBER(10),
  OTHER_MUTANTS            NUMBER(10),
  CSD                      VARCHAR2(4000 BYTE),
  REGENERON                VARCHAR2(4000 BYTE),
  EUCOMM                   VARCHAR2(4000 BYTE),
  VEGA_IDS                 VARCHAR2(4000 BYTE),
  NCBI_IDS                 VARCHAR2(4000 BYTE),
  ENSEMBL_IDS              VARCHAR2(4000 BYTE),
  CCDS_IDS                 VARCHAR2(4000 BYTE),
  OMIM_IDS                 VARCHAR2(4000 BYTE),
  DCC_MASTER_GENE_LIST_ID  NUMBER,
  BATCH                    NUMBER(10),
  BATCH_DATE               DATE,
  GNM_GENE_ID              NUMBER(10)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.GENE_COMMENT
(
  GENE_COMMENT_ID  NUMBER(10),
  GENE_ID          NUMBER(10),
  GENE_COMMENT     VARCHAR2(1000 BYTE),
  VISIBILITY       VARCHAR2(10 BYTE),
  EDITED_USER      VARCHAR2(30 BYTE),
  EDITED_DATE      DATE
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.SESSIONS
(
  ID            VARCHAR2(72 BYTE),
  SESSION_DATA  CLOB,
  EXPIRES       NUMBER
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.FEATURE_TYPE_DICT
(
  FEATURE_TYPE_ID  NUMBER(10),
  DESCRIPTION      VARCHAR2(255 BYTE)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.HIT
(
  HIT_ID            NUMBER(10),
  BLAST_ID          NUMBER(10)                  DEFAULT 0,
  QUERY_START       NUMBER(10),
  QUERY_END         NUMBER(10),
  HIT_START         NUMBER(10),
  HIT_END           NUMBER(10),
  QUERY_STRAND      VARCHAR2(100 BYTE),
  HIT_STRAND        VARCHAR2(100 BYTE),
  QUERY_LENGTH      NUMBER(10),
  HIT_LENGTH        NUMBER(10),
  PERCENT_IDENTITY  FLOAT(126),
  EVALUE            VARCHAR2(20 BYTE)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.POST_CRE_RESULTS
(
  COLUMN1    VARCHAR2(4000 BYTE),
  ID         INTEGER,
  EXON_NAME  VARCHAR2(4000 BYTE),
  R1_VALID   INTEGER
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.TARGET
(
  TARGET_ID        NUMBER(10),
  GENE_ID          NUMBER(10),
  LOCUS_ID         NUMBER(10)                   DEFAULT 0,
  CHR_ID           NUMBER(10)                   DEFAULT 0,
  TARGET_START     NUMBER(10)                   DEFAULT 0,
  TARGET_END       NUMBER(10)                   DEFAULT 0,
  TARGET_MIDPOINT  FLOAT(126),
  STRAND           VARCHAR2(100 BYTE),
  PHASE            NUMBER(10),
  END_PHASE        NUMBER(10),
  EXON_ID          VARCHAR2(45 BYTE)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.DISPLAY_FEATURE
(
  DISPLAY_FEATURE_ID     NUMBER(10),
  GENE_BUILD_ID          NUMBER(10),
  FEATURE_ID             NUMBER(10),
  DISPLAY_FEATURE_TYPE   VARCHAR2(255 BYTE),
  DISPLAY_FEATURE_GROUP  VARCHAR2(255 BYTE),
  CHR_ID                 NUMBER(10),
  FEATURE_START          NUMBER(10),
  FEATURE_END            NUMBER(10),
  FEATURE_STRAND         NUMBER(10),
  CREATED_DATE           DATE                   DEFAULT sysdate,
  CREATED_USER           VARCHAR2(255 BYTE),
  LABEL                  VARCHAR2(255 BYTE),
  ASSEMBLY_ID            NUMBER
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.MANUAL_PAIRING
(
  MANUAL_PAIRING_ID  NUMBER(10),
  GB_GENE1_ID        NUMBER,
  GB_GENE2_ID        NUMBER,
  COMMENTS           VARCHAR2(4000 BYTE),
  SOURCE             VARCHAR2(128 BYTE),
  CURATE_DATE        DATE
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.GENE_SUPPLEMENTARY
(
  SUPPLEMENTARY_ID  NUMBER(10),
  GB_GENE_ID        NUMBER,
  OMNI_HITS         NUMBER(10),
  BIOTYPE           VARCHAR2(255 BYTE),
  GENE_STATUS       VARCHAR2(50 BYTE),
  IGTC_HITS         NUMBER(10),
  SIGTR_BG_HITS     NUMBER(10),
  BG_HITS           NUMBER(10),
  ESDB_HITS         NUMBER(10),
  FHCRC_HITS        NUMBER(10),
  SIGTR_HITS        NUMBER(10),
  GGTC_HITS         NUMBER(10),
  CMHD_HITS         NUMBER(10),
  TIGEM_HITS        NUMBER(10)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.UPDATE_FREQUENCY
(
  UPDATE_ID  NUMBER(10),
  FREQUENCY  VARCHAR2(255 BYTE)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.ANNOTATION
(
  ANNOTATION_ID         NUMBER(10),
  GB_GENE_ID            NUMBER,
  SEQ_ID                NUMBER(10),
  RESULT_TYPE           VARCHAR2(255 BYTE),
  CLASS                 VARCHAR2(255 BYTE),
  CHR                   VARCHAR2(255 BYTE),
  GENE                  VARCHAR2(255 BYTE),
  STRAND                NUMBER(10),
  KNOWN                 VARCHAR2(255 BYTE),
  ENSEMBL               VARCHAR2(255 BYTE),
  REFSEQ                VARCHAR2(255 BYTE),
  SWISSPROT             VARCHAR2(255 BYTE),
  SPTREMBL              VARCHAR2(255 BYTE),
  GENE_START            NUMBER(10),
  GENE_END              NUMBER(10),
  EXON_OR_INTRON        VARCHAR2(255 BYTE),
  EXON_OR_INTRON_START  NUMBER(10),
  EXON_OR_INTRON_END    NUMBER(10),
  HIT_START             NUMBER(10),
  HIT_END               VARCHAR2(10 BYTE),
  HIT_LENGTH            NUMBER(10),
  ORIGIN                NUMBER(10),
  SCORE                 NUMBER(10)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.LOCATION
(
  LOCATION_ID  NUMBER(10),
  LOCATION     VARCHAR2(255 BYTE)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.UPDATE_METHOD
(
  UPDATE_METHOD_ID  NUMBER(10),
  UPDATE_METHOD     VARCHAR2(255 BYTE)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.SOURCE
(
  SOURCE_ID         NUMBER(10),
  UPDATE_METHOD_ID  NUMBER(10),
  NAME              VARCHAR2(255 BYTE),
  UPDATE_ID         NUMBER(10),
  LOCATION_ID       NUMBER(10),
  FUNCTION_ID       NUMBER(10)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.DATA_FUNCTION
(
  FUNCTION_ID    NUMBER(10),
  FUNCTION_DESC  VARCHAR2(255 BYTE)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.OMNIBANK_II
(
  OB2_ID       NUMBER(10),
  GB_GENE_ID   NUMBER,
  SOURCE_ID    NUMBER(10),
  GENE_TYPE    VARCHAR2(255 BYTE),
  GENE         VARCHAR2(255 BYTE),
  IMPORT_DATE  DATE
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.DESIGN_INSTANCE_BAC
(
  DESIGN_INSTANCE_ID  NUMBER(10),
  BAC_CLONE_ID        NUMBER(10),
  BAC_PLATE           VARCHAR2(1000 CHAR)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.DESIGN_INSTANCE
(
  DESIGN_ID           NUMBER(10),
  PLATE               VARCHAR2(255 BYTE),
  WELL                VARCHAR2(255 BYTE),
  SOURCE              VARCHAR2(255 BYTE),
  DESIGN_INSTANCE_ID  NUMBER(10)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.RESTORE_DESIGN
(
  DESIGN_ID            NUMBER(10),
  TARGET_ID            NUMBER(10),
  BUILD_ID             NUMBER(10),
  DESIGN_NAME          VARCHAR2(45 BYTE),
  PSEUDO_PLATE         NUMBER(10),
  FINAL_PLATE          VARCHAR2(45 BYTE),
  WELL_LOC             VARCHAR2(20 BYTE),
  DESIGN_PARAMETER_ID  NUMBER,
  LOCUS_ID             INTEGER,
  RANDOM_NAME          VARCHAR2(125 BYTE),
  START_EXON_ID        NUMBER,
  END_EXON_ID          NUMBER,
  GENE_BUILD_ID        NUMBER
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.RESTORE_DESIGN_STATUS
(
  DESIGN_STATUS_ID  NUMBER(10),
  DESIGN_ID         NUMBER(10),
  STATUS_DATE       DATE,
  IS_CURRENT        CHAR(1 BYTE),
  ID_ROLE           NUMBER(10)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.RESTORE_FEATURE
(
  FEATURE_ID       NUMBER(10),
  FEATURE_TYPE_ID  NUMBER(10),
  DESIGN_ID        NUMBER(10),
  CHR_ID           NUMBER(10),
  FEATURE_START    NUMBER(10),
  FEATURE_END      NUMBER(10)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.RESTORE_DESIGN_NOTE
(
  DESIGN_NOTE_ID       NUMBER(10),
  DESIGN_NOTE_TYPE_ID  NUMBER(10),
  DESIGN_ID            NUMBER(10),
  NOTE                 VARCHAR2(4000 BYTE),
  CREATED              DATE
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.DESIGN_INSTANCE_STATUS
(
  DESIGN_INSTANCE_STATUS_ID  NUMBER(10),
  DESIGN_INSTANCE_ID         NUMBER,
  STATUS_DATE                DATE,
  IS_CURRENT                 CHAR(1 BYTE),
  ID_ROLE                    NUMBER(10)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.DESIGN_INSTANCE_STATUS_DICT
(
  DESIGN_INSTANCE_STATUS_ID  NUMBER(10),
  DESCRIPTION                VARCHAR2(255 BYTE)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.DESIGN_AUDIT
(
  DESIGN_ID            NUMBER(10),
  TARGET_ID            NUMBER(10)               DEFAULT 0,
  BUILD_ID             NUMBER(10)               DEFAULT 0,
  DESIGN_NAME          VARCHAR2(45 BYTE),
  PSEUDO_PLATE         NUMBER(10),
  FINAL_PLATE          VARCHAR2(45 BYTE),
  WELL_LOC             VARCHAR2(20 BYTE),
  DESIGN_PARAMETER_ID  NUMBER                   DEFAULT 0,
  LOCUS_ID             INTEGER,
  START_EXON_ID        NUMBER,
  END_EXON_ID          NUMBER,
  GENE_BUILD_ID        NUMBER,
  RANDOM_NAME          VARCHAR2(125 BYTE),
  AUDIT_DATE           DATE                     DEFAULT SYSTIMESTAMP
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.DESIGN_STATUS_AUDIT
(
  DESIGN_STATUS_ID  NUMBER(10)                  DEFAULT 0,
  DESIGN_ID         NUMBER(10)                  DEFAULT 0,
  STATUS_DATE       DATE,
  IS_CURRENT        CHAR(1 BYTE),
  ID_ROLE           NUMBER(10),
  AUDIT_DATE        DATE                        DEFAULT SYSTIMESTAMP
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.DESIGN_INSTANCE_AUDIT
(
  DESIGN_ID           NUMBER(10),
  DESIGN_INSTANCE_ID  NUMBER,
  PLATE               VARCHAR2(255 BYTE),
  WELL                VARCHAR2(255 BYTE),
  SOURCE              VARCHAR2(255 BYTE),
  AUDIT_DATE          DATE                      DEFAULT SYSTIMESTAMP
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.FEATURE_AUDIT
(
  FEATURE_ID       NUMBER(10),
  FEATURE_TYPE_ID  NUMBER(10)                   DEFAULT 0,
  DESIGN_ID        NUMBER(10)                   DEFAULT 0,
  CHR_ID           NUMBER(10)                   DEFAULT 0,
  FEATURE_START    NUMBER(10)                   DEFAULT 0,
  FEATURE_END      NUMBER(10)                   DEFAULT 0,
  AUDIT_DATE       DATE                         DEFAULT SYSTIMESTAMP
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.DISPLAY_FEATURE_AUDIT
(
  DISPLAY_FEATURE_ID     NUMBER(10),
  GENE_BUILD_ID          NUMBER(10),
  FEATURE_ID             NUMBER(10),
  DISPLAY_FEATURE_TYPE   VARCHAR2(255 BYTE),
  DISPLAY_FEATURE_GROUP  VARCHAR2(255 BYTE),
  CHR_ID                 NUMBER(10),
  FEATURE_START          NUMBER(10),
  FEATURE_END            NUMBER(10),
  FEATURE_STRAND         NUMBER(10),
  CREATED_DATE           DATE                   DEFAULT sysdate,
  CREATED_USER           VARCHAR2(255 BYTE),
  LABEL                  VARCHAR2(255 BYTE),
  AUDIT_DATE             DATE                   DEFAULT SYSTIMESTAMP
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.DESIGN_NOTE_AUDIT
(
  DESIGN_NOTE_ID       NUMBER(10),
  DESIGN_NOTE_TYPE_ID  NUMBER(10)               DEFAULT 0,
  DESIGN_ID            NUMBER(10)               DEFAULT 0,
  NOTE                 VARCHAR2(4000 BYTE),
  CREATED              DATE                     DEFAULT sysdate,
  AUDIT_DATE           DATE                     DEFAULT SYSTIMESTAMP
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.DESIGN_INSTANCE_FEATURE
(
  DESIGN_INSTANCE_ID  NUMBER(10),
  CREATED_DATE        DATE                      DEFAULT sysdate,
  FEATURE_ID          NUMBER(10),
  CREATED_USER        VARCHAR2(255 BYTE)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.DESIGN_INSTANCE_BAC_AUDIT
(
  DESIGN_INSTANCE_ID  NUMBER,
  BAC_CLONE_ID        NUMBER(10),
  AUDIT_DATE          DATE                      DEFAULT SYSTIMESTAMP
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.DESIGN_INSTANCE_FEATURE_AUDIT
(
  DESIGN_INSTANCE_ID  NUMBER(10),
  CREATED_DATE        DATE                      DEFAULT sysdate,
  FEATURE_ID          NUMBER(10),
  CREATED_USER        VARCHAR2(255 BYTE),
  AUDIT_DATE          DATE                      DEFAULT SYSTIMESTAMP
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.GENE_INFO
(
  GENE_INFO_ID        NUMBER(10),
  GENE_ID             NUMBER,
  SP                  NUMBER(1),
  TM                  NUMBER(1),
  ENSEMBL_ID          VARCHAR2(100 BYTE),
  OTTER_ID            VARCHAR2(100 BYTE),
  MGI_SYMBOL          VARCHAR2(100 BYTE),
  MGI_SYMBOL_SOURCE   VARCHAR2(100 BYTE),
  OTTER_ID_SOURCE     VARCHAR2(100 BYTE),
  ENSEMBL_ID_SOURCE   VARCHAR2(100 BYTE),
  OTTER_MATCH_METHOD  VARCHAR2(100 BYTE),
  ARQ_SOURCES         VARCHAR2(4000 BYTE),
  BATCH               NUMBER(10),
  FOR_EUCOMM_MOUSE    NUMBER(1),
  FOR_RECOVERY        NUMBER(1),
  RECOVERY_COMMENT    VARCHAR2(400 BYTE),
  IGTC_HITS           NUMBER(10),
  OB_HITS             NUMBER(10),
  FOR_EUMODIC         NUMBER(1),
  EUCOMM_COMMENT      VARCHAR2(400 BYTE),
  HOMOZYGOUS_LETHAL   NUMBER(1),
  STATUS_EDIT_USER    VARCHAR2(100 BYTE),
  STATUS_EDIT_DATE    DATE,
  ICS_STATUS          VARCHAR2(100 BYTE),
  MRC_STATUS          VARCHAR2(100 BYTE),
  SNG_STATUS          VARCHAR2(100 BYTE),
  GSF_STATUS          VARCHAR2(100 BYTE),
  CNR_STATUS          VARCHAR2(100 BYTE),
  TIGM_HITS           NUMBER(10),
  ES_CELL_COUNT       NUMBER(10),
  TIGM_SANGER_HITS    NUMBER(10),
  PC_SUMMARY_STATUS   VARCHAR2(4000 BYTE),
  PG_SUMMARY_STATUS   VARCHAR2(4000 BYTE),
  EPD_SUMMARY_COUNTS  NUMBER
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.PLATE
(
  PLATE_ID      NUMBER(10),
  NAME          VARCHAR2(100 BYTE),
  DESCRIPTION   VARCHAR2(4000 BYTE),
  CREATED_USER  VARCHAR2(100 BYTE),
  CREATED_DATE  DATE                            DEFAULT sysdate,
  EDITED_USER   VARCHAR2(100 BYTE),
  EDITED_DATE   DATE                            DEFAULT sysdate,
  TYPE          VARCHAR2(100 BYTE),
  IS_LOCKED     CHAR(1 BYTE)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.PLATE_COMMENT
(
  PLATE_ID          NUMBER(10),
  PLATE_COMMENT     VARCHAR2(1000 BYTE),
  CREATED_USER      VARCHAR2(100 BYTE),
  CREATED_DATE      DATE,
  PLATE_COMMENT_ID  NUMBER(10)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.PLATE_DATA
(
  PLATE_ID       NUMBER(10),
  DATA_VALUE     VARCHAR2(1000 BYTE),
  DATA_TYPE      VARCHAR2(100 BYTE),
  PLATE_DATA_ID  NUMBER(10)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.PLATE_PLATE
(
  PARENT_PLATE_ID  NUMBER(10),
  CHILD_PLATE_ID   NUMBER(10)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.APP_AUDIT_TABLES
(
  ID           NUMBER,
  TABLE_NAME   VARCHAR2(30 CHAR),
  AUDIT_TABLE  VARCHAR2(30 CHAR)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.JMS_DESIGN_QC_STATUS
(
  DESIGN_ID              NUMBER,
  POSTCRE_QC_STATUS      VARCHAR2(128 BYTE)     DEFAULT 'pending',
  POSTGATEWAY_QC_STATUS  VARCHAR2(128 BYTE)     DEFAULT 'pending',
  GB_GENE_ID             NUMBER
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.WELL
(
  PLATE_ID            NUMBER(10),
  DESIGN_INSTANCE_ID  NUMBER(10),
  WELL_NAME           VARCHAR2(24 BYTE),
  WELL_ID             NUMBER(10),
  PARENT_WELL_ID      NUMBER(10),
  QCTEST_RESULT_ID    NUMBER(38),
  EDIT_USER           VARCHAR2(100 BYTE),
  EDIT_DATE           DATE
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.WELL_DATA
(
  DATA_VALUE    VARCHAR2(100 BYTE),
  WELL_ID       NUMBER(10),
  WELL_DATA_ID  NUMBER(10),
  DATA_TYPE     VARCHAR2(100 BYTE),
  EDIT_USER     VARCHAR2(100 BYTE),
  EDIT_DATE     DATE                            DEFAULT sysdate
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.DESIGN_PARAMETER
(
  DESIGN_PARAMETER_ID  NUMBER(10),
  PARAMETER_NAME       VARCHAR2(45 BYTE)        DEFAULT '',
  PARAMETER_VALUE      CLOB,
  CREATED              DATE                     DEFAULT sysdate
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.FEATURE_DATA
(
  FEATURE_DATA_ID       NUMBER(10),
  FEATURE_DATA_TYPE_ID  NUMBER(10)              DEFAULT 0,
  FEATURE_ID            NUMBER(10)              DEFAULT 0,
  DATA_ITEM             CLOB
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.FEATURE_DATA_AUDIT
(
  FEATURE_DATA_ID       NUMBER(10),
  FEATURE_DATA_TYPE_ID  NUMBER(10)              DEFAULT 0,
  FEATURE_ID            NUMBER(10)              DEFAULT 0,
  DATA_ITEM             CLOB,
  AUDIT_DATE            DATE                    DEFAULT SYSTIMESTAMP
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.BAC
(
  BAC_CLONE_ID     NUMBER(10),
  REMOTE_CLONE_ID  VARCHAR2(45 BYTE),
  CLONE_LIB_ID     NUMBER(10)                   DEFAULT 0,
  CHR_ID           NUMBER(10)                   DEFAULT 0,
  BAC_START        NUMBER(10),
  BAC_END          NUMBER(10),
  BAC_MIDPOINT     FLOAT(126),
  BUILD_ID         NUMBER
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.BLAST_BAC
(
  BAC_CLONE_ID  NUMBER(10)                      DEFAULT 0,
  BLAST_ID      NUMBER(10)                      DEFAULT 0
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.BUILD_INFO
(
  BUILD_ID      NUMBER(10),
  GOLDEN_PATH   VARCHAR2(255 BYTE),
  MAPMASTER     VARCHAR2(255 BYTE),
  CORE_VERSION  VARCHAR2(255 BYTE),
  RUN_DATE      DATE,
  SOFTWARE_VER  VARCHAR2(255 BYTE)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.CHROMOSOME_DICT
(
  CHR_ID  NUMBER(10),
  NAME    VARCHAR2(20 BYTE)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.CLONE_LIB_DICT
(
  CLONE_LIB_ID  NUMBER(10),
  LIBRARY       VARCHAR2(255 BYTE)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.DESIGN
(
  DESIGN_ID            NUMBER(10),
  TARGET_ID            NUMBER(10)               DEFAULT 0,
  BUILD_ID             NUMBER(10)               DEFAULT 0,
  DESIGN_NAME          VARCHAR2(45 BYTE),
  PSEUDO_PLATE         NUMBER(10),
  FINAL_PLATE          VARCHAR2(45 BYTE),
  WELL_LOC             VARCHAR2(20 BYTE),
  DESIGN_PARAMETER_ID  NUMBER                   DEFAULT 0,
  LOCUS_ID             INTEGER,
  RANDOM_NAME          VARCHAR2(125 BYTE),
  START_EXON_ID        NUMBER,
  END_EXON_ID          NUMBER,
  GENE_BUILD_ID        NUMBER,
  LR_STATUS            VARCHAR2(100 BYTE),
  CREATED_DATE         DATE                     DEFAULT systimestamp,
  SP                   NUMBER(1),
  TM                   NUMBER(1),
  ATG                  NUMBER(1),
  PHASE                NUMBER(1),
  PI                   NUMBER(1),
  CREATED_USER         VARCHAR2(100 BYTE),
  DESIGN_TYPE          VARCHAR2(20 BYTE),
  SUBTYPE              VARCHAR2(20 BYTE),
  SUBTYPE_DESCRIPTION  VARCHAR2(200 BYTE)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.DESIGN_BAC
(
  BAC_CLONE_ID          NUMBER(10)              DEFAULT 0,
  DESIGN_ID             NUMBER(10)              DEFAULT 0,
  MIDPOINT_DIFF         FLOAT(126),
  ALLOCATE_TO_INSTANCE  NUMBER(1)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.DESIGN_DESIGN_GROUP
(
  DESIGN_ID        NUMBER(10),
  DESIGN_GROUP_ID  NUMBER
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.DESIGN_GROUP
(
  DESIGN_GROUP_ID  NUMBER(10),
  NAME             VARCHAR2(255 BYTE)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.DESIGN_NOTE
(
  DESIGN_NOTE_ID       NUMBER(10),
  DESIGN_NOTE_TYPE_ID  NUMBER(10)               DEFAULT 0,
  DESIGN_ID            NUMBER(10)               DEFAULT 0,
  NOTE                 VARCHAR2(4000 BYTE),
  CREATED              DATE
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.DESIGN_NOTE_TYPE_DICT
(
  DESIGN_NOTE_TYPE_ID  NUMBER(10),
  DESCRIPTION          VARCHAR2(255 BYTE)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.DESIGN_STATUS
(
  DESIGN_STATUS_ID  NUMBER(10)                  DEFAULT 0,
  DESIGN_ID         NUMBER(10)                  DEFAULT 0,
  STATUS_DATE       DATE                        DEFAULT sysdate,
  IS_CURRENT        CHAR(1 BYTE),
  ID_ROLE           NUMBER(10)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.DESIGN_STATUS_DICT
(
  DESIGN_STATUS_ID  NUMBER(10),
  DESCRIPTION       VARCHAR2(255 BYTE)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.EUCOMM_GENE
(
  GENE_ID    NUMBER(10),
  GENE_NAME  VARCHAR2(30 BYTE),
  PRIORITY   CHAR(1 BYTE)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.FEATURE
(
  FEATURE_ID            NUMBER(10),
  FEATURE_TYPE_ID       NUMBER(10)              DEFAULT 0,
  DESIGN_ID             NUMBER(10)              DEFAULT 0,
  CHR_ID                NUMBER(10)              DEFAULT 0,
  FEATURE_START         NUMBER(10)              DEFAULT 0,
  FEATURE_END           NUMBER(10)              DEFAULT 0,
  ALLOCATE_TO_INSTANCE  NUMBER(1)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.FEATURE_BLAST
(
  BLAST_ID    NUMBER(10),
  FEATURE_ID  NUMBER(10)                        DEFAULT 0
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE EUCOMM_VECTOR.FEATURE_DATA_TYPE_DICT
(
  FEATURE_DATA_TYPE_ID  NUMBER(10),
  DESCRIPTION           VARCHAR2(255 BYTE)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;

CREATE table EUCOMM_VECTOR.AVAILABLE_ES_CLONES (
GENE_SYMBOL	VARCHAR2(512 CHAR),
ENSEMBL_ID	VARCHAR2(4000 CHAR),
BUILD_GENE_PRIMARY_NAME	VARCHAR2(4000 CHAR),
EXON_PRIMARY_NAME	VARCHAR2(4000 CHAR),
WELL_NAME	VARCHAR2(24 BYTE),
DATA_TYPE	VARCHAR2(100 BYTE),
DATA_VALUE	VARCHAR2(100 BYTE),
DESIGN_ID	NUMBER(10,0),
DESIGN_INSTANCE_ID	NUMBER(10,0),
BAC_LIBRARY	VARCHAR2(100 BYTE),
REQUEST_SOURCE	VARCHAR2(6 BYTE)
);


CREATE TABLE EUCOMM_VECTOR.WELL_SUMMARY
(
  PROJECT_ID                 INTEGER,
  BUILD_GENE_ID              INTEGER,
  GENE_ID                    INTEGER,
  DESIGN_INSTANCE_ID         NUMBER,
  DESIGN_PLATE_NAME          VARCHAR2(100 BYTE),
  DESIGN_WELL_NAME           VARCHAR2(24 BYTE),
  DESIGN_WELL_ID             NUMBER,
  DESIGN_DESIGN_INSTANCE_ID  NUMBER,
  BAC                        VARCHAR2(100 BYTE),
  PCS_PLATE_NAME             VARCHAR2(100 BYTE),
  PCS_WELL_NAME              VARCHAR2(24 BYTE),
  PCS_WELL_ID                NUMBER,
  PCS_DESIGN_INSTANCE_ID     NUMBER,
  PC_QCTEST_RESULT_ID        NUMBER,
  PC_PASS_LEVEL              VARCHAR2(100 BYTE),
  PCS_DISTRIBUTE             VARCHAR2(100 BYTE),
  PGDGR_PLATE_NAME           VARCHAR2(100 BYTE),
  PGDGR_WELL_NAME            VARCHAR2(24 BYTE),
  PGDGR_WELL_ID              NUMBER,
  PGDGR_DESIGN_INSTANCE_ID   NUMBER,
  PG_QCTEST_RESULT_ID        NUMBER,
  PG_PASS_LEVEL              VARCHAR2(100 BYTE),
  CASSETTE                   VARCHAR2(100 BYTE),
  BACKBONE                   VARCHAR2(100 BYTE),
  PGDGR_DISTRIBUTE           VARCHAR2(100 BYTE),
  EP_PLATE_NAME              VARCHAR2(100 BYTE),
  EP_WELL_NAME               VARCHAR2(24 BYTE),
  EP_WELL_ID                 NUMBER,
  EP_DESIGN_INSTANCE_ID      NUMBER,
  ES_CELL_LINE               VARCHAR2(100 BYTE),
  COLONIES_PICKED            VARCHAR2(100 BYTE),
  TOTAL_COLONIES             VARCHAR2(100 BYTE),
  EPD_PLATE_NAME             VARCHAR2(100 BYTE),
  EPD_WELL_NAME              VARCHAR2(24 BYTE),
  EPD_WELL_ID                NUMBER(10),
  EPD_DESIGN_INSTANCE_ID     NUMBER(10),
  EPD_QCTEST_RESULT_ID       NUMBER(38),
  EPD_PASS_LEVEL             VARCHAR2(100 BYTE),
  EPD_DISTRIBUTE             VARCHAR2(100 BYTE),
  ALLELE_NAME                VARCHAR2(160 BYTE)
);

grant REFERENCES on EUCOMM_VECTOR.SEQUENCE_TAG to MIG;
grant REFERENCES on EUCOMM_VECTOR.DESIGN_USER_COMMENTS to MIG;
grant REFERENCES on EUCOMM_VECTOR.MGI_TO_VEGA to MIG;
grant REFERENCES on EUCOMM_VECTOR.MGI_TO_ENSEMBL to MIG;
grant REFERENCES on EUCOMM_VECTOR.TOAD_PLAN_TABLE to MIG;
grant REFERENCES on EUCOMM_VECTOR.HTGT_STATUS_MSGS to MIG;
grant REFERENCES on EUCOMM_VECTOR.GENE_INFO_BACKUP_JAN_21_2008 to MIG;
grant REFERENCES on EUCOMM_VECTOR.DCC_MASTER_GENE_LIST to MIG;
grant REFERENCES on EUCOMM_VECTOR.GENE_COMMENT to MIG;
grant REFERENCES on EUCOMM_VECTOR.SESSIONS to MIG;
grant REFERENCES on EUCOMM_VECTOR.WELL_SUMMARY to MIG;
grant REFERENCES on EUCOMM_VECTOR.FEATURE_TYPE_DICT to MIG;
grant REFERENCES on EUCOMM_VECTOR.HIT to MIG;
grant REFERENCES on EUCOMM_VECTOR.POST_CRE_RESULTS to MIG;
grant REFERENCES on EUCOMM_VECTOR.TARGET to MIG;
grant REFERENCES on EUCOMM_VECTOR.DISPLAY_FEATURE to MIG;
grant REFERENCES on EUCOMM_VECTOR.MANUAL_PAIRING to MIG;
grant REFERENCES on EUCOMM_VECTOR.GENE_SUPPLEMENTARY to MIG;
grant REFERENCES on EUCOMM_VECTOR.UPDATE_FREQUENCY to MIG;
grant REFERENCES on EUCOMM_VECTOR.ANNOTATION to MIG;
grant REFERENCES on EUCOMM_VECTOR.LOCATION to MIG;
grant REFERENCES on EUCOMM_VECTOR.UPDATE_METHOD to MIG;
grant REFERENCES on EUCOMM_VECTOR.SOURCE to MIG;
grant REFERENCES on EUCOMM_VECTOR.DATA_FUNCTION to MIG;
grant REFERENCES on EUCOMM_VECTOR.OMNIBANK_II to MIG;
grant REFERENCES on EUCOMM_VECTOR.DESIGN_INSTANCE_BAC to MIG;
grant REFERENCES on EUCOMM_VECTOR.DESIGN_INSTANCE to MIG;
grant REFERENCES on EUCOMM_VECTOR.RESTORE_DESIGN to MIG;
grant REFERENCES on EUCOMM_VECTOR.RESTORE_DESIGN_STATUS to MIG;
grant REFERENCES on EUCOMM_VECTOR.RESTORE_FEATURE to MIG;
grant REFERENCES on EUCOMM_VECTOR.RESTORE_DESIGN_NOTE to MIG;
grant REFERENCES on EUCOMM_VECTOR.DESIGN_INSTANCE_STATUS to MIG;
grant REFERENCES on EUCOMM_VECTOR.DESIGN_INSTANCE_STATUS_DICT to MIG;
grant REFERENCES on EUCOMM_VECTOR.DESIGN_AUDIT to MIG;
grant REFERENCES on EUCOMM_VECTOR.DESIGN_STATUS_AUDIT to MIG;
grant REFERENCES on EUCOMM_VECTOR.DESIGN_INSTANCE_AUDIT to MIG;
grant REFERENCES on EUCOMM_VECTOR.FEATURE_AUDIT to MIG;
grant REFERENCES on EUCOMM_VECTOR.DISPLAY_FEATURE_AUDIT to MIG;
grant REFERENCES on EUCOMM_VECTOR.DESIGN_NOTE_AUDIT to MIG;
grant REFERENCES on EUCOMM_VECTOR.DESIGN_INSTANCE_FEATURE to MIG;
grant REFERENCES on EUCOMM_VECTOR.DESIGN_INSTANCE_BAC_AUDIT to MIG;
grant REFERENCES on EUCOMM_VECTOR.DESIGN_INSTANCE_FEATURE_AUDIT to MIG;
grant REFERENCES on EUCOMM_VECTOR.GENE_INFO to MIG;
grant REFERENCES on EUCOMM_VECTOR.PLATE to MIG;
grant REFERENCES on EUCOMM_VECTOR.PLATE_COMMENT to MIG;
grant REFERENCES on EUCOMM_VECTOR.PLATE_DATA to MIG;
grant REFERENCES on EUCOMM_VECTOR.PLATE_PLATE to MIG;
grant REFERENCES on EUCOMM_VECTOR.APP_AUDIT_TABLES to MIG;
grant REFERENCES on EUCOMM_VECTOR.JMS_DESIGN_QC_STATUS to MIG;
grant REFERENCES on EUCOMM_VECTOR.WELL to MIG;
grant REFERENCES on EUCOMM_VECTOR.WELL_DATA to MIG;
grant REFERENCES on EUCOMM_VECTOR.DESIGN_PARAMETER to MIG;
grant REFERENCES on EUCOMM_VECTOR.FEATURE_DATA to MIG;
grant REFERENCES on EUCOMM_VECTOR.FEATURE_DATA_AUDIT to MIG;
grant REFERENCES on EUCOMM_VECTOR.BAC to MIG;
grant REFERENCES on EUCOMM_VECTOR.BLAST_BAC to MIG;
grant REFERENCES on EUCOMM_VECTOR.BUILD_INFO to MIG;
grant REFERENCES on EUCOMM_VECTOR.CHROMOSOME_DICT to MIG;
grant REFERENCES on EUCOMM_VECTOR.CLONE_LIB_DICT to MIG;
grant REFERENCES on EUCOMM_VECTOR.DESIGN to MIG;
grant REFERENCES on EUCOMM_VECTOR.DESIGN_BAC to MIG;
grant REFERENCES on EUCOMM_VECTOR.DESIGN_DESIGN_GROUP to MIG;
grant REFERENCES on EUCOMM_VECTOR.DESIGN_GROUP to MIG;
grant REFERENCES on EUCOMM_VECTOR.DESIGN_NOTE to MIG;
grant REFERENCES on EUCOMM_VECTOR.DESIGN_NOTE_TYPE_DICT to MIG;
grant REFERENCES on EUCOMM_VECTOR.DESIGN_STATUS to MIG;
grant REFERENCES on EUCOMM_VECTOR.DESIGN_STATUS_DICT to MIG;
grant REFERENCES on EUCOMM_VECTOR.EUCOMM_GENE to MIG;
grant REFERENCES on EUCOMM_VECTOR.FEATURE to MIG;
grant REFERENCES on EUCOMM_VECTOR.FEATURE_BLAST to MIG;
grant REFERENCES on EUCOMM_VECTOR.FEATURE_DATA_TYPE_DICT to MIG;
grant REFERENCES on EUCOMM_VECTOR.AVAILABLE_ES_CLONES to MIG;

CREATE INDEX EUCOMM_VECTOR.BLAST_ID_1 ON EUCOMM_VECTOR.BLAST_BAC
(BLAST_ID)
LOGGING
NOPARALLEL;


CREATE INDEX EUCOMM_VECTOR.BAC_CLONE_ID ON EUCOMM_VECTOR.BLAST_BAC
(BAC_CLONE_ID)
LOGGING
NOPARALLEL;


CREATE INDEX EUCOMM_VECTOR.BAC_ID ON EUCOMM_VECTOR.DESIGN_BAC
(BAC_CLONE_ID)
LOGGING
NOPARALLEL;


CREATE INDEX EUCOMM_VECTOR.DESIGN_ID_1 ON EUCOMM_VECTOR.DESIGN_BAC
(DESIGN_ID)
LOGGING
NOPARALLEL;


CREATE INDEX EUCOMM_VECTOR.DISPLAY_FEATURE_START_STOP ON EUCOMM_VECTOR.DISPLAY_FEATURE
(CHR_ID, FEATURE_START, FEATURE_END)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.WELL_PLATE_WELL_NAME_C ON EUCOMM_VECTOR.WELL
(PLATE_ID, WELL_NAME)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.GENE_INFO_PK ON EUCOMM_VECTOR.GENE_INFO
(GENE_INFO_ID)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.PLATE_COMMENT_PK ON EUCOMM_VECTOR.PLATE_COMMENT
(PLATE_COMMENT_ID)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.PLATE_DATA_PK ON EUCOMM_VECTOR.PLATE_DATA
(PLATE_DATA_ID)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.PK_FEATURE_DATA_TYPE_DICT ON EUCOMM_VECTOR.FEATURE_DATA_TYPE_DICT
(FEATURE_DATA_TYPE_ID)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.PK_FEATURE_TYPE_DICT ON EUCOMM_VECTOR.FEATURE_TYPE_DICT
(FEATURE_TYPE_ID)
LOGGING
NOPARALLEL;


CREATE INDEX EUCOMM_VECTOR.BLAST_ID ON EUCOMM_VECTOR.HIT
(BLAST_ID)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.PK_HIT ON EUCOMM_VECTOR.HIT
(HIT_ID)
LOGGING
NOPARALLEL;


CREATE INDEX EUCOMM_VECTOR.TARGET_FKINDEX2 ON EUCOMM_VECTOR.TARGET
(GENE_ID)
LOGGING
NOPARALLEL;


CREATE INDEX EUCOMM_VECTOR.CHR_ID ON EUCOMM_VECTOR.TARGET
(CHR_ID)
LOGGING
NOPARALLEL;


CREATE INDEX EUCOMM_VECTOR.LOCUS_ID ON EUCOMM_VECTOR.TARGET
(LOCUS_ID)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.PK_TARGET ON EUCOMM_VECTOR.TARGET
(TARGET_ID)
LOGGING
NOPARALLEL;


CREATE INDEX EUCOMM_VECTOR.CHR_ID_1 ON EUCOMM_VECTOR.BAC
(CHR_ID)
LOGGING
NOPARALLEL;


CREATE INDEX EUCOMM_VECTOR.CLONE_LIB_ID ON EUCOMM_VECTOR.BAC
(CLONE_LIB_ID)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.PK_BAC ON EUCOMM_VECTOR.BAC
(BAC_CLONE_ID)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.PK_BUILD_INFO ON EUCOMM_VECTOR.BUILD_INFO
(BUILD_ID)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.PK_CHROMOSOME_DICT ON EUCOMM_VECTOR.CHROMOSOME_DICT
(CHR_ID)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.PK_CLONE_LIB_DICT ON EUCOMM_VECTOR.CLONE_LIB_DICT
(CLONE_LIB_ID)
LOGGING
NOPARALLEL;


CREATE INDEX EUCOMM_VECTOR.TARGET_ID ON EUCOMM_VECTOR.DESIGN
(TARGET_ID)
LOGGING
NOPARALLEL;


CREATE INDEX EUCOMM_VECTOR.BUILD_ID ON EUCOMM_VECTOR.DESIGN
(BUILD_ID)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.PK_DESIGN ON EUCOMM_VECTOR.DESIGN
(DESIGN_ID)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.PK_DESIGN_GROUP ON EUCOMM_VECTOR.DESIGN_GROUP
(DESIGN_GROUP_ID)
LOGGING
NOPARALLEL;


CREATE INDEX EUCOMM_VECTOR.DESIGN_NOTE_TYPE_ID ON EUCOMM_VECTOR.DESIGN_NOTE
(DESIGN_NOTE_TYPE_ID)
LOGGING
NOPARALLEL;


CREATE INDEX EUCOMM_VECTOR.DESIGN_ID_2 ON EUCOMM_VECTOR.DESIGN_NOTE
(DESIGN_ID)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.PK_DESIGN_NOTE ON EUCOMM_VECTOR.DESIGN_NOTE
(DESIGN_NOTE_ID)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.PK_DESIGN_NOTE_TYPE_DICT ON EUCOMM_VECTOR.DESIGN_NOTE_TYPE_DICT
(DESIGN_NOTE_TYPE_ID)
LOGGING
NOPARALLEL;


CREATE INDEX EUCOMM_VECTOR.DESIGN_STATUS_ID ON EUCOMM_VECTOR.DESIGN_STATUS
(DESIGN_STATUS_ID)
LOGGING
NOPARALLEL;


CREATE INDEX EUCOMM_VECTOR.DESIGN_ID_3 ON EUCOMM_VECTOR.DESIGN_STATUS
(DESIGN_ID)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.PK_DESIGN_STATUS ON EUCOMM_VECTOR.DESIGN_STATUS
(DESIGN_STATUS_ID, DESIGN_ID)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.PK_DESIGN_STATUS_DICT ON EUCOMM_VECTOR.DESIGN_STATUS_DICT
(DESIGN_STATUS_ID)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.PK_EUCOMM_GENE ON EUCOMM_VECTOR.EUCOMM_GENE
(GENE_ID)
LOGGING
NOPARALLEL;


CREATE INDEX EUCOMM_VECTOR.FEATURE_TYPE_ID ON EUCOMM_VECTOR.FEATURE
(FEATURE_TYPE_ID)
LOGGING
NOPARALLEL;


CREATE INDEX EUCOMM_VECTOR.DESIGN_ID ON EUCOMM_VECTOR.FEATURE
(DESIGN_ID)
LOGGING
NOPARALLEL;


CREATE INDEX EUCOMM_VECTOR.CHR_ID_2 ON EUCOMM_VECTOR.FEATURE
(CHR_ID)
LOGGING
NOPARALLEL;


CREATE INDEX EUCOMM_VECTOR.FEATURE_START ON EUCOMM_VECTOR.FEATURE
(FEATURE_START)
LOGGING
NOPARALLEL;


CREATE INDEX EUCOMM_VECTOR.FEATURE_END ON EUCOMM_VECTOR.FEATURE
(FEATURE_END)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.PK_FEATURE ON EUCOMM_VECTOR.FEATURE
(FEATURE_ID)
LOGGING
NOPARALLEL;


CREATE INDEX EUCOMM_VECTOR.FEATURE_ID ON EUCOMM_VECTOR.FEATURE_BLAST
(FEATURE_ID)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.PK_FEATURE_BLAST ON EUCOMM_VECTOR.FEATURE_BLAST
(BLAST_ID)
LOGGING
NOPARALLEL;


CREATE INDEX EUCOMM_VECTOR.FEATURE_DATA_TYPE_ID ON EUCOMM_VECTOR.FEATURE_DATA
(FEATURE_DATA_TYPE_ID)
LOGGING
NOPARALLEL;


CREATE INDEX EUCOMM_VECTOR.FEATURE_ID_1 ON EUCOMM_VECTOR.FEATURE_DATA
(FEATURE_ID)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.PK_FEATURE_DATA ON EUCOMM_VECTOR.FEATURE_DATA
(FEATURE_DATA_ID)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.DIS_PK ON EUCOMM_VECTOR.DESIGN_INSTANCE_STATUS
(DESIGN_INSTANCE_STATUS_ID, DESIGN_INSTANCE_ID, STATUS_DATE)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.DISD_PK ON EUCOMM_VECTOR.DESIGN_INSTANCE_STATUS_DICT
(DESIGN_INSTANCE_STATUS_ID)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.JMS_DESIGN_QC_STATUS_UK1 ON EUCOMM_VECTOR.JMS_DESIGN_QC_STATUS
(DESIGN_ID)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.WELL_PK ON EUCOMM_VECTOR.WELL
(WELL_ID)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.WELL_DATA_PK ON EUCOMM_VECTOR.WELL_DATA
(WELL_DATA_ID)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.GSY_PK ON EUCOMM_VECTOR.GENE_SUPPLEMENTARY
(SUPPLEMENTARY_ID)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.UPDATE_ID ON EUCOMM_VECTOR.UPDATE_FREQUENCY
(UPDATE_ID)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.STG_PK ON EUCOMM_VECTOR.SEQUENCE_TAG
(SEQ_ID)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.LOCATION_ID ON EUCOMM_VECTOR.LOCATION
(LOCATION_ID)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.UPDATE_METHOD_ID ON EUCOMM_VECTOR.UPDATE_METHOD
(UPDATE_METHOD_ID)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.SOURCE_ID ON EUCOMM_VECTOR.SOURCE
(SOURCE_ID)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.FUNCTION_ID ON EUCOMM_VECTOR.DATA_FUNCTION
(FUNCTION_ID)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.OII_PK ON EUCOMM_VECTOR.OMNIBANK_II
(OB2_ID)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.STG_UK ON EUCOMM_VECTOR.SEQUENCE_TAG
(SEQUENCE_NAME)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.DIC_PK ON EUCOMM_VECTOR.DESIGN_INSTANCE_BAC
(DESIGN_INSTANCE_ID, BAC_CLONE_ID)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.DCC_MASTER_GENE_LIST_PK ON EUCOMM_VECTOR.DCC_MASTER_GENE_LIST
(DCC_MASTER_GENE_LIST_ID)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.HTGT_STATUS_MSGS_PK ON EUCOMM_VECTOR.HTGT_STATUS_MSGS
(ID)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX EUCOMM_VECTOR.APP_AUDIT_TABLES_PK ON EUCOMM_VECTOR.APP_AUDIT_TABLES
(ID)
LOGGING
NOPARALLEL;


CREATE INDEX EUCOMM_VECTOR.WELL_DATA_DATA_TYPE_I ON EUCOMM_VECTOR.WELL_DATA
(DATA_TYPE)
LOGGING
NOPARALLEL;


CREATE INDEX EUCOMM_VECTOR.WELL_DATA_DATA_TYPE_WELL_ID_I ON EUCOMM_VECTOR.WELL_DATA
(WELL_ID, DATA_TYPE)
LOGGING
NOPARALLEL;


ALTER TABLE EUCOMM_VECTOR.FEATURE_DATA ADD (
  CONSTRAINT PK_FEATURE_DATA
 PRIMARY KEY
 (FEATURE_DATA_ID) DISABLE);

ALTER TABLE EUCOMM_VECTOR.BAC ADD (
  CONSTRAINT PK_BAC
 PRIMARY KEY
 (BAC_CLONE_ID));

ALTER TABLE EUCOMM_VECTOR.BUILD_INFO ADD (
  CONSTRAINT PK_BUILD_INFO
 PRIMARY KEY
 (BUILD_ID));

ALTER TABLE EUCOMM_VECTOR.CHROMOSOME_DICT ADD (
  CONSTRAINT PK_CHROMOSOME_DICT
 PRIMARY KEY
 (CHR_ID));

ALTER TABLE EUCOMM_VECTOR.CLONE_LIB_DICT ADD (
  CONSTRAINT PK_CLONE_LIB_DICT
 PRIMARY KEY
 (CLONE_LIB_ID));

ALTER TABLE EUCOMM_VECTOR.DESIGN ADD (
  CONSTRAINT PK_DESIGN
 PRIMARY KEY
 (DESIGN_ID));

ALTER TABLE EUCOMM_VECTOR.DESIGN_GROUP ADD (
  CONSTRAINT PK_DESIGN_GROUP
 PRIMARY KEY
 (DESIGN_GROUP_ID));

ALTER TABLE EUCOMM_VECTOR.DESIGN_NOTE ADD (
  CONSTRAINT PK_DESIGN_NOTE
 PRIMARY KEY
 (DESIGN_NOTE_ID));

ALTER TABLE EUCOMM_VECTOR.DESIGN_NOTE_TYPE_DICT ADD (
  CONSTRAINT PK_DESIGN_NOTE_TYPE_DICT
 PRIMARY KEY
 (DESIGN_NOTE_TYPE_ID));

ALTER TABLE EUCOMM_VECTOR.DESIGN_PARAMETER ADD (
  PRIMARY KEY
 (DESIGN_PARAMETER_ID));

ALTER TABLE EUCOMM_VECTOR.DESIGN_STATUS ADD (
  CONSTRAINT PK_DESIGN_STATUS
 PRIMARY KEY
 (DESIGN_STATUS_ID, DESIGN_ID));

ALTER TABLE EUCOMM_VECTOR.DESIGN_STATUS_DICT ADD (
  CONSTRAINT PK_DESIGN_STATUS_DICT
 PRIMARY KEY
 (DESIGN_STATUS_ID));

ALTER TABLE EUCOMM_VECTOR.EUCOMM_GENE ADD (
  CONSTRAINT PK_EUCOMM_GENE
 PRIMARY KEY
 (GENE_ID));

ALTER TABLE EUCOMM_VECTOR.FEATURE ADD (
  CONSTRAINT PK_FEATURE
 PRIMARY KEY
 (FEATURE_ID));

ALTER TABLE EUCOMM_VECTOR.FEATURE_BLAST ADD (
  CONSTRAINT PK_FEATURE_BLAST
 PRIMARY KEY
 (BLAST_ID));

ALTER TABLE EUCOMM_VECTOR.FEATURE_DATA_TYPE_DICT ADD (
  CONSTRAINT PK_FEATURE_DATA_TYPE_DICT
 PRIMARY KEY
 (FEATURE_DATA_TYPE_ID));

ALTER TABLE EUCOMM_VECTOR.FEATURE_TYPE_DICT ADD (
  CONSTRAINT PK_FEATURE_TYPE_DICT
 PRIMARY KEY
 (FEATURE_TYPE_ID));

ALTER TABLE EUCOMM_VECTOR.HIT ADD (
  CONSTRAINT PK_HIT
 PRIMARY KEY
 (HIT_ID));

ALTER TABLE EUCOMM_VECTOR.TARGET ADD (
  CONSTRAINT PK_TARGET
 PRIMARY KEY
 (TARGET_ID));

ALTER TABLE EUCOMM_VECTOR.DESIGN_INSTANCE ADD (
  PRIMARY KEY
 (DESIGN_INSTANCE_ID));

ALTER TABLE EUCOMM_VECTOR.GENE_SUPPLEMENTARY ADD (
  CONSTRAINT GSY_PK
 PRIMARY KEY
 (SUPPLEMENTARY_ID));

ALTER TABLE EUCOMM_VECTOR.UPDATE_FREQUENCY ADD (
  CONSTRAINT UPDATE_ID
 PRIMARY KEY
 (UPDATE_ID));

ALTER TABLE EUCOMM_VECTOR.SEQUENCE_TAG ADD (
  CONSTRAINT STG_PK
 PRIMARY KEY
 (SEQ_ID),
  CONSTRAINT STG_UK
 UNIQUE (SEQUENCE_NAME));

ALTER TABLE EUCOMM_VECTOR.LOCATION ADD (
  CONSTRAINT LOCATION_ID
 PRIMARY KEY
 (LOCATION_ID));

ALTER TABLE EUCOMM_VECTOR.UPDATE_METHOD ADD (
  CONSTRAINT UPDATE_METHOD_ID
 PRIMARY KEY
 (UPDATE_METHOD_ID));

ALTER TABLE EUCOMM_VECTOR.SOURCE ADD (
  CONSTRAINT SOURCE_ID
 PRIMARY KEY
 (SOURCE_ID));

ALTER TABLE EUCOMM_VECTOR.DATA_FUNCTION ADD (
  CONSTRAINT FUNCTION_ID
 PRIMARY KEY
 (FUNCTION_ID));

ALTER TABLE EUCOMM_VECTOR.OMNIBANK_II ADD (
  CONSTRAINT OII_PK
 PRIMARY KEY
 (OB2_ID));

ALTER TABLE EUCOMM_VECTOR.DESIGN_INSTANCE_BAC ADD (
  CONSTRAINT DIC_PK
 PRIMARY KEY
 (DESIGN_INSTANCE_ID, BAC_CLONE_ID));

ALTER TABLE EUCOMM_VECTOR.DESIGN_INSTANCE_STATUS ADD (
  CONSTRAINT DIS_PK
 PRIMARY KEY
 (DESIGN_INSTANCE_STATUS_ID, DESIGN_INSTANCE_ID, STATUS_DATE));

ALTER TABLE EUCOMM_VECTOR.DESIGN_INSTANCE_STATUS_DICT ADD (
  CONSTRAINT DISD_PK
 PRIMARY KEY
 (DESIGN_INSTANCE_STATUS_ID));

ALTER TABLE EUCOMM_VECTOR.GENE_INFO ADD (
  CONSTRAINT GENE_INFO_PK
 PRIMARY KEY
 (GENE_INFO_ID));

ALTER TABLE EUCOMM_VECTOR.SESSIONS ADD (
  PRIMARY KEY
 (ID));

ALTER TABLE EUCOMM_VECTOR.PLATE ADD (
  PRIMARY KEY
 (PLATE_ID));

ALTER TABLE EUCOMM_VECTOR.PLATE_COMMENT ADD (
  CONSTRAINT PLATE_COMMENT_PK
 PRIMARY KEY
 (PLATE_COMMENT_ID));

ALTER TABLE EUCOMM_VECTOR.PLATE_DATA ADD (
  CONSTRAINT PLATE_DATA_PK
 PRIMARY KEY
 (PLATE_DATA_ID));

ALTER TABLE EUCOMM_VECTOR.APP_AUDIT_TABLES ADD (
  CONSTRAINT APP_AUDIT_TABLES_PK
 PRIMARY KEY
 (ID));

ALTER TABLE EUCOMM_VECTOR.WELL ADD (
  CONSTRAINT WELL_PK
 PRIMARY KEY
 (WELL_ID),
  CONSTRAINT WELL_PLATE_WELL_NAME_C
 UNIQUE (PLATE_ID, WELL_NAME));

ALTER TABLE EUCOMM_VECTOR.WELL_DATA ADD (
  CONSTRAINT WELL_DATA_PK
 PRIMARY KEY
 (WELL_DATA_ID));

ALTER TABLE EUCOMM_VECTOR.HTGT_STATUS_MSGS ADD (
  CONSTRAINT HTGT_STATUS_MSGS_PK
 PRIMARY KEY
 (ID));

ALTER TABLE EUCOMM_VECTOR.DCC_MASTER_GENE_LIST ADD (
  CONSTRAINT DCC_MASTER_GENE_LIST_PK
 PRIMARY KEY
 (DCC_MASTER_GENE_LIST_ID));

ALTER TABLE EUCOMM_VECTOR.GENE_COMMENT ADD (
  PRIMARY KEY
 (GENE_COMMENT_ID));

ALTER TABLE EUCOMM_VECTOR.JMS_DESIGN_QC_STATUS ADD (
  CONSTRAINT JMS_DESIGN_QC_STATUS_UK1
 UNIQUE (DESIGN_ID));