-- Extracting Data for Home-Office Returns 

--How many dead mice on this PPL have a mutated allele and have a genotyping procedure on them?
-- Should we be including F1 genotypes here or not?
select count(distinct m.id)
from mts_mouse m,
     mts_mouse_procedure p,
     mts_mouse_allele a
where m.id = p.mouse_id and
      m.birth_date between '1-Jan-2007' and '31-Dec-2007' and
      m.death_date between '1-Jan-2007' and '31-Dec-2007' and
      m.status = 'Deceased' and
      a.mouse_id = m.id and
      p.procedure_dict_id in (37, 20) and
      p.protocol_id in (select id from lic_protocol_19b where project_licence_id = 99);

--NB. Includes LIVE Mice.      
--How many WT mice have ear clips for genotyping on this PPL?
select count(distinct m.id)
from mts_mouse m,
     mts_mouse_procedure p
where m.id = p.mouse_id and
      m.birth_date between '1-Jan-2007' and '31-Dec-2007' and
      not exists(select null from mts_mouse_allele a where a.mouse_id = m.id) and
      p.procedure_dict_id in (37, 20) and
      p.protocol_id in (select id from lic_protocol_19b where project_licence_id = 99);    


--How many dead WT mice on this PPL have been X-rayed AND had a terminal bleed/Blood Sample (phenotyping)?
select count(distinct m.id)
from mts_mouse m
where m.status = 'Deceased' and
      m.birth_date between '1-Jan-2007' and '31-Dec-2007' and
      m.death_date between '1-Jan-2007' and '31-Dec-2007' and
      not exists(select null from mts_mouse_allele a where a.mouse_id = m.id) and
      exists(select null from mts_mouse_procedure p where p.mouse_id = m.id and p.procedure_dict_id in (1, 32) and p.protocol_id in (select id from lic_protocol_19b where project_licence_id = 99)) and
      exists(select null from mts_mouse_procedure p where p.mouse_id = m.id and p.procedure_dict_id = 12 and p.protocol_id in (select id from lic_protocol_19b where project_licence_id = 99));
      
--How many dead WT mice on this PPL have been bled but NOT X-Rayed?
select count(distinct m.id)
from mts_mouse m
where m.status = 'Deceased' and
      m.birth_date between '1-Jan-2007' and '31-Dec-2007' and
      m.death_date between '1-Jan-2007' and '31-Dec-2007' and
      not exists(select null from mts_mouse_allele a where a.mouse_id = m.id) and
      exists(select null from mts_mouse_procedure p where p.mouse_id = m.id and p.procedure_dict_id in (1, 32) and p.protocol_id in (select id from lic_protocol_19b where project_licence_id = 99)) and
      not exists(select null from mts_mouse_procedure p where p.mouse_id = m.id and p.procedure_dict_id = 12 and p.protocol_id in (select id from lic_protocol_19b where project_licence_id = 99));
      
--How many dead WT mice on this PPL have a phenotyping entry that is not bleeding, X-Rays, genotyping or breeding
select count(distinct m.id)
from mts_mouse m
where m.status = 'Deceased' and
      m.birth_date between '1-Jan-2007' and '31-Dec-2007' and
      m.death_date between '1-Jan-2007' and '31-Dec-2007' and
      not exists(select null from mts_mouse_allele a where a.mouse_id = m.id) and
      exists(select null from mts_mouse_procedure p where p.mouse_id = m.id and p.procedure_dict_id not in (1, 32, 12, 37, 20, 21, 36) and p.protocol_id in (select id from lic_protocol_19b where project_licence_id = 99));

-- Requires valid data for Mutation class on the Allele, who has responsibility for this and is it up-to-date?
--NB. Includes LIVE Mice. 
--How many mice on this PPL have colonies where the allele is marked as harmful and have genotyping procedures done
select count(distinct m.id)
from mts_mouse m,
     mts_mouse_procedure p,
     mts_mouse_allele a,
     typ_modified_allele ta
where m.id = p.mouse_id and
      m.birth_date between '1-Jan-2007' and '31-Dec-2007' and
      ta.id = a.allele_id and
      ta.mutation_class_dict_id = 3 and
      a.mouse_id = m.id and
      p.procedure_dict_id in (37, 20) and
      p.protocol_id in (select id from lic_protocol_19b where project_licence_id = 99); 
      
-- Requires valid data for Mutation class on the Allele, who has responsibility for this and is it up-to-date?
--NB. Includes LIVE Mice. 
--How many mice on this PPL have colonies where the allele is marked as harmful but have no genotyping procedures done
select count(distinct m.id)
from mts_mouse m,
     mts_mouse_allele a,
     typ_modified_allele ta
where ta.id = a.allele_id and
      m.birth_date between '1-Jan-2007' and '31-Dec-2007' and
      ta.mutation_class_dict_id = 3 and
      exists(select null from mts_mouse_procedure p where p.mouse_id = m.id and p.procedure_dict_id in (36, 21) and p.protocol_id in (select id from lic_protocol_19b where project_licence_id = 99)) and
      not exists(select null from mts_mouse_procedure p where p.mouse_id = m.id and p.procedure_dict_id in (37, 20) and p.protocol_id in (select id from lic_protocol_19b where project_licence_id = 99)) and
      a.mouse_id = m.id;