/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

alter table req_animal_request_audit rename column age_or_weight_vs_embryo_age to development_endpoint;

alter table req_animal_request_audit drop column identification;

alter table req_animal_request_audit drop column age_matched_litermates;

alter table arq_design_request_audit add retrieval_primer_offset_3p integer;

alter table arq_design_request_audit add retrieval_primer_length_3p integer;

alter table arq_design_request_audit rename column retrieval_primer_length to retrieval_primer_length_5p;

alter table arq_design_request_audit rename column retrieval_primer_offset to retrieval_primer_offset_5p  

alter table arq_design_request_audit add critical_exon_contains_atg number(1);

alter table arq_design_request_audit add score integer;


CREATE TABLE MTS_MOUSE_AUDIT
(
  ID                          INTEGER,
  LITTER_ID                   INTEGER,
  NAME                        VARCHAR2(64 CHAR),
  EDIT_DATE                   DATE,
  RFID_TAG                    VARCHAR2(256 CHAR),
  COAT_COLOUR_DICT_ID         NUMBER,
  EYE_COLOUR_DICT_ID          NUMBER,
  EARMARK_DICT_ID             NUMBER,
  BIRTH_DATE                  DATE,
  DEATH_DATE                  DATE,
  CAUSE_OF_DEATH_DICT_ID      NUMBER,
  EDITED_BY                   VARCHAR2(128 CHAR),
  WEAN_DATE                   DATE,
  CAGE_ID                     NUMBER,
  CURRENT_OWNER_ID            NUMBER,
  CURRENT_PROJECT_LICENCE_ID  NUMBER,
  CHECK_NUMBER                NUMBER,
  GENDER_DICT_ID              NUMBER,
  MOUSE_STRAIN_DICT_ID        INTEGER,
  STATUS                      VARCHAR2(20 CHAR),
  CREATOR_ID                  INTEGER,
  CREATED_DATE                DATE,
  BARCODE                     VARCHAR2(128 CHAR),
  COMMENTS                    VARCHAR2(4000 CHAR),
  CURRENT_PROTOCOL_ID         INTEGER,
  SUPPLIER_DICT_ID            INTEGER,
  IS_NON_BREEDER              NUMBER(1),
  IS_SENTINEL                 NUMBER(1),
  RESERVATION_ID              INTEGER,
  GENERATION                  VARCHAR2(128 CHAR),
  COLONY_INFO_ID              INTEGER,
  COHORT_ID                   INTEGER,
  ARRIVAL_DATE                DATE,
  RESERVED_BY_ID              INTEGER,
  FATHER_ID                   INTEGER,
  MOTHER_ID                   INTEGER,
  AUDIT_DATE                  DATE              DEFAULT SYSTIMESTAMP,
  EARMARK_LEFT                INTEGER,
  EARMARK_RIGHT               INTEGER,
  RESERVATION_TYPE            VARCHAR2(30 BYTE),
  RESERVED_FOR_ID             INTEGER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

grant select,insert on MTS_MOUSE_AUDIT to mig;

CREATE TABLE MTS_CAGE_AUDIT
(
  ID                 INTEGER,
  RACK_ID            INTEGER,
  STATUS             VARCHAR2(20 CHAR),
  CHECK_NUMBER       INTEGER,
  COMMENTS           VARCHAR2(4000 CHAR),
  EDITED_BY          VARCHAR2(128 CHAR),
  EDIT_DATE          DATE,
  CREATOR_ID         INTEGER,
  CREATED_DATE       DATE,
  BARCODE            VARCHAR2(128 CHAR)         NOT NULL,
  NAME               INTEGER,
  LAST_CLEANED_DATE  DATE,
  AUDIT_DATE         DATE                       DEFAULT SYSTIMESTAMP
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

grant select,insert on mts_cage_audit to mig;

CREATE TABLE MTS_MOUSE_HEALTH_AUDIT
(
  ID                      NUMBER,
  MOUSE_ID                NUMBER,
  START_DATE              DATE,
  END_DATE                DATE,
  EDIT_DATE               DATE,
  EDITED_BY               VARCHAR2(100 CHAR),
  CREATOR_ID              INTEGER,
  CREATED_DATE            DATE,
  COMMENTS                VARCHAR2(4000 CHAR),
  STATUS                  VARCHAR2(20 CHAR),
  BODY_SUBSYSTEM_DICT_ID  NUMBER,
  BODY_SYSTEM_DICT_ID     NUMBER,
  HEALTH_CONCERN_DICT_ID  NUMBER,
  AUDIT_DATE              DATE                  DEFAULT SYSTIMESTAMP
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

grant select,insert on mts_mouse_health_audit to mig;

CREATE TABLE MTS_AIR_HANDLING_UNIT_AUDIT
(
  ID             NUMBER,
  NAME           VARCHAR2(100 CHAR),
  ROOM_ID        NUMBER,
  CHECK_NUMBER   NUMBER,
  AUDIT_DATE     DATE                           DEFAULT SYSTIMESTAMP,
  RADIO_ADDRESS  VARCHAR2(100 CHAR),
  EDITED_BY      VARCHAR2(128 CHAR),
  EDIT_DATE      DATE,
  CREATED_DATE   DATE
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

grant select,insert on MTS_AIR_HANDLING_UNIT_AUDIT to mig;

CREATE TABLE MTS_LITTER_AUDIT
(
  ID                INTEGER,
  LITTER_SOURCE     VARCHAR2(32 CHAR),
  BREEDING_ID       INTEGER,
  BIRTH_DATE        DATE,
  CHECK_NUMBER      NUMBER,
  EDITED_BY         VARCHAR2(128 CHAR),
  EDIT_DATE         DATE,
  CREATOR_ID        INTEGER,
  CREATED_DATE      DATE,
  PLUG_CHECK_DATE   DATE,
  FOSTER_MOTHER_ID  INTEGER,
  NUMBER_BORN       INTEGER,
  NUMBER_WEANED     INTEGER,
  NUMBER_USED       INTEGER,
  COMMENTS          VARCHAR2(4000 CHAR),
  NUMBER_DIED       INTEGER,
  STATUS            VARCHAR2(32 CHAR),
  LITTER_NAME       VARCHAR2(32 CHAR),
  AUDIT_DATE        DATE                        DEFAULT SYSTIMESTAMP,
  NUMBER_HARVESTED  INTEGER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

grant select,insert on MTS_LITTER_AUDIT to mig;

CREATE TABLE MTS_ROOM_AUDIT
(
  ID                    INTEGER,
  ROOM_NUMBER           VARCHAR2(128 CHAR)      NOT NULL,
  BUILDING_NAME         VARCHAR2(128 CHAR),
  CORRIDOR              VARCHAR2(128 CHAR),
  DESCRIPTION           VARCHAR2(1028 CHAR),
  CHECK_NUMBER          NUMBER,
  ACTIVE                NUMBER(1),
  OFFICIAL_ROOM_NUMBER  VARCHAR2(4000 CHAR),
  AUDIT_DATE            DATE                    DEFAULT SYSTIMESTAMP
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

grant select,insert on mts_room_audit to mig;

CREATE TABLE MTS_RACK_AUDIT
(
  ID                    INTEGER,
  AIR_HANDLING_UNIT_ID  INTEGER,
  ROOM_ID               INTEGER,
  STATUS                VARCHAR2(20 CHAR),
  TECHNOPLAST_NAME      VARCHAR2(128 CHAR),
  CHECK_NUMBER          INTEGER,
  EDITED_BY             VARCHAR2(128 CHAR),
  EDIT_DATE             DATE,
  CREATOR_ID            INTEGER,
  CREATED_DATE          DATE,
  BARCODE               VARCHAR2(128 CHAR),
  MAX_CAPACITY          INTEGER,
  NAME                  INTEGER,
  AUDIT_DATE            DATE                    DEFAULT SYSTIMESTAMP
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

grant select,insert on mts_rack_audit to mig;

CREATE TABLE MTS_BREEDING_AUDIT
(
  ID                   INTEGER,
  EVENT_START          DATE,
  EVENT_END            DATE,
  CHECK_NUMBER         INTEGER,
  EDITED_BY            VARCHAR2(128 CHAR),
  EDIT_DATE            DATE,
  COMMENTS             VARCHAR2(4000 CHAR),
  RESERVATION_ID       INTEGER,
  CREATOR_ID           INTEGER,
  CREATED_DATE         DATE,
  MALE_ID              INTEGER,
  FEMALE_ID            NUMBER,
  STATUS               VARCHAR2(32 CHAR),
  BREEDING_NAME        VARCHAR2(32 CHAR),
  OFFSPRING_COLONY_ID  INTEGER,
  AUDIT_DATE           DATE                     DEFAULT SYSTIMESTAMP,
  PSEUDO_BREEDING      NUMBER(1),
  EMBRYO_TRANSFER_ID   INTEGER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

grant select,insert on mts_breeding_audit to mig;