/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


CREATE SEQUENCE MTS_COHORT_MOUSE_SEQ
  START WITH 12
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE MTS_MOUSE_WEIGHT_SEQ
  START WITH 12
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

DROP TABLE MTS_RESERVED_MOUSE CASCADE CONSTRAINTS purge;

DROP TABLE CRQ_CRYO_REQUEST_OLD CASCADE CONSTRAINTS purge;

DROP TABLE MTS_RESERVATION CASCADE CONSTRAINTS purge;

DROP TABLE MIR_REQUEST_STATUS_DICT CASCADE CONSTRAINTS purge;

alter table mts_breeding rename column event_start to start_date;

alter table mts_breeding rename column event_end to end_date;

CREATE TABLE MTS_STRAIN_COAT_COLOUR
(
  ID              NUMBER,
  STRAIN_ID       NUMBER                        NOT NULL,
  COAT_COLOUR_ID  NUMBER                        NOT NULL
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_COHORT_MOUSE
(
  ID            INTEGER,
  COHORT_ID     INTEGER,
  MOUSE_ID      INTEGER,
  CHECK_NUMBER  NUMBER,
  CREATOR_ID    INTEGER,
  CREATED_DATE  DATE,
  EDITED_BY     VARCHAR2(128 BYTE),
  EDIT_DATE     DATE
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_COHORT
(
  ID                  INTEGER,
  COHORT_NAME         VARCHAR2(128 BYTE),
  COMMENTS            VARCHAR2(4000 BYTE),
  CHECK_NUMBER        NUMBER,
  CREATOR_ID          INTEGER,
  CREATED_DATE        DATE,
  EDITED_BY           VARCHAR2(128 BYTE),
  EDIT_DATE           DATE,
  FOREIGN_TABLE_NAME  VARCHAR2(30 BYTE),
  FOREIGN_KEY_ID      INTEGER,
  REASON              VARCHAR2(4000 BYTE)
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_MOUSE_WEIGHT
(
  ID            INTEGER,
  MOUSE_ID      INTEGER,
  WEIGHT_VALUE  FLOAT(126),
  WEIGHT_UNITS  VARCHAR2(10 BYTE),
  CHECK_NUMBER  NUMBER,
  CREATOR_ID    INTEGER,
  CREATED_DATE  DATE,
  EDITED_BY     VARCHAR2(128 BYTE),
  EDIT_DATE     DATE
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_WILDTYPE_REQ_GROUP_DICT
(
  ID           NUMBER,
  NAME         VARCHAR2(256 BYTE)               NOT NULL,
  DESCRIPTION  VARCHAR2(4000 BYTE),
  ORDER_BY     NUMBER                           NOT NULL,
  ACTIVE       NUMBER                           NOT NULL
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;


/* This object may not be sorted properly in the script due to cirular references */
CREATE OR REPLACE FORCE VIEW MTS_CURRENT_BREEDING
(BREEDING_ID, BREEDING_NAME, MOUSE_ID)
AS 
select 
  b.id breeding_id, 
  b.breeding_name, 
  b.female_id mouse_id 
from 
  mts_breeding b 
where 
  b.end_date is null 
union 
-- males (in one breeding) 
select 
  b.id breeding_id, 
  b.breeding_name, 
  b.male_id mouse_id 
from 
  mts_breeding b 
where 
  b.male_id in (select male_id from mts_breeding where end_date is null group by male_id having count(*) = 1) 
union 
-- males (in multiple breedings) 
select 
  0 breeding_id, 
  'In '||count(*)||' matings' breeding_name, 
  b.male_id mouse_id 
from 
  mts_breeding b 
where 
  end_date is null 
group by male_id having count(*) >1;

ALTER TABLE MTS_STRAIN_COAT_COLOUR
 ADD CONSTRAINT MTS_STRAIN_COAT_COLOUR_PK
 PRIMARY KEY
 (ID);

ALTER TABLE MTS_STRAIN_COAT_COLOUR
 ADD CONSTRAINT MTS_STRAIN_COAT_COLOUR_R02 
 FOREIGN KEY (STRAIN_ID) 
 REFERENCES TYP_STRAIN (ID);

ALTER TABLE MTS_STRAIN_COAT_COLOUR
 ADD CONSTRAINT MTS_STRAIN_COAT_COLOUR_R01 
 FOREIGN KEY (COAT_COLOUR_ID) 
 REFERENCES MTS_COAT_COLOUR_DICT (ID);

ALTER TABLE MIR_MICRO_INJECTION
 ADD CONSTRAINT MIR_MICRO_INJECTION_R06 
 FOREIGN KEY (TECHNICIAN_ID) 
 REFERENCES PER_PERSON (PERSON_ID);

ALTER TABLE REQ_ANIMAL_REQUEST
 ADD FOREIGN KEY (GROUP_DICT_ID) 
 REFERENCES MTS_WILDTYPE_REQ_GROUP_DICT (ID);

ALTER TABLE MTS_COHORT
 ADD CONSTRAINT MTS_COHORT_PK
 PRIMARY KEY
 (ID);

ALTER TABLE MTS_MOUSE_WEIGHT
 ADD CONSTRAINT MTS_MOUSE_WEIGHT_PK
 PRIMARY KEY
 (ID);

ALTER TABLE MTS_WILDTYPE_REQ_GROUP_DICT
 ADD CONSTRAINT MTS_WILDTYPE_REQ_GROUP_DICTR01
 PRIMARY KEY
 (ID);

CREATE UNIQUE INDEX MTS_COHORT_MOUSE_PK ON MTS_COHORT_MOUSE
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_COHORT_PK ON MTS_COHORT
(ID)
LOGGING
NOPARALLEL;

CREATE OR REPLACE TRIGGER mts_cohort_t1 
 before insert or update or delete on mts_cohort
for each row
declare

cursor get_table_metadata(in_table_name varchar2) is
select
  *
from
  app_table_metadata
where
  table_name = in_table_name;
  
user_exception exception;
exception_message varchar2(4000);

v_table_metadata app_table_metadata%rowtype;

begin

  -- updated records cannot change the table metadata (doesn't make sense to do so)
  if updating then
    if :new.foreign_table_name != :old.foreign_table_name then
       exception_message := 'FOREIGN_TABLE_NAME reference cannot be updated';
       raise user_exception;
    end if;   
  end if;
  
  -- inserted record must contain a valid table name
  if inserting and :new.foreign_table_name is not null then
   open get_table_metadata(:new.foreign_table_name);
  fetch get_table_metadata into v_table_metadata;
  if get_table_metadata%notfound then
    close get_table_metadata;
    exception_message := 'FOREIGN_TABLE_NAME ('||:new.foreign_table_name||') is not a valid reference';
       raise user_exception;
  end if;
  close get_table_metadata;
  end if; 
  
  -- if deleting, ensure foreign key does not exist
  if deleting then
   open get_table_metadata(:old.foreign_table_name);
  fetch get_table_metadata into v_table_metadata;
  if get_table_metadata%notfound then
    close get_table_metadata;
    exception_message := 'FOREIGN_TABLE_NAME ('||:old.foreign_table_name||') is not a valid reference';
       raise user_exception;
  end if;
  close get_table_metadata;
     execute immediate 'select * from '||v_table_metadata.table_name||' where '||v_table_metadata.primary_key_column||'=:1' using :old.foreign_key_id;
  if sql%rowcount > 0 then
    exception_message := 'Cannot delete MTS_COHORT (ID='||:old.id||') because foreign key exists.';
       raise user_exception;
    
  end if;
 end if;
  

exception
  when user_exception then raise_application_error(-20001, exception_message);
    
end mts_mouse_procedure_t1;
/
SHOW ERRORS;


CREATE UNIQUE INDEX MTS_MOUSE_WEIGHT_PK ON MTS_MOUSE_WEIGHT
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_WILDTYPE_REQ_GROUP_DICTR01 ON MTS_WILDTYPE_REQ_GROUP_DICT
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_WILDTYPE_REQ_GROUP_DICTU01 ON MTS_WILDTYPE_REQ_GROUP_DICT
(NAME)
LOGGING
NOPARALLEL;

ALTER TABLE MTS_COHORT_MOUSE
 ADD CONSTRAINT MTS_COHORT_MOUSE_PK
 PRIMARY KEY
 (ID);

ALTER TABLE MTS_WILDTYPE_REQ_GROUP_DICT
 ADD CONSTRAINT MTS_WILDTYPE_REQ_GROUP_DICTU01
 UNIQUE (NAME);

CREATE UNIQUE INDEX MTS_STRAIN_COAT_COLOUR_PK ON MTS_STRAIN_COAT_COLOUR
(ID)
LOGGING
NOPARALLEL;

CREATE OR REPLACE FORCE VIEW MTS_MOUSE_CURRENT_WEIGHT_VW
(ID, MOUSE_ID, WEIGHT_VALUE, WEIGHT_UNITS, CHECK_NUMBER, 
 CREATOR_ID, CREATED_DATE, EDITED_BY, EDIT_DATE)
AS 
select 
  w.id, 
  w.mouse_id, 
  w.weight_value, 
  w.weight_units, 
  w.check_number, 
  w.creator_id, 
  w.created_date, 
  w.edited_by, 
  w.edit_date 
from 
  mts_mouse_weight w 
where 
  w.id in (select max(id) from mts_mouse_weight group by mouse_id);



ALTER TABLE MIR_SCHEDULED_MICRO_INJECTION
 ADD (RECIPIENT_REQUEST_EMAIL  NUMBER(1)            DEFAULT 0);

ALTER TABLE MIR_MICRO_INJECTION
 ADD (TECHNICIAN_ID  INTEGER);

ALTER TABLE REQ_ANIMAL_REQUEST
 ADD (GROUP_DICT_ID  NUMBER);

ALTER TABLE MIR_SCHEDULED_MICRO_INJECTION
 ADD (DONOR_REQUEST_EMAIL  NUMBER(1)                DEFAULT 0);





CREATE OR REPLACE FORCE VIEW MIR_SCHEDULED_MI_LIST_VW
(ID, MICRO_INJECTION_REQUEST_ID, INTERNAL_STATUS_ID, INTERNAL_STATUS_NAME, ENDPOINT_ID, 
 ENDPOINT_NAME, TARGET_SCHEDULE_DATE, DONOR_ANIMAL_REQUEST_ID, RECIPIENT_ANIMAL_REQUEST_ID, SUPPLEMENTAL_RECIPIENT_REQ_ID, 
 MI_ACTUAL_COMPLETION_DATE, ET_ACTUAL_COMPLETION_DATE, F0_ACTUAL_COMPLETION_DATE, F1_ACTUAL_COMPLETION_DATE, DONOR_MOUSE_COUNT, 
 RECIPIENT_MOUSE_COUNT, SUPPLEMENTAL_MOUSE_COUNT, REQUESTER_NAME, CELL_LINE_PROVIDER_NAME_NO, MICRO_INJECTION_ID, 
 CELL_LINE_NAME, CELL_LINE_CLONE)
AS 
SELECT smi.ID, smi.micro_injection_request_id, isd.ID internal_status_id, 
       isd.NAME internal_status_name, med.ID endpoint_id, 
       med.NAME endpoint_name, smi.target_schedule_date, 
       smi.donor_animal_request_id, smi.recipient_animal_request_id, 
       smi.supplemental_recipient_req_id, 
       --mi.id micro_injection_id, 
       --mi.date_completed micro_injection_completed_date 
       smt_mi.actual_completion_date mi_actual_completion_date, 
       smt_et.actual_completion_date et_actual_completion_date, 
       smt_f0.actual_completion_date f0_actual_completion_date, 
       smt_f1.actual_completion_date f1_actual_completion_date, 
       donor_req.num_females_needed donor_mouse_count,
       recip_req.num_females_needed recipient_mouse_count,  
       0 supplemental_mouse_count, 
       per_r.first_name || ' ' || per_r.last_name requester_name, 
       DECODE (per_cl.phone_number, 
               '', per_cl.first_name|| ' '|| per_cl.last_name, 
               per_cl.first_name || ' ' || per_cl.last_name || ' (' 
                || per_cl.phone_number || ')' 
              ) cell_line_provider_name_no, 
       mi.ID micro_injection_id,
    cell_line.cell_line_name cell_line_name,
    cell_line.clone_name cell_line_clone
  FROM mir_scheduled_micro_injection smi, 
       mir_internal_status_dict isd, 
       mir_micro_injection_request mir,
    mir_cell_line cell_line, 
       mir_target_endpoint_dict med, 
       -- mir_micro_injection mi 
       (SELECT smt.* 
          FROM mir_scheduled_mi_task smt, mir_scheduled_micro_injection smi 
         WHERE smi.ID = smt.scheduled_micro_injection_id(+) 
               AND smt.NAME = 'Microinjection Completed') smt_mi, 
       (SELECT smt.* 
          FROM mir_scheduled_mi_task smt, mir_scheduled_micro_injection smi 
         WHERE smi.ID = smt.scheduled_micro_injection_id(+) 
               AND smt.NAME = 'Embryo Transfer Completed') smt_et, 
       (SELECT smt.* 
          FROM mir_scheduled_mi_task smt, mir_scheduled_micro_injection smi 
         WHERE smi.ID = smt.scheduled_micro_injection_id(+) 
               AND smt.NAME = 'F0s Weaned') smt_f0, 
       (SELECT smt.* 
          FROM mir_scheduled_mi_task smt, mir_scheduled_micro_injection smi 
         WHERE smi.ID = smt.scheduled_micro_injection_id(+) 
               AND smt.NAME = 'F1s Genotyped') smt_f1, 
       per_person per_r, 
       per_person per_cl, 
       mir_micro_injection mi,
       req_animal_request donor_req,
       req_animal_request recip_req
 WHERE smi.internal_status_dict_id = isd.ID 
   AND mir.ID = smi.micro_injection_request_id 
   AND mir.endpoint_dict_id = med.ID 
   AND smt_mi.scheduled_micro_injection_id(+) = smi.ID 
   AND smt_et.scheduled_micro_injection_id(+) = smi.ID 
   AND smt_f0.scheduled_micro_injection_id(+) = smi.ID 
   AND smt_f1.scheduled_micro_injection_id(+) = smi.ID  
   AND mir.requester_id = per_r.person_id 
   AND smi.cell_line_provider_id = per_cl.person_id 
   AND smi.ID = mi.scheduled_micro_injection_id(+)
   AND donor_req.id(+) = smi.donor_animal_request_id
   AND recip_req.id(+) = smi.recipient_animal_request_id
   AND mir.cell_line_id = cell_line.id;

/* This object may not be sorted properly in the script due to cirular references */
CREATE OR REPLACE TRIGGER MTS_BREEDING_ta
before update or delete on MTS_BREEDING for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
declare
audit_action varchar2(10);
begin

if deleting then audit_action := 'deleted'; end if;
if updating then audit_action := 'updated'; end if;
if deleting or updating then 
 insert into MTS_BREEDING_AUDIT(
    ID,
    START_DATE,
    END_DATE,
    CHECK_NUMBER,
    EDITED_BY,
    EDIT_DATE,
    COMMENTS,
    RESERVATION_ID,
    CREATOR_ID,
    CREATED_DATE,
    MALE_ID,
    FEMALE_ID,
    STATUS,
    BREEDING_NAME,
    OFFSPRING_COLONY_ID,
    PSEUDO_BREEDING,
    EMBRYO_TRANSFER_ID,
    AUDIT_ACTION)
 values (
    :old.ID,
    :old.START_DATE,
    :old.END_DATE,
    :old.CHECK_NUMBER,
    :old.EDITED_BY,
    :old.EDIT_DATE,
    :old.COMMENTS,
    :old.RESERVATION_ID,
    :old.CREATOR_ID,
    :old.CREATED_DATE,
    :old.MALE_ID,
    :old.FEMALE_ID,
    :old.STATUS,
    :old.BREEDING_NAME,
    :old.OFFSPRING_COLONY_ID,
    :old.PSEUDO_BREEDING,
    :old.EMBRYO_TRANSFER_ID,
    AUDIT_ACTION);
end if;
end;
/
SHOW ERRORS;


/* This object may not be sorted properly in the script due to cirular references */
CREATE OR REPLACE FORCE VIEW MTS_MOUSE_VW
(ID, LITTER_ID, NAME, EDIT_DATE, COAT_COLOUR_DICT_ID, 
 COAT_COLOUR, EYE_COLOUR_DICT_ID, EYE_COLOUR, EARMARK_DICT_ID, EARMARK, 
 EARMARK_LEFT, EARMARK_RIGHT, BIRTH_DATE, AGE_IN_WEEKS, DEATH_DATE, 
 AGE_AT_DEATH, CAUSE_OF_DEATH_DICT_ID, CAUSE_OF_DEATH, EDITED_BY, WEAN_DATE, 
 CAGE_ID, CAGE_NAME, CAGE_BARCODE, RACK_ID, RACK_NAME, 
 ROOM_ID, ROOM_NAME, CURRENT_OWNER_ID, CURRENT_OWNER, CURRENT_PROJECT_LICENCE_ID, 
 CURRENT_PROJECT_LICENCE, CURRENT_PROTOCOL_ID, CURRENT_PROTOCOL_CODE, CHECK_NUMBER, GENDER_DICT_ID, 
 GENDER, MOUSE_STRAIN_DICT_ID, STRAIN, STATUS, CREATOR_ID, 
 CREATED_DATE, BARCODE, COMMENTS, IS_NON_BREEDER, IS_SENTINEL, 
 GENERATION, COLONY_NAME, COLONY_INFO_ID, ARRIVAL_DATE, FATHER_ID, 
 MOTHER_ID, LATEST_PLUG_DATE, BREEDING_NAME)
AS 
select 
  m.id, 
  m.litter_id, 
  m.name, 
  m.edit_date, 
  m.coat_colour_dict_id, 
  c.name coat_colour, 
  m.eye_colour_dict_id, 
  e.name eye_colour, 
  m.earmark_dict_id, 
  ear.name earmark, 
  m.earmark_left, 
  m.earmark_right, 
  m.birth_date, 
  round((nvl(m.death_date,sysdate) - m.birth_date)/7,1) age_in_weeks, 
  m.death_date, 
  round((m.death_date - m.birth_date)/7,1) age_at_death, 
  m.cause_of_death_dict_id, 
  d.name cause_of_death, 
  m.edited_by, 
  m.wean_date, 
  m.cage_id, 
  l.cage_name, 
  l.cage_barcode, 
  l.rack_id, 
  l.rack_name, 
  l.room_id, 
  l.room_name, 
  m.current_owner_id, 
  owner.first_name||' '||owner.last_name current_owner, 
  b.project_licence_id current_project_licence_id, 
  b.licence_number current_project_licence, 
  b.protocol_id current_protocol_id, 
  b.protocol_code current_protocol_code, 
  m.check_number, 
  m.gender_dict_id, 
  s.name gender, 
  m.mouse_strain_dict_id, 
  t.name strain, 
  m.status, 
  m.creator_id, 
  m.created_date, 
  m.barcode, 
  m.comments, 
  m.is_non_breeder, 
  m.is_sentinel, 
  m.generation, 
  colony.colony_name, 
  m.colony_info_id, 
  m.arrival_date, 
  m.father_id, 
  m.mother_id, 
  m.latest_plug_date, 
  breeding.breeding_name 
from 
  mts_mouse m, 
  mts_coat_colour_dict c, 
  mts_eye_colour_dict e, 
  mts_earmark_dict ear, 
  mts_cause_of_death_dict d, 
  per_person owner, 
  mts_gender_dict s, 
  mts_cage_vw l, 
  mts_mouse_current_19b_vw b, 
  typ_strain t, 
  mts_colony_info colony, 
  mts_current_breeding breeding 
where 
  m.coat_colour_dict_id = c.id(+) and 
  m.eye_colour_dict_id = e.id(+) and 
  m.earmark_dict_id = ear.id(+) and 
  m.cause_of_death_dict_id = d.id(+) and 
  m.current_owner_id = owner.person_id(+) and 
  m.gender_dict_id = s.id(+) and 
  m.cage_id = l.cage_id(+) and 
  m.mouse_strain_dict_id = t.id(+) and 
  m.colony_info_id = colony.id(+) and 
  m.id = b.mouse_id(+) and 
  m.id = breeding.mouse_id(+);
  

CREATE OR REPLACE FORCE VIEW REQ_ANIMAL_REQUEST_LIST_VW
(ID, PROJECT_LICENCE_ID, PPL_HOLDER, REQUEST_REASON, STRAIN_ID, 
 STRAIN, NUM_MALES_NEEDED, NUM_FEMALES_NEEDED, DATE_REQUIRED, DESTINATION_ROOM_ID, 
 DESTINATION_ROOM, STANDING_ORDER_FREQ, STANDING_ORDER_DAY, NUMBER_IN_CAGE, REDERIVATION_REQUESTED, 
 COMMENTS, EMBRYO_AGE_NEEDED, AGE_OR_WEIGHT_UNITS, AGE_OR_WEIGHT, FUNDING_SOURCE, 
 STATUS_DICT_ID, STATUS, DEVELOPMENT_ENDPOINT, CREATED_DATE, EDITED_BY, 
 EDIT_DATE, REQUEST_ORIGINATOR_ID, REQUESTER, TEAM_NUMBER, CREATOR_ID, 
 CHECK_NUMBER, PSEUDO_PREGNANT_FEMALE, END_DATE, GROUP_DICT_ID, GROUP_DICT_NAME)
AS 
select 
  r.id, 
  r.project_licence_id, 
  h.first_name||' '||h.last_name ppl_holder, 
  r.request_reason, 
  r.strain_id, 
  s.name strain, 
  r.num_males_needed, 
  r.num_females_needed, 
  r.date_required, 
  r.destination_room_id, 
  m.room_number destination_room, 
  r.standing_order_freq, 
  r.standing_order_day, 
  r.number_in_cage, 
  r.rederivation_requested, 
  r.comments, 
  r.embryo_age_needed, 
  r.age_or_weight_units, 
  r.age_or_weight, 
  r.funding_source, 
  r.status_dict_id, 
  d.name status, 
  r.development_endpoint, 
  r.created_date, 
  r.edited_by, 
  r.edit_date, 
  r.request_originator_id, 
  p.first_name||' '||p.last_name requester, 
  t.team_number, 
  r.creator_id, 
  r.check_number, 
  r.pseudo_pregnant_female, 
  r.end_date,
  g.id group_dict_id,
  g.name group_dict_name
from 
  req_animal_request r, 
  per_person p, 
  typ_strain s, 
  req_animal_request_status_dict d, 
  mts_room m, 
  lic_project_licence l, 
  per_person h, 
  per_team t,
  mts_wildtype_req_group_dict g
where 
  r.status_dict_id = d.id and 
  r.strain_id = s.id and 
  r.request_originator_id = p.person_id and 
  r.destination_room_id = m.id(+) and 
  r.project_licence_id = l.project_licence_id and 
  l.responsible_person_id = h.person_id and 
  p.team_id = t.id(+) and
  r.group_dict_id = g.id(+);
  
ALTER TABLE MIR_MICRO_INJECTION
 ADD CONSTRAINT MIR_MICRO_INJECTION_R06 
 FOREIGN KEY (TECHNICIAN_ID) 
 REFERENCES PER_PERSON (PERSON_ID);  
  
ALTER TABLE REQ_ANIMAL_REQUEST
 ADD FOREIGN KEY (GROUP_DICT_ID) 
 REFERENCES MTS_WILDTYPE_REQ_GROUP_DICT (ID);  
  
INSERT INTO APP_COLUMN_PREFS ( ID, TABLE_NAME, COLUMN_NAME, COLUMN_TITLE, GETTER_METHOD, ORDER_BY,
DATATYPE ) VALUES ( 
29, 'mts_mouse_list_vw', 'breeding_name', 'Current Mating', 'getBreedingName', NULL
, NULL); 
COMMIT;

INSERT INTO APP_TABLE_METADATA ( ID, TABLE_NAME, PRIMARY_KEY_COLUMN ) VALUES ( 
10, 'MIR_SCHEDULED_MICRO_INJECTION', 'ID'); 
COMMIT;

INSERT INTO MTS_STRAIN_COAT_COLOUR ( ID, STRAIN_ID, COAT_COLOUR_ID ) VALUES ( 
1, 3, 9); 
INSERT INTO MTS_STRAIN_COAT_COLOUR ( ID, STRAIN_ID, COAT_COLOUR_ID ) VALUES ( 
2, 1, 6); 
INSERT INTO MTS_STRAIN_COAT_COLOUR ( ID, STRAIN_ID, COAT_COLOUR_ID ) VALUES ( 
3, 5, 4); 
COMMIT;

INSERT INTO MTS_WILDTYPE_REQ_GROUP_DICT ( ID, NAME, DESCRIPTION, ORDER_BY,
ACTIVE ) VALUES ( 
1, 'Microinjection Suite', 'Miicroinjection-related Wiltdype Requests', 1, 1); 
INSERT INTO MTS_WILDTYPE_REQ_GROUP_DICT ( ID, NAME, DESCRIPTION, ORDER_BY,
ACTIVE ) VALUES ( 
2, 'Cryo Preservation', 'Cryo-Preservation related Wildtype Requests', 2, 1); 
COMMIT;

