/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

-- tables

/*create tables-15*/
CREATE TABLE CRQ_FREEZE_DOWN_SAMPLE
(
  ID                    NUMBER,
  EMBRYO_HARVEST_ID     NUMBER,
  EDIT_DATE             DATE                    DEFAULT SYSDATE,
  EDITED_BY             VARCHAR2(128 BYTE),
  CREATED_DATE          DATE                    DEFAULT SYSDATE,
  CREATOR_ID            NUMBER,
  CHECK_NUMBER          NUMBER,
  COMMENTS              VARCHAR2(4000 BYTE),
  TECHNICIAN_ID         NUMBER,
  LOCATION_ID           NUMBER,
  EMBRYO_GRADE_DICT_ID  NUMBER,
  EMBRYO_COUNT          INTEGER,
  FREEZE_DOWN_DATE      DATE                    NOT NULL,
  THAW_DATE             DATE
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE CRQ_LOCATION
(
  ID        NUMBER,
  VIAL_ID   NUMBER,
  STRAW_ID  NUMBER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE CRQ_EMBRYO_HARVEST
(
  ID                       NUMBER,
  SCHEDULED_JOB_ID         NUMBER,
  EDITED_DATE              DATE                 DEFAULT SYSDATE,
  EDITED_BY                VARCHAR2(128 BYTE),
  CREATED_DATE             DATE                 DEFAULT SYSDATE,
  CREATOR_ID               NUMBER,
  CHECK_NUMBER             NUMBER,
  COMMENTS                 VARCHAR2(4000 BYTE),
  CELL_COUNT_16            INTEGER,
  CELL_COUNT_8             INTEGER,
  CELL_COUNT_4             INTEGER,
  CELL_COUNT_2             INTEGER,
  CELL_COUNT_1             INTEGER,
  DEAD_COUNT               INTEGER,
  FRAGMENTED_COUNT         INTEGER,
  OTHER_EMBRYO_TYPE_COUNT  INTEGER,
  NUMBER_SUPEROVULATED     INTEGER,
  NUMBER_PLUGGED           INTEGER,
  FLUSH_DATE               DATE                 NOT NULL,
  TECHNICIAN_ID            NUMBER,
  OTHER_DESCRIPTION        VARCHAR2(4000 BYTE),
  WILDTYPE_TEST_STRAIN_ID  INTEGER,
  USE_16_CELL              NUMBER(1),
  USE_8_CELL               NUMBER(1),
  USE_4_CELL               NUMBER(1),
  MOUSE_ID                 NUMBER,
  USE_2_CELL               NUMBER(1),
  COHORT_ID                INTEGER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE CRQ_VIAL
(
  ID            NUMBER,
  EDIT_DATE     DATE                            DEFAULT SYSDATE,
  EDITED_BY     VARCHAR2(128 BYTE),
  CREATED_DATE  DATE                            DEFAULT SYSDATE,
  CREATOR_ID    NUMBER,
  CHECK_NUMBER  NUMBER,
  COMMENTS      VARCHAR2(4000 BYTE),
  BOX_ID        NUMBER,
  NAME          VARCHAR2(1000 BYTE),
  IN_USE        NUMBER(1),
  LABEL         VARCHAR2(1000 BYTE),
  POSITION      INTEGER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE CRQ_WEDGE
(
  ID            NUMBER,
  COMMENTS      VARCHAR2(4000 BYTE),
  GOBLET_ID     NUMBER,
  COLOUR        VARCHAR2(1000 BYTE),
  COLOUR_ORDER  INTEGER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE CRQ_SCHEDULED_CRYO_PRV
(
  ID                       NUMBER,
  CRYO_REQUEST_ID          NUMBER,
  CRYO_JOB_STATUS_DICT_ID  NUMBER,
  TARGET_SCHEDULED_DATE    DATE,
  CANCEL_REASON            VARCHAR2(4000 BYTE),
  EDIT_DATE                DATE                 DEFAULT SYSDATE,
  EDITED_BY                VARCHAR2(128 BYTE),
  CREATED_DATE             DATE                 DEFAULT SYSDATE,
  CREATOR_ID               NUMBER,
  CHECK_NUMBER             NUMBER,
  COMMENTS                 VARCHAR2(4000 BYTE),
  JOB_NAME                 VARCHAR2(100 BYTE)
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE CRQ_CANISTER
(
  ID          NUMBER,
  COMMENTS    VARCHAR2(4000 BYTE),
  FREEZER_ID  NUMBER,
  NAME        VARCHAR2(1000 BYTE)
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE CRQ_STRAW
(
  ID            NUMBER,
  EDIT_DATE     DATE                            DEFAULT SYSDATE,
  EDITED_BY     VARCHAR2(128 BYTE),
  CREATED_DATE  DATE                            DEFAULT SYSDATE,
  CREATOR_ID    NUMBER,
  CHECK_NUMBER  NUMBER,
  COMMENTS      VARCHAR2(4000 BYTE),
  WEDGE_ID      NUMBER,
  IN_USE        NUMBER(1)
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE CRQ_GOBLET
(
  ID           NUMBER,
  COMMENTS     VARCHAR2(4000 BYTE),
  CANISTER_ID  NUMBER,
  NAME         VARCHAR2(1000 BYTE)
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE CRQ_SCHEDULED_JOB_STATUS_DICT
(
  ID           NUMBER                           NOT NULL,
  NAME         VARCHAR2(128 CHAR)               NOT NULL,
  DESCRIPTION  VARCHAR2(2048 CHAR),
  ACTIVE       NUMBER(1)                        NOT NULL,
  ORDER_BY     NUMBER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE CRQ_TOWER
(
  ID            NUMBER,
  CHECK_NUMBER  NUMBER,
  NAME          VARCHAR2(1000 BYTE),
  DESCRIPTION   VARCHAR2(2000 BYTE),
  FREEZER_ID    NUMBER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE CRQ_CRYO_WILDTYPE_STRAIN_DICT
(
  ID           INTEGER,
  NAME         VARCHAR2(64 CHAR)                NOT NULL,
  DESCRIPTION  VARCHAR2(2048 CHAR),
  ACTIVE       NUMBER(1)                        NOT NULL,
  ORDER_BY     NUMBER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE CRQ_FREEZER
(
  ID           NUMBER,
  COMMENTS     VARCHAR2(4000 BYTE),
  NAME         VARCHAR2(1000 BYTE),
  DESCRIPTION  VARCHAR2(2000 BYTE),
  IS_STRAW     NUMBER(1)
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE CRQ_BOX
(
  ID            NUMBER,
  CHECK_NUMBER  NUMBER,
  COMMENTS      VARCHAR2(4000 BYTE),
  TOWER_ID      NUMBER,
  NAME          VARCHAR2(1000 BYTE)
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE CRQ_EMBRYO_GRADE_DICT
(
  ID           INTEGER                          NOT NULL,
  NAME         VARCHAR2(256 CHAR)               NOT NULL,
  DESCRIPTION  VARCHAR2(2048 CHAR),
  ACTIVE       NUMBER(1)                        DEFAULT 1                     NOT NULL,
  ORDER_BY     NUMBER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

--alter table, columns etc


ALTER TABLE MTL_EMBRYO_TRANSFER_CAGE_CARD
 ADD (CREATOR_ID  INTEGER);

ALTER TABLE MTL_EMBRYO_TRANSFER_CAGE_CARD
 ADD (EDITED_BY  VARCHAR2(128 BYTE));

ALTER TABLE MTL_EMBRYO_TRANSFER_CAGE_CARD
 ADD (EDIT_DATE  DATE);

ALTER TABLE MTL_EMBRYO_TRANSFER_CAGE_CARD
 ADD (CHECK_NUMBER  INTEGER);

ALTER TABLE MTL_STOCK_CAGE_CARD
 ADD (LAST_PROCEDURE_TEXT  VARCHAR2(512 BYTE));

ALTER TABLE MTL_STOCK_CAGE_CARD
 ADD (CREATOR_ID  INTEGER);

ALTER TABLE MTL_STOCK_CAGE_CARD
 ADD (EDITED_BY  VARCHAR2(128 BYTE));

ALTER TABLE MTL_STOCK_CAGE_CARD
 ADD (EDIT_DATE  DATE);

ALTER TABLE MTL_STOCK_CAGE_CARD
 ADD (CHECK_NUMBER  INTEGER);

ALTER TABLE MTL_MATING_CAGE_CARD
 ADD (CREATOR_ID  INTEGER);

ALTER TABLE MTL_MATING_CAGE_CARD
 ADD (EDITED_BY  VARCHAR2(128 BYTE));

ALTER TABLE MTL_MATING_CAGE_CARD
 ADD (EDIT_DATE  DATE);

ALTER TABLE MTL_MATING_CAGE_CARD
 ADD (CHECK_NUMBER  INTEGER);



ALTER TABLE CRQ_CRYO_REQUEST RENAME COLUMN person_id TO requester_id;
ALTER TABLE CRQ_CRYO_REQUEST RENAME COLUMN strain_dict_id TO female_strain_dict_id;
ALTER TABLE CRQ_CRYO_REQUEST
 ADD (TARGET_COUNT  INTEGER);

ALTER TABLE CRQ_CRYO_REQUEST
 ADD (NUMBER_THAWED  INTEGER);

--functions

--functions

/* functions*/
CREATE OR REPLACE FUNCTION Addstrainsforcryorequest(cryo_req_id IN NUMBER) RETURN VARCHAR2
IS
testString VARCHAR2(2000);
BEGIN
FOR rowtarget IN(
 SELECT ts.NAME AS strain_name FROM CRQ_CRYO_REQUEST ccr, MTS_COLONY_INFO mci,
  MTS_COLONY_STRAIN mcs, TYP_STRAIN ts WHERE ccr.ID = cryo_req_id AND
  ccr.COLONY_ID = mci.ID AND
  mci.ID = mcs.COLONY_ID AND
  mcs.STRAIN_ID = ts.ID
  )
LOOP  
testString := testString || rowtarget.strain_name || ',' ||CHR(13);
END LOOP;
RETURN SUBSTR(testString, 1, LENGTH(testString)-2);
 END Addstrainsforcryorequest;
/

SHOW ERRORS;

CREATE OR REPLACE FUNCTION Addallelesforcryorequest(cryo_req_id IN NUMBER) RETURN VARCHAR2
IS
testString VARCHAR2(2000);
BEGIN
FOR rowtarget IN(
 SELECT  tma.OFFICIAL_NAME_SUPERSCRIPT AS superScriptName, g.primary_name AS geneName FROM CRQ_CRYO_REQUEST ccr, 
  MTS_COLONY_INFO mci,
  MTS_COLONY_ALLELE mca, TYP_MODIFIED_ALLELE tma, GNM_GENE g WHERE ccr.ID = cryo_req_id AND
  ccr.COLONY_ID = mci.ID AND
  mci.ID = mca.COLONY_ID AND
  mca.MODIFIED_ALLELE_ID = tma.ID AND
  tma.GENE_ID = g.ID
  )
LOOP  
testString := testString || rowTarget.geneName || '('|| rowtarget.superScriptName || ')' || ',' || CHR(13);
END LOOP;
RETURN SUBSTR(testString, 1, LENGTH(testString)-2);
 END Addallelesforcryorequest;
/

SHOW ERRORS;

CREATE OR REPLACE FUNCTION Addhomozygouslethals(cryo_req_id IN NUMBER) RETURN VARCHAR2
IS
testString VARCHAR2(2000);
BEGIN
FOR rowtarget IN(
 SELECT tma.IS_HOMOZYGOUS_LETHAL AS isHomozygousLethal FROM CRQ_CRYO_REQUEST ccr, MTS_COLONY_INFO mci,
  MTS_COLONY_ALLELE mca, TYP_MODIFIED_ALLELE tma WHERE ccr.ID = cryo_req_id AND
  ccr.COLONY_ID = mci.ID AND
  mci.ID = mca.COLONY_ID AND
  mca.MODIFIED_ALLELE_ID = tma.ID
  )
LOOP  
testString := testString || rowtarget.isHomozygousLethal || ',' || CHR(13);
END LOOP;
RETURN SUBSTR(testString, 1, LENGTH(testString)-2);
 END Addhomozygouslethals;
/

SHOW ERRORS;

CREATE OR REPLACE FUNCTION Addstring(allele_req_id IN NUMBER) RETURN VARCHAR2
IS
testString VARCHAR2(2000);
BEGIN
FOR rowtarget IN(SELECT comments AS commentz FROM ARQ_DESIGN_REQUEST adr WHERE adr.allele_request_id = allele_req_id)
LOOP  
testString := testString || rowtarget.commentz || CHR(13);
END LOOP;
RETURN testString;
 END Addstring;
/

SHOW ERRORS;

--views


/* This object may not be sorted properly in the script due to cirular references */
CREATE OR REPLACE FORCE VIEW MTS_COHORT_LIST_VW
(ID, COHORT_NAME, REASON, TOTAL_MICE, LIVE_MICE, 
 DEAD_MICE, FOREIGN_TABLE_NAME, FOREIGN_KEY_ID, CREATOR_ID, CREATED_DATE, 
 EDITED_BY, EDIT_DATE, CHECK_NUMBER)
AS 
select 
  c.id, 
  c.cohort_name, 
  c.reason, 
  l.total_mice, 
  l.live_mice, 
  l.dead_mice, 
  c.foreign_table_name, 
  c.foreign_key_id, 
  c.creator_id, 
  c.created_date, 
  c.edited_by, 
  c.edit_date, 
  c.check_number 
from 
  mts_cohort c, 
  (select 
    l.cohort_id, 
    count(m.id) total_mice, 
	count(decode(m.death_date,null,1,null)) live_mice, 
	count(decode(m.death_date,null,null,1)) dead_mice 
   from 
    mts_mouse m, 
    mts_cohort_mouse l 
   where m.id = l.mouse_id 
   group by l.cohort_id) l 
where 
  c.id = l.cohort_id(+);


 CREATE OR REPLACE VIEW CRQ_VIAL_LOCATION_VW
AS 
select 
  v.id vial_id, 
  v.position vial_position,  
  b.id box_id, 
  b.name box_name, 
  t.id tower_id,
  t.name tower_name, 
  f.id freezer_id,
  f.name freezer_name
from 
  crq_vial v, 
  crq_box b, 
  crq_tower t,
  crq_freezer f
where 
  v.box_id = b.id and 
  b.tower_id = t.id and
  t.freezer_id = f.id AND F.IS_STRAW = 0 and
  v.in_use = 1 ORDER BY V.ID
/
  
 CREATE OR REPLACE VIEW CRQ_STRAW_LOCATION_VW
AS 
select 
  S.id STRAW_id, 
  W.ID WEDGE_ID,  
  W.COLOUR WEDGE_COLOUR,
  G.ID GOBLET_id, 
  g.name GOBLET_name, 
  C.id CANISTER_id,
  C.name CANISTER_name, 
  f.id freezer_id,
  f.name freezer_name
from 
  CRQ_STRAW S,
  crq_WEDGE W, 
  crq_GOBLET G, 
  crq_CANISTER C,
  crq_freezer f
where
  S.WEDGE_id = W.id and 
  W.GOBLET_id = G.id and
  G.CANISTER_id = C.id AND
  C.FREEZER_ID = F.ID AND 
  F.IS_STRAW = 1 and
  S.IN_USE = 1
/
  

CREATE OR REPLACE VIEW CRQ_SCHEDULED_JOB_LIST_VW
AS 
SELECT   cpv.ID, 
      cpv.job_name, 
   csjsd.NAME job_status, 
   csjsd.ID status_id, 
            cpv.target_scheduled_date, 
   crq.ID cryo_request_id, 
            colinfo.colony_name, 
   strain.NAME female_strain_name, 
            cpv.cancel_reason, 
   ceh.ID embryo_harvest_id, 
            NVL (cpv.comments, '') comments, 
            NVL (ceh.number_plugged, 0) total_plugged, 
            NVL (ceh.number_superovulated, 0) total_superovulated, 
            NVL (SUM(f_loc_v_s.EMBRYO_COUNT), 0) total_frozen_count, 
            NVL ((SUM(f_loc_v_s.EMBRYO_COUNT)) / ceh.number_plugged, 
                 0 
                ) AS average_frozen_count 
       FROM crq_cryo_request crq, 
            crq_scheduled_cryo_prv cpv, 
   crq_scheduled_job_status_dict csjsd, 
            crq_embryo_harvest ceh, 
            mts_colony_info colinfo, 
            typ_strain strain, 
   (select 
   cfds.id freeze_down_id, 
   cfds.EMBRYO_HARVEST_ID embryo_harvest_id, 
   cfds.EMBRYO_COUNT embryo_count, 
   cl.id loc_id, 
   cl.vial_id vial_id, 
   cl.straw_id straw_id 
   from  crq_freeze_down_sample cfds, crq_location cl, crq_straw s 
   where cfds.LOCATION_ID = cl.id and cl.STRAW_ID = s.id and s.IN_USE=1 
   union 
   select 
   cfds.id freeze_down_id, 
   cfds.EMBRYO_HARVEST_ID embryo_harvest_id, 
   cfds.EMBRYO_COUNT embryo_count, 
   cl.id loc_id, 
   cl.vial_id vial_id, 
   cl.straw_id straw_id 
   from crq_freeze_down_sample cfds, crq_location cl, crq_vial v 
   where cfds.LOCATION_ID = cl.id and cl.vial_id = v.id and v.IN_USE=1) f_loc_v_s 
      WHERE 
     cpv.cryo_request_id = crq.ID(+) 
  AND cpv.cryo_job_status_dict_id = csjsd.ID(+) 
        AND crq.colony_id = colinfo.ID(+) 
        AND crq.female_strain_dict_id = strain.ID(+) 
        AND cpv.ID = ceh.scheduled_job_id(+) 
        AND ceh.ID = f_loc_v_s.embryo_harvest_id(+) 
   GROUP BY cpv.ID, 
            cpv.job_name, 
            csjsd.NAME, 
            cpv.target_scheduled_date, 
            crq.ID, 
            csjsd.ID, 
            cpv.cancel_reason, 
            ceh.ID, 
            colinfo.colony_name, 
            cpv.comments, 
            strain.NAME, 
            ceh.number_plugged, 
            ceh.number_superovulated
/


CREATE OR REPLACE VIEW CRQ_REQ_ATTEMPT_COUNT_LIST_VW
AS 
SELECT   ccr.ID, COUNT (csj.ID) AS total_attempts 
       FROM crq_cryo_request ccr, crq_scheduled_cryo_prv csj 
      WHERE ccr.ID = csj.cryo_request_id 
        AND csj.target_scheduled_date <= SYSDATE 
		and csj.CRYO_JOB_STATUS_DICT_ID in (3,4) 
   GROUP BY ccr.ID 
   ORDER BY ccr.ID ASC
/

CREATE OR REPLACE VIEW CRQ_STRAW_SAMPLE_LIST_VW
AS 
SELECT svw.straw_id ID, c.colony_name, c.colony_id, c.request_id,
       fds.freeze_down_date, fds.embryo_count, gd.NAME embryo_grade,
       gd.ID embryo_grade_dict_id, svw.freezer_name, svw.freezer_id,
       svw.canister_name, svw.canister_id, svw.goblet_name, svw.goblet_id,
       svw.wedge_colour, svw.wedge_id,
       (p.first_name || ' ' || p.last_name) technician_name,
       p.person_id technician_id, fds.ID sample_id, cr.ID scheduled_job_id,
       cr.cryo_job_status_dict_id
  FROM crq_freeze_down_sample fds,
       per_person p,
       crq_embryo_harvest eh,
       crq_scheduled_cryo_prv cr,
       crq_location l,
       crq_straw s,
       crq_straw_location_vw svw,
       crq_embryo_grade_dict gd,
       (SELECT ci.colony_name, ci.ID colony_id, re.ID request_id
          FROM crq_cryo_request re, mts_colony_info ci
         WHERE re.colony_id = ci.ID) c
 WHERE fds.embryo_harvest_id = eh.ID
   AND eh.scheduled_job_id = cr.ID(+)
   AND cr.cryo_request_id = c.request_id(+)
   AND p.person_id = fds.technician_id
   AND l.straw_id = s.ID
   AND fds.location_id = l.ID
   AND svw.straw_id = s.ID
   AND fds.embryo_grade_dict_id = gd.ID
/

CREATE OR REPLACE VIEW CRQ_VIAL_SAMPLE_LIST_VW
AS 
SELECT svw.vial_id ID, c.colony_name, c.colony_id, c.request_id,
       fds.freeze_down_date, fds.embryo_count, gd.NAME embryo_grade,
       gd.ID embryo_grade_dict_id, svw.freezer_name, svw.freezer_id,
       svw.tower_name, svw.tower_id, svw.box_name, svw.box_id,
       svw.vial_position,
       (p.first_name || ' ' || p.last_name) technician_name,
       p.person_id technician_id, fds.ID sample_id, cr.ID scheduled_job_id,cr.cryo_job_status_dict_id
  FROM crq_freeze_down_sample fds,
       crq_embryo_harvest eh,
       crq_scheduled_cryo_prv cr,
       per_person p,
       crq_location l,
       crq_vial v,
       crq_vial_location_vw svw,
       crq_embryo_grade_dict gd,
       (SELECT ci.colony_name, ci.ID colony_id, re.ID request_id
          FROM crq_cryo_request re, mts_colony_info ci
         WHERE re.colony_id = ci.ID) c
 WHERE fds.embryo_harvest_id = eh.ID
   AND eh.scheduled_job_id = cr.ID(+)
   AND cr.cryo_request_id = c.request_id(+)
   AND p.person_id = fds.technician_id
   AND l.vial_id = v.ID
   AND fds.location_id = l.ID
   AND svw.vial_id = v.ID
   AND fds.embryo_grade_dict_id = gd.ID
/


CREATE OR REPLACE VIEW crq_sample_list_vw
AS
SELECT v.colony_name colony_name, v.colony_id colony_id,
          v.request_id request_id, v.freeze_down_date freeze_down_date,
          v.embryo_count embryo_count, v.embryo_grade embryo_grade,
          v.embryo_grade_dict_id embryo_grade_dict_id,
          (   'Freezer ' || v.freezer_name
           || ', Tower '
           || v.tower_name
           || ', Box '
           || v.box_name
           || ', Vial '
           || v.vial_position
          ) location_name,
          v.ID ID, v.technician_name technician_name,
          v.technician_id technician_id, v.sample_id, v.scheduled_job_id,
          v.cryo_job_status_dict_id, 'vial' storage_type
     FROM crq_vial_sample_list_vw v
   UNION
   SELECT s.colony_name colony_name, s.colony_id colony_id,
          s.request_id request_id, s.freeze_down_date freeze_down_date,
          s.embryo_count embryo_count, s.embryo_grade embryo_grade,
          s.embryo_grade_dict_id embryo_grade_dict_id,
          (   'Freezer ' || s.freezer_name
           || ', Canister '
           || s.canister_name
           || ', Goblet '
           || s.goblet_name
           || ', Wedge '
           || s.wedge_colour
          ) location_name,
          s.ID ID, s.technician_name technician_name,
          s.technician_id technician_id, s.sample_id, s.scheduled_job_id,
          s.cryo_job_status_dict_id, 'straw' storage_type
     FROM crq_straw_sample_list_vw s
/



CREATE OR REPLACE VIEW CRQ_CRYO_REQUEST_LIST_VW
AS 
SELECT   ccr.ID, ccr.status_dict_id, crsd.NAME status, p.person_id, 
            p.first_name || ' ' || p.last_name AS requester_name, 
            t.team_number, mci.ID colony_info_id, mci.colony_name, 
            mci.colony_prefix, 
            addstrainsforcryorequest (ccr.ID) appended_strains, 
            addallelesforcryorequest (ccr.ID) appended_alleles, 
            addhomozygouslethals (ccr.ID) append_homozygous_lethal, 
            crstd.NAME female_strain, 
            NVL (SUM (sjlv.total_plugged), 0) total_plugged, 
            NVL (SUM (sjlv.total_superovulated), 0) total_superovulated, 
            nvl(rac.total_attempts,0) total_attempts, 
            NVL (SUM (sjlv.total_frozen_count), 0) total_frozen, 
            NVL (ccr.target_count, 0) target_count, ccr.created_date 
       FROM crq_cryo_request ccr, 
            mts_colony_info mci, 
            crq_cryo_request_strain_dict crstd, 
            crq_scheduled_job_list_vw sjlv, 
            crq_req_attempt_count_list_vw rac, 
            crq_cryo_request_status_dict crsd, 
            per_person p, 
            per_team t 
      WHERE ccr.colony_id = mci.ID(+) 
        AND ccr.ID = sjlv.cryo_request_id(+) 
        AND ccr.ID = rac.ID(+) 
        AND ccr.status_dict_id = crsd.ID(+) 
        AND ccr.female_strain_dict_id = crstd.ID(+) 
        AND ccr.requester_id = p.person_id(+) 
        AND p.team_id = t.ID(+) 
        AND sjlv.status_id(+) ! = 4 
        AND sjlv.cryo_request_id(+) IS NOT NULL 
   GROUP BY ccr.ID, 
            ccr.status_dict_id, 
            rac.total_attempts, 
            crsd.NAME, 
            p.person_id, 
            p.first_name || ' ' || p.last_name, 
            t.team_number, 
            mci.ID, 
            mci.colony_name, 
            mci.colony_prefix, 
            crstd.NAME, 
            ccr.target_count, 
            ccr.created_date 
   ORDER BY ccr.ID ASC
/






-- sequences

/*new sequence-12*/
CREATE SEQUENCE CRQ_CRYO_BOX_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;
  
  CREATE SEQUENCE CRQ_CRYO_CANISTER_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE CRQ_CRYO_EMBRYO_HARVEST_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE CRQ_CRYO_FREEZER_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE CRQ_CRYO_FREEZE_SAMPLE_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE CRQ_CRYO_GOBLET_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE CRQ_CRYO_LOCATION_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;



CREATE SEQUENCE CRQ_CRYO_TOWER_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE CRQ_CRYO_STRAW_VIAL_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE CRQ_CRYO_WEDGE_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE CRQ_SCHEDULED_CRYO_PRV_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

--indexes

/* This object may not be sorted properly in the script due to cirular references */
CREATE INDEX MTS_COHORT_MOUSE_IND2 ON MTS_COHORT_MOUSE
(MOUSE_ID)
LOGGING
NOPARALLEL;

/* This object may not be sorted properly in the script due to cirular references */
CREATE INDEX MTS_COHORT_MOUSE_IND1 ON MTS_COHORT_MOUSE
(COHORT_ID)
LOGGING
NOPARALLEL;

--constraints

/*Create primary keys 15*/

ALTER TABLE CRQ_WEDGE
 ADD CONSTRAINT CRQ_CRYO_WEDGE_PK
 PRIMARY KEY
 (ID);
 
 ALTER TABLE CRQ_VIAL
 ADD CONSTRAINT CRQ_CRYO_VIAL_PK
 PRIMARY KEY
 (ID);
 
 ALTER TABLE CRQ_SCHEDULED_CRYO_PRV
 ADD CONSTRAINT CRQ_CRYO_SCHEDULED_JOB_PK
 PRIMARY KEY
 (ID);
 
 ALTER TABLE CRQ_CANISTER
 ADD CONSTRAINT CRQ_CRYO_CANISTER_PK
 PRIMARY KEY
 (ID);
 
 ALTER TABLE CRQ_GOBLET
 ADD CONSTRAINT CRQ_CRYO_GOBLET_PK
 PRIMARY KEY
 (ID);

ALTER TABLE CRQ_BOX
 ADD CONSTRAINT CRQ_CRYO_BOX_PK
 PRIMARY KEY
 (ID);

 ALTER TABLE CRQ_TOWER
 ADD CONSTRAINT CRQ_CRYO_TOWER_PK
 PRIMARY KEY
 (ID);
 
 ALTER TABLE CRQ_FREEZER
 ADD CONSTRAINT CRQ_CRYO_FREEZER_PK
 PRIMARY KEY
 (ID);

ALTER TABLE CRQ_SCHEDULED_JOB_STATUS_DICT
 ADD CONSTRAINT CRQ_JOB_STATUS_DICT_PK
 PRIMARY KEY
 (ID);
 
 ALTER TABLE CRQ_STRAW
 ADD CONSTRAINT CRQ_CRYO_STRAW_PK
 PRIMARY KEY
 (ID);
 
 ALTER TABLE CRQ_CRYO_WILDTYPE_STRAIN_DICT
 ADD CONSTRAINT CRQ_WILDTYPE_STRAIN_DICTPK
 PRIMARY KEY
 (ID);

ALTER TABLE CRQ_EMBRYO_GRADE_DICT
 ADD PRIMARY KEY
 (ID);
 
 ALTER TABLE CRQ_FREEZE_DOWN_SAMPLE
 ADD CONSTRAINT CRQ_CRYO_FREEZE_DOWN_PK
 PRIMARY KEY
 (ID);
 
 ALTER TABLE CRQ_LOCATION
 ADD CONSTRAINT CRQ_CRYO_LOCATION_PK
 PRIMARY KEY
 (ID);

 ALTER TABLE CRQ_EMBRYO_HARVEST
 ADD CONSTRAINT CRQ_EMBRYO_HARVEST_PK
 PRIMARY KEY
 (ID);


ALTER TABLE MTS_COHORT_MOUSE
 ADD CONSTRAINT MTS_COHORT_MOUSE_R02 
 FOREIGN KEY (MOUSE_ID) 
 REFERENCES MTS_MOUSE (ID);

ALTER TABLE MTS_COHORT_MOUSE
 ADD CONSTRAINT MTS_COHORT_MOUSE_R01 
 FOREIGN KEY (COHORT_ID) 
 REFERENCES MTS_COHORT (ID);





--unique keys

 /* CREATE INDEX FOR  PRIMARY KEYS 15 + 3 UNIQUE KEY FOR DICT NAMES*/


CREATE UNIQUE INDEX MIG.CRQ_EMBRYO_GRADE_DICT_R01 ON MIG.CRQ_EMBRYO_GRADE_DICT
(NAME)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX MIG.CRQ_EMBRYO_GRADE_DICT_PK ON MIG.CRQ_EMBRYO_GRADE_DICT
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX CRQ_CRYO_FREEZER_PK ON CRQ_FREEZER
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX CRQ_CRYO_TOWER_PK ON CRQ_TOWER
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX CRQ_CRYO_BOX_PK ON CRQ_BOX
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX CRQ_CRYO_CANISTER_PK ON CRQ_CANISTER
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX CRQ_EMBRYO_HARVEST_PK ON CRQ_EMBRYO_HARVEST
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX CRQ_CRYO_GOBLET_PK ON CRQ_GOBLET
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX CRQ_CRYO_SCHEDULED_JOB_PK ON CRQ_SCHEDULED_CRYO_PRV
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX CRQ_CRYO_VIAL_PK ON CRQ_VIAL
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX CRQ_CRYO_WEDGE_PK ON CRQ_WEDGE
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX CRQ_CRYO_STRAW_PK ON CRQ_STRAW
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX CRQ_CRYO_LOCATION_PK ON CRQ_LOCATION
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX CRQ_CRYO_FREEZE_DOWN_PK ON CRQ_FREEZE_DOWN_SAMPLE
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX CRQ_EMBRYO_GRADE_DICT_R01 ON CRQ_EMBRYO_GRADE_DICT
(NAME)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX CRQ_JOB_STATUS_DICT_R01 ON CRQ_SCHEDULED_JOB_STATUS_DICT
(NAME)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX CRQ_EMBRYO_HARVEST_U01 ON CRQ_EMBRYO_HARVEST
(SCHEDULED_JOB_ID)
LOGGING
NOPARALLEL;


--foreign constraints

 ALTER TABLE CRQ_WEDGE
 ADD CONSTRAINT CRQ_CRYO_WEDGE_R01 
 FOREIGN KEY (GOBLET_ID) 
 REFERENCES CRQ_GOBLET (ID);



ALTER TABLE CRQ_EMBRYO_HARVEST
 ADD CONSTRAINT CRQ_EMBRYO_HARVEST_R05 
 FOREIGN KEY (COHORT_ID) 
 REFERENCES MTS_COHORT (ID);

ALTER TABLE CRQ_EMBRYO_HARVEST
 ADD CONSTRAINT CRQ_EMBRYO_HARVEST_R03 
 FOREIGN KEY (TECHNICIAN_ID) 
 REFERENCES PER_PERSON (PERSON_ID);

ALTER TABLE CRQ_EMBRYO_HARVEST
 ADD CONSTRAINT CRQ_EMBRYO_HARVEST_R01 
 FOREIGN KEY (SCHEDULED_JOB_ID) 
 REFERENCES CRQ_SCHEDULED_CRYO_PRV (ID);

ALTER TABLE CRQ_EMBRYO_HARVEST
 ADD CONSTRAINT CRQ_EMBRYO_HARVEST_R02 
 FOREIGN KEY (WILDTYPE_TEST_STRAIN_ID) 
 REFERENCES TYP_STRAIN (ID);
 
 ALTER TABLE CRQ_LOCATION
 ADD CONSTRAINT CRQ_CRYO_LOCATION_R01 
 FOREIGN KEY (VIAL_ID) 
 REFERENCES CRQ_VIAL (ID);

ALTER TABLE CRQ_LOCATION
 ADD CONSTRAINT CRQ_CRYO_LOCATION_R02 
 FOREIGN KEY (STRAW_ID) 
 REFERENCES CRQ_STRAW (ID);



ALTER TABLE CRQ_FREEZE_DOWN_SAMPLE
 ADD FOREIGN KEY (EMBRYO_HARVEST_ID) 
 REFERENCES CRQ_EMBRYO_HARVEST (ID);

ALTER TABLE CRQ_FREEZE_DOWN_SAMPLE
 ADD CONSTRAINT CRQ_CRYO_FREEZE_DOWN_SAMPLER01 
 FOREIGN KEY (LOCATION_ID) 
 REFERENCES CRQ_LOCATION (ID);

ALTER TABLE CRQ_FREEZE_DOWN_SAMPLE
 ADD CONSTRAINT CRQ_CRYO_FREEZE_DOWN_SAMPLER02 
 FOREIGN KEY (TECHNICIAN_ID) 
 REFERENCES PER_PERSON (PERSON_ID);

ALTER TABLE CRQ_FREEZE_DOWN_SAMPLE
 ADD CONSTRAINT CRQ_CRYO_FREEZE_DOWN_SAMPLER03 
 FOREIGN KEY (EMBRYO_GRADE_DICT_ID) 
 REFERENCES CRQ_EMBRYO_GRADE_DICT (ID);

 ALTER TABLE CRQ_TOWER
 ADD FOREIGN KEY (FREEZER_ID) 
 REFERENCES CRQ_FREEZER (ID);


ALTER TABLE CRQ_BOX
 ADD CONSTRAINT CRQ_CRYO_BOX_R01 
 FOREIGN KEY (TOWER_ID) 
 REFERENCES CRQ_TOWER (ID) DISABLE;



ALTER TABLE CRQ_CANISTER
 ADD FOREIGN KEY (FREEZER_ID) 
 REFERENCES CRQ_FREEZER (ID);

ALTER TABLE CRQ_GOBLET
 ADD FOREIGN KEY (CANISTER_ID) 
 REFERENCES CRQ_CANISTER (ID);
 
 ALTER TABLE CRQ_SCHEDULED_CRYO_PRV
 ADD CONSTRAINT CRQ_SCHEDULED_CRYO_PRV_R01 
 FOREIGN KEY (CRYO_REQUEST_ID) 
 REFERENCES CRQ_CRYO_REQUEST (ID);

ALTER TABLE CRQ_SCHEDULED_CRYO_PRV
 ADD CONSTRAINT CRQ_SCHEDULED_CRYO_PRV_R02 
 FOREIGN KEY (CRYO_JOB_STATUS_DICT_ID) 
 REFERENCES CRQ_SCHEDULED_JOB_STATUS_DICT (ID);



ALTER TABLE CRQ_VIAL
 ADD FOREIGN KEY (BOX_ID) 
 REFERENCES CRQ_BOX (ID) DISABLE;
 
 ALTER TABLE CRQ_STRAW
 ADD FOREIGN KEY (WEDGE_ID) 
 REFERENCES CRQ_WEDGE (ID);
 
 ALTER TABLE CRQ_EMBRYO_GRADE_DICT
 ADD CONSTRAINT CRQ_EMBRYO_GRADE_DICT_R01
 UNIQUE (NAME);



ALTER TABLE CRQ_SCHEDULED_JOB_STATUS_DICT
 ADD CONSTRAINT CRQ_JOB_STATUS_DICT_R01
 UNIQUE (NAME);
 
 ALTER TABLE CRQ_LOCATION
 ADD CONSTRAINT CRQ_LOCATION_C1
 CHECK (vial_id IS NOT NULL OR straw_id IS NOT NULL);

--triggers

/* noraml trigger-12*/
CREATE OR REPLACE TRIGGER crq_cryo_goblet_ts
BEFORE INSERT OR UPDATE ON CRQ_GOBLET FOR EACH ROW
BEGIN
  IF(:NEW.ID IS NULL) THEN
    SELECT crq_cryo_goblet_seq.NEXTVAL INTO :NEW.ID FROM dual;
  END IF;
END;
/
SHOW ERRORS;

CREATE OR REPLACE TRIGGER crq_cryo_canister_ts
BEFORE INSERT OR UPDATE ON CRQ_CANISTER FOR EACH ROW
BEGIN
  IF(:NEW.ID IS NULL) THEN
    SELECT crq_cryo_canister_seq.NEXTVAL INTO :NEW.ID FROM dual;
  END IF;
END;
/
SHOW ERRORS;

CREATE OR REPLACE TRIGGER crq_cryo_straw_ts
BEFORE INSERT OR UPDATE ON CRQ_STRAW FOR EACH ROW
BEGIN
  IF(:NEW.ID IS NULL) THEN
    SELECT CRQ_CRYO_STRAW_VIAL_SEQ.NEXTVAL INTO :NEW.ID FROM dual;
  END IF;
END;
/
SHOW ERRORS;

CREATE OR REPLACE TRIGGER crq_cryo_tower_ts
BEFORE INSERT OR UPDATE ON CRQ_TOWER FOR EACH ROW
BEGIN
  IF(:NEW.ID IS NULL) THEN
    SELECT crq_cryo_tower_seq.NEXTVAL INTO :NEW.ID FROM dual;
  END IF;
END;
/
SHOW ERRORS;

CREATE OR REPLACE TRIGGER crq_cryo_freeze_sample_ts
BEFORE INSERT OR UPDATE ON CRQ_FREEZE_DOWN_SAMPLE FOR EACH ROW
BEGIN
  IF(:NEW.ID IS NULL) THEN
    SELECT crq_cryo_freeze_sample_seq.NEXTVAL INTO :NEW.ID FROM dual;
  END IF;
END;
/
SHOW ERRORS;

CREATE OR REPLACE TRIGGER crq_cryo_wedge_ts
BEFORE INSERT OR UPDATE ON CRQ_WEDGE FOR EACH ROW
BEGIN
  IF(:NEW.ID IS NULL) THEN
    SELECT crq_cryo_wedge_seq.NEXTVAL INTO :NEW.ID FROM dual;
  END IF;
END;
/
SHOW ERRORS;

CREATE OR REPLACE TRIGGER crq_embryo_harvest_ts
BEFORE INSERT OR UPDATE ON CRQ_EMBRYO_HARVEST FOR EACH ROW
BEGIN
  IF(:NEW.ID IS NULL) THEN
    SELECT CRQ_CRYO_EMBRYO_HARVEST_SEQ.NEXTVAL INTO :NEW.ID FROM dual;
  END IF;
END;
/
SHOW ERRORS;

CREATE OR REPLACE TRIGGER crq_cryo_vial_ts
BEFORE INSERT OR UPDATE ON CRQ_VIAL FOR EACH ROW
BEGIN
  IF(:NEW.ID IS NULL) THEN
    SELECT CRQ_CRYO_STRAW_VIAL_SEQ.NEXTVAL INTO :NEW.ID FROM dual;
  END IF;
END;
/
SHOW ERRORS;

CREATE OR REPLACE TRIGGER crq_cryo_location_ts
BEFORE INSERT OR UPDATE ON CRQ_LOCATION FOR EACH ROW
BEGIN
  IF(:NEW.ID IS NULL) THEN
    SELECT crq_cryo_location_seq.NEXTVAL INTO :NEW.ID FROM dual;
  END IF;
END;
/
SHOW ERRORS;


CREATE OR REPLACE TRIGGER crq_scheduled_cryo_prv_ts 
BEFORE INSERT ON CRQ_SCHEDULED_CRYO_PRV 
FOR EACH ROW
BEGIN 
  IF :NEW.ID IS NULL THEN 
    SELECT crq_scheduled_cryo_prv_seq.NEXTVAL INTO :NEW.ID FROM dual; 
  END IF; 
END;
/
SHOW ERRORS;

CREATE OR REPLACE TRIGGER crq_cryo_box_ts
BEFORE INSERT OR UPDATE ON CRQ_BOX FOR EACH ROW
BEGIN
  IF(:NEW.ID IS NULL) THEN
    SELECT crq_cryo_box_seq.NEXTVAL INTO :NEW.ID FROM dual;
  END IF;
END;
/
SHOW ERRORS;

CREATE OR REPLACE TRIGGER crq_cryo_freezer_ts
BEFORE INSERT OR UPDATE ON CRQ_FREEZER FOR EACH ROW
BEGIN
  IF(:NEW.ID IS NULL) THEN
    SELECT crq_cryo_freezer_seq.NEXTVAL INTO :NEW.ID FROM dual;
  END IF;
END;
/
SHOW ERRORS;


--inserts

/* insert for freezers*/
 INSERT INTO MIG.CRQ_FREEZER
   (NAME, DESCRIPTION, IS_STRAW)
 VALUES
   ('RSF1', 'Freezer 1', 0);

INSERT INTO MIG.CRQ_FREEZER
   (NAME, DESCRIPTION, IS_STRAW)
 VALUES
   ('RSF2', 'Freezer 2', 1);

INSERT INTO MIG.CRQ_FREEZER
   (NAME, DESCRIPTION, IS_STRAW)
 VALUES
   ('RSF3', 'Freezer 3', 1);

INSERT INTO MIG.CRQ_FREEZER
   (NAME, DESCRIPTION, IS_STRAW)
 VALUES
   ('RSF4', 'Freezer 4', 1);
  
/* canister */
BEGIN
FOR i IN 2 .. 4 LOOP
 FOR j IN 1 .. 81 LOOP
INSERT INTO MIG.CRQ_CANISTER
   (FREEZER_ID, NAME)
 VALUES
   (i, j);
   END LOOP;
   END LOOP;
END;

/*goblets*/
BEGIN
FOR i IN 1 .. 243 LOOP
INSERT INTO MIG.CRQ_GOBLET
   (CANISTER_ID, NAME)
 VALUES
   (i, 'A');
INSERT INTO MIG.CRQ_GOBLET
   (CANISTER_ID, NAME)
 VALUES
   (i, 'B');
INSERT INTO MIG.CRQ_GOBLET
   (CANISTER_ID, NAME)
 VALUES
   (i, 'C');
INSERT INTO MIG.CRQ_GOBLET
   (CANISTER_ID, NAME)
 VALUES
   (i,'D');
   END LOOP;
END;
/* wedges */

BEGIN
FOR i IN 1 .. 972
LOOP 
INSERT INTO MIG.CRQ_WEDGE
   (GOBLET_ID, COLOUR, COLOUR_ORDER)
 VALUES
   (i, 'Black', 1);
INSERT INTO MIG.CRQ_WEDGE
   (GOBLET_ID, COLOUR, COLOUR_ORDER)
 VALUES
   (i, 'Grey', 2);
INSERT INTO MIG.CRQ_WEDGE
   (GOBLET_ID, COLOUR, COLOUR_ORDER)
 VALUES
   (i, 'Brown', 3);
INSERT INTO MIG.CRQ_WEDGE
   (GOBLET_ID, COLOUR, COLOUR_ORDER)
 VALUES
   (i, 'Red', 4);
INSERT INTO MIG.CRQ_WEDGE
   (GOBLET_ID, COLOUR, COLOUR_ORDER)
 VALUES
   (i, 'Green', 5);
INSERT INTO MIG.CRQ_WEDGE
   (GOBLET_ID, COLOUR, COLOUR_ORDER)
 VALUES
   (i, 'Purple', 6);
INSERT INTO MIG.CRQ_WEDGE
   (GOBLET_ID, COLOUR, COLOUR_ORDER)
 VALUES
   (i, 'Turquoise', 7);
INSERT INTO MIG.CRQ_WEDGE
   (GOBLET_ID, COLOUR, COLOUR_ORDER)
 VALUES
   (i, 'Blue', 8);
INSERT INTO MIG.CRQ_WEDGE
   (GOBLET_ID, COLOUR, COLOUR_ORDER)
 VALUES
   (i, 'Yellow', 9);
INSERT INTO MIG.CRQ_WEDGE
   (GOBLET_ID, COLOUR, COLOUR_ORDER)
 VALUES
   (i, 'Orange', 10);
INSERT INTO MIG.CRQ_WEDGE
   (GOBLET_ID, COLOUR, COLOUR_ORDER)
 VALUES
   (i, 'Pink', 11);
END LOOP;

END;


BEGIN
INSERT INTO MIG.CRQ_TOWER(NAME, FREEZER_ID)VALUES('A', 1);
INSERT INTO MIG.CRQ_TOWER(NAME, FREEZER_ID)VALUES('B', 1);
INSERT INTO MIG.CRQ_TOWER(NAME, FREEZER_ID)VALUES('C', 1);
INSERT INTO MIG.CRQ_TOWER(NAME, FREEZER_ID)VALUES('D', 1);
INSERT INTO MIG.CRQ_TOWER(NAME, FREEZER_ID)VALUES('E', 1);
INSERT INTO MIG.CRQ_TOWER(NAME, FREEZER_ID)VALUES('F', 1);
INSERT INTO MIG.CRQ_TOWER(NAME, FREEZER_ID)VALUES('G', 1);
INSERT INTO MIG.CRQ_TOWER(NAME, FREEZER_ID)VALUES('H', 1);
INSERT INTO MIG.CRQ_TOWER(NAME, FREEZER_ID)VALUES('I', 1);
INSERT INTO MIG.CRQ_TOWER(NAME, FREEZER_ID)VALUES('G', 1);
INSERT INTO MIG.CRQ_TOWER(NAME, FREEZER_ID)VALUES('K', 1);
INSERT INTO MIG.CRQ_TOWER(NAME, FREEZER_ID)VALUES('L', 1);
INSERT INTO MIG.CRQ_TOWER(NAME, FREEZER_ID)VALUES('M', 1);
INSERT INTO MIG.CRQ_TOWER(NAME, FREEZER_ID)VALUES('N', 1);
INSERT INTO MIG.CRQ_TOWER(NAME, FREEZER_ID)VALUES('O', 1); 
END;

begin
for i in 1 .. 15 loop
for j in 1 ..13 loop
insert into crq_box(name, tower_id) values(j,i);
end loop;
end loop;
end;

Insert into CRQ_SCHEDULED_JOB_STATUS_DICT
   (ID, NAME, DESCRIPTION, ACTIVE, ORDER_BY)
 Values
   (1, 'Scheduled', NULL, 1, 1);
Insert into CRQ_SCHEDULED_JOB_STATUS_DICT
   (ID, NAME, DESCRIPTION, ACTIVE, ORDER_BY)
 Values
   (2, 'Flush Completed', NULL, 1, 2);
Insert into CRQ_SCHEDULED_JOB_STATUS_DICT
   (ID, NAME, DESCRIPTION, ACTIVE, ORDER_BY)
 Values
   (4, 'Cancelled', NULL, 1, 4);
Insert into CRQ_SCHEDULED_JOB_STATUS_DICT
   (ID, NAME, DESCRIPTION, ACTIVE, ORDER_BY)
 Values
   (3, 'Attempt Complete', NULL, 1, 3);
COMMIT;

Insert into CRQ_EMBRYO_GRADE_DICT
   (ID, NAME, DESCRIPTION, ACTIVE, ORDER_BY)
 Values
   (5, '8/16 Cell', NULL, 1, 2);
Insert into CRQ_EMBRYO_GRADE_DICT
   (ID, NAME, DESCRIPTION, ACTIVE, ORDER_BY)
 Values
   (4, '4/8 Cell', NULL, 1, 4);
Insert into CRQ_EMBRYO_GRADE_DICT
   (ID, NAME, DESCRIPTION, ACTIVE, ORDER_BY)
 Values
   (3, '4 Cell', NULL, 1, 5);
Insert into CRQ_EMBRYO_GRADE_DICT
   (ID, NAME, DESCRIPTION, ACTIVE, ORDER_BY)
 Values
   (2, '8 Cell', NULL, 1, 3);
Insert into CRQ_EMBRYO_GRADE_DICT
   (ID, NAME, DESCRIPTION, ACTIVE, ORDER_BY)
 Values
   (1, '16 Cell', NULL, 1, 1);
Insert into CRQ_EMBRYO_GRADE_DICT
   (ID, NAME, DESCRIPTION, ACTIVE, ORDER_BY)
 Values
   (6, '2 Cell', NULL, 1, 6);



update CRQ_CRYO_REQUEST_STATUS_DICT set name='Cryo Preservation Requested(Legacy)',order_by=20 where ID=1; 

update CRQ_CRYO_REQUEST_STATUS_DICT set name='Waiting for Mice(Legacy)',order_by=21 where ID=2;

update CRQ_CRYO_REQUEST_STATUS_DICT set name='Mice Received(Legacy)' ,order_by=22 where ID=3;

update CRQ_CRYO_REQUEST_STATUS_DICT set name='Freezing in Progress(Legacy)',order_by=23 where ID=4; 

update CRQ_CRYO_REQUEST_STATUS_DICT set name='Finished Awaiting Test Thaw(Legacy)',order_by=24 where ID=5;

update CRQ_CRYO_REQUEST_STATUS_DICT set name='Test Thawed Waiting for Births(Legacy)',order_by=25 where ID=6;

update CRQ_CRYO_REQUEST_STATUS_DICT set name='Test Thawed Waiting for Genotyping(Legacy)',order_by=26 where ID=7; 

update CRQ_CRYO_REQUEST_STATUS_DICT set name='Troubleshooting(Legacy)',order_by=27 where ID=8; 

update CRQ_CRYO_REQUEST_STATUS_DICT set name='Line Frozen(Legacy)',order_by=28 where ID=9;

update CRQ_CRYO_REQUEST_STATUS_DICT SET NAME='Cancelled(Legacy)',order_by =29 where ID=10;



Insert into CRQ_CRYO_WILDTYPE_STRAIN_DICT
   (ID, NAME, DESCRIPTION, ACTIVE, ORDER_BY)
 Values
   (1, 'Albino B6', NULL, 1, 1);

Insert into CRQ_CRYO_WILDTYPE_STRAIN_DICT
   (ID, NAME, DESCRIPTION, ACTIVE, ORDER_BY)
 Values
   (2, 'Black B6', NULL, 1, 2);

Insert into CRQ_CRYO_WILDTYPE_STRAIN_DICT
   (ID, NAME, DESCRIPTION, ACTIVE, ORDER_BY)
 Values
   (3, '129Sv5', NULL, 1, 3);


Insert into "CRQ_CRYO_REQUEST_STATUS_DICT" ("ID","NAME","ORDER_BY","ACTIVE") values (11,'Requested',1,1); 

Insert into "CRQ_CRYO_REQUEST_STATUS_DICT" ("ID","NAME","ORDER_BY","ACTIVE") values (12,'Scheduled',2,1); 

Insert into "CRQ_CRYO_REQUEST_STATUS_DICT" ("ID","NAME","ORDER_BY","ACTIVE") values (13,'Freezing In Process',3,1); 

Insert into CRQ_CRYO_REQUEST_STATUS_DICT ("ID","NAME","ORDER_BY","ACTIVE") values (14,'Rechedule Needed',4,1); 

Insert into "CRQ_CRYO_REQUEST_STATUS_DICT" ("ID","NAME","ORDER_BY","ACTIVE") values (15,'Completed',10,1); 

Insert into "CRQ_CRYO_REQUEST_STATUS_DICT" ("ID","NAME","ORDER_BY","ACTIVE") values (16,'Cancelled',19,1); 

Insert into CRQ_CRYO_REQUEST_STATUS_DICT (ID, NAME,ORDER_BY, ACTIVE) Values (17, 'Awaiting Test Thaw',5, 1); 

Insert into CRQ_CRYO_REQUEST_STATUS_DICT (ID, NAME,ORDER_BY, ACTIVE) Values (18, 'Thaw Test Completed Awaiting Births',6, 1);


Insert into LIC_PROTOCOL_19B
   (ID, PROJECT_LICENCE_ID, EDITED_BY, EDIT_DATE, CHECK_NUMBER, 
    PROTOCOL_CODE, TITLE, CREATOR_ID, CREATED_DATE, HARMFUL_MUTANT)
 Values
   (89, 100, 'wl1', TO_DATE('07/25/2007 00:00:00', 'MM/DD/YYYY HH24:MI:SS'), 0, 
    '1a', 'Superovulation', NULL, TO_DATE('07/25/2007 00:00:00', 'MM/DD/YYYY HH24:MI:SS'), 0);
Insert into LIC_PROTOCOL_19B
   (ID, PROJECT_LICENCE_ID, EDITED_BY, EDIT_DATE, CHECK_NUMBER, 
    PROTOCOL_CODE, TITLE, CREATOR_ID, CREATED_DATE, HARMFUL_MUTANT)
 Values
   (90, 89, 'wl1', TO_DATE('07/25/2007 00:00:00', 'MM/DD/YYYY HH24:MI:SS'), 0, 
    '1c', 'Superovulation', NULL, TO_DATE('07/25/2007 00:00:00', 'MM/DD/YYYY HH24:MI:SS'), 0);

/* SOPs*/

/* advance sequences to allow for imported data*/
ALTER SEQUENCE PHN_STD_OP_PROC_SEQ INCREMENT BY 20;
SELECT PHN_STD_OP_PROC_SEQ.NEXTVAL FROM DUAL;
ALTER SEQUENCE PHN_STD_OP_PROC_SEQ INCREMENT BY 1;

ALTER SEQUENCE PHN_OBSERVATION_TYPE_SEQ INCREMENT BY 100;
SELECT PHN_OBSERVATION_TYPE_SEQ.NEXTVAL FROM DUAL;
ALTER SEQUENCE PHN_OBSERVATION_TYPE_SEQ INCREMENT BY 1;

ALTER SEQUENCE PHN_RESTRICTED_OPTION_SEQ INCREMENT BY 100;
SELECT PHN_RESTRICTED_OPTION_SEQ.NEXTVAL FROM DUAL;
ALTER SEQUENCE PHN_RESTRICTED_OPTION_SEQ INCREMENT BY 1;

ALTER SEQUENCE PHN_REQUIRED_OBSERVATION_SEQ INCREMENT BY 200;
SELECT PHN_REQUIRED_OBSERVATION_SEQ.NEXTVAL FROM DUAL;
ALTER SEQUENCE PHN_REQUIRED_OBSERVATION_SEQ INCREMENT BY 1;

/* import sop data from migd2 */
INSERT INTO PHN_STD_OPERATING_PROCEDURE (ID,PROCEDURE_ID,NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (1,9,'Hot Plate V1 27-07-2007',1,TO_DATE( '2007-07-10' , 'YYYY-MM-DD'),439,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38195);
INSERT INTO PHN_STD_OPERATING_PROCEDURE (ID,PROCEDURE_ID,NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (2,13,'Dysmorphology Observation V1 27-07-2007',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38545);
INSERT INTO PHN_STD_OPERATING_PROCEDURE (ID,PROCEDURE_ID,NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (3,4,'SHIRPA V1 30-07-2007',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41575);
INSERT INTO PHN_STD_OPERATING_PROCEDURE (ID,PROCEDURE_ID,NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (4,3,'Open Field V1 27-07-2007',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38509);
INSERT INTO PHN_STD_OPERATING_PROCEDURE (ID,PROCEDURE_ID,NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (5,5,'Grip Strength V1 30-07-2007',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41352);
INSERT INTO PHN_STD_OPERATING_PROCEDURE (ID,PROCEDURE_ID,NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (6,11,'DEXA 30-07-2007',1,TO_DATE( '2007-07-20' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41179);
INSERT INTO PHN_STD_OPERATING_PROCEDURE (ID,PROCEDURE_ID,NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (7,5,'Rotarod V1 30-07-2007',1,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42445);
INSERT INTO PHN_STD_OPERATING_PROCEDURE (ID,PROCEDURE_ID,NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (8,8,'Prepulse Inhibition (Acoustic startle) V1 30-07-2007',1,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42345);
INSERT INTO PHN_STD_OPERATING_PROCEDURE (ID,PROCEDURE_ID,NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (9,15,'Calorimetry V1 31-07-2007',1,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),'na5',43452);
INSERT INTO PHN_STD_OPERATING_PROCEDURE (ID,PROCEDURE_ID,NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (10,14,'IP glucose tolerance test V1 30-07-2007',1,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',43389);
INSERT INTO PHN_STD_OPERATING_PROCEDURE (ID,PROCEDURE_ID,NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (11,2,'Slit Lamp',0,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38561);
INSERT INTO PHN_STD_OPERATING_PROCEDURE (ID,PROCEDURE_ID,NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (12,2,'Ophthalmascope',0,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38562);
INSERT INTO PHN_STD_OPERATING_PROCEDURE (ID,PROCEDURE_ID,NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (13,10,'Non invasive blood pressure',0,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),'na5',43473);


INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (1,6,'Weight','Weight of an object in grams',0,null,'g',0,TO_DATE( '2007-07-10' , 'YYYY-MM-DD'),439,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',43402);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (2,5,'Behaviour','Dysmorphology obeservation',null,null,null,0,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),'na5',37540);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (3,5,'Coat','Dysmorphology',null,null,null,0,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),'na5',37546);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (4,5,'Eyes','Dysmorphology',null,null,null,0,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),'na5',37552);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (5,5,'Gait','Dysmorphology',null,null,null,0,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41408);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (6,5,'Skin','Dysmorphology',null,null,null,0,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),'na5',37576);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (7,5,'Teeth','Dysmorphology',null,null,null,0,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),'na5',37582);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (8,2,'Clickbox test score','Dysmorphology',null,null,null,0,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-20' , 'YYYY-MM-DD'),'na5',38032);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (9,1,'Dysmorphology examination comment','Dysmorphology',null,null,null,0,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-20' , 'YYYY-MM-DD'),'na5',38033);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (10,5,'Dysmorphology Growth/Weight','Dysmorphology',null,null,null,0,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',43399);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (11,4,'Skeletal Defects','Dysmorphology',null,null,null,0,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),'na5',37614);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (12,1,'Other Abnormalities','Dysmorphology',null,null,null,0,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),'na5',37617);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (13,3,'Latency to respond','Hot Plate',0,60000,'ms',0,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38186);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (14,5,'Hot Plate Response','Hot Plate',null,null,null,0,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38049);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (15,3,'Distance traveled','Open Field',0,null,'cm',0,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38320);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (20,2,'Number of rears','Open Field',0,null,null,0,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-20' , 'YYYY-MM-DD'),'dr4',38013);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (25,3,'% distance moved','Open Field',0,100,'Percentage',0,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38214);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (30,5,'Body Position','SHIRPA observation',null,null,null,0,TO_DATE( '2007-07-19' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-19' , 'YYYY-MM-DD'),'na5',37996);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (31,3,'DEXA Fat mass','DEXA',0,50,'g',0,TO_DATE( '2007-07-20' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',43329);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (32,3,'DEXA Lean mass','DEXA',0,50,'g',0,TO_DATE( '2007-07-20' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',43331);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (33,3,'Bone mineral density (without skull)','DEXA',0,null,'g/cm2',0,TO_DATE( '2007-07-20' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-20' , 'YYYY-MM-DD'),'na5',38036);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (34,3,'Bone mineral content','DEXA',0,null,'g',0,TO_DATE( '2007-07-20' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-20' , 'YYYY-MM-DD'),'na5',38037);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (35,3,'Length','DEXA etc',0,null,'cm',0,TO_DATE( '2007-07-20' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-20' , 'YYYY-MM-DD'),'na5',38038);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (36,1,'Comment','Comment',null,null,null,0,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38040);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (37,3,'Hot Plate Temperature','Hot Plate Temperature',10,100,'C',0,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38187);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (38,3,'% time spent','Open field observation',0,100,null,0,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38217);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (39,3,'Open field time','Open field',0,1200,'s',0,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38220);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (40,2,'Number of mice in cage',null,1,10,'mice',0,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38221);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (41,3,'Light intensity','open field',0,null,'Lux',0,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38222);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (42,2,'Number of entries to center','Open field',0,null,null,0,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38467);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (43,3,'Speed','Open field',0,100,'cm/s',0,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38224);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (44,3,'Area percentage',null,0,100,'cm2',0,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38469);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (45,3,'Estimated total mass','DEXA',0,100,'g',0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41150);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (46,3,'DEXA Area','DEXA',0,1000,'cm2',0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41159);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (47,3,'DEXA Fat percentage calculation','DEXA',0,100,'%',0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41177);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (48,3,'Grip Strength','Grip Strength',0,1000,'g',0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41365);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (49,5,'Tremor','SHIRPA',null,null,null,0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41372);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (50,5,'SHIRPA Palpebral Closure','Palpebral Closure',null,null,null,0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',43326);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (51,5,'Whiskers','Whiskers',null,null,null,0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41384);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (52,5,'Lacrimation','Lacrimation',null,null,null,0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41390);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (53,5,'Defecation','Defecation',null,null,null,0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41396);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (54,5,'Transfer Arousal','Transfer Arousal',null,null,null,0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41411);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (55,2,'Locomotor Activity','The total number of squares the animal enters with all four feet in 30 seconds.',1,100,null,0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41407);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (56,5,'Tail Elevation','Tail Elevation',null,null,null,0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41419);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (57,5,'Startle Response','Startle Response',null,null,null,0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41427);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (58,5,'Touch escape','Touch Escape SHIRPA',null,null,null,0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41449);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (59,5,'Positional passivity','SHIRPA Positional passivity',null,null,null,0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41444);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (60,5,'Skin Colour','Skin Colour',null,null,null,0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41457);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (61,5,'Trunk Curl','Trunk Curl',null,null,null,0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41464);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (62,5,'Limb Grasping','Limb Grasping',null,null,null,0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41470);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (63,5,'Generic Reflex','SHIRPA Reflex',null,null,null,0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42287);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (64,5,'Evidence of Biting','Evidence of Biting',null,null,null,0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41488);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (65,5,'Vocalisation','Vocalisation',null,null,null,0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41494);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (66,3,'Glucose Dose','IPGTT',0,2,'ml',0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42121);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (67,3,'Rotarod latency','Rotarod latency',null,null,'s',0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42275);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (68,5,'Rotarod ending',null,null,null,null,0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42280);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (69,3,'Time','Generic time',0,null,'min',0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42284);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (70,3,'Noise amplitude','Generic noise value',0,100,'dB',0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42285);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (71,3,'PPI Startle amplitude','PPI value',null,null,null,0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42290);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (72,3,'PPI Prepulse inhibition','derived value',0,100,'%',0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42291);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (73,3,'Blood glucose concentration',null,0,100,'mmol/L',0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',43337);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (74,1,'Generic Reagent batch code',null,null,null,null,0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',43367);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (75,3,'Oxygen consumption','Calorimetry',0,null,'ml/h',0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',43403);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (76,3,'Carbon dioxide production','Calorimetry',0,null,'ml/h',0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',43404);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (77,3,'Respiratory Exchange Ratio','Calorimetry',null,null,null,0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',43405);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (78,3,'Heat production','Calorimetry',0,null,'mW',0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',43406);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (79,2,'Activity','Calorimetry.  Beam break counts per hour',null,null,null,0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',43407);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (80,2,'Temperature','Used for Calorimetry',15,30,'C',0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',43408);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (81,3,'Time of experiment start','Calorimetry.  Hours before the dark cycle starts',null,null,'h',0,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',43409);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (82,3,'Blood pressure','Generic for non invassive blood pressure measurements',0,null,'mmHg',0,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),'na5',43468);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (83,3,'Pulse rate','generic pulse rate measurement for non invassive blood pressure',0,1000,'bpm',0,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),'na5',43467);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (84,5,'QC check','Generic QC check field - primarily used for blood pressure type measurements, but could be extended for elsewhere.  Does the experimenter accept the data as sound?',null,null,null,0,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),'na5',43448);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (85,2,'Number of observations','used in blood pressure',null,null,null,0,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),'na5',43478);
INSERT INTO PHN_OBSERVATION_TYPE (ID,OBSERVATION_META_TYPE_ID,NAME,DESCRIPTION,RANGE_MIN,RANGE_MAX,UNITS,RECORD_INSTRUMENT,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (86,3,'Generic Standard Deviation','Generic Standard Deviation',0,null,null,0,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),'na5',43480);

INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (25,1,1,'Weight',1,TO_DATE( '2007-07-10' , 'YYYY-MM-DD'),439,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38196,1,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (26,2,1,'Behaviour',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38546,2,'1',1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (27,3,2,'Coat Appearance',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38547,2,'3',1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (28,4,3,'Eyes',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38548,2,'5',1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (29,5,4,'Gait',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38549,2,'7',1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (30,6,5,'Skin',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38550,2,'9',1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (31,7,6,'Teeth',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38551,2,'11',1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (32,8,8,'Clickbox score',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38553,2,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (33,9,11,'Dysmorphology comment',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38556,2,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (34,10,7,'Growth/Weight Assessment',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38552,2,'13',1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (35,11,9,'Skeletal Defects',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38554,2,'16',1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (36,12,10,'Other Abnormalities',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38555,2,'none',1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (37,13,3,'Latency to respond',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38198,1,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (38,14,4,'Response',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38199,1,'17',1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (39,15,1,'Distance traveled 0-5mins',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38510,4,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (40,15,2,'Distance traveled 5-10mins',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38511,4,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (41,15,3,'Distance traveled 10-15mins',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38512,4,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (42,15,4,'Distance traveled 15-20mins',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38513,4,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (43,15,20,'Whole arena total distance traveled',1,TO_DATE( '2007-07-19' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38529,4,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (44,30,1,'Behaviour recorded in Viewing Jar: Body Position',1,TO_DATE( '2007-07-19' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41576,3,'20',1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (45,36,5,'Welfare related comment',1,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38200,1,null,0);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (46,37,2,'Hot Plate Temperature',1,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38197,1,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (47,20,5,'Number of rears 0-5mins',1,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38514,4,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (48,20,6,'Number of rears 5-10mins',1,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38515,4,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (49,20,7,'Number of rears 10-15mins',1,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38516,4,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (50,20,8,'Number of rears 15-20mins',1,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38517,4,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (51,20,9,'Number of rears - total',0,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38518,4,null,0);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (52,25,10,'% distance moved in centre 0-5mins',1,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38519,4,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (53,25,11,'% distance moved in centre 5-10mins',1,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38520,4,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (54,25,12,'% distance moved in centre 10-15mins',1,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38521,4,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (55,25,13,'% distance moved in centre 15-20mins',1,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38522,4,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (56,25,14,'% distance moved - total',0,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38523,4,null,0);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (57,38,15,'% time spent in centre 0-5mins',1,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38524,4,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (58,38,16,'% time spent in centre 5-10mins',1,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38525,4,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (59,38,17,'% time spent in centre 10-15mins',1,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38526,4,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (60,38,18,'% time spent in centre 15-20mins',1,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38527,4,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (61,38,19,'% time spent in centre - total',0,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38528,4,null,0);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (62,39,22,'Whole arena resting time',1,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38531,4,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (63,39,21,'Total time in open field',1,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38530,4,'1200',1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (64,43,23,'Whole arena - average speed',1,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38532,4,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (65,15,24,'Periphery distance traveled',1,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38533,4,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (66,39,25,'Periphery resting time',1,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38534,4,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (67,39,26,'Periphery total time',1,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38535,4,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (68,43,27,'Periphery average speed',1,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38536,4,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (69,15,28,'Center total distance traveled',1,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38537,4,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (70,39,29,'Center total resting time',1,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38538,4,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (71,39,30,'Center total time',1,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38539,4,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (72,43,31,'Center average speed',1,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38540,4,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (73,39,32,'Latency to enter center',1,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38541,4,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (74,42,33,'Number of entries to centre',1,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38542,4,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (75,41,34,'Light intensity of the center of the area',1,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38543,4,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (76,44,35,'Central zone area percentage',1,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38544,4,'25',1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (77,33,2,'Bone mineral density (without skull)',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41181,6,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (78,34,3,'Bone mineral content',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41182,6,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (79,32,5,'Lean mass',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41184,6,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (80,31,6,'Fat mass',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41185,6,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (81,1,1,'Weight',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41180,6,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (82,45,7,'Estimated total total tissue mass',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41186,6,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (83,46,4,'Bone Area',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41183,6,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (84,47,8,'Fat percentage estimate',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41187,6,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (85,1,1,'Weight',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41353,5,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (86,48,2,'Grip Strength Fore Paws 1',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41354,5,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (87,48,3,'Grip Strength Fore Paws 2',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41355,5,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (88,48,4,'Grip Strength Fore Paws 3',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41356,5,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (89,48,5,'Grip Strength Fore Paws 4',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41357,5,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (90,48,6,'Grip Strength Fore Paws 5',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41358,5,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (91,48,7,'Grip Strength All Paws 1',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41359,5,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (92,48,8,'Grip Strength All Paws 2',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41360,5,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (93,48,9,'Grip Strength All Paws 3',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41361,5,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (94,48,10,'Grip Strength All Paws 4',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41362,5,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (95,48,11,'Grip Strength All Paws 5',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41363,5,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (96,36,12,'Comment',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41364,5,null,0);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (97,49,2,'Tremor',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41577,3,'25',1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (98,50,3,'Palpebral Closure',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41578,3,'27',1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (99,3,4,'Coat Appearance',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41579,3,'3',1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (100,51,5,'Whiskers',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41580,3,'29',1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (101,52,7,'Lacrimation',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41582,3,'31',1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (102,53,8,'Defecation',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41583,3,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (103,54,9,'Behaviour recorded in the arena: Transfer Arousal',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41584,3,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (104,55,10,'Locomotor Activity',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41585,3,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (105,36,6,'Whisker related comment',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41581,3,null,0);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (106,5,11,'Gait',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41586,3,'7',1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (107,36,12,'Gair related comment',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41587,3,null,0);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (108,56,13,'Tail Elevation',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41588,3,'39',1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (109,57,14,'Startle Response',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41589,3,'42',1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (110,58,15,'Touch escape',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41590,3,'46',1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (111,59,16,'Behaviour recorded above the Arena: Positional passivity',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41591,3,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (112,60,17,'Skin Colour',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41592,3,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (113,61,18,'Trunk Curl',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41593,3,'54',1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (114,62,19,'Limb Grasping',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41594,3,'56',1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (115,63,20,'Pinna reflex',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41595,3,'58',1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (116,63,21,'Corneal reflex',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41596,3,'58',1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (117,63,22,'Contact righting reflex',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41597,3,'58',1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (118,64,23,'Evidence of Biting',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41598,3,'60',1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (119,65,24,'Vocalisation',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41599,3,'62',1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (120,70,1,'Background noise',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42346,8,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (121,70,2,'Prepulse',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42347,8,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (122,70,3,'Startle amplitude - BN',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42348,8,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (123,70,4,'Startle amplitude - P1',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42349,8,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (124,70,5,'Noise amplitude - P2',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42350,8,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (125,70,6,'Noise amplitude - P3',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42351,8,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (126,70,7,'Noise amplitude - P4',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42352,8,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (127,70,8,'Noise amplitude - P5',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42353,8,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (128,70,9,'Noise amplitude - ST110',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42354,8,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (129,70,10,'Noise amplitude - PP1',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42355,8,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (130,70,11,'Noise amplitude - PP2',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42356,8,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (131,70,12,'Noise amplitude - PP3',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42357,8,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (132,70,13,'Noise amplitude - PP4',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42358,8,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (133,72,14,'PPI Prepulse inhibition - PP1',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42359,8,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (134,72,15,'PPI Prepulse inhibition - PP2',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42360,8,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (135,72,16,'PPI Prepulse inhibition - PP3',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42361,8,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (136,72,17,'PPI Prepulse inhibition - PP4',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42362,8,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (137,72,18,'PPI Prepulse inhibition - Global',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42363,8,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (138,36,19,'Comment',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42364,8,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (139,67,2,'Test trial 1 latency',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42447,7,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (140,69,4,'Inter trail interval 1',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42449,7,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (141,67,5,'Test trial 2 latency',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42450,7,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (142,68,3,'Reason for test end',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42448,7,'64',1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (143,67,8,'Rotarod latency',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42453,7,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (144,69,7,'Inter trail interval 2',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42452,7,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (145,68,6,'Reason for test end',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42451,7,'64',1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (146,68,9,'Reason for test end',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42454,7,'64',1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (147,1,1,'Weight',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42446,7,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (148,1,3,'Weight at end of experiment',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),'na5',43455,9,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (149,1,1,'Weight at start of experiment',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),'na5',43453,9,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (150,66,4,'Glucose Dose',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',43393,10,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (151,1,2,'Weight',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',43391,10,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (152,73,3,'Blood glucose concentration T0',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',43392,10,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (153,73,5,'Blood glucose concentration T15',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',43394,10,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (154,73,6,'Blood glucose concentration T30',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',43395,10,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (155,73,7,'Blood glucose concentration T60',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',43396,10,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (156,73,8,'Blood glucose concentration T120',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',43397,10,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (157,36,9,'Comment',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',43398,10,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (158,36,1,'QC related comment',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',43390,10,null,0);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (159,81,2,'Time at start of experiment',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),'na5',43454,9,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (160,76,4,'Dark period rate of carbon dioxide production',1,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),'na5',43456,9,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (161,76,5,'Light period rate of carbon dioxide production',1,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),'na5',43457,9,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (162,75,6,'Dark period rate of oxygen consumption',1,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),'na5',43458,9,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (163,75,7,'Light period rate of oxygen consumption',1,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),'na5',43459,9,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (164,79,8,'Dark period rate of activity',1,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),'na5',43460,9,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (165,79,9,'Light period rate of activity',1,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),'na5',43461,9,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (166,77,10,'Dark period Respiratory Exchange Ratio',1,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),'na5',43462,9,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (167,77,11,'Light period Respiratory Exchange Ratio',1,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),'na5',43463,9,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (168,78,12,'Dark period rate of heat production',1,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),'na5',43464,9,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (169,78,13,'Light period rate of heat production',1,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),'na5',43465,9,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (170,84,14,'QC check',1,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),'na5',43466,9,'67',1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (171,82,2,'Average systolic blood pressure',1,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),'na5',43474,13,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (172,82,3,'Average diastolic blood pressure',1,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),'na5',43476,13,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (173,83,4,'Average pulse rate',1,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),'na5',43477,13,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (174,1,1,'Weight',1,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),'na5',43475,13,null,1);
INSERT INTO PHN_REQUIRED_OBSERVATION (ID,OBSERVATION_TYPE_ID,ORDER_BY,DISPLAY_NAME,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER,SOP_ID,DEFAULT_VALUE,MANDATORY_OBSERVATION) VALUES (175,85,5,'Number of observations contribting to data',1,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),'na5',43479,13,null,1);


INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (1,2,null,'Normal',1,'Normal',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),'na5',37541);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (2,2,null,'Abnormal',2,'Abnormal',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),'na5',37542);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (3,3,null,'Normal',1,'Normal',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),'na5',37547);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (4,3,null,'Abnormal',2,'Abnormal',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),'na5',37548);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (5,4,null,'Normal',1,'Normal',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),'na5',37553);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (6,4,null,'Abnormal',2,'Abnormal',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),'na5',37554);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (7,5,null,'Normal',1,'Fluid movement and approximately 3mm pelvic elevation',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41409);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (8,5,null,'Abnormal',2,'Lack of fluidity in movement',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41410);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (9,6,null,'Normal',1,'Normal',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),'na5',37577);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (10,6,null,'Abnormal',2,'Abnormal',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),'na5',37578);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (11,7,null,'Normal',1,'Normal',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),'na5',37583);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (12,7,null,'Abnormal',2,'Abnormal',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),'na5',37584);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (13,10,null,'Normal',1,'Normal',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',43400);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (14,10,null,'Abnormal',2,'Abnormal',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',43401);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (15,11,null,'Kinky Tail',2,'Kinky Tail',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),'na5',37616);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (16,11,null,'None',1,'None',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),'na5',37615);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (17,14,null,'Hindlimb kick',1,'Hindlimb kick',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38050);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (18,14,null,'Paw Lick',2,'Paw Lick',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38051);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (19,14,null,'Jumping',3,'Jumping',1,TO_DATE( '2007-07-18' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38052);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (20,30,null,'Active',1,'Active',1,TO_DATE( '2007-07-19' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-19' , 'YYYY-MM-DD'),'na5',37997);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (21,30,null,'Inactive',2,'Inactive',1,TO_DATE( '2007-07-19' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-19' , 'YYYY-MM-DD'),'na5',37998);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (22,30,null,'Excessive activity',3,'Excessive activity',1,TO_DATE( '2007-07-19' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-19' , 'YYYY-MM-DD'),'na5',37999);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (23,14,null,'Time out',4,'Time out',1,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38053);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (24,14,null,'Welfare issue',5,'Welfare issue (comment required)',1,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-27' , 'YYYY-MM-DD'),'na5',38054);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (25,49,null,'Absent',1,'Absent',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41373);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (26,49,null,'Present',2,'Present',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41374);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (27,50,null,'Eyes open',1,'Eyes open',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',43327);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (28,50,null,'Eyes closed',2,'Eyes closed',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',43328);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (29,51,null,'Present',1,'Present',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41385);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (30,51,null,'Absent',2,'Absent',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41386);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (31,52,null,'Absent',1,'Absent',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41391);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (32,52,null,'Present',2,'Present',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41392);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (33,53,null,'Present',1,'Present',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41397);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (34,53,null,'Absent',2,'Absent',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41398);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (35,54,null,'Extended freeze (over 5 seconds)',1,'Extended freeze (over 5 seconds)',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41412);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (36,54,null,'Brief freeze followed by movement',2,'Brief freeze followed by movement',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41413);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (37,54,null,'Immediate movement',3,'Immediate movement',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41414);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (38,56,null,'Dragging',1,'Dragging',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41420);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (39,56,null,'Horizontal extension',2,'Horizontal extension',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41421);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (40,56,null,'Elevated/straub tail',3,'Elevated/straub tail',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41422);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (41,57,null,'None',1,'None',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41428);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (42,57,null,'Preyer reflex',2,'backwards flick of the pinnae',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41429);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (43,57,null,'Reaction in addition to the Preyer reflex',3,'Reaction in addition to the Preyer reflex (eg. Startled response)',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41430);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (44,58,null,'No response',1,'No response',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41450);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (45,58,null,'Response to touch',2,'Response to touch',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41451);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (46,58,null,'Flees prior to touch',3,'Flees prior to touch',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41452);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (47,59,null,'Struggles when held by the tail',1,'Struggles when held by the tail',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41445);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (48,59,null,'Struggles when held by the neck',2,'loose scruff between the forefinger and thumb',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41446);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (49,59,null,'Struggles when laid supine',3,'Struggles when laid supine',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41447);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (50,59,null,'No struggle',4,'No struggle',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41448);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (51,60,null,'Blanched',1,'Blanched',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41458);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (52,60,null,'Pink',2,'Pink',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41459);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (53,60,null,'Bright, deep red flush',3,'Bright, deep red flush',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41460);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (54,61,null,'Absent',1,'Absent',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41465);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (55,61,null,'Present',2,'Present',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41466);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (56,62,null,'Absent',1,'Absent',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41471);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (57,62,null,'Present',2,'Present',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41472);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (58,63,null,'Present',1,'Present',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42288);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (59,63,null,'Absent',2,'Absent',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42289);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (60,64,null,'None',1,'None',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41489);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (61,64,null,'Biting in response to handling',2,'Biting in response to handling',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41490);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (62,65,null,'None',1,'None',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41495);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (63,65,null,'Vocal',2,'Vocal',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',41496);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (64,68,null,'Jumping',1,'Jumping',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42281);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (65,68,null,'Passive rotation',2,'Passive rotation',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42282);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (66,68,null,'Time out',3,'Time out',1,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-30' , 'YYYY-MM-DD'),'na5',42283);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (67,84,null,'Yes',1,'Data good for primetime',1,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),'na5',43449);
INSERT INTO PHN_RESTRICTED_OPTION (ID,OBSERVATION_TYPE_ID,PARENT_OPTION_ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) VALUES (68,84,null,'No',2,'Data not good for primetime',1,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),64,TO_DATE( '2007-07-31' , 'YYYY-MM-DD'),'na5',43450);



commit;







