/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

--audit triggers (first generate all audit files using the dbms function, and then give mig the grant
-- select 'grant insert on ' || table_name || ' to mig;' from user_tables  
--now run the triggers

CREATE OR REPLACE TRIGGER CRQ_CRYO_REQUEST_ta
BEFORE UPDATE OR DELETE ON CRQ_CRYO_REQUEST FOR EACH ROW
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
DECLARE
audit_action VARCHAR2(10);
BEGIN

IF DELETING THEN audit_action := 'deleted'; END IF;
IF UPDATING THEN audit_action := 'updated'; END IF;
IF DELETING OR UPDATING THEN 
 INSERT INTO mig_audit.CRQ_CRYO_REQUEST(
    ID,
    REQUESTER_ID,
    PROJECT_LICENCE_ID,
    COLONY_ID,
    FEMALE_STRAIN_DICT_ID,
    CREATOR_ID,
    CREATED_DATE,
    EDITED_BY,
    EDIT_DATE,
    CHECK_NUMBER,
    STATUS_DICT_ID,
    TARGET_COUNT,
    NUMBER_THAWED,
    AUDIT_ACTION)
 VALUES (
    :OLD.ID,
    :OLD.REQUESTER_ID,
    :OLD.PROJECT_LICENCE_ID,
    :OLD.COLONY_ID,
    :OLD.FEMALE_STRAIN_DICT_ID,
    :OLD.CREATOR_ID,
    :OLD.CREATED_DATE,
    :OLD.EDITED_BY,
    :OLD.EDIT_DATE,
    :OLD.CHECK_NUMBER,
    :OLD.STATUS_DICT_ID,
    :OLD.TARGET_COUNT,
    :OLD.NUMBER_THAWED,
    AUDIT_ACTION);
END IF;
END;
/
SHOW ERRORS;

/* triger with audit tables*/
CREATE OR REPLACE TRIGGER CRQ_VIAL_ta
BEFORE UPDATE OR DELETE ON CRQ_VIAL FOR EACH ROW
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
DECLARE
audit_action VARCHAR2(10);
BEGIN

IF DELETING THEN audit_action := 'deleted'; END IF;
IF UPDATING THEN audit_action := 'updated'; END IF;
IF DELETING OR UPDATING THEN 
 INSERT INTO mig_audit.CRQ_VIAL(
    ID,
    EDIT_DATE,
    EDITED_BY,
    CREATED_DATE,
    CREATOR_ID,
    CHECK_NUMBER,
    COMMENTS,
    BOX_ID,
    NAME,
    IN_USE,
    LABEL,
    POSITION,
    AUDIT_ACTION)
 VALUES (
    :OLD.ID,
    :OLD.EDIT_DATE,
    :OLD.EDITED_BY,
    :OLD.CREATED_DATE,
    :OLD.CREATOR_ID,
    :OLD.CHECK_NUMBER,
    :OLD.COMMENTS,
    :OLD.BOX_ID,
    :OLD.NAME,
    :OLD.IN_USE,
    :OLD.LABEL,
    :OLD.POSITION,
    AUDIT_ACTION);
END IF;
END;
/
SHOW ERRORS;

CREATE OR REPLACE TRIGGER CRQ_CANISTER_ta
BEFORE UPDATE OR DELETE ON CRQ_CANISTER FOR EACH ROW
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
DECLARE
audit_action VARCHAR2(10);
BEGIN

IF DELETING THEN audit_action := 'deleted'; END IF;
IF UPDATING THEN audit_action := 'updated'; END IF;
IF DELETING OR UPDATING THEN 
 INSERT INTO mig_audit.CRQ_CANISTER(
    ID,
    COMMENTS,
    FREEZER_ID,
    NAME,
    AUDIT_ACTION)
 VALUES (
    :OLD.ID,
    :OLD.COMMENTS,
    :OLD.FREEZER_ID,
    :OLD.NAME,
    AUDIT_ACTION);
END IF;
END;
/
SHOW ERRORS;


CREATE OR REPLACE TRIGGER CRQ_CRYO_REQUEST_STRAIN_DIC_ta
BEFORE UPDATE OR DELETE ON CRQ_CRYO_REQUEST_STRAIN_DICT FOR EACH ROW
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
DECLARE
audit_action VARCHAR2(10);
BEGIN

IF DELETING THEN audit_action := 'deleted'; END IF;
IF UPDATING THEN audit_action := 'updated'; END IF;
IF DELETING OR UPDATING THEN 
 INSERT INTO mig_audit.CRQ_CRYO_REQUEST_STRAIN_DICT(
    ID,
    NAME,
    DESCRIPTION,
    ACTIVE,
    ORDER_BY,
    AUDIT_ACTION)
 VALUES (
    :OLD.ID,
    :OLD.NAME,
    :OLD.DESCRIPTION,
    :OLD.ACTIVE,
    :OLD.ORDER_BY,
    AUDIT_ACTION);
END IF;
END;
/
SHOW ERRORS;


CREATE OR REPLACE TRIGGER CRQ_EMBRYO_GRADE_DICT_ta
BEFORE UPDATE OR DELETE ON CRQ_EMBRYO_GRADE_DICT FOR EACH ROW
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
DECLARE
audit_action VARCHAR2(10);
BEGIN

IF DELETING THEN audit_action := 'deleted'; END IF;
IF UPDATING THEN audit_action := 'updated'; END IF;
IF DELETING OR UPDATING THEN 
 INSERT INTO mig_audit.CRQ_EMBRYO_GRADE_DICT(
    ID,
    NAME,
    DESCRIPTION,
    ACTIVE,
    ORDER_BY,
    AUDIT_ACTION)
 VALUES (
    :OLD.ID,
    :OLD.NAME,
    :OLD.DESCRIPTION,
    :OLD.ACTIVE,
    :OLD.ORDER_BY,
    AUDIT_ACTION);
END IF;
END;
/
SHOW ERRORS;


CREATE OR REPLACE TRIGGER CRQ_SCHEDULED_CRYO_PRV_ta
BEFORE UPDATE OR DELETE ON CRQ_SCHEDULED_CRYO_PRV FOR EACH ROW
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
DECLARE
audit_action VARCHAR2(10);
BEGIN

IF DELETING THEN audit_action := 'deleted'; END IF;
IF UPDATING THEN audit_action := 'updated'; END IF;
IF DELETING OR UPDATING THEN 
 INSERT INTO mig_audit.CRQ_SCHEDULED_CRYO_PRV(
    ID,
    CRYO_REQUEST_ID,
    CRYO_JOB_STATUS_DICT_ID,
    TARGET_SCHEDULED_DATE,
    CANCEL_REASON,
    EDIT_DATE,
    EDITED_BY,
    CREATED_DATE,
    CREATOR_ID,
    CHECK_NUMBER,
    COMMENTS,
    JOB_NAME,
    AUDIT_ACTION)
 VALUES (
    :OLD.ID,
    :OLD.CRYO_REQUEST_ID,
    :OLD.CRYO_JOB_STATUS_DICT_ID,
    :OLD.TARGET_SCHEDULED_DATE,
    :OLD.CANCEL_REASON,
    :OLD.EDIT_DATE,
    :OLD.EDITED_BY,
    :OLD.CREATED_DATE,
    :OLD.CREATOR_ID,
    :OLD.CHECK_NUMBER,
    :OLD.COMMENTS,
    :OLD.JOB_NAME,
    AUDIT_ACTION);
END IF;
END;
/
SHOW ERRORS;



CREATE OR REPLACE TRIGGER CRQ_LOCATION_ta
BEFORE UPDATE OR DELETE ON CRQ_LOCATION FOR EACH ROW
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
DECLARE
audit_action VARCHAR2(10);
BEGIN

IF DELETING THEN audit_action := 'deleted'; END IF;
IF UPDATING THEN audit_action := 'updated'; END IF;
IF DELETING OR UPDATING THEN 
 INSERT INTO mig_audit.CRQ_LOCATION(
    ID,
    VIAL_ID,
    STRAW_ID,
    AUDIT_ACTION)
 VALUES (
    :OLD.ID,
    :OLD.VIAL_ID,
    :OLD.STRAW_ID,
    AUDIT_ACTION);
END IF;
END;
/
SHOW ERRORS;


CREATE OR REPLACE TRIGGER CRQ_FREEZE_DOWN_SAMPLE_ta
BEFORE UPDATE OR DELETE ON CRQ_FREEZE_DOWN_SAMPLE FOR EACH ROW
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
DECLARE
audit_action VARCHAR2(10);
BEGIN

IF DELETING THEN audit_action := 'deleted'; END IF;
IF UPDATING THEN audit_action := 'updated'; END IF;
IF DELETING OR UPDATING THEN 
 INSERT INTO mig_audit.CRQ_FREEZE_DOWN_SAMPLE(
    ID,
    EMBRYO_HARVEST_ID,
    EDIT_DATE,
    EDITED_BY,
    CREATED_DATE,
    CREATOR_ID,
    CHECK_NUMBER,
    COMMENTS,
    TECHNICIAN_ID,
    LOCATION_ID,
    EMBRYO_GRADE_DICT_ID,
    EMBRYO_COUNT,
    FREEZE_DOWN_DATE,
    THAW_DATE,
    AUDIT_ACTION)
 VALUES (
    :OLD.ID,
    :OLD.EMBRYO_HARVEST_ID,
    :OLD.EDIT_DATE,
    :OLD.EDITED_BY,
    :OLD.CREATED_DATE,
    :OLD.CREATOR_ID,
    :OLD.CHECK_NUMBER,
    :OLD.COMMENTS,
    :OLD.TECHNICIAN_ID,
    :OLD.LOCATION_ID,
    :OLD.EMBRYO_GRADE_DICT_ID,
    :OLD.EMBRYO_COUNT,
    :OLD.FREEZE_DOWN_DATE,
    :OLD.THAW_DATE,
    AUDIT_ACTION);
END IF;
END;
/
SHOW ERRORS;


CREATE OR REPLACE TRIGGER CRQ_EMBRYO_HARVEST_ta
BEFORE UPDATE OR DELETE ON CRQ_EMBRYO_HARVEST FOR EACH ROW
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
DECLARE
audit_action VARCHAR2(10);
BEGIN

IF DELETING THEN audit_action := 'deleted'; END IF;
IF UPDATING THEN audit_action := 'updated'; END IF;
IF DELETING OR UPDATING THEN 
 INSERT INTO mig_audit.CRQ_EMBRYO_HARVEST(
    ID,
    SCHEDULED_JOB_ID,
    EDITED_DATE,
    EDITED_BY,
    CREATED_DATE,
    CREATOR_ID,
    CHECK_NUMBER,
    COMMENTS,
    CELL_COUNT_16,
    CELL_COUNT_8,
    CELL_COUNT_4,
    CELL_COUNT_2,
    CELL_COUNT_1,
    DEAD_COUNT,
    FRAGMENTED_COUNT,
    OTHER_EMBRYO_TYPE_COUNT,
    NUMBER_SUPEROVULATED,
    NUMBER_PLUGGED,
    FLUSH_DATE,
    TECHNICIAN_ID,
    OTHER_DESCRIPTION,
    WILDTYPE_TEST_STRAIN_ID,
    USE_16_CELL,
    USE_8_CELL,
    USE_4_CELL,
    MOUSE_ID,
 cohort_id,
    AUDIT_ACTION)
 VALUES (
    :OLD.ID,
    :OLD.SCHEDULED_JOB_ID,
    :OLD.EDITED_DATE,
    :OLD.EDITED_BY,
    :OLD.CREATED_DATE,
    :OLD.CREATOR_ID,
    :OLD.CHECK_NUMBER,
    :OLD.COMMENTS,
    :OLD.CELL_COUNT_16,
    :OLD.CELL_COUNT_8,
    :OLD.CELL_COUNT_4,
    :OLD.CELL_COUNT_2,
    :OLD.CELL_COUNT_1,
    :OLD.DEAD_COUNT,
    :OLD.FRAGMENTED_COUNT,
    :OLD.OTHER_EMBRYO_TYPE_COUNT,
    :OLD.NUMBER_SUPEROVULATED,
    :OLD.NUMBER_PLUGGED,
    :OLD.FLUSH_DATE,
    :OLD.TECHNICIAN_ID,
    :OLD.OTHER_DESCRIPTION,
    :OLD.WILDTYPE_TEST_STRAIN_ID,
    :OLD.USE_16_CELL,
    :OLD.USE_8_CELL,
    :OLD.USE_4_CELL,
    :OLD.MOUSE_ID,
 :OLD.cohort_id,
    AUDIT_ACTION);
END IF;
END;
/
SHOW ERRORS;

CREATE OR REPLACE TRIGGER CRQ_GOBLET_ta
BEFORE UPDATE OR DELETE ON CRQ_GOBLET FOR EACH ROW
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
DECLARE
audit_action VARCHAR2(10);
BEGIN

IF DELETING THEN audit_action := 'deleted'; END IF;
IF UPDATING THEN audit_action := 'updated'; END IF;
IF DELETING OR UPDATING THEN 
 INSERT INTO mig_audit.CRQ_GOBLET(
    ID,
    COMMENTS,
    CANISTER_ID,
    NAME,
    AUDIT_ACTION)
 VALUES (
    :OLD.ID,
    :OLD.COMMENTS,
    :OLD.CANISTER_ID,
    :OLD.NAME,
    AUDIT_ACTION);
END IF;
END;
/
SHOW ERRORS;

CREATE OR REPLACE TRIGGER CRQ_CRYO_REQUEST_STATUS_DIC_ta
BEFORE UPDATE OR DELETE ON CRQ_CRYO_REQUEST_STATUS_DICT FOR EACH ROW
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
DECLARE
audit_action VARCHAR2(10);
BEGIN

IF DELETING THEN audit_action := 'deleted'; END IF;
IF UPDATING THEN audit_action := 'updated'; END IF;
IF DELETING OR UPDATING THEN 
 INSERT INTO mig_audit.CRQ_CRYO_REQUEST_STATUS_DICT(
    ID,
    NAME,
    DESCRIPTION,
    ORDER_BY,
    ACTIVE,
    AUDIT_ACTION)
 VALUES (
    :OLD.ID,
    :OLD.NAME,
    :OLD.DESCRIPTION,
    :OLD.ORDER_BY,
    :OLD.ACTIVE,
    AUDIT_ACTION);
END IF;
END;
/
SHOW ERRORS;

CREATE OR REPLACE TRIGGER CRQ_SCHEDULED_JOB_STATUS_DI_ta
BEFORE UPDATE OR DELETE ON CRQ_SCHEDULED_JOB_STATUS_DICT FOR EACH ROW
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
DECLARE
audit_action VARCHAR2(10);
BEGIN

IF DELETING THEN audit_action := 'deleted'; END IF;
IF UPDATING THEN audit_action := 'updated'; END IF;
IF DELETING OR UPDATING THEN 
 INSERT INTO mig_audit.CRQ_SCHEDULED_JOB_STATUS_DICT(
    ID,
    NAME,
    DESCRIPTION,
    ACTIVE,
    ORDER_BY,
    AUDIT_ACTION)
 VALUES (
    :OLD.ID,
    :OLD.NAME,
    :OLD.DESCRIPTION,
    :OLD.ACTIVE,
    :OLD.ORDER_BY,
    AUDIT_ACTION);
END IF;
END;
/
SHOW ERRORS;

CREATE OR REPLACE TRIGGER CRQ_STRAW_ta
BEFORE UPDATE OR DELETE ON CRQ_STRAW FOR EACH ROW
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
DECLARE
audit_action VARCHAR2(10);
BEGIN

IF DELETING THEN audit_action := 'deleted'; END IF;
IF UPDATING THEN audit_action := 'updated'; END IF;
IF DELETING OR UPDATING THEN 
 INSERT INTO mig_audit.CRQ_STRAW(
    ID,
    EDIT_DATE,
    EDITED_BY,
    CREATED_DATE,
    CREATOR_ID,
    CHECK_NUMBER,
    COMMENTS,
    WEDGE_ID,
    IN_USE,
    AUDIT_ACTION)
 VALUES (
    :OLD.ID,
    :OLD.EDIT_DATE,
    :OLD.EDITED_BY,
    :OLD.CREATED_DATE,
    :OLD.CREATOR_ID,
    :OLD.CHECK_NUMBER,
    :OLD.COMMENTS,
    :OLD.WEDGE_ID,
    :OLD.IN_USE,
    AUDIT_ACTION);
END IF;
END;
/
SHOW ERRORS;

CREATE OR REPLACE TRIGGER CRQ_WEDGE_ta
BEFORE UPDATE OR DELETE ON CRQ_WEDGE FOR EACH ROW
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
DECLARE
audit_action VARCHAR2(10);
BEGIN

IF DELETING THEN audit_action := 'deleted'; END IF;
IF UPDATING THEN audit_action := 'updated'; END IF;
IF DELETING OR UPDATING THEN 
 INSERT INTO mig_audit.CRQ_WEDGE(
    ID,
    COMMENTS,
    GOBLET_ID,
    COLOUR,
    COLOUR_ORDER,
    AUDIT_ACTION)
 VALUES (
    :OLD.ID,
    :OLD.COMMENTS,
    :OLD.GOBLET_ID,
    :OLD.COLOUR,
    :OLD.COLOUR_ORDER,
    AUDIT_ACTION);
END IF;
END;
/
SHOW ERRORS;

CREATE OR REPLACE TRIGGER CRQ_TOWER_ta
BEFORE UPDATE OR DELETE ON CRQ_TOWER FOR EACH ROW
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
DECLARE
audit_action VARCHAR2(10);
BEGIN

IF DELETING THEN audit_action := 'deleted'; END IF;
IF UPDATING THEN audit_action := 'updated'; END IF;
IF DELETING OR UPDATING THEN 
 INSERT INTO mig_audit.CRQ_TOWER(
    ID,
    CHECK_NUMBER,
    NAME,
    DESCRIPTION,
    FREEZER_ID,
    AUDIT_ACTION)
 VALUES (
    :OLD.ID,
    :OLD.CHECK_NUMBER,
    :OLD.NAME,
    :OLD.DESCRIPTION,
    :OLD.FREEZER_ID,
    AUDIT_ACTION);
END IF;
END;
/
SHOW ERRORS;

CREATE OR REPLACE TRIGGER CRQ_FREEZER_ta
BEFORE UPDATE OR DELETE ON CRQ_FREEZER FOR EACH ROW
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
DECLARE
audit_action VARCHAR2(10);
BEGIN

IF DELETING THEN audit_action := 'deleted'; END IF;
IF UPDATING THEN audit_action := 'updated'; END IF;
IF DELETING OR UPDATING THEN 
 INSERT INTO mig_audit.CRQ_FREEZER(
    ID,
    COMMENTS,
    NAME,
    DESCRIPTION,
    IS_STRAW,
    AUDIT_ACTION)
 VALUES (
    :OLD.ID,
    :OLD.COMMENTS,
    :OLD.NAME,
    :OLD.DESCRIPTION,
    :OLD.IS_STRAW,
    AUDIT_ACTION);
END IF;
END;
/
SHOW ERRORS;

CREATE OR REPLACE TRIGGER CRQ_BOX_ta
BEFORE UPDATE OR DELETE ON CRQ_BOX FOR EACH ROW
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
DECLARE
audit_action VARCHAR2(10);
BEGIN

IF DELETING THEN audit_action := 'deleted'; END IF;
IF UPDATING THEN audit_action := 'updated'; END IF;
IF DELETING OR UPDATING THEN 
 INSERT INTO mig_audit.CRQ_BOX(
    ID,
    CHECK_NUMBER,
    COMMENTS,
    TOWER_ID,
    NAME,
    AUDIT_ACTION)
 VALUES (
    :OLD.ID,
    :OLD.CHECK_NUMBER,
    :OLD.COMMENTS,
    :OLD.TOWER_ID,
    :OLD.NAME,
    AUDIT_ACTION);
END IF;
END;
/
SHOW ERRORS;

