/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

CREATE OR REPLACE FORCE VIEW MTS_CAGE_VW
(CAGE_ID, CAGE_NAME, CAGE_BARCODE, RACK_ID, RACK_NAME, 
 RACK_BARCODE, ROOM_ID, ROOM_NAME)
AS 
select 
  c.id cage_id, 
  c.id cage_name, 
  c.barcode cage_barcode, 
  r.id rack_id, 
  r.name rack_name, 
  r.barcode rack_barcode, 
  m.id room_id, 
  m.room_number room_name 
from 
  mts_cage c, 
  mts_rack r, 
  mts_room m 
where 
  c.rack_id = r.id and 
  r.room_id = m.id;

CREATE OR REPLACE FORCE VIEW MTL_STOCK_CARD_VW
(CAGE_ID, CAGE_BARCODE, CAGE_LOCATION, PROJECT_LICENCE_NUMBER, PROTOCOL_19B, 
 OWNER, OWNER_PHONE_NUMBER, COLONY_NAME, COLONY_PREFIX)
AS 
select distinct 
  c.cage_id, 
  c.cage_barcode, 
  c.room_name||' Rack '||c.rack_name cage_location, 
  o.licence_number project_licence_number, 
  o.protocol_code protocol_19b, 
  p.first_name||' '||p.last_name owner, 
  p.phone_number owner_phone_number, 
  i.colony_name, 
  i.colony_prefix 
from 
  mts_mouse m, 
  mts_cage_vw c, 
  mts_colony_info i, 
  per_person p, 
  mts_mouse_current_19b_vw o 
where 
  m.cage_id = c.cage_id and 
  m.current_owner_id = p.person_id(+) and 
  m.colony_info_id = i.id(+) and 
  m.id = o.mouse_id(+);

CREATE OR REPLACE FORCE VIEW MTS_CAGE_HEADER_VW
(CAGE_ID, CAGE_BARCODE, RACK_ID, RACK_NAME, RACK_BARCODE, 
 ROOM_ID, ROOM_NAME, OWNER_ID, OWNER_NAME, OWNER_PHONE_NUMBER, 
 COLONY_INFO_ID, COLONY_NAME, COLONY_PREFIX, PROTOCOL_ID, PROTOCOL_CODE, 
 PROJECT_LICENCE_ID, LICENCE_NUMBER, PROCEDURE_DICT_ID, PROCEDURE, PERSONAL_LICENCE_ID, 
 PIL_NUMBER)
AS 
select distinct 
  c.cage_id, 
  c.cage_barcode, 
  c.rack_id, 
  c.rack_name, 
  c.rack_barcode, 
  c.room_id, 
  c.room_name, 
  o.person_id owner_id, 
  o.first_name||' '||o.last_name owner_name, 
  o.phone_number owner_phone_number, 
  i.id colony_info_id, 
  i.colony_name, 
  i.colony_prefix, 
  b.protocol_id, 
  b.protocol_code, 
  b.project_licence_id, 
  b.licence_number, 
  b.procedure_dict_id, 
  b.procedure, 
  b.personal_licence_id, 
  b.pil_number 
from 
  mts_mouse m, 
  mts_cage_vw c, 
  per_person o, 
  mts_colony_info i, 
  mts_mouse_current_19b_vw b 
where 
  m.cage_id = c.cage_id and 
  m.current_owner_id = o.person_id and 
  m.colony_info_id = i.id(+) and 
  m.id = b.mouse_id(+);

CREATE OR REPLACE FORCE VIEW MTL_MATING_CARD_VW
(CAGE_ID, CAGE_BARCODE, CAGE_LOCATION, PROJECT_LICENCE_NUMBER, PROTOCOL_19B, 
 OWNER, OWNER_PHONE_NUMBER, BREEDING_ID, DATE_PAIRED, NAME_PREFIX, 
 BREEDING_NUMBER, COLONY_NAME, COLONY_PREFIX)
AS 
select distinct 
  c.cage_id, 
  c.cage_barcode, 
  c.room_name||' Rack '||c.rack_name cage_location, 
  o.licence_number project_licence_number, 
  o.protocol_code protocol_19b, 
  p.first_name||' '||p.last_name owner, 
  p.phone_number owner_phone_number, 
  b.id breeding_id, 
  b.start_date date_paired, 
  b.name_prefix, 
  b.breeding_number, 
  i.colony_name, 
  i.colony_prefix 
from 
  mts_breeding b, 
  mts_mouse m, 
  mts_cage_vw c, 
  mts_colony_info i, 
  per_person p, 
  mts_mouse_current_19b_vw o 
where 
  b.female_id = m.id and 
  m.cage_id = c.cage_id and 
  m.current_owner_id = p.person_id(+) and 
  m.colony_info_id = i.id(+) and 
  m.id = o.mouse_id(+);

ALTER TABLE PHN_REQUIRED_OBSERVATION
ADD SECTION_TITLE VARCHAR2(500);

CREATE OR REPLACE VIEW PHN_EXPERIMENT_SET_VIEW  AS 
  select es.id, es.IS_COMPLETE, c.COHORT_NAME, sop.NAME as SOP_NAME, es.sop_id, es.cohort_id, es.PPL_ID, es.PIL_ID, es.CREATOR_ID,
perl.LAST_NAME || ', ' || perl.FIRST_NAME || ' (' || pil.PIL_NUMBER || ')' as PERSONAL_LICENCE,
ppl.LICENCE_NUMBER || ' ' || ppl.TITLE as PROJECT_LICENCE,
per.LAST_NAME || ', ' || per.FIRST_NAME  as CREATOR_NAME,
et.EXP_COUNT,
nvl(ec.COMP_EXP_COUNT, 0) as COMP_EXP_COUNT,
es.created_date
from PHN_EXPERIMENT_SET es
join (select experiment_set_id, count(id) as EXP_COUNT from PHN_EXPERIMENT group by experiment_set_id) et on es.id = et.experiment_set_id
left outer join (select experiment_set_id, count(id) as COMP_EXP_COUNT from PHN_EXPERIMENT where IS_COMPLETE = 1 group by experiment_set_id) ec on es.id = ec.experiment_set_id
join PHN_STD_OPERATING_PROCEDURE sop on es.SOP_ID = sop.ID
join MTS_COHORT c on es.COHORT_ID = c.ID
join LIC_PERSONAL_LICENCE pil on es.PIL_ID = pil.PERSONAL_LICENCE_ID
join LIC_PROJECT_LICENCE ppl on es.PPL_ID = ppl.PROJECT_LICENCE_ID
join PER_PERSON per on es.CREATOR_ID = per.PERSON_ID
join PER_PERSON perl on pil.PERSON_ID = perl.PERSON_ID;

INSERT INTO PHN_OBSERVATION_META_TYPE_DICT (ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE) VALUES (7,'Date',7,'Date, in the format dd-MMM-yyyy',1);
INSERT INTO PHN_OBSERVATION_META_TYPE_DICT (ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE) VALUES (8,'Clock Time',8,'Clock Time, in the format hh:mm',1);
INSERT INTO PHN_OBSERVATION_META_TYPE_DICT (ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE) VALUES (9,'Date & Time',9,'Date & Time, in the format dd-MMM-yyyy hh:mm',1);
