/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


ALTER TABLE CRQ_CRYO_REQUEST
 ADD (CANCEL_REASON  VARCHAR2(2000 BYTE));

CREATE OR REPLACE FORCE VIEW MTS_COLOUR_WITH_STRAIN_DICT_VW
(ID, NAME, DESCRIPTION, ORDER_BY, ACTIVE, 
 STRAIN_ID)
AS 
select 
  c.id, 
  c.name, 
  c.description, 
  c.order_by, 
  c.active, 
  s.strain_id 
from 
  mts_coat_colour_dict c, 
  mts_strain_coat_colour s 
where 
  c.id = s.coat_colour_id(+);

/* This object may not be sorted properly in the script due to cirular references */
CREATE OR REPLACE FORCE VIEW MTS_MOUSE_LOCATION_VW
(MOUSE_ID, CAGE_ID, CAGE_NAME, CAGE_BARCODE, RACK_ID, 
 RACK_NAME, RACK_BARCODE, ROOM_ID, ROOM_NAME, BREEDING_ID, 
 BREEDING_NAME, DEATH_DATE, CAUSE_OF_DEATH_DICT_ID, CAUSE_OF_DEATH)
AS 
select 
  m.id mouse_id, 
  c.cage_id, 
  c.cage_name, 
  c.cage_barcode, 
  c.rack_id, 
  c.rack_name, 
  c.rack_barcode, 
  c.room_id, 
  c.room_name, 
  b.breeding_id, 
  b.breeding_name, 
  m.death_date, 
  m.cause_of_death_dict_id, 
  d.name cause_of_death 
from 
  mts_mouse m, 
  mts_current_breeding_vw b, 
  mts_cage_vw c, 
  mts_cause_of_death_dict d 
where 
  m.id = b.mouse_id(+) and 
  m.cage_id = c.cage_id(+) and 
  m.cause_of_death_dict_id = d.id(+);

/* This object may not be sorted properly in the script due to cirular references */
CREATE OR REPLACE FORCE VIEW MTS_CURRENT_BREEDING_VW
(BREEDING_ID, BREEDING_NAME, MOUSE_ID)
AS 
select 
  b.id breeding_id, 
  b.name_prefix||b.breeding_number breeding_name, 
  b.female_id mouse_id 
from 
  mts_breeding b 
where 
  b.end_date is null 
union 
-- males (return only one breeding) 
select 
  b.id breeding_id, 
  b.name_prefix||b.breeding_number breeding_name, 
  b.male_id mouse_id 
from 
  mts_breeding b, 
  mts_mouse male 
where 
  b.end_date is null and 
  b.male_id = male.id and 
  b.id = (select b.id from mts_breeding b, mts_mouse female where b.male_id = male.id and b.female_id = female.id and male.cage_id = female.cage_id and rownum = 1);



/* This object may not be sorted properly in the script due to cirular references */
CREATE OR REPLACE FORCE VIEW MTS_MOUSE_VW
(ID, LITTER_ID, NAME, EDIT_DATE, COAT_COLOUR_DICT_ID, 
 COAT_COLOUR, EYE_COLOUR_DICT_ID, EYE_COLOUR, EARMARK_DICT_ID, EARMARK, 
 EARMARK_LEFT, EARMARK_RIGHT, BIRTH_DATE, AGE_IN_WEEKS, DEATH_DATE, 
 AGE_AT_DEATH, CAUSE_OF_DEATH_DICT_ID, CAUSE_OF_DEATH, EDITED_BY, WEAN_DATE, 
 CAGE_ID, CAGE_NAME, CAGE_BARCODE, RACK_ID, RACK_NAME, 
 ROOM_ID, ROOM_NAME, CURRENT_OWNER_ID, CURRENT_OWNER, CURRENT_PROJECT_LICENCE_ID, 
 CURRENT_PROJECT_LICENCE, CURRENT_PROTOCOL_ID, CURRENT_PROTOCOL_CODE, CHECK_NUMBER, GENDER_DICT_ID, 
 GENDER, MOUSE_STRAIN_DICT_ID, STRAIN, STATUS, CREATOR_ID, 
 CREATED_DATE, BARCODE, COMMENTS, IS_NON_BREEDER, IS_SENTINEL, 
 GENERATION, COLONY_NAME, COLONY_INFO_ID, ARRIVAL_DATE, LATEST_PLUG_DATE, 
 BREEDING_NAME)
AS 
select 
  m.id, 
  m.litter_id, 
  m.name, 
  m.edit_date, 
  m.coat_colour_dict_id, 
  c.name coat_colour, 
  m.eye_colour_dict_id, 
  e.name eye_colour, 
  m.earmark_dict_id, 
  ear.name earmark, 
  m.earmark_left, 
  m.earmark_right, 
  m.birth_date, 
  round((nvl(m.death_date,sysdate) - m.birth_date)/7,1) age_in_weeks, 
  m.death_date, 
  round((m.death_date - m.birth_date)/7,1) age_at_death, 
  m.cause_of_death_dict_id, 
  d.name cause_of_death, 
  m.edited_by, 
  m.wean_date, 
  m.cage_id, 
  l.cage_name, 
  l.cage_barcode, 
  l.rack_id, 
  l.rack_name, 
  l.room_id, 
  l.room_name, 
  m.current_owner_id, 
  owner.first_name||' '||owner.last_name current_owner, 
  b.project_licence_id current_project_licence_id, 
  b.licence_number current_project_licence, 
  b.protocol_id current_protocol_id, 
  b.protocol_code current_protocol_code, 
  m.check_number, 
  m.gender_dict_id, 
  s.name gender, 
  m.mouse_strain_dict_id, 
  t.name strain, 
  m.status, 
  m.creator_id, 
  m.created_date, 
  m.barcode, 
  m.comments, 
  m.is_non_breeder, 
  m.is_sentinel, 
  m.generation, 
  colony.colony_name, 
  m.colony_info_id, 
  m.arrival_date, 
  m.latest_plug_date, 
  breeding.breeding_name 
from 
  mts_mouse m, 
  mts_coat_colour_dict c, 
  mts_eye_colour_dict e, 
  mts_earmark_dict ear, 
  mts_cause_of_death_dict d, 
  per_person owner, 
  mts_gender_dict s, 
  mts_cage_vw l, 
  mts_mouse_current_19b_vw b, 
  typ_strain t, 
  mts_colony_info colony, 
  mts_current_breeding_vw breeding 
where 
  m.coat_colour_dict_id = c.id(+) and 
  m.eye_colour_dict_id = e.id(+) and 
  m.earmark_dict_id = ear.id(+) and 
  m.cause_of_death_dict_id = d.id(+) and 
  m.current_owner_id = owner.person_id(+) and 
  m.gender_dict_id = s.id(+) and 
  m.cage_id = l.cage_id(+) and 
  m.mouse_strain_dict_id = t.id(+) and 
  m.colony_info_id = colony.id(+) and 
  m.id = b.mouse_id(+) and 
  m.id = breeding.mouse_id(+);


			
CREATE OR REPLACE FORCE VIEW MIR_SCHEDULED_MI_LIST_VW
(ID, MICRO_INJECTION_REQUEST_ID, INTERNAL_STATUS_ID, INTERNAL_STATUS_NAME, ENDPOINT_ID, 
 ENDPOINT_NAME, TARGET_SCHEDULE_DATE, DONOR_ANIMAL_REQUEST_ID, RECIPIENT_ANIMAL_REQUEST_ID, SUPPLEMENTAL_RECIPIENT_REQ_ID, 
 JOB_ID, MICRO_INJECTION_ID, MI_ACTUAL_COMPLETION_DATE, ET_ACTUAL_COMPLETION_DATE, F0_ACTUAL_COMPLETION_DATE, 
 F1_ACTUAL_COMPLETION_DATE, DONOR_MOUSE_COUNT, RECIPIENT_MOUSE_COUNT, SUPPLEMENTAL_MOUSE_COUNT, REQUESTER_NAME, 
 CELL_LINE_PROVIDER_NAME_NO, CELL_LINE_NAME, CELL_LINE_CLONE)
AS 
SELECT smi.ID, smi.micro_injection_request_id, isd.ID internal_status_id,
       isd.NAME internal_status_name, med.ID endpoint_id,
       med.NAME endpoint_name, smi.target_schedule_date,
       smi.donor_animal_request_id, smi.recipient_animal_request_id,
       smi.supplemental_recipient_req_id, smi.job_id job_id,
       --et.id embryo_trasnfer_id,
       mi.id micro_injection_id,
       --mi.date_completed micro_injection_completed_date
       smt_mi.actual_completion_date mi_actual_completion_date,
       smt_et.actual_completion_date et_actual_completion_date,
       smt_f0.actual_completion_date f0_actual_completion_date,
       smt_f1.actual_completion_date f1_actual_completion_date,
       donor_req.num_females_needed donor_mouse_count,
       recip_req.num_females_needed recipient_mouse_count,
       0 supplemental_mouse_count,
       per_r.first_name || ' ' || per_r.last_name requester_name,
       DECODE (per_cl.phone_number,
               '', per_cl.first_name || ' ' || per_cl.last_name,
                  per_cl.first_name
               || ' '
               || per_cl.last_name
               || ' ('
               || per_cl.phone_number
               || ')'
              ) cell_line_provider_name_no,
       --mi.ID micro_injection_id, 
    cell_line.cell_line_name cell_line_name,
       cell_line.clone_name cell_line_clone
  FROM mir_scheduled_micro_injection smi,
       mir_internal_status_dict isd,
       mir_micro_injection_request mir,
       mir_cell_line cell_line,
       mir_target_endpoint_dict med,
       
       -- mir_micro_injection mi
       (SELECT smt.*
          FROM mir_scheduled_mi_task smt, mir_scheduled_micro_injection smi
         WHERE smi.ID = smt.scheduled_micro_injection_id(+)
               AND smt.NAME = 'Microinjection Completed') smt_mi,
       (SELECT smt.*
          FROM mir_scheduled_mi_task smt, mir_scheduled_micro_injection smi
         WHERE smi.ID = smt.scheduled_micro_injection_id(+)
               AND smt.NAME = 'Embryo Transfer Completed') smt_et,
       (SELECT smt.*
          FROM mir_scheduled_mi_task smt, mir_scheduled_micro_injection smi
         WHERE smi.ID = smt.scheduled_micro_injection_id(+)
               AND smt.NAME = 'F0s Weaned') smt_f0,
       (SELECT smt.*
          FROM mir_scheduled_mi_task smt, mir_scheduled_micro_injection smi
         WHERE smi.ID = smt.scheduled_micro_injection_id(+)
               AND smt.NAME = 'F1s Genotyped') smt_f1,
       per_person per_r,
       per_person per_cl,
       mir_micro_injection mi,
       req_animal_request donor_req,
       req_animal_request recip_req
 WHERE smi.internal_status_dict_id = isd.ID
   AND mir.ID = smi.micro_injection_request_id
   AND mir.endpoint_dict_id = med.ID
   AND smt_mi.scheduled_micro_injection_id(+) = smi.ID
   AND smt_et.scheduled_micro_injection_id(+) = smi.ID
   AND smt_f0.scheduled_micro_injection_id(+) = smi.ID
   AND smt_f1.scheduled_micro_injection_id(+) = smi.ID
   AND mir.requester_id = per_r.person_id
   AND smi.cell_line_provider_id = per_cl.person_id
   AND smi.ID = mi.scheduled_micro_injection_id(+)
   AND donor_req.ID(+) = smi.donor_animal_request_id
   AND recip_req.ID(+) = smi.recipient_animal_request_id
   AND mir.cell_line_id = cell_line.ID;

CREATE INDEX PHN_REQUIRED_OBS_SOP_IDX ON PHN_REQUIRED_OBSERVATION
(SOP_ID, ACTIVE)
LOGGING
NOPARALLEL;

CREATE INDEX PHN_EXPERIMENT_ESID_IDX ON PHN_EXPERIMENT
(EXPERIMENT_SET_ID)
LOGGING
NOPARALLEL;

CREATE INDEX PHN_OBSERVATION_EXPID_IDX ON PHN_OBSERVATION
(EXPERIMENT_ID)
LOGGING
NOPARALLEL;

--Cryo Old Status Mappings with New statuses

delete from crq_cryo_request_status_dict where name ='Awaiting Test Thaw';

insert into crq_cryo_request_status_dict(id, name, description, order_by, active)
	   values(17, 'Freezing in Process: Awaiting Test Thaw', '', 5,1);

delete from crq_cryo_request_status_dict where name ='Thaw Test Completed Awaiting Births';

insert into crq_cryo_request_status_dict(id, name, description, order_by, active)
	   values(18, 'Freezing Complete: Awaiting Test Thaw', '', 6,1);
	   

insert into crq_cryo_request_status_dict(id, name, description, order_by, active)
	   values(19, 'Freezing in Process: Awaiting Births','', 7,1);

insert into crq_cryo_request_status_dict(id, name, description, order_by, active)
	   values(20, 'Freezing Complete: Awaiting Births', '', 8,1);
	   
insert into crq_cryo_request_status_dict(id, name, description, order_by, active)
	   values(21, 'Freezing in Process: Thaw Complete : Awaiting Genotyping', '',9,1);
	   
insert into crq_cryo_request_status_dict(id, name, description, order_by, active)
	   values(22, 'Freezing Complete: Thaw Complete : Awaiting Genotyping', '',10,1);
	   
update crq_cryo_request_status_dict set order_by = '11' where name = 'Completed';
	   
update crq_cryo_request_status_dict set order_by = '12' where name = 'Cancelled';



update crq_cryo_request set status_dict_id = (select id from crq_cryo_request_status_dict where name = 'Freezing in Process: Awaiting Test Thaw') 
 where status_dict_id = (select id from crq_cryo_request_status_dict where name = 'Finished Awaiting Test Thaw(Legacy)');

delete from crq_cryo_request_status_dict where name ='Finished Awaiting Test Thaw(Legacy)';

update crq_cryo_request set status_dict_id = (select id from crq_cryo_request_status_dict where name = 'Freezing in Process: Awaiting Births') 
 where status_dict_id = (select id from crq_cryo_request_status_dict where name = 'Test Thawed Waiting for Births(Legacy)');

delete from crq_cryo_request_status_dict where name ='Test Thawed Waiting for Births(Legacy)';


delete from crq_cryo_request_status_dict where name ='Mice Received(Legacy)';
	   

update crq_cryo_request set status_dict_id = (select id from crq_cryo_request_status_dict where name = 'Requested') 
 where status_dict_id = (select id from crq_cryo_request_status_dict where name = 'Cryo Preservation Requested(Legacy)');

delete from crq_cryo_request_status_dict where name = 'Cryo Preservation Requested(Legacy)';
 
update crq_cryo_request set status_dict_id = (select id from crq_cryo_request_status_dict where name = 'Freezing In Process') 
 where status_dict_id = (select id from crq_cryo_request_status_dict where name = 'Freezing in Progress(Legacy)');

delete from crq_cryo_request_status_dict where name = 'Freezing in Progress(Legacy)';

 
update crq_cryo_request set status_dict_id = (select id from crq_cryo_request_status_dict where name = 'Completed') 
 where status_dict_id = (select id from crq_cryo_request_status_dict where name = 'Line Frozen(Legacy)');


delete from crq_cryo_request_status_dict where name = 'Line Frozen(Legacy)' ;


update crq_cryo_request set status_dict_id = (select id from crq_cryo_request_status_dict where name = 'Freezing in Process: Thaw Complete: Awaiting Genotyping') 
 where status_dict_id = (select id from crq_cryo_request_status_dict where name = 'Test Thawed Waiting for Genotyping(Legacy)');
 
delete from crq_cryo_request_status_dict where name = 'Test Thawed Waiting for Genotyping(Legacy)' ;

 
update crq_cryo_request c set status_dict_id = (select id from crq_cryo_request_status_dict where name = 'Cancelled') 
 where status_dict_id = (select id from crq_cryo_request_status_dict where name = 'Cancelled(Legacy)');
 
 
delete from crq_cryo_request_status_dict where name = 'Cancelled(Legacy)';

update crq_cryo_request set status_dict_id = (select id from crq_cryo_request_status_dict where name = 'Freezing in Process: Awaiting Births') 
 where status_dict_id = (select id from crq_cryo_request_status_dict where name = 'Test Thawed Waiting for Births(Legacy)');
 
 
delete from crq_cryo_request_status_dict where name = 'Test Thawed Waiting for Births(Legacy)';

commit;



