/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

DROP VIEW MTS_CURRENT_BREEDING;

CREATE SEQUENCE MTS_PREWEAN_DEATH_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE TABLE MTS_PREWEAN_DEATH_DICT
(
  ID           NUMBER,
  NAME         VARCHAR2(256 CHAR)               NOT NULL,
  ORDER_BY     INTEGER,
  DESCRIPTION  VARCHAR2(2048 CHAR),
  ACTIVE       NUMBER                           NOT NULL
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE UNIQUE INDEX MTS_PREWEAN_DEATH_DICT_PK ON MTS_PREWEAN_DEATH_DICT
(ID)
LOGGING
NOPARALLEL;

/* This object may not be sorted properly in the script due to cirular references */
CREATE TABLE MTS_PREWEAN_DEATH
(
  ID                      INTEGER,
  LITTER_ID               INTEGER,
  DEATH_DATE              DATE,
  NUMBER_MALE             INTEGER,
  NUMBER_FEMALE           INTEGER,
  NUMBER_MALE_CHIMERA     INTEGER,
  NUMBER_FEMALE_CHIMERA   INTEGER,
  COMMENTS                VARCHAR2(4000 BYTE),
  CAUSE_OF_DEATH_DICT_ID  INTEGER,
  CREATOR_ID              INTEGER,
  CREATED_DATE            DATE,
  EDITED_BY               VARCHAR2(128 BYTE),
  EDIT_DATE               DATE,
  CHECK_NUMBER            INTEGER,
  NUMBER_UNKNOWN          INTEGER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

/* This object may not be sorted properly in the script due to cirular references */
CREATE INDEX MTS_LITTER_IND3 ON MTS_LITTER
(BREEDING_ID)
LOGGING
NOPARALLEL;

/* This object may not be sorted properly in the script due to cirular references */
CREATE UNIQUE INDEX MTS_PREWEAN_DEATH_PK ON MTS_PREWEAN_DEATH
(ID)
LOGGING
NOPARALLEL;

/* This object may not be sorted properly in the script due to cirular references */
CREATE OR REPLACE FORCE VIEW MTS_MOUSE_VW
(ID, LITTER_ID, NAME, EDIT_DATE, COAT_COLOUR_DICT_ID, 
 COAT_COLOUR, EYE_COLOUR_DICT_ID, EYE_COLOUR, EARMARK_DICT_ID, EARMARK, 
 EARMARK_LEFT, EARMARK_RIGHT, BIRTH_DATE, AGE_IN_WEEKS, DEATH_DATE, 
 AGE_AT_DEATH, CAUSE_OF_DEATH_DICT_ID, CAUSE_OF_DEATH, EDITED_BY, WEAN_DATE, 
 CAGE_ID, CAGE_NAME, CAGE_BARCODE, RACK_ID, RACK_NAME, 
 ROOM_ID, ROOM_NAME, CURRENT_OWNER_ID, CURRENT_OWNER, CURRENT_PROJECT_LICENCE_ID, 
 CURRENT_PROJECT_LICENCE, CURRENT_PROTOCOL_ID, CURRENT_PROTOCOL_CODE, CHECK_NUMBER, GENDER_DICT_ID, 
 GENDER, MOUSE_STRAIN_DICT_ID, STRAIN, STATUS, CREATOR_ID, 
 CREATED_DATE, BARCODE, COMMENTS, IS_NON_BREEDER, IS_SENTINEL, 
 GENERATION, COLONY_NAME, COLONY_PREFIX, COLONY_INFO_ID, ARRIVAL_DATE, 
 LATEST_PLUG_DATE, BREEDING_NAME)
AS 
select 
  m.id, 
  m.litter_id, 
  m.name, 
  m.edit_date, 
  m.coat_colour_dict_id, 
  c.name coat_colour, 
  m.eye_colour_dict_id, 
  e.name eye_colour, 
  m.earmark_dict_id, 
  ear.name earmark, 
  m.earmark_left, 
  m.earmark_right, 
  m.birth_date, 
  round((nvl(m.death_date,sysdate) - m.birth_date)/7,1) age_in_weeks, 
  m.death_date, 
  round((m.death_date - m.birth_date)/7,1) age_at_death, 
  m.cause_of_death_dict_id, 
  d.name cause_of_death, 
  m.edited_by, 
  m.wean_date, 
  m.cage_id, 
  l.cage_name, 
  l.cage_barcode, 
  l.rack_id, 
  l.rack_name, 
  l.room_id, 
  l.room_name, 
  m.current_owner_id, 
  owner.first_name||' '||owner.last_name current_owner, 
  b.project_licence_id current_project_licence_id, 
  b.licence_number current_project_licence, 
  b.protocol_id current_protocol_id, 
  b.protocol_code current_protocol_code, 
  m.check_number, 
  m.gender_dict_id, 
  s.name gender, 
  m.mouse_strain_dict_id, 
  t.name strain, 
  m.status, 
  m.creator_id, 
  m.created_date, 
  m.barcode, 
  m.comments, 
  m.is_non_breeder, 
  m.is_sentinel, 
  m.generation, 
  colony.colony_name, 
  colony.colony_prefix, 
  m.colony_info_id, 
  m.arrival_date, 
  m.latest_plug_date, 
  breeding.breeding_name 
from 
  mts_mouse m, 
  mts_coat_colour_dict c, 
  mts_eye_colour_dict e, 
  mts_earmark_dict ear, 
  mts_cause_of_death_dict d, 
  per_person owner, 
  mts_gender_dict s, 
  mts_cage_vw l, 
  mts_mouse_current_19b_vw b, 
  typ_strain t, 
  mts_colony_info colony, 
  mts_current_breeding_vw breeding 
where 
  m.coat_colour_dict_id = c.id(+) and 
  m.eye_colour_dict_id = e.id(+) and 
  m.earmark_dict_id = ear.id(+) and 
  m.cause_of_death_dict_id = d.id(+) and 
  m.current_owner_id = owner.person_id(+) and 
  m.gender_dict_id = s.id(+) and 
  m.cage_id = l.cage_id(+) and 
  m.mouse_strain_dict_id = t.id(+) and 
  m.colony_info_id = colony.id(+) and 
  m.id = b.mouse_id(+) and 
  m.id = breeding.mouse_id(+);

ALTER TABLE MTS_PREWEAN_DEATH_DICT
 ADD CONSTRAINT MTS_PREWEAN_DEATH_DICT_PK
 PRIMARY KEY
 (ID);

ALTER TABLE MTS_PREWEAN_DEATH
 ADD CONSTRAINT MTS_PREWEAN_DEATH_PK
 PRIMARY KEY
 (ID);

ALTER TABLE MTS_PREWEAN_DEATH
 ADD CONSTRAINT MTS_PREWEAN_DEATH_R01 
 FOREIGN KEY (LITTER_ID) 
 REFERENCES MTS_LITTER (ID);

ALTER TABLE MTS_PREWEAN_DEATH
 ADD CONSTRAINT MTS_PREWEAN_DEATH_R02 
 FOREIGN KEY (CAUSE_OF_DEATH_DICT_ID) 
 REFERENCES MTS_PREWEAN_DEATH_DICT (ID);


INSERT INTO APP_COLUMN_PREFS ( ID, TABLE_NAME, COLUMN_NAME, COLUMN_TITLE, GETTER_METHOD, ORDER_BY,
DATATYPE ) VALUES ( 
30, 'mts_mouse_list_vw', 'colony_prefix', 'Colony Prefix', 'getColonyPrefix', 30, NULL); 

INSERT INTO MTS_PREWEAN_DEATH_DICT ( ID, NAME, ORDER_BY, DESCRIPTION,
ACTIVE ) VALUES ( 
1, 'Culled', NULL, 'Culled', 1); 
INSERT INTO MTS_PREWEAN_DEATH_DICT ( ID, NAME, ORDER_BY, DESCRIPTION,
ACTIVE ) VALUES ( 
2, 'Found Dead', NULL, 'Found Dead', 1); 
INSERT INTO MTS_PREWEAN_DEATH_DICT ( ID, NAME, ORDER_BY, DESCRIPTION,
ACTIVE ) VALUES ( 
3, 'Missing', NULL, 'Missing', 1); 
COMMIT;
