/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

connect mig_audit

alter table phn_std_operating_procedure
  add terminal_procedure number;

connect mig

CREATE OR REPLACE FUNCTION fetch_genotype(in_mouse_id number) RETURN varchar2 IS

cursor c_alleles is
select
  decode(m.genotype_dict_id, 
    1, '+/+', 
	2, a.short_allele_symbol||'/+', 
	3, a.short_allele_symbol||'/'||a.short_allele_symbol,
	4, a.short_allele_symbol||'-?') genotype
from
  mts_mouse_allele m,
  typ_modified_allele a
where
  m.mouse_id = in_mouse_id and
  m.allele_id = a.id;
  
v_genotype varchar2(4000) := '';

BEGIN

  for a in c_alleles loop
  	  v_genotype := v_genotype||a.genotype||' ';
  end loop;

  return trim(v_genotype);
END fetch_genotype;
/

CREATE OR REPLACE VIEW MTS_MOUSE_VW
AS 
select 
  m.id, 
  m.litter_id, 
  m.name, 
  m.edit_date, 
  m.coat_colour_dict_id, 
  c.name coat_colour, 
  m.eye_colour_dict_id, 
  e.name eye_colour, 
  m.earmark_dict_id, 
  ear.name earmark, 
  m.earmark_left, 
  m.earmark_right, 
  m.birth_date, 
  round((nvl(m.death_date,sysdate) - m.birth_date)/7,1) age_in_weeks, 
  m.death_date, 
  round((m.death_date - m.birth_date)/7,1) age_at_death, 
  m.cause_of_death_dict_id, 
  d.name cause_of_death, 
  m.edited_by, 
  m.wean_date, 
  m.cage_id, 
  l.cage_name, 
  l.cage_barcode, 
  l.rack_id, 
  l.rack_name, 
  l.room_id, 
  l.room_name, 
  m.current_owner_id, 
  owner.first_name||' '||owner.last_name current_owner, 
  b.project_licence_id current_project_licence_id, 
  b.licence_number current_project_licence, 
  b.protocol_id current_protocol_id, 
  b.protocol_code current_protocol_code, 
  m.check_number, 
  m.gender_dict_id, 
  s.name gender, 
  m.mouse_strain_dict_id, 
  t.name strain, 
  m.status, 
  m.creator_id, 
  m.created_date, 
  m.barcode, 
  m.comments, 
  m.is_non_breeder, 
  m.is_sentinel, 
  m.generation, 
  colony.colony_name, 
  colony.colony_prefix, 
  m.colony_info_id, 
  m.arrival_date, 
  m.latest_plug_date, 
  breeding.breeding_name,
  fetch_genotype(m.id) genotype
from 
  mts_mouse m, 
  mts_coat_colour_dict c, 
  mts_eye_colour_dict e, 
  mts_earmark_dict ear, 
  mts_cause_of_death_dict d, 
  per_person owner, 
  mts_gender_dict s, 
  mts_cage_vw l, 
  mts_mouse_current_19b_vw b, 
  typ_strain t, 
  mts_colony_info colony, 
  mts_current_breeding_vw breeding 
where 
  m.coat_colour_dict_id = c.id(+) and 
  m.eye_colour_dict_id = e.id(+) and 
  m.earmark_dict_id = ear.id(+) and 
  m.cause_of_death_dict_id = d.id(+) and 
  m.current_owner_id = owner.person_id(+) and 
  m.gender_dict_id = s.id(+) and 
  m.cage_id = l.cage_id(+) and 
  m.mouse_strain_dict_id = t.id(+) and 
  m.colony_info_id = colony.id(+) and 
  m.id = b.mouse_id(+) and 
  m.id = breeding.mouse_id(+)
/


INSERT INTO APP_COLUMN_PREFS ( ID, TABLE_NAME, COLUMN_NAME, COLUMN_TITLE, GETTER_METHOD, ORDER_BY,
DATATYPE ) VALUES ( 
31, 'mts_mouse_list_vw', 'genotype', 'Genotype', 'getGenotype', 31, NULL); 

alter table phn_std_operating_procedure
  add terminal_procedure number default 0 not null;
 
create or replace TRIGGER "MIG"."PHN_STD_OPERATING_PROCEDURE_TA" 
before update or delete on PHN_STD_OPERATING_PROCEDURE for each row
 
declare
audit_action varchar2(10);
begin
 
if deleting then audit_action := 'deleted'; end if;
if updating then audit_action := 'updated'; end if;
if deleting or updating then 
 insert into mig_audit.PHN_STD_OPERATING_PROCEDURE(
    ID,
    PROCEDURE_ID,
    NAME,
    ACTIVE,
    CREATED_DATE,
    CREATOR_ID,
    EDIT_DATE,
    EDITED_BY,
    CHECK_NUMBER,
    AUDIT_ACTION,
    TERMINAL_PROCEDURE)
 values (
    :old.ID,
    :old.PROCEDURE_ID,
    :old.NAME,
    :old.ACTIVE,
    :old.CREATED_DATE,
    :old.CREATOR_ID,
    :old.EDIT_DATE,
    :old.EDITED_BY,
    :old.CHECK_NUMBER,
    AUDIT_ACTION,
    :old.TERMINAL_PROCEDURE);
end if;
end;
/

CREATE OR REPLACE VIEW ARQ_HAVANA_REQ_HISTORICAL_VW
AS 
select 
  v.id, 
  v.allele_request_id, 
  v.status_dict_id, 
  d.name status, 
  v.created_by, 
  v.created_date, 
  v.edited_by, 
  v.edited_date, 
  v.comments, 
  v.vega_id, 
  v.updated_gene_name, 
  v.updated_chromosome_name, 
  v.start_not_found, 
  v.end_not_found, 
  v.critical_exon_id, 
  g.primary_name, 
  g.gene_build_gene_primary_name, 
  g.chromosome_name, 
  g.chromosome_start, 
  g.chromosome_end, 
  g.build_name, 
  g.build_version, 
  a.request_source_dict_id, 
  s.name source, 
  g.unique_exon_count, 
  g.total_exon_count, 
  a.requester_person_id, 
  a.SUBMIT_TO_QUEUE_DATE 
from 
  mig_audit.arq_havana_request v, 
  arq_allele_request a, 
  gnm_gene_vw g, 
  arq_havana_req_status_dict_vw d, 
  arq_allele_request_source_dict s 
where 
  a.id = v.allele_request_id and 
  a.gene_id = g.id and 
  a.request_source_dict_id =  s.id and 
  v.status_dict_id = d.id
/