connect mig_audit

ALTER TABLE MTS_COHORT
 ADD (END_DATE  DATE);

ALTER TABLE MTS_BREEDING
 ADD (OFFSPRING_GENERATION  VARCHAR2(5 BYTE));
 
connect mig
 
ALTER TABLE MTS_COHORT
 ADD (END_DATE  DATE);

ALTER TABLE MTS_BREEDING
 ADD (OFFSPRING_GENERATION  VARCHAR2(5 BYTE));
 
/* This object may not be sorted properly in the script due to cirular references */
CREATE OR REPLACE FORCE VIEW MTS_LATEST_BREEDING_VW
(BREEDING_ID, MOUSE_ID)
AS 
select 
  max(id) breeding_id, 
  b.female_id mouse_id 
  from mts_breeding b, 
 (select 
	max(start_date) max_start_date, 
	female_id 
  from 
	mts_breeding 
  group by 
	female_id 
  ) x 
where 
  b.female_id = x.female_id and 
  b.start_date = x.max_start_date 
group by b.female_id 
union 
select 
  max(id) breeding_id, 
  b.male_id mouse_id 
  from mts_breeding b, 
 (select 
	max(start_date) max_start_date, 
	male_id 
  from 
	mts_breeding 
  group by 
	male_id 
  ) x 
where 
  b.male_id = x.male_id and 
  b.start_date = x.max_start_date 
group by b.male_id; 

SHOW ERRORS;

/* This object may not be sorted properly in the script due to cirular references */
CREATE OR REPLACE FORCE VIEW MTS_CAGE_HEADER_VW
(CAGE_ID, CAGE_BARCODE, RACK_ID, RACK_NAME, RACK_BARCODE, 
 ROOM_ID, ROOM_NAME, OWNER_ID, OWNER_NAME, OWNER_PHONE_NUMBER, 
 OWNER_EMAIL, COLONY_INFO_ID, COLONY_NAME, COLONY_PREFIX, PROTOCOL_ID, 
 PROTOCOL_CODE, PROJECT_LICENCE_ID, LICENCE_NUMBER, PROCEDURE_DICT_ID, PROCEDURE, 
 PERSONAL_LICENCE_ID, PIL_NUMBER)
AS 
select distinct 
  c.cage_id, 
  c.cage_barcode, 
  c.rack_id, 
  c.rack_name, 
  c.rack_barcode, 
  c.room_id, 
  c.room_name, 
  o.person_id owner_id, 
  o.first_name||' '||o.last_name owner_name, 
  o.phone_number owner_phone_number, 
  o.email owner_email, 
  i.id colony_info_id, 
  i.colony_name, 
  i.colony_prefix, 
  b.protocol_id, 
  b.protocol_code, 
  b.project_licence_id, 
  b.licence_number, 
  b.procedure_dict_id, 
  b.procedure||' '||to_char(b.start_date,'DD-Mon-YYYY') procedure, 
  b.personal_licence_id, 
  b.pil_number 
from 
  mts_mouse m, 
  mts_cage_vw c, 
  per_person o, 
  mts_colony_info i, 
  mts_mouse_current_19b_vw b 
where 
  m.cage_id = c.cage_id and 
  m.current_owner_id = o.person_id and 
  m.colony_info_id = i.id(+) and 
  m.id = b.mouse_id(+) 
order by b.protocol_id;

/* This object may not be sorted properly in the script due to cirular references */
CREATE OR REPLACE FORCE VIEW MTS_COHORT_LIST_VW
(ID, COHORT_NAME, REASON, TOTAL_MICE, LIVE_MICE, 
 DEAD_MICE, FOREIGN_TABLE_NAME, FOREIGN_KEY_ID, CREATOR_ID, CREATED_DATE, 
 EDITED_BY, EDIT_DATE, CHECK_NUMBER, CREATOR_NAME, COHORT_TYPE_ID, 
 END_DATE)
AS 
select 
  c.id, 
  c.cohort_name, 
  c.reason, 
  l.total_mice, 
  l.live_mice, 
  l.dead_mice, 
  c.foreign_table_name, 
  c.foreign_key_id, 
  c.creator_id, 
  c.created_date, 
  c.edited_by, 
  c.edit_date, 
  c.check_number,
  p.last_name || ', ' || p.first_name as creator_name,
  c.cohort_type_id,
  c.end_date
from 
  mts_cohort c,
  per_person p,
  (select 
    l.cohort_id, 
    count(m.id) total_mice, 
 count(decode(m.death_date,null,1,null)) live_mice, 
 count(decode(m.death_date,null,null,1)) dead_mice 
   from 
    mts_mouse m, 
    mts_cohort_mouse l 
   where m.id = l.mouse_id 
   group by l.cohort_id) l 
where 
  c.id = l.cohort_id(+)
and c.creator_id = p.person_id;

CREATE TABLE TYP_ALLELE_SYNONYM
(
  ID              INTEGER,
  ALLELE_ID       INTEGER,
  ALLELE_SYNONYM  VARCHAR2(512 CHAR),
  CREATOR_ID      INTEGER,
  CREATED_DATE    DATE,
  EDITED_BY       VARCHAR2(128 CHAR),
  EDIT_DATE       DATE,
  CHECK_NUMBER    INTEGER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

ALTER TABLE TYP_ALLELE_SYNONYM
 ADD CONSTRAINT TYP_ALLELE_SYNONYM_R01 
 FOREIGN KEY (ALLELE_ID) 
 REFERENCES TYP_MODIFIED_ALLELE (ID);

ALTER TABLE TYP_ALLELE_SYNONYM
 ADD CONSTRAINT TYP_ALLELE_SYNONYM_PK
 PRIMARY KEY
 (ID);

ALTER TABLE MTS_COLONY_CONTACT
 ADD CONSTRAINT MTS_COLONY_CONTACT_FK1 
 FOREIGN KEY (COLONY_CONTACT_TYPE_DICT_ID) 
 REFERENCES MTS_COLONY_CONTACT_TYPE_DICT (ID);

/* This object may not be sorted properly in the script due to cirular references */
CREATE OR REPLACE FORCE VIEW MTL_EMBRYO_TRANSFER_CARD_VW
(CAGE_ID, MICRO_INJECTION_REQUEST_ID, CAGE_BARCODE, PROJECT_LICENCE_NUMBER, PROTOCOL_19B, 
 PIL_NUMBER, PIL_HOLDER, OWNER, OWNER_PHONE_NUMBER, OWNER_EMAIL, 
 WORKFLOW_PIPELINE_DICT_ID, PIPELINE, CELL_LINE_NAME, CLONE_NAME, CELL_LINE_STRAIN_DICT_ID, 
 CELL_LINE_STRAIN, TRANSFER_DATE, ENDPOINT_DICT_ID, ENDPOINT)
AS 
select distinct 
  c.id cage_id, 
  smi.micro_injection_request_id, 
  c.barcode cage_barcode, 
  ppl.licence_number project_licence_number, 
  p19b.protocol_code protocol_19b, 
  pil.pil_number, 
  p.first_name||' '||p.last_name pil_holder, 
  o.first_name||' '||o.last_name owner, 
  o.phone_number owner_phone_number, 
  o.email owner_email, 
  mir.workflow_pipeline_dict_id, 
  wrk.name pipeline, 
  cell.cell_line_name, 
  cell.clone_name, 
  cell.cell_line_strain_dict_id, 
  strain.name cell_line_strain, 
  smi.target_schedule_date transfer_date, 
  mir.endpoint_dict_id, 
  ten.name endpoint 
from 
  mts_mouse_procedure mp, 
  mir_embryo_transfer_procedure et, 
  mir_scheduled_micro_injection smi, 
  mir_micro_injection_request mir, 
  app_workflow_pipeline_dict wrk, 
  mir_target_endpoint_dict ten, 
  mir_cell_line cell, 
  mir_cell_line_strain_dict strain, 
  mts_breeding b, 
  mts_mouse m, 
  mts_cage c, 
  lic_project_licence ppl, 
  lic_protocol_19b p19b, 
  lic_personal_licence pil, 
  per_person p, 
  per_person o 
where 
  mp.foreign_table_name = 'MIR_EMBRYO_TRANSFER_PROCEDURE' and 
  mp.foreign_key_id = et.id and 
  et.scheduled_micro_injection_id = smi.id and 
  smi.micro_injection_request_id = mir.id and 
  b.embryo_transfer_id = et.id and 
  b.female_id = m.id and 
  m.cage_id = c.id and 
  mp.protocol_id = p19b.id and 
  p19b.project_licence_id = ppl.project_licence_id and 
  mp.personal_licence_id = pil.personal_licence_id and 
  pil.person_id = p.person_id and 
  m.current_owner_id = o.person_id and 
  mir.workflow_pipeline_dict_id = wrk.id and 
  mir.cell_line_id = cell.id and 
  mir.endpoint_dict_id = ten.id and 
  cell.cell_line_strain_dict_id = strain.id 
/

/* This object may not be sorted properly in the script due to cirular references */
CREATE OR REPLACE FORCE VIEW MTL_MATING_CARD_VW
(CAGE_ID, CAGE_BARCODE, CAGE_LOCATION, PROJECT_LICENCE_NUMBER, PROTOCOL_19B, 
 OWNER, OWNER_PHONE_NUMBER, OWNER_EMAIL, BREEDING_ID, DATE_PAIRED, 
 NAME_PREFIX, BREEDING_NUMBER, COLONY_NAME, COLONY_PREFIX)
AS 
select distinct 
  c.cage_id, 
  c.cage_barcode, 
  c.room_name||' Rack '||c.rack_name cage_location, 
  o.licence_number project_licence_number, 
  o.protocol_code protocol_19b, 
  p.first_name||' '||p.last_name owner, 
  p.phone_number owner_phone_number, 
  p.email owner_email, 
  b.id breeding_id, 
  b.start_date date_paired, 
  b.name_prefix, 
  b.breeding_number, 
  i.colony_name, 
  i.colony_prefix 
from 
  mts_breeding b, 
  mts_mouse m, 
  mts_cage_vw c, 
  mts_colony_info i, 
  per_person p, 
  mts_mouse_current_19b_vw o 
where 
  b.female_id = m.id and 
  m.cage_id = c.cage_id and 
  m.current_owner_id = p.person_id(+) and 
  b.offspring_colony_id = i.id and 
  m.id = o.mouse_id(+);

CREATE SEQUENCE TYP_ALLELE_SYNONYM_SEQ
  START WITH 41
  MAXVALUE 9999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE OR REPLACE FUNCTION       "ADDALLELESYNONYMS" (in_allele_id IN NUMBER) RETURN VARCHAR2
IS
alleleSynonymString VARCHAR2(2000);
BEGIN
FOR rowtarget IN(
 SELECT ALLELE_SYNONYM FROM TYP_ALLELE_SYNONYM WHERE ALLELE_ID = in_allele_id
)
LOOP  
alleleSynonymString := alleleSynonymString || rowTarget.ALLELE_SYNONYM || ', ';
END LOOP;
RETURN SUBSTR(alleleSynonymString, 1, LENGTH(alleleSynonymString)-2);
 END ADDALLELESYNONYMS;
/

CREATE OR REPLACE FORCE VIEW TYP_MODIFIED_ALLELE_LIST_VW
(ID, LOCUS_ID, MUTATION_NATURE_ID, MUTATION_NATURE, HTML_ALLELE_SYMBOL, 
 INTERNAL_NAME, OFFICIAL_NAME_SUPERSCRIPT, MULTI_GENE_REGION, IS_HOMOZYGOUS_LETHAL, INHERITANCE_MODE_ID, 
 INHERITANCE_MODE, HAS_ASSOCIATED_PHENOTYPE, PHENOTYPE_DESCRIPTION, MULTI_GENE_REGION_DESCRIP, ALLELE_DESCRIPTION, 
 SHORT_ALLELE_SYMBOL, CREATED_DATE, CREATOR_ID, CREATOR_NAME, GENE_ID, 
 GENE_NAME, ENSEMBL_ID, MULTIPLE_GENE_REGION_NAME, ALLELE_MAKER_ID, ALLELE_MAKER_NAME, 
 EDIT_DATE, EDITED_BY, CHECK_NUMBER, HARMFUL_MUTANT, MUTATION_CLASS_DICT_ID, 
 MUTATION_CLASS, EXTERNAL_MAKER_NAME, ALLELE_SYNONYMS)
AS 
select distinct
  m.id, 
  m.locus_id, 
  m.mutation_nature_id, 
  d2.name mutation_nature, 
  '<i>'||nvl(g.primary_name,'(no gene)')||'<sup><font size=''-1''>'||nvl(m.official_name_superscript,'(no allele)')||'</font></sup></i>' html_allele_symbol, 
  m.internal_name, 
  m.official_name_superscript, 
  m.multi_gene_region, 
  m.is_homozygous_lethal, 
  m.inheritance_mode_id, 
  d1.name inheritance_mode, 
  m.has_associated_phenotype, 
  m.phenotype_description, 
  m.multi_gene_region_descrip, 
  m.allele_description, 
  m.short_allele_symbol, 
  m.created_date, 
  m.creator_id, 
  c.first_name||' '||c.last_name creator_name, 
  m.gene_id, 
  g.primary_name gene_name, 
  g.ensembl_id, 
  m.multiple_gene_region_name, 
  m.allele_maker_id, 
  p.first_name||' '||p.last_name allele_maker_name, 
  m.edit_date, 
  m.edited_by, 
  m.check_number, 
  m.harmful_mutant, 
  m.mutation_class_dict_id, 
  d3.name mutation_class, 
  m.maker_name external_maker_name,
  addallelesynonyms(m.id) allele_synonyms
from 
  typ_modified_allele m, 
  (select 
    g.id gene_id, 
    g.primary_name, 
    b.primary_name ensembl_id 
  from 
    gnm_gene g, 
    gnm_gene_build_gene b 
  where 
    g.primary_ensembl_build_gene_id = b.id(+) 
  ) g, 
  typ_inheritance_mode_dict d1, 
  typ_mutation_nature_dict d2, 
  typ_mutation_class_dict d3, 
  per_person p, 
  per_person c, 
  typ_allele_synonym s
where 
  m.gene_id = g.gene_id(+) and 
  m.inheritance_mode_id = d1.id(+) and 
  m.mutation_nature_id = d2.id(+) and 
  m.mutation_class_dict_id = d3.id(+) and 
  m.allele_maker_id = p.person_id(+) and 
  m.creator_id = c.person_id(+) and
  m.id = s.allele_id(+);

CREATE OR REPLACE TRIGGER MIG.mts_cohort_ta
before update or delete on mts_cohort for each row
declare
audit_action varchar2(10);
begin

if deleting then audit_action := 'deleted'; end if;
if updating then audit_action := 'updated'; end if;
if deleting or updating then 
 insert into mig_audit.mts_cohort(
    ID,
    COHORT_NAME,
    COMMENTS,
    CHECK_NUMBER,
    CREATOR_ID,
    CREATED_DATE,
    EDITED_BY,
    EDIT_DATE,
    FOREIGN_TABLE_NAME,
    FOREIGN_KEY_ID,
    REASON,
    COHORT_TYPE_ID,
    END_DATE,
    AUDIT_ACTION)
 values (
    :old.ID,
    :old.COHORT_NAME,
    :old.COMMENTS,
    :old.CHECK_NUMBER,
    :old.CREATOR_ID,
    :old.CREATED_DATE,
    :old.EDITED_BY,
    :old.EDIT_DATE,
    :old.FOREIGN_TABLE_NAME,
    :old.FOREIGN_KEY_ID,
    :old.REASON,
    :old.COHORT_TYPE_ID,
    :old.END_DATE,
    AUDIT_ACTION);
end if;
end;
/

CREATE OR REPLACE FUNCTION "FETCH_GENOTYPE" (in_mouse_id number) RETURN varchar2 IS

cursor c_alleles is
select
  decode(m.genotype_dict_id, 
    1, '+/+', --wildtype
 	2, decode(a.inheritance_mode_id, -- heterozygous
	   		1,a.short_allele_symbol||'/+', -- dominant 
			3,a.short_allele_symbol||'/+', -- semi-dominant
			'+/'||a.short_allele_symbol),
 	3, a.short_allele_symbol||'/'||a.short_allele_symbol, --homozygous
 	4, a.short_allele_symbol||'-?') genotype -- unknown
from
  mts_mouse_allele m,
  typ_modified_allele a
where
  m.mouse_id = in_mouse_id and
  m.allele_id = a.id;
  
v_genotype varchar2(4000) := '';

BEGIN

  for a in c_alleles loop
    v_genotype := v_genotype||a.genotype||' ';
  end loop;
  
  return trim(nvl(v_genotype,'+/+'));

END fetch_genotype;
/

