connect mig_audit

ALTER TABLE HTL_BLOCK
 ADD (NAME  VARCHAR2(128 CHAR));


connect mig

ALTER TABLE HTL_BLOCK
 ADD (NAME  VARCHAR2(128 CHAR));


/* This object may not be sorted properly in the script due to cirular references */
CREATE OR REPLACE FORCE VIEW HTL_BLOCK_VW
(ID, MOUSE_ID, MOUSE_BARCODE, BLOCK_TYPE_ID, CREATOR_ID,
 BARCODE, COMMENTS, FIXATION_END_TIME, PROGRAM_DICT_ID, PROGRAM_START_TIME,
 BLOCK_TYPE_DESC, STANDARD_BLOCK, CASSETTE_TYPE_DICT_ID, BLOCK_TYPE_NAME, NAME)
AS
SELECT
    b.ID,
    n.MOUSE_ID,
    m.barcode mouse_barcode,
    b.BLOCK_TYPE_ID,
    b.CREATOR_ID,
    b.BARCODE,
    b.COMMENTS,
    b.FIXATION_END_TIME,
    b.PROGRAM_DICT_ID,
    b.PROGRAM_START_TIME,
    btv.FULL_DESCIPTION BLOCK_TYPE_DESC,
    btv.STANDARD_BLOCK,
    btv.CASSETTE_TYPE_DICT_ID,
    btv.NAME BLOCK_TYPE_name,
    b.name
FROM
    HTL_BLOCK b,
    HTL_BLOCK_TYPE_VW btv,
   htl_fixation f,
htl_necropsy n,
mts_mouse m
WHERE
    b.BLOCK_TYPE_ID = btv.ID and
    b.fixation_id = f.id and
   f.necropsy_id = n.id and
 n.mouse_id = m.id;

CREATE OR REPLACE TRIGGER HTL_BLOCK_ta
before update or delete on HTL_BLOCK for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
declare
audit_action varchar2(10);
begin

if deleting then audit_action := 'deleted'; end if;
if updating then audit_action := 'updated'; end if;
if deleting or updating then
 insert into mig_audit.HTL_BLOCK(
    ID,
    BLOCK_TYPE_ID,
    CREATOR_ID,
    CREATED_DATE,
    EDITED_BY,
    EDIT_DATE,
    CHECK_NUMBER,
    BARCODE,
    COMMENTS,
    FIXATION_END_TIME,
    PROGRAM_DICT_ID,
    PROGRAM_START_TIME,
    FIXATION_ID,
    NAME,
    AUDIT_ACTION)
 values (
    :old.ID,
    :old.BLOCK_TYPE_ID,
    :old.CREATOR_ID,
    :old.CREATED_DATE,
    :old.EDITED_BY,
    :old.EDIT_DATE,
    :old.CHECK_NUMBER,
    :old.BARCODE,
    :old.COMMENTS,
    :old.FIXATION_END_TIME,
    :old.PROGRAM_DICT_ID,
    :old.PROGRAM_START_TIME,
    :old.FIXATION_ID,
    :old.NAME,
    AUDIT_ACTION);
end if;
end;
/

CREATE MATERIALIZED VIEW MIR_SMI_POST_ET_STATUS_MV
NOCACHE
LOGGING
NOCOMPRESS
NOPARALLEL
BUILD IMMEDIATE
REFRESH FORCE
START WITH TO_DATE('15-Jan-2008','dd-mon-yyyy')
NEXT trunc(sysdate) + 1
WITH PRIMARY KEY
AS
select
  smi.id,
  decode(med.id,2,mir_f0_status(smi.id),1,mir_f0_status(smi.id),null) f0_status,
  decode(med.id,1,mir_f1_status(smi.id),null) f1_status
from
  mir_scheduled_micro_injection smi,
  mir_micro_injection_request mir,
  mir_target_endpoint_dict med
where mir.id = smi.micro_injection_request_id
   and mir.endpoint_dict_id = med.id;



CREATE OR REPLACE FORCE VIEW MIR_SCHEDULED_MI_LIST_VW
(ID, MICRO_INJECTION_REQUEST_ID, INTERNAL_STATUS_ID, INTERNAL_STATUS_NAME, ENDPOINT_ID,
 ENDPOINT_NAME, TARGET_SCHEDULE_DATE, DONOR_ANIMAL_REQUEST_ID, RECIPIENT_ANIMAL_REQUEST_ID, SUPPLEMENTAL_RECIPIENT_REQ_ID,
 JOB_ID, F0_STATUS, F1_STATUS, MICRO_INJECTION_ID, MI_ACTUAL_COMPLETION_DATE,
 ET_ACTUAL_COMPLETION_DATE, F0_ACTUAL_COMPLETION_DATE, F1_ACTUAL_COMPLETION_DATE, DONOR_MOUSE_COUNT, RECIPIENT_MOUSE_COUNT,
 SUPPLEMENTAL_MOUSE_COUNT, REQUESTER_NAME, CELL_LINE_PROVIDER_NAME_NO, CELL_LINE_NAME, CELL_LINE_CLONE)
AS
SELECT smi.ID, smi.micro_injection_request_id, isd.ID internal_status_id,
       isd.NAME internal_status_name, med.ID endpoint_id,
       med.NAME endpoint_name, smi.target_schedule_date,
       smi.donor_animal_request_id, smi.recipient_animal_request_id,
       smi.supplemental_recipient_req_id, smi.job_id job_id,

    mir_mv.f0_status f0_status,
    mir_mv.f1_status f1_status,

       mi.id micro_injection_id,
       --mi.date_completed micro_injection_completed_date
       smt_mi.actual_completion_date mi_actual_completion_date,
       smt_et.actual_completion_date et_actual_completion_date,
       smt_f0.actual_completion_date f0_actual_completion_date,
       smt_f1.actual_completion_date f1_actual_completion_date,
       donor_req.num_females_needed donor_mouse_count,
       recip_req.num_females_needed recipient_mouse_count,
       0 supplemental_mouse_count,
       per_r.first_name || ' ' || per_r.last_name requester_name,
       DECODE (per_cl.phone_number,
               '', per_cl.first_name || ' ' || per_cl.last_name,
                  per_cl.first_name
               || ' '
               || per_cl.last_name
               || ' ('
               || per_cl.phone_number
               || ')'
              ) cell_line_provider_name_no,
       --mi.ID micro_injection_id,
    cell_line.cell_line_name cell_line_name,
       cell_line.clone_name cell_line_clone
  FROM mir_scheduled_micro_injection smi,
       mir_internal_status_dict isd,
       mir_micro_injection_request mir,
       mir_cell_line cell_line,
       mir_target_endpoint_dict med,

       -- mir_micro_injection mi
       (SELECT smt.*
          FROM mir_scheduled_mi_task smt, mir_scheduled_micro_injection smi
         WHERE smi.ID = smt.scheduled_micro_injection_id(+)
               AND smt.NAME = 'Microinjection Completed') smt_mi,
       (SELECT smt.*
          FROM mir_scheduled_mi_task smt, mir_scheduled_micro_injection smi
         WHERE smi.ID = smt.scheduled_micro_injection_id(+)
               AND smt.NAME = 'Embryo Transfer Completed') smt_et,
       (SELECT smt.*
          FROM mir_scheduled_mi_task smt, mir_scheduled_micro_injection smi
         WHERE smi.ID = smt.scheduled_micro_injection_id(+)
               AND smt.NAME = 'F0s Weaned') smt_f0,
       (SELECT smt.*
          FROM mir_scheduled_mi_task smt, mir_scheduled_micro_injection smi
         WHERE smi.ID = smt.scheduled_micro_injection_id(+)
               AND smt.NAME = 'F1s Genotyped') smt_f1,
       per_person per_r,
       per_person per_cl,
       mir_micro_injection mi,
       req_animal_request donor_req,
       req_animal_request recip_req,
       mir_smi_post_et_status_mv mir_mv
 WHERE smi.internal_status_dict_id = isd.ID
   AND mir.ID = smi.micro_injection_request_id
   AND mir.endpoint_dict_id = med.ID
   AND smt_mi.scheduled_micro_injection_id(+) = smi.ID
   AND smt_et.scheduled_micro_injection_id(+) = smi.ID
   AND smt_f0.scheduled_micro_injection_id(+) = smi.ID
   AND smt_f1.scheduled_micro_injection_id(+) = smi.ID
   AND mir.requester_id = per_r.person_id
   AND smi.cell_line_provider_id = per_cl.person_id
   AND smi.ID = mi.scheduled_micro_injection_id(+)
   AND donor_req.ID(+) = smi.donor_animal_request_id
   AND recip_req.ID(+) = smi.recipient_animal_request_id
   AND mir.cell_line_id = cell_line.ID
   AND mir_mv.id(+) = smi.id;

-- retrofit names onto existing blocks
  update htl_block b set name = (select name from htl_block_type bt where bt.ID = b.BLOCK_TYPE_ID) where name is null;
