connect mig_audit

alter table mts_procedure_dict add (is_licenced number, is_terminal number);

ALTER TABLE MTS_LITTER DROP COLUMN NUMBER_MALE_BORN;

ALTER TABLE MTS_LITTER DROP COLUMN STATUS;

ALTER TABLE MTS_LITTER DROP COLUMN LITTER_SOURCE;

ALTER TABLE MTS_LITTER DROP COLUMN NUMBER_FEMALE_BORN;

ALTER TABLE MTS_LITTER DROP COLUMN NUMBER_DIED;

ALTER TABLE MTS_LITTER DROP COLUMN NUMBER_WEANED;

ALTER TABLE MTS_LITTER DROP COLUMN NUMBER_USED;

ALTER TABLE MTS_LITTER DROP COLUMN FOSTER_MOTHER_ID;

connect mig

alter table mts_procedure_dict add (is_licenced number, is_terminal number);

CREATE OR REPLACE PROCEDURE MTS_DELETE_MOUSE(IN_MOUSE_ID number) IS

BEGIN

	 delete mts_mouse_procedure where mouse_id = in_mouse_id;
	 
	 delete mts_chimeric_mouse_data where mouse_id = in_mouse_id;
	 
	 delete mts_mouse_cage_history where mouse_id = in_mouse_id;
	 
	 delete mts_mouse_allele where mouse_id = in_mouse_id;
	 
	 delete mts_mouse where id = in_mouse_id;

END MTS_DELETE_MOUSE;
/

SHOW ERRORS;

ALTER TABLE MTS_LITTER DROP COLUMN NUMBER_MALE_BORN;

ALTER TABLE MTS_LITTER DROP COLUMN STATUS;

ALTER TABLE MTS_LITTER DROP COLUMN LITTER_SOURCE;

ALTER TABLE MTS_LITTER DROP COLUMN NUMBER_FEMALE_BORN;

ALTER TABLE MTS_LITTER DROP COLUMN NUMBER_DIED;

ALTER TABLE MTS_LITTER DROP COLUMN NUMBER_WEANED;

ALTER TABLE MTS_LITTER DROP COLUMN NUMBER_USED;

ALTER TABLE MTS_LITTER DROP COLUMN FOSTER_MOTHER_ID;

ALTER TABLE MTS_PREWEAN_DEATH add (refactored varchar2(3));

CREATE OR REPLACE VIEW MTS_LITTER_LIST_VW
(ID, LITTER_NAME, OFFSPRING_COLONY_ID, FATHER_ID, FATHER_NAME, 
 MOTHER_ID, MOTHER_NAME, MICRO_INJECTION_REQUEST_ID, PLUG_DATE, BIRTH_DATE, 
 NOT_PREGNANT, NUMBER_PUPS, NUMBER_BORN, NUMBER_WEANED, NUMBER_WEANED_FEMALE, 
 NUMBER_WEANED_MALE, NUMBER_EMBRYOS, NUMBER_USED, COMMENTS)
AS 
select 
  l.id, 
  l.name_prefix||l.litter_number litter_name, 
  b.offspring_colony_id, 
  male.id father_id, 
  male.name father_name, 
  female.id mother_id, 
  female.name mother_name, 
  et.micro_injection_request_id, 
  l.plug_check_date plug_date, 
  l.birth_date, 
  l.not_pregnant, 
  count(pups.id) number_pups, 
  nvl(l.number_born,0) number_born,-- count(decode(pups.birth_date,null,null,1)) number_born, 
  count(decode(pups.wean_date,null,null,1)) number_weaned, 
  count(decode(pups.gender_dict_id,1,(decode(pups.wean_date,null,null,1)),null)) number_weaned_female, 
  count(decode(pups.gender_dict_id,2,(decode(pups.wean_date,null,null,1)),null)) number_weaned_male, 
  nvl(l.number_harvested,0) number_harvested,-- count(decode(pups.birth_date,null,(decode(pups.death_date,null,null,1)),null)) number_embryos, 
  count(decode(pups.wean_date,null,(decode(pups.death_date,null,null,1)),null)) number_used, 
  l.comments 
from 
  mts_litter l, 
  mts_breeding b, 
  mts_mouse male, 
  mts_mouse female, 
  mts_mouse pups, 
  (select et.id,smi.micro_injection_request_id 
   from 
     mir_embryo_transfer_procedure et, 
  mir_scheduled_micro_injection smi 
   where 
     et.scheduled_micro_injection_id = smi.id) et 
where 
  l.breeding_id = b.id and 
  b.male_id = male.id and 
  b.female_id = female.id and 
  pups.litter_id(+) = l.id and 
  b.embryo_transfer_id = et.id(+) 
group by 
  l.id, 
  l.name_prefix||l.litter_number, 
  b.offspring_colony_id, 
  male.id, 
  male.name, 
  female.id, 
  female.name, 
  et.micro_injection_request_id, 
  l.plug_check_date, 
  l.birth_date, 
  l.not_pregnant, 
  nvl(l.number_born,0),
  nvl(l.number_harvested,0),
  l.comments
/

CREATE OR REPLACE TRIGGER MTS_LITTER_TA 
before update or delete on MTS_LITTER for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
declare
audit_action varchar2(10);
begin

if deleting then audit_action := 'deleted'; end if;
if updating then audit_action := 'updated'; end if;
if deleting or updating then 
 insert into mig_audit.MTS_LITTER(
    ID,
    BREEDING_ID,
    BIRTH_DATE,
    CHECK_NUMBER,
    EDITED_BY,
    EDIT_DATE,
    CREATOR_ID,
    CREATED_DATE,
    PLUG_CHECK_DATE,
    NUMBER_BORN,
    COMMENTS,
    NUMBER_HARVESTED,
    DUE_DATE,
    LITTER_NUMBER,
	NOT_PREGNANT,
    NAME_PREFIX,
    AUDIT_ACTION)
 values (
    :old.ID,
    :old.BREEDING_ID,
    :old.BIRTH_DATE,
    :old.CHECK_NUMBER,
    :old.EDITED_BY,
    :old.EDIT_DATE,
    :old.CREATOR_ID,
    :old.CREATED_DATE,
    :old.PLUG_CHECK_DATE,
    :old.NUMBER_BORN,
    :old.COMMENTS,
    :old.NUMBER_HARVESTED,
    :old.DUE_DATE,
    :old.LITTER_NUMBER,
	:old.NOT_PREGNANT,
    :old.NAME_PREFIX,
    AUDIT_ACTION);
end if;
end;
/

CREATE OR REPLACE PROCEDURE temp_load_prewean_mouse(
	   in_litter_id in number,
	   in_fate in number,
	   in_fate_date in date,
	   in_gender in number,
	   in_colour in number,
	   in_chimerism in number
	   ) IS

cursor c_next_mouse_number is
select ascii(max(substr(name,length(name)))) last_mouse
from mts_mouse
where litter_id = in_litter_id
group by litter_id
;

cursor c_litter_data is
select *
from mts_litter
where id = in_litter_id
;

cursor c_breeding_data(in_breeding_id number) is
select *
from mts_breeding
where id = in_breeding_id
;

cursor c_next_mouse_id is
select mts_mouse_seq.nextval from dual
;

litter_data mts_litter%rowtype;

breeding_data mts_breeding%rowtype;

next_mouse_number number;

next_mouse_id number;
	   
begin
  
    open c_litter_data; 
	fetch c_litter_data into litter_data; 
	close c_litter_data;
	
	open c_breeding_data(litter_data.breeding_id); 
	fetch c_breeding_data into breeding_data; 
	close c_breeding_data;

	open c_next_mouse_number;
	fetch c_next_mouse_number into next_mouse_number;
	if c_next_mouse_number%NOTFOUND then
	  next_mouse_number := 96;
	end if;
	close c_next_mouse_number;
	
	open c_next_mouse_id;
	fetch c_next_mouse_id into next_mouse_id;
	close c_next_mouse_id;	
	
	 dbms_output.put_line('inserting mouse '||next_mouse_id||' '||litter_data.name_prefix||litter_data.litter_number||chr(1 + next_mouse_number));
	
	 insert into mts_mouse(
	 		id,
			name,
			birth_date,
			death_date,
			cause_of_death_dict_id,
			litter_id,
			gender_dict_id,
			creator_id,
			created_date,
			edited_by,
			edit_date,
			colony_info_id,
			comments)
	 values(
	 		next_mouse_id,
			litter_data.name_prefix||litter_data.litter_number||chr(1 + next_mouse_number),
			litter_data.birth_date,
			nvl(in_fate_date,litter_data.birth_date),			
			decode(in_fate,1,21,2,23,3,24),
			in_litter_id,
			in_gender,
			275,
			sysdate,
			'dg6',
			sysdate,
			breeding_data.offspring_colony_id,
			'Prewean Death Legacy Data.'||decode(in_chimerism,null,null,'? Percent Chimerism.') 			
	 );
	 
	 if in_chimerism is not null then
	 	insert into mts_chimeric_mouse_data(id,mouse_id,percent_chimeric)
		values(mts_chimeric_mouse_data_seq.nextval,next_mouse_id,in_chimerism);
	 end if;

end temp_load_prewean_mouse;
/


CREATE OR REPLACE PROCEDURE temp_load_prewean_deaths IS

cursor c_prewean_death_data is
select *
from mts_prewean_death
where refactored is null --and id = 894
for update of refactored
;

BEGIN

  for pdd in c_prewean_death_data loop
  -- males
  if pdd.number_male is not null then
    for i in 1..pdd.number_male loop
	  temp_load_prewean_mouse(
	    pdd.litter_id,
		pdd.cause_of_death_dict_id,
		pdd.death_date,
		2, --male
		null,
		null
	  );
	end loop;
  end if;
  
  -- male chimeras
  if pdd.number_male_chimera is not null then
    for i in 1..pdd.number_male_chimera loop
	  temp_load_prewean_mouse(
	    pdd.litter_id,
		pdd.cause_of_death_dict_id,
		pdd.death_date,
		2, --male
		null,
		0
	  );
	end loop;
  end if;
    
  -- females
  if pdd.number_female is not null then
    for i in 1..pdd.number_female loop
	  temp_load_prewean_mouse(
	    pdd.litter_id,
		pdd.cause_of_death_dict_id,
		pdd.death_date,
		1, --female
		null,
		null
	  );
	end loop;
  end if;  
  
  -- female chimeras
  if pdd.number_female_chimera is not null then
    for i in 1..pdd.number_female_chimera loop
	  temp_load_prewean_mouse(
	    pdd.litter_id,
		pdd.cause_of_death_dict_id,
		pdd.death_date,
		1, --female
		null,
		0
	  );
	end loop;
  end if;  
  
  -- unknowns
  if pdd.number_unknown is not null then
    for i in 1..pdd.number_unknown loop
	  temp_load_prewean_mouse(
	    pdd.litter_id,
		pdd.cause_of_death_dict_id,
		pdd.death_date,
		3, --unknown
		null,
		null
	  );
	end loop;
  end if;
  
  if pdd.comments is not null then
    update mts_litter set comments = pdd.comments
    where id = pdd.litter_id and comments is null;
  end if; 
  
  update mts_prewean_death set refactored = 'Yes' where current of c_prewean_death_data;
  
  end loop;
	 

END temp_load_prewean_deaths;
/

CREATE OR REPLACE FORCE VIEW PHN_EXPERIMENT_SET_VIEW AS 
  with
exp_total as (
    select experiment_set_id, count(id) as EXP_COUNT
    from PHN_EXPERIMENT group by experiment_set_id
),
exp_completed as (
    select experiment_set_id, count(id) as COMP_EXP_COUNT
    from PHN_EXPERIMENT where IS_COMPLETE = 1 group by experiment_set_id
),
work_start as (
    select pe.EXPERIMENT_SET_ID, min(mp.START_DATE) as PROCEDURE_DATE
    from MTS_MOUSE_PROCEDURE mp
    join PHN_EXPERIMENT pe on mp.FOREIGN_KEY_ID = pe.ID
    WHERE mp.FOREIGN_TABLE_NAME = 'PHN_EXPERIMENT'
    group by pe.EXPERIMENT_SET_ID
),
obs_count as (
    select e.EXPERIMENT_SET_ID, count(o.id) as obs_count
    from phn_experiment e
    join phn_observation o on e.id = o.EXPERIMENT_ID
    where LENGTH(o.value) > 0
    group by e.EXPERIMENT_SET_ID
)
select es.id, es.IS_COMPLETE, c.COHORT_NAME, sop.NAME as SOP_NAME, es.sop_id, es.cohort_id, es.PPL_ID, es.PIL_ID, es.CREATOR_ID, 
perl.LAST_NAME || ', ' || perl.FIRST_NAME || ' (' || pil.PIL_NUMBER || ')' as PERSONAL_LICENCE, 
ppl.LICENCE_NUMBER || ' ' || ppl.TITLE as PROJECT_LICENCE, 
per.LAST_NAME || ', ' || per.FIRST_NAME  as CREATOR_NAME, 
et.EXP_COUNT, 
nvl(ec.COMP_EXP_COUNT, 0) as COMP_EXP_COUNT,
nvl(ec.COMP_EXP_COUNT, 0) / et.EXP_COUNT as COMPLETION,
es.created_date, 
ws.PROCEDURE_DATE, 
sop.procedure_id,
oc.obs_count
from PHN_EXPERIMENT_SET es  
join PHN_STD_OPERATING_PROCEDURE sop on es.SOP_ID = sop.ID 
join MTS_COHORT c on es.COHORT_ID = c.ID 
join LIC_PERSONAL_LICENCE pil on es.PIL_ID = pil.PERSONAL_LICENCE_ID 
join LIC_PROJECT_LICENCE ppl on es.PPL_ID = ppl.PROJECT_LICENCE_ID 
join PER_PERSON per on es.CREATOR_ID = per.PERSON_ID 
join PER_PERSON perl on pil.PERSON_ID = perl.PERSON_ID 
left outer join work_start ws on ws.EXPERIMENT_SET_ID = es.ID
left outer join obs_count oc on oc.EXPERIMENT_SET_ID = es.id
join exp_total et on es.id = et.experiment_set_id 
left outer join exp_completed ec on es.id = ec.experiment_set_id;

CREATE OR REPLACE PROCEDURE PHN_DELETE_EXPERIMENT_SET (IN_SET_ID number) IS

BEGIN

  delete from MTS_MOUSE_PROCEDURE where id in (
    select mp.id from phn_experiment e
    join MTS_MOUSE_PROCEDURE mp on e.ID = mp.FOREIGN_KEY_ID and mp.FOREIGN_TABLE_NAME = 'PHN_EXPERIMENT'
    where e.EXPERIMENT_SET_ID = IN_SET_ID
  );
      
  delete from PHN_OBSERVATION where id in (
    select o.id from PHN_EXPERIMENT e
    join PHN_OBSERVATION o on e.ID = o.EXPERIMENT_ID
    where e.EXPERIMENT_SET_ID = IN_SET_ID
  );
  
  delete from PHN_EXPERIMENT where EXPERIMENT_SET_ID = IN_SET_ID;
  
  delete from PHN_EXPERIMENT_SET where id = IN_SET_ID;

END;
/


update mts_breeding set offspring_generation = 'F0' where offspring_generation is null and embryo_transfer_id is not null;

update mts_breeding set offspring_generation = 'F1' where offspring_generation is null and male_id in (
select id from mts_mouse where generation='F0');

update mts_procedure_dict set is_licenced = 1, is_terminal = 0;

update mts_procedure_dict set is_licenced = 0 where id = 18; --earclip for ID

update mts_procedure_dict set is_terminal = 1 where id in (1,22,23,33);

update mts_litter set number_harvested = null where number_harvested = 0;

commit;

begin
temp_load_prewean_deaths;
end;
/

commit;