connect mig_aduit;

CREATE TABLE APP_PRINTER
(
  PRINTER_MODEL  VARCHAR2(4000 CHAR),
  ID             NUMBER,
  LOADED_MEDIA   VARCHAR2(4000 CHAR),
  SYS_NAME       VARCHAR2(4000 CHAR),
  ROOM_ID        NUMBER,
  DESCRIPTION    VARCHAR2(128 CHAR),
  CORRIDOR       VARCHAR2(30 BYTE),
  ACTIVE         NUMBER(1),
  CREATED_DATE   DATE                           DEFAULT sysdate,
  CREATOR_ID     NUMBER,
  EDITED_BY      VARCHAR2(12 BYTE),
  EDIT_DATE      DATE,
  CHECK_NUMBER   NUMBER,
  AUDIT_ACTION     VARCHAR2(10 BYTE)
)

TABLESPACE MIG_AUDIT
PCTUSED    0
PCTFREE    10
INITRANS   1
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            BUFFER_POOL      DEFAULT
           )
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;


GRANT INSERT ON  APP_PRINTER TO MIG;

ALTER TABLE CRQ_THAW_TEST DROP COLUMN IS_COMPLETED;
ALTER TABLE MIR_EMBRYO_TRANSFER_PROCEDURE
ADD (THAW_TEST_ID  NUMBER);

DROP TABLE CRQ_THAW_TEST;

CREATE TABLE CRQ_THAW_TEST
(
  ID              INTEGER,
  CRQ_REQUEST_ID  INTEGER,
  CREATOR_ID      INTEGER,
  CREATED_DATE    DATE,
  EDITED_BY       VARCHAR2(128 CHAR),
  EDIT_DATE       DATE,
  CHECK_NUMBER    NUMBER,
  COMMENTS        VARCHAR2(4000 BYTE),
  COMPLETE_DATE   DATE,
  AUDIT_TIMESTAMP  TIMESTAMP(6)                 DEFAULT systimestamp,
  OS_USER          VARCHAR2(30 BYTE)            DEFAULT sys_context('USERENV','OS_USER'),
  AUDIT_ACTION     VARCHAR2(10 BYTE)
)
TABLESPACE MIG_AUDIT
PCTUSED    0
PCTFREE    10
INITRANS   1
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            BUFFER_POOL      DEFAULT
           )
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;


GRANT INSERT ON  CRQ_THAW_TEST TO MIG;


connect mig;

ALTER TABLE MIG.APP_PRINTER
 ADD (creator_id  NUMBER);

ALTER TABLE MIG.APP_PRINTER
 ADD (created_date  DATE);

ALTER TABLE MIG.APP_PRINTER
 ADD (edited_by  VARCHAR2(12));

ALTER TABLE MIG.APP_PRINTER
 ADD (edit_date  DATE);

ALTER TABLE MIG.APP_PRINTER
 ADD (check_number  NUMBER);

ALTER TABLE APP_PRINTER ADD (
  CONSTRAINT APP_PRINTER_R01
 FOREIGN KEY (CREATOR_ID)
 REFERENCES PER_PERSON (PERSON_ID));

ALTER TABLE CRQ_THAW_TEST DROP COLUMN IS_COMPLETED;

ALTER TABLE MIR_EMBRYO_TRANSFER_PROCEDURE
 ADD (THAW_TEST_ID  NUMBER);

ALTER TABLE MIR_EMBRYO_TRANSFER_PROCEDURE
 ADD FOREIGN KEY (THAW_TEST_ID) 
 REFERENCES CRQ_THAW_TEST (ID);

ALTER TABLE MIR_EMBRYO_TRANSFER_PROCEDURE
MODIFY(SCHEDULED_MICRO_INJECTION_ID  NULL);


create or replace trigger CRQ_THAW_TEST_ta
before update or delete on CRQ_THAW_TEST for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */

declare
audit_action varchar2(10);
begin

if deleting then audit_action := 'deleted'; end if;
if updating then audit_action := 'updated'; end if;
if deleting or updating then 
 insert into mig_audit.CRQ_THAW_TEST(
    ID,
    CRQ_REQUEST_ID,
    CREATOR_ID,
    CREATED_DATE,
    EDITED_BY,
    EDIT_DATE,
    CHECK_NUMBER,
    COMMENTS,
    COMPLETE_DATE,
    AUDIT_ACTION)
 values (
    :old.ID,
    :old.CRQ_REQUEST_ID,
    :old.CREATOR_ID,
    :old.CREATED_DATE,
    :old.EDITED_BY,
    :old.EDIT_DATE,
    :old.CHECK_NUMBER,
    :old.COMMENTS,
    :old.COMPLETE_DATE,
    AUDIT_ACTION);
end if;
end;
/

create or replace trigger mir_embryo_transfer_procedu_ta
before update or delete on mir_embryo_transfer_procedure for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */

declare
audit_action varchar2(10);
begin

if deleting then audit_action := 'deleted'; end if;
if updating then audit_action := 'updated'; end if;
if deleting or updating then 
 insert into mig_audit.mir_embryo_transfer_procedure(
    ID,
    CREATED_DATE,
    EDITED_BY,
    EDIT_DATE,
    CHECK_NUMBER,
    MOUSE_WEIGHT,
    NUMBER_RIGHT,
    NUMBER_LEFT,
    ANAESTHETIC_DICT_ID,
    DOSE_ANESTHETIC,
    ANALGESIA_DICT_ID,
    DOSE_ANALGESIA,
    TRANSFER_TYPE_DICT_ID,
    STUFFER_STRAIN_ID,
    NUMBER_RIGHT_STUFFERS,
    NUMBER_LEFT_STUFFERS,
    CREATOR_ID,
    COMMENTS,
    SCHEDULED_MICRO_INJECTION_ID,
    MOUSE_ID,
    DAYS_FROM_PLUG,
    THAW_TEST_ID,
    AUDIT_ACTION)
 values (
    :old.ID,
    :old.CREATED_DATE,
    :old.EDITED_BY,
    :old.EDIT_DATE,
    :old.CHECK_NUMBER,
    :old.MOUSE_WEIGHT,
    :old.NUMBER_RIGHT,
    :old.NUMBER_LEFT,
    :old.ANAESTHETIC_DICT_ID,
    :old.DOSE_ANESTHETIC,
    :old.ANALGESIA_DICT_ID,
    :old.DOSE_ANALGESIA,
    :old.TRANSFER_TYPE_DICT_ID,
    :old.STUFFER_STRAIN_ID,
    :old.NUMBER_RIGHT_STUFFERS,
    :old.NUMBER_LEFT_STUFFERS,
    :old.CREATOR_ID,
    :old.COMMENTS,
    :old.SCHEDULED_MICRO_INJECTION_ID,
    :old.MOUSE_ID,
    :old.DAYS_FROM_PLUG,
    :old.THAW_TEST_ID,
    AUDIT_ACTION);
end if;
end;
/

CREATE OR REPLACE VIEW MTS_LITTER_LIST_VW
AS 
select 
  l.id, 
  b.name_prefix breeding_name_prefix,
  b.breeding_number,
  l.litter_number,
  l.name_prefix||l.litter_number litter_name, 
  b.offspring_colony_id, 
  male.id father_id, 
  male.name father_name, 
  female.id mother_id, 
  female.name mother_name, 
  et.micro_injection_request_id, 
  l.plug_check_date plug_date, 
  l.birth_date, 
  l.not_pregnant, 
  count(pups.id) number_pups, 
  nvl(l.number_born,0) number_born,-- count(decode(pups.birth_date,null,null,1)) number_born, 
  count(decode(pups.wean_date,null,null,1)) number_weaned, 
  count(decode(pups.gender_dict_id,1,(decode(pups.wean_date,null,null,1)),null)) number_weaned_female, 
  count(decode(pups.gender_dict_id,2,(decode(pups.wean_date,null,null,1)),null)) number_weaned_male, 
  nvl(l.number_harvested,0) number_embryos,-- count(decode(pups.birth_date,null,(decode(pups.death_date,null,null,1)),null)) number_embryos, 
  count(decode(pups.wean_date,null,(decode(pups.death_date,null,null,1)),null)) number_used, 
  l.comments 
from 
  mts_litter l, 
  mts_breeding b, 
  mts_mouse male, 
  mts_mouse female, 
  mts_mouse pups, 
  (select et.id,smi.micro_injection_request_id 
   from 
     mir_embryo_transfer_procedure et, 
  mir_scheduled_micro_injection smi 
   where 
     et.scheduled_micro_injection_id = smi.id) et 
where 
  l.breeding_id = b.id and 
  b.male_id = male.id and 
  b.female_id = female.id and 
  pups.litter_id(+) = l.id and 
  b.embryo_transfer_id = et.id(+) 
group by 
  l.id,  
  b.name_prefix,
  b.breeding_number,
  l.litter_number,
  l.name_prefix||l.litter_number, 
  b.offspring_colony_id, 
  male.id, 
  male.name, 
  female.id, 
  female.name, 
  et.micro_injection_request_id, 
  l.plug_check_date, 
  l.birth_date, 
  l.not_pregnant, 
  nvl(l.number_born,0), 
  nvl(l.number_harvested,0), 
  l.comments
/

CREATE OR REPLACE FUNCTION "MTS_NEXT_BREEDING_NUMBERS" (in_colony_id number) return integer_list IS

output_list integer_list := integer_list();

cursor c_colony_exists is
select count(*) 
from mts_colony_info
where id = in_colony_id;

cursor c_last_breeding_number is
select max(breeding_number) max_number
from mts_breeding
where offspring_colony_id = in_colony_id;

cursor c_breeding_number_used(in_number number) is
select count(*) in_use
from mts_breeding
where offspring_colony_id = in_colony_id
and breeding_number = in_number;

cursor c_breeding_number_offset is
select offset
from mts_breeding_offset
where colony_info_id = in_colony_id;

n_colony_exists number;

n_last_breeding_number number;

n_breeding_number_used number;

n_breeding_number_offset number;

n_index number := 1;

BEGIN
     if in_colony_id is null then return null; 
	 end if;
	 
	 open c_colony_exists;
	 fetch c_colony_exists into n_colony_exists;
	 close c_colony_exists;
	 if n_colony_exists = 0 then return null;
	 end if;

	 open c_last_breeding_number;
	 fetch c_last_breeding_number into n_last_breeding_number;
	 close c_last_breeding_number;
	 
	 if n_last_breeding_number is null then
	   n_last_breeding_number := 1;
	 end if;
	 
	 if n_last_breeding_number = 1 then
	   open c_breeding_number_offset;
	   fetch  c_breeding_number_offset into n_breeding_number_offset;
	   close c_breeding_number_offset;
	 end if;
	 
	 if n_breeding_number_offset is not null then
	   n_last_breeding_number := n_breeding_number_offset + n_last_breeding_number;
	 else 
	   n_breeding_number_offset := 1;
	 end if;

	 for n in n_breeding_number_offset .. (n_last_breeding_number + 100) loop
	 	 open c_breeding_number_used(n);
		 fetch c_breeding_number_used into n_breeding_number_used;
		 close c_breeding_number_used;
		 if n_breeding_number_used = 0 then
		   output_list.extend;
		   output_list(n_index) := n;
		   n_index := n_index + 1;
		 end if;	 	 
	 end loop;
	 
	 return output_list;
END mts_next_breeding_numbers;

create or replace trigger APP_PRINTER_ta
before update or delete on APP_PRINTER for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */

declare
audit_action varchar2(10);
begin

if deleting then audit_action := 'deleted'; end if;
if updating then audit_action := 'updated'; end if;
if deleting or updating then 
 insert into mig_audit.APP_PRINTER(
    PRINTER_MODEL,
    ID,
    LOADED_MEDIA,
    SYS_NAME,
    ROOM_ID,
    DESCRIPTION,
    CORRIDOR,
    ACTIVE,
    CREATOR_ID,
    CREATED_DATE,
    EDITED_BY,
    EDIT_DATE,
    CHECK_NUMBER,
    AUDIT_ACTION)
 values (
    :old.PRINTER_MODEL,
    :old.ID,
    :old.LOADED_MEDIA,
    :old.SYS_NAME,
    :old.ROOM_ID,
    :old.DESCRIPTION,
    :old.CORRIDOR,
    :old.ACTIVE,
    :old.CREATOR_ID,
    :old.CREATED_DATE,
    :old.EDITED_BY,
    :old.EDIT_DATE,
    :old.CHECK_NUMBER,
    AUDIT_ACTION);
end if;
end;
/
