connect mig_audit

alter table mts_breeding drop column status;

alter table mts_breeding add (timed_mating number(1), timed_mating_embryo_age number);

alter table phn_experiment_set add scheduled_date date;

connect mig

-- in MIG
alter table phn_experiment_set add scheduled_date date;

create or replace trigger PHN_EXPERIMENT_SET_ta
before update or delete on PHN_EXPERIMENT_SET for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */

declare
audit_action varchar2(10);
begin

if deleting then audit_action := 'deleted'; end if;
if updating then audit_action := 'updated'; end if;
if deleting or updating then 
 insert into mig_audit.PHN_EXPERIMENT_SET(
    ID,
    COHORT_ID,
    IS_COMPLETE,
    CREATED_DATE,
    CREATOR_ID,
    EDIT_DATE,
    EDITED_BY,
    CHECK_NUMBER,
    SOP_ID,
    PPL_ID,
    PIL_ID,
    SCHEDULED_DATE,
    AUDIT_ACTION)
 values (
    :old.ID,
    :old.COHORT_ID,
    :old.IS_COMPLETE,
    :old.CREATED_DATE,
    :old.CREATOR_ID,
    :old.EDIT_DATE,
    :old.EDITED_BY,
    :old.CHECK_NUMBER,
    :old.SOP_ID,
    :old.PPL_ID,
    :old.PIL_ID,
    :old.SCHEDULED_DATE,
    AUDIT_ACTION);
end if;
end;
/

CREATE OR REPLACE FORCE VIEW PHN_EXPERIMENT_SET_VIEW AS 
  with
exp_total as (
    select experiment_set_id, count(id) as EXP_COUNT
    from PHN_EXPERIMENT group by experiment_set_id
),
exp_completed as (
    select experiment_set_id, count(id) as COMP_EXP_COUNT
    from PHN_EXPERIMENT where IS_COMPLETE = 1 group by experiment_set_id
),
work_start as (
    select pe.EXPERIMENT_SET_ID, min(mp.START_DATE) as PROCEDURE_DATE
    from MTS_MOUSE_PROCEDURE mp
    join PHN_EXPERIMENT pe on mp.FOREIGN_KEY_ID = pe.ID
    WHERE mp.FOREIGN_TABLE_NAME = 'PHN_EXPERIMENT'
    group by pe.EXPERIMENT_SET_ID
),
obs_count as (
    select e.EXPERIMENT_SET_ID, count(o.id) as obs_count
    from phn_experiment e
    join phn_observation o on e.id = o.EXPERIMENT_ID
    where LENGTH(o.value) > 0
    group by e.EXPERIMENT_SET_ID
)
select es.id, es.IS_COMPLETE, c.COHORT_NAME, sop.NAME as SOP_NAME, es.sop_id, es.cohort_id, es.PPL_ID, es.PIL_ID, es.CREATOR_ID, 
perl.LAST_NAME || ', ' || perl.FIRST_NAME || ' (' || pil.PIL_NUMBER || ')' as PERSONAL_LICENCE, 
ppl.LICENCE_NUMBER || ' ' || ppl.TITLE as PROJECT_LICENCE, 
per.LAST_NAME || ', ' || per.FIRST_NAME  as CREATOR_NAME, 
nvl(et.EXP_COUNT,0) as EXP_COUNT, 
nvl(ec.COMP_EXP_COUNT, 0) as COMP_EXP_COUNT,
nvl(ec.COMP_EXP_COUNT, 0) / et.EXP_COUNT as COMPLETION,
es.created_date, 
ws.PROCEDURE_DATE, 
sop.procedure_id,
oc.obs_count,
es.scheduled_date
from PHN_EXPERIMENT_SET es  
join PHN_STD_OPERATING_PROCEDURE sop on es.SOP_ID = sop.ID 
join MTS_COHORT c on es.COHORT_ID = c.ID 
join LIC_PERSONAL_LICENCE pil on es.PIL_ID = pil.PERSONAL_LICENCE_ID 
join LIC_PROJECT_LICENCE ppl on es.PPL_ID = ppl.PROJECT_LICENCE_ID 
join PER_PERSON per on es.CREATOR_ID = per.PERSON_ID 
join PER_PERSON perl on pil.PERSON_ID = perl.PERSON_ID 
left outer join work_start ws on ws.EXPERIMENT_SET_ID = es.ID
left outer join obs_count oc on oc.EXPERIMENT_SET_ID = es.id
left outer join exp_total et on es.id = et.experiment_set_id 
left outer join exp_completed ec on es.id = ec.experiment_set_id;
 
alter table mts_breeding drop column status;

alter table mts_breeding add (timed_mating number(1), timed_mating_embryo_age number);

CREATE OR REPLACE TRIGGER MTS_BREEDING_TA
before update or delete on MTS_BREEDING for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
declare
audit_action varchar2(10);
begin

if deleting then audit_action := 'deleted'; end if;
if updating then audit_action := 'updated'; end if;
if deleting or updating then
 insert into mig_audit.MTS_BREEDING(
    ID,
    START_DATE,
    END_DATE,
    CHECK_NUMBER,
    EDITED_BY,
    EDIT_DATE,
    COMMENTS,
    CREATOR_ID,
    CREATED_DATE,
    MALE_ID,
    FEMALE_ID,
    OFFSPRING_COLONY_ID,
    PSEUDO_BREEDING,
    EMBRYO_TRANSFER_ID,
    NAME_PREFIX,
    BREEDING_NUMBER,
	TIMED_MATING,
	TIMED_MATING_EMBRYO_AGE,
    AUDIT_ACTION)
 values (
    :old.ID,
    :old.START_DATE,
    :old.END_DATE,
    :old.CHECK_NUMBER,
    :old.EDITED_BY,
    :old.EDIT_DATE,
    :old.COMMENTS,
    :old.CREATOR_ID,
    :old.CREATED_DATE,
    :old.MALE_ID,
    :old.FEMALE_ID,
    :old.OFFSPRING_COLONY_ID,
    :old.PSEUDO_BREEDING,
    :old.EMBRYO_TRANSFER_ID,
    :old.NAME_PREFIX,
    :old.BREEDING_NUMBER,
	:old.TIMED_MATING,
	:old.TIMED_MATING_EMBRYO_AGE,
    AUDIT_ACTION);
end if;
end;
/

create or replace view mts_breeding_timed_harvest_vw as
select
  b.id breeding_id,
  l.id litter_id,
  b.timed_mating_embryo_age,
  l.plug_check_date,
  l.plug_check_date + (b.timed_mating_embryo_age + 0.5) timed_harvest_date
from
  mts_breeding b,
  mts_litter l,
  (select
    breeding_id,
	max(litter_number) litter_number
   from mts_litter
   group by breeding_id) m
where
  b.id = l.breeding_id and
  l.litter_number = m.litter_number and
  b.id = m.breeding_id and b.timed_mating = 1;

create or replace function fetch_genotype (in_mouse_id number) return varchar2 is

cursor c_alleles is
select
  decode(c.percent_chimeric,
  null,
	  decode(m.genotype_dict_id,
	    1, '+/+', --wildtype
	 	2, decode(a.inheritance_mode_id, -- heterozygous
		   		1,a.short_allele_symbol||'/+', -- dominant
				3,a.short_allele_symbol||'/+', -- semi-dominant
				'+/'||a.short_allele_symbol),
	 	3, a.short_allele_symbol||'/'||a.short_allele_symbol, --homozygous
	 	4, a.short_allele_symbol||'-?'),
   0, '+/+', -- zero percent chimera
   c.percent_chimeric||'% '||a.short_allele_symbol --chimera
  ) genotype -- unknown
from
  mts_mouse_allele m,
  typ_modified_allele a,
  mts_chimeric_mouse_data c
where
  m.mouse_id = in_mouse_id and
  m.allele_id = a.id and
  m.mouse_id = c.mouse_id(+);

v_genotype varchar2(4000) := '';

begin

  for a in c_alleles loop
    v_genotype := v_genotype||a.genotype||' ';
  end loop;

  return trim(nvl(v_genotype,'+/+'));

end fetch_genotype;
/

create or replace function mir_f0_status(in_smi_id number) return varchar2 is

cursor c_f0_data is
select
  count(distinct b.female_id) embryo_recipients,
  count(decode(l.not_pregnant,1,1,null)) not_pregnant,
  count(m.id) male_chimeras,
  min(l.due_date) due_date
from
  mts_breeding b,
  mts_litter l,
  mir_embryo_transfer_procedure e,
  (
   select
     m.id,
  	 m.litter_id
   from
     mts_mouse m,
  	 mts_chimeric_mouse_data c
   where
     c.mouse_id = m.id and
  	 m.gender_dict_id = 2 and
 	 m.wean_date is not null and
	 c.percent_chimeric > 0
  ) m
where
  e.scheduled_micro_injection_id = in_smi_id and
  b.embryo_transfer_id = e.id and
  l.breeding_id = b.id and
  m.litter_id(+) = l.id
;

t_embryo_recipients number;
t_not_pregnant number;
t_male_chimera number;
t_due_date date;

t_return_string varchar2(50);

begin
  open c_f0_data;
  fetch c_f0_data into t_embryo_recipients, t_not_pregnant, t_male_chimera, t_due_date;
  close c_f0_data;

  if nvl(t_embryo_recipients,0) = 0 then
    t_return_string := null;
  elsif t_embryo_recipients - t_not_pregnant = 0 then
    t_return_string := 'Failed: None Pregnant';
  elsif t_due_date + 21 > sysdate then
    t_return_string := null;
  else
    t_return_string := t_male_chimera||' Male Chimeras Weaned';
  end if;

  return t_return_string;

end mir_f0_status;
/

CREATE OR REPLACE VIEW MIR_CHIMERA_SUMMARY
AS
select
  b.embryo_transfer_id,
  count(c.mouse_id) number_chimeric,
  count(decode(c.gender_dict_id,2,1,null)) number_male,
  count(decode(c.gender_dict_id,1,1,null)) number_female,
  count(c.percent_100) number_100_percent,
  count(c.percent_lt_40) number_lt_40_percent,
  count(c.percent_gt_80) number_gt_80_percent,
  count(decode(c.gender_dict_id,2,decode(c.percent_100||c.percent_lt_40||c.percent_gt_80, null, 1, null),null)) number_40_to_80_percent
from
  mts_breeding b,
  mts_litter l,
  (select
    m.id mouse_id,
	m.litter_id,
	m.gender_dict_id,
	d.percent_chimeric,
	decode(m.gender_dict_id,2,decode(d.percent_chimeric,100,1,null),null) percent_100,
	decode(m.gender_dict_id,2,decode(least(40,d.percent_chimeric),40,null,1),null) percent_lt_40,
	decode(m.gender_dict_id,2,decode(greatest(79.99,decode(d.percent_chimeric,100,0,d.percent_chimeric)),79.99,null,1),null) percent_gt_80
   from
    mts_mouse m,
	mts_chimeric_mouse_data d
   where
    m.id = d.mouse_id and
	d.percent_chimeric > 0
   ) c
where
  l.breeding_id = b.id and
  c.litter_id  = l.id
group by b.embryo_transfer_id
/

create or replace view mts_chimeric_mouse_data_vw as
select
  cd.id,
  cd.percent_chimeric,
  chimera.id mouse_id,
  cell.id cell_line_id,
  cell.cell_line_name,
  strain.id cell_line_strain_dict_id,
  strain.name cell_line_strain,
  coat.id expected_coat_colour_dict_id,
  coat.name expected_coat_colour,
  cd.creator_id,
  cd.created_date,
  cd.edited_by,
  cd.edit_date,
  cd.check_number
from
  mts_breeding b,
  mts_litter l,
  mts_mouse chimera,
  mts_chimeric_mouse_data cd,
  mir_cell_line cell,
  mir_cell_line_strain_dict strain,
  mir_embryo_transfer_procedure et,
  mir_scheduled_micro_injection smi,
  mir_micro_injection_request mir,
  mts_coat_colour_dict coat
where
  chimera.id = cd.mouse_id(+) and
  l.id = chimera.litter_id and
  b.id = l.breeding_id and
  b.embryo_transfer_id = et.id and
  et.scheduled_micro_injection_id = smi.id and
  smi.micro_injection_request_id = mir.id and
  mir.cell_line_id = cell.id and
  cell.cell_line_strain_dict_id = strain.id and
  cell.expected_coat_color_dict_id = coat.id;

-- retrofit planning data for experiment sets
update phn_experiment_set es set scheduled_date = (
  select min(mp.START_DATE)
  from MTS_MOUSE_PROCEDURE mp
  join PHN_EXPERIMENT pe on mp.FOREIGN_KEY_ID = pe.ID
  WHERE mp.FOREIGN_TABLE_NAME = 'PHN_EXPERIMENT'
  and pe.EXPERIMENT_SET_ID = es.id
  group by pe.EXPERIMENT_SET_ID
);

-- insert new roles and set up users
insert into per_role (role_id, name, rank) values (per_role_seq.nextval, 'phenotyper', 50);
insert into per_role (role_id, name, rank) values (per_role_seq.nextval, 'bloods-user', 50);

insert into per_person_2_role (role_id, person_id) (
  select r.role_id, p.person_id from per_person p, per_role r
  where r.name = 'phenotyper'
  and p.user_name in ('akg','cs7','vv2','lr4','lb9','oi1','ms14','je2','yh1','kfc','cp3','lm3','ni3')
  union
  select r.role_id, p.person_id from per_person p, per_role r
  where r.name = 'bloods-user'
  and p.user_name in ('je2','cp3','psc')
);

Insert into MTS_CAUSE_OF_DEATH_DICT (ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE) values (27,'To Cull',null,'TC',1);