connect mig_audit;

alter table typ_strain add wildtype_request_strain number(1);

alter table mts_procedure_dict add is_phenotyping number(1);

rename HTL_SLIDE_SCAN_STATUS_DICT to HTL_SCAN_STATUS_DICT;

connect mig;

CREATE TABLE HTL_SLIDE_RECREATION_BIN
(
  SLIDE_ID  NUMBER,
  ADDED_ON  DATE                                DEFAULT sysdate
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;

rename HTL_SLIDE_SCAN_STATUS_DICT to HTL_SCAN_STATUS_DICT;

CREATE OR REPLACE VIEW MIR_REQUEST_LIST_VW
(ID, REQUESTER_NAME, TEAM_NUMBER, CHIMERA_MATE_STRAIN_NAME, CHIMERA_MATE_STRAIN_ID,
 STRAIN_NAME, STRAIN_ID, CELL_LINE_NAME, CELL_LINE_ID, CLONE_NAME,
 ENDPOINT_NAME, ENDPOINT_ID, EMBRYO_STAGE_NAME, EMBRYO_STAGE_ID, EDIT_DATE,
 CREATED_DATE, PROJECT_LICENCE, WORKFLOW_PIPELINE, WORKFLOW_PIPELINE_ID, REQUESTER_ID,
 EXTERNAL_STATUS_DICT_ID, EXTERNAL_STATUS_NAME, SMI_COUNT, REQUESTER_PROVIDED_GENOTYPING, GENE_NAME,
 COLONY_INFO_ID, COLONY_NAME, COLONY_PREFIX)
AS
SELECT mir.ID, per.requester_name, per.team_number,
          cms.NAME chimera_mate_strain_name, cms.ID chimera_mate_strain_id,
          esline.NAME strain_name, esline.ID strain_id, cl.cell_line_name,
          cl.ID cell_line_id, cl.clone_name, ed.NAME endpoint_name,
          ed.ID endpoint_id, sd.NAME embryo_stage_name, sd.ID embryo_stage_id,
          mir.edit_date, mir.created_date, pl.ppl project_licence,
          aw.NAME workflow_pipeline, aw.ID workflow_pipeline_id,
          mir.requester_id requester_id, esd.ID external_status_dict_id,
          esd.NAME external_status_name,
          NVL (smi_table.smi_count, 0) smi_count,
          mir.requester_provided_genotyping,
    g.primary_name gene_name,
    col.id colony_info_id,
    col.colony_name,
    col.colony_prefix
     FROM mir_micro_injection_request mir,
          app_workflow_pipeline_dict aw,
          mir_chimera_mate_strain_dict cms,
          mir_cell_line_strain_dict esline,
          mir_target_endpoint_dict ed,
          (SELECT   micro_injection_request_id, COUNT (*) smi_count
               FROM mir_scheduled_micro_injection
           GROUP BY micro_injection_request_id) smi_table,
          (SELECT p.person_id,
                  p.first_name || ' ' || p.last_name requester_name,
                  tm.team_number
             FROM per_person p, per_team tm
            WHERE p.team_id = tm.ID(+)) per,
          mir_cell_line cl,
    typ_modified_allele tma,
          mir_embryo_stage_dict sd,
          lic_project_licence pl,
          mir_external_status_dict esd,
    mts_colony_info col ,
 gnm_gene g
    WHERE mir.endpoint_dict_id = ed.ID(+)
      AND aw.ID(+) = mir.workflow_pipeline_dict_id
      AND mir.donor_embryo_stage_dict_id = sd.ID(+)
      AND mir.chimera_mate_strain_dict_id = cms.ID(+)
      AND mir.requester_id = per.person_id(+)
      AND mir.cell_line_id = cl.ID(+)
      AND mir.project_licence_id = pl.project_licence_id(+)
      AND cl.cell_line_strain_dict_id = esline.ID(+)
      AND smi_table.micro_injection_request_id(+) = mir.ID
      AND mir.external_status_dict_id = esd.ID(+)
   AND mir.colony_info_id = col.id(+)
   and cl.modified_allele_id=tma.id(+)
   and tma.gene_id=g.id(+)
/

alter table typ_strain add wildtype_request_strain number(1);

alter table mts_procedure_dict add is_phenotyping number(1);

update typ_strain set wildtype_request_strain = 1 where name not like 'C3H%' and id not in (12,18);

update typ_strain set wildtype_request_strain = 0 where wildtype_request_strain is null;

update mts_procedure_dict set is_phenotyping = 1
where id in (
select procedure_id from phn_std_operating_procedure) and id not in (21,14);

update mts_procedure_dict set is_phenotyping = 0 where is_phenotyping is null;

commit;

CREATE OR REPLACE TRIGGER MIG.TYP_STRAIN_TA
before update or delete on TYP_STRAIN for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
declare
audit_action varchar2(10);
begin

if deleting then audit_action := 'deleted'; end if;
if updating then audit_action := 'updated'; end if;
if deleting or updating then
 insert into mig_audit.TYP_STRAIN(
    ID,
    NAME,
    DESCRIPTION,
    ACTIVE,
    ORDER_BY,
 CRYO_REQUEST_STRAIN,
 CRYO_WILDTYPE_STRAIN,
 WILDTYPE_REQUEST_STRAIN,
    AUDIT_ACTION)
 values (
    :old.ID,
    :old.NAME,
    :old.DESCRIPTION,
    :old.ACTIVE,
    :old.ORDER_BY,
 :old.CRYO_REQUEST_STRAIN,
 :old.CRYO_WILDTYPE_STRAIN,
 :old.WILDTYPE_REQUEST_STRAIN,
    AUDIT_ACTION);
end if;
end;
/

CREATE OR REPLACE TRIGGER MIG.MTS_PROCEDURE_DICT_TA
before update or delete on MTS_PROCEDURE_DICT for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
declare
audit_action varchar2(10);
begin

if deleting then audit_action := 'deleted'; end if;
if updating then audit_action := 'updated'; end if;
if deleting or updating then
 insert into mig_audit.MTS_PROCEDURE_DICT(
    ID,
    NAME,
    DESCRIPTION,
    ACTIVE,
    ORDER_BY,
    AUDIT_ACTION,
	IS_LICENCED,
	IS_TERMINAL,
	IS_PHENOTYPING)
 values (
    :old.ID,
    :old.NAME,
    :old.DESCRIPTION,
    :old.ACTIVE,
    :old.ORDER_BY,
    AUDIT_ACTION,
	:old.IS_LICENCED,
	:old.IS_TERMINAL,
	:old.IS_PHENOTYPING);
end if;
end;
/

CREATE OR REPLACE VIEW MTS_WILDTYPE_STRAIN_DICT_VW
AS
SELECT ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE
FROM TYP_STRAIN
WHERE wildtype_request_strain = 1
/

CREATE OR REPLACE VIEW MTS_PROCEDURE_NO_PHENO_DICT_VW
AS
SELECT ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE
FROM MTS_PROCEDURE_DICT
WHERE IS_PHENOTYPING = 0
/

/* This object may not be sorted properly in the script due to cirular references */
CREATE OR REPLACE FORCE VIEW MTS_MOUSE_VW
(ID, LITTER_ID, NAME, RFID_TAG, EDIT_DATE,
 COAT_COLOUR_DICT_ID, COAT_COLOUR, EYE_COLOUR_DICT_ID, EYE_COLOUR, EARMARK_DICT_ID,
 EARMARK, EARMARK_LEFT, EARMARK_RIGHT, BIRTH_DATE, AGE_IN_WEEKS,
 DEATH_DATE, AGE_AT_DEATH, CAUSE_OF_DEATH_DICT_ID, CAUSE_OF_DEATH, EDITED_BY,
 WEAN_DATE, CAGE_ID, CAGE_NAME, CAGE_BARCODE, RACK_ID,
 RACK_NAME, ROOM_ID, ROOM_NAME, CURRENT_OWNER_ID, CURRENT_OWNER,
 CURRENT_PROJECT_LICENCE_ID, CURRENT_PROJECT_LICENCE, CURRENT_PROTOCOL_ID, CURRENT_PROTOCOL_CODE, CHECK_NUMBER,
 GENDER_DICT_ID, GENDER, MOUSE_STRAIN_DICT_ID, STRAIN, STATUS,
 CREATOR_ID, CREATED_DATE, BARCODE, COMMENTS, IS_NON_BREEDER,
 IS_SENTINEL, GENERATION, COLONY_NAME, COLONY_PREFIX, COLONY_INFO_ID,
 ARRIVAL_DATE, LATEST_PLUG_DATE, BREEDING_NAME, GENOTYPE, FATHER_GENOTYPE,
 MOTHER_GENOTYPE)
AS
select
  m.id,
  m.litter_id,
  m.name,
  m.rfid_tag,
  m.edit_date,
  m.coat_colour_dict_id,
  c.name||decode(chim.percent_chimeric,null,null,' ('||chim.percent_chimeric||'%)') coat_colour,
  m.eye_colour_dict_id,
  e.name eye_colour,
  m.earmark_dict_id,
  ear.name earmark,
  m.earmark_left,
  m.earmark_right,
  m.birth_date,
  round((nvl(m.death_date,sysdate) - m.birth_date)/7,1) age_in_weeks,
  m.death_date,
  round((m.death_date - m.birth_date)/7,1) age_at_death,
  m.cause_of_death_dict_id,
  d.name cause_of_death,
  m.edited_by,
  m.wean_date,
  m.cage_id,
  l.cage_name,
  l.cage_barcode,
  l.rack_id,
  l.rack_name,
  l.room_id,
  l.room_name,
  m.current_owner_id,
  owner.first_name||' '||owner.last_name current_owner,
  b.project_licence_id current_project_licence_id,
  b.licence_number current_project_licence,
  b.protocol_id current_protocol_id,
  b.protocol_code current_protocol_code,
  m.check_number,
  m.gender_dict_id,
  s.name gender,
  m.mouse_strain_dict_id,
  t.name strain,
  m.status,
  m.creator_id,
  m.created_date,
  m.barcode,
  m.comments,
  m.is_non_breeder,
  m.is_sentinel,
  m.generation,
  colony.colony_name,
  colony.colony_prefix,
  m.colony_info_id,
  m.arrival_date,
  m.latest_plug_date,
  breeding.breeding_name,
  fetch_genotype(m.id) genotype,
  decode(m.generation,'F0',null,decode(p.male_id,null,null,fetch_genotype(p.male_id))) father_genotype,
  decode(m.generation,'F0',null,decode(p.female_id,null,null,fetch_genotype(p.female_id))) mother_genotype
from
  mts_mouse m,
  mts_coat_colour_dict c,
  mts_eye_colour_dict e,
  mts_earmark_dict ear,
  mts_cause_of_death_dict d,
  per_person owner,
  mts_gender_dict s,
  mts_cage_vw l,
  mts_mouse_current_19b_vw b,
  typ_strain t,
  mts_colony_info colony,
  mts_current_breeding_vw breeding,
  mts_chimeric_mouse_data chim,
  (select b.male_id, b.female_id, l.id litter_id
   from
    mts_litter l,
 mts_breeding b
   where
    l.breeding_id = b.id
  ) p
where
  m.coat_colour_dict_id = c.id(+) and
  m.eye_colour_dict_id = e.id(+) and
  m.earmark_dict_id = ear.id(+) and
  m.cause_of_death_dict_id = d.id(+) and
  m.current_owner_id = owner.person_id(+) and
  m.gender_dict_id = s.id(+) and
  m.cage_id = l.cage_id(+) and
  m.mouse_strain_dict_id = t.id(+) and
  m.colony_info_id = colony.id(+) and
  m.id = b.mouse_id(+) and
  m.id = breeding.mouse_id(+) and
  m.id = chim.mouse_id(+) and
  m.litter_id = p.litter_id(+);


INSERT INTO APP_COLUMN_PREFS ( ID, TABLE_NAME, COLUMN_NAME, COLUMN_TITLE, GETTER_METHOD, ORDER_BY,
DATATYPE) VALUES (
34, 'mts_mouse_list_vw', 'rfid_tag', 'RFID', 'getRfidTag', NULL, NULL);

CREATE OR REPLACE TRIGGER MIG.HTL_BLOCK_TS
before insert or update on htl_block for each row
begin
  if(:new.id is null) then
    select htl_block_seq.nextval into :new.id from dual;
  end if;
end;
/

CREATE OR REPLACE TRIGGER MIG.HTL_SLIDE_TS
before insert or update on htl_slide for each row
begin
  if(:new.id is null) then
    select htl_slide_seq.nextval into :new.id from dual;
  end if;
end;
/

drop trigger MTS_CAGE_TS;

drop trigger MTS_RACK_TS;

drop trigger MTS_MOUSE_TS;

CREATE OR REPLACE TRIGGER MIG.HTL_SLIDE_SCAN_STATUS_DICT_TA 
before update or delete on HTL_SCAN_STATUS_DICT for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
declare
audit_action varchar2(10);
begin 

if deleting then audit_action := 'deleted'; end if;
if updating then audit_action := 'updated'; end if;
if deleting or updating then
 insert into mig_audit.HTL_SCAN_STATUS_DICT(
    ID,
    NAME,
    DESCRIPTION,
    ACTIVE,
    ORDER_BY,
    AUDIT_ACTION)
 values (
    :old.ID,
    :old.NAME,
    :old.DESCRIPTION,
    :old.ACTIVE,
    :old.ORDER_BY,
    AUDIT_ACTION);
end if;

end;
/
