connect mig_audit;


CREATE TABLE GNM_BAC_LOCUS
(
  ID               INTEGER,
  BAC_ID           INTEGER,
  LOCUS_ID         INTEGER,
  CREATOR_ID       INTEGER,
  CREATED_DATE     DATE,
  EDITED_BY        VARCHAR2(128 CHAR),
  EDIT_DATE        DATE,
  CHECK_NUMBER     NUMBER,
  AUDIT_TIMESTAMP  TIMESTAMP(6)                 DEFAULT systimestamp,
  OS_USER          VARCHAR2(30 BYTE)            DEFAULT sys_context('USERENV','OS_USER'),
  AUDIT_ACTION     VARCHAR2(10 BYTE)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE GNM_BAC
(
  ID               INTEGER,
  NAME             VARCHAR2(256 CHAR),
  TYPE_ID          INTEGER,
  CREATOR_ID       INTEGER,
  CREATED_DATE     DATE,
  EDITED_BY        VARCHAR2(128 CHAR),
  EDIT_DATE        DATE,
  CHECK_NUMBER     NUMBER,
  AUDIT_TIMESTAMP  TIMESTAMP(6)                 DEFAULT systimestamp,
  OS_USER          VARCHAR2(30 BYTE)            DEFAULT sys_context('USERENV','OS_USER'),
  AUDIT_ACTION     VARCHAR2(10 BYTE)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE GNM_BAC_TYPE_DICT
(
  ID               INTEGER,
  NAME             VARCHAR2(256 CHAR),
  DESCRIPTION      VARCHAR2(256 CHAR),
  ORDER_BY         NUMBER,
  ACTIVE           NUMBER(1),
  AUDIT_TIMESTAMP  TIMESTAMP(6)                 DEFAULT systimestamp,
  OS_USER          VARCHAR2(30 BYTE)            DEFAULT sys_context('USERENV','OS_USER'),
  AUDIT_ACTION     VARCHAR2(10 BYTE)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;

GRANT INSERT ON  GNM_BAC TO MIG;

GRANT INSERT ON  GNM_BAC_LOCUS TO MIG;

GRANT INSERT ON  GNM_BAC_TYPE_DICT TO MIG;


connect mig;

CREATE TABLE APP_CUSTOM_QUERY
(
  ID               INTEGER,
  QUERY_TITLE      VARCHAR2(512 BYTE),
  QUERY_VIEW_NAME  VARCHAR2(30 BYTE)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE APP_CUSTOM_QUERY_COLUMN
(
  ID               INTEGER,
  CUSTOM_QUERY_ID  INTEGER,
  COLUMN_NAME      VARCHAR2(30 CHAR),
  COLUMN_TITLE     VARCHAR2(128 CHAR),
  DATATYPE         VARCHAR2(30 CHAR),
  ORDER_BY         INTEGER,
  DATATYPE_FORMAT  VARCHAR2(512 BYTE)
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE APP_CUSTOM_QUERY_PERSON_PREF
(
  PERSON_ID        INTEGER,
  QUERY_COLUMN_ID  INTEGER,
  ORDER_BY         INTEGER
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;

ALTER TABLE APP_CUSTOM_QUERY ADD (
  CONSTRAINT APP_CUSTOM_QUERY_PK
 PRIMARY KEY
 (ID));

ALTER TABLE APP_CUSTOM_QUERY_COLUMN ADD (
  CONSTRAINT APP_CUSTOM_QUERY_COLUMN_PK
 PRIMARY KEY
 (ID));

ALTER TABLE APP_CUSTOM_QUERY_COLUMN ADD (
  CONSTRAINT APP_CUSTOM_QUERY_COLUMN_FK1
 FOREIGN KEY (CUSTOM_QUERY_ID)
 REFERENCES APP_CUSTOM_QUERY (ID));

CREATE OR REPLACE VIEW CUS_ROOM_BREEDINGS_VW
AS
select
  b.id,
  g.room_id,
  g.room_name,
  b.name_prefix||b.breeding_number breeding_name,
  b.start_date,
  decode(b.embryo_transfer_id,
      null, decode(nvl(male.cage_id,-1),nvl(female.cage_id,-2),'Mating','Separeted'),
	  'Embryo Transfer') status,
  decode(max(l.litter_number),0,null,null,null,b.name_prefix||b.breeding_number||'.'||max(l.litter_number)) last_litter,
  trunc(sysdate - b.start_date) days_in_mating
from
  mts_breeding b,
  mts_mouse female,
  mts_mouse male,
  mts_cage_vw g,
  mts_litter l
where
  b.female_id = female.id and
  female.cage_id = g.cage_id and
  b.male_id = male.id and
  b.end_date is null and
  l.breeding_id(+) = b.id
group by
  b.id,
  g.room_id,
  g.room_name,
  b.name_prefix||b.breeding_number,
  b.start_date,
  decode(b.embryo_transfer_id,
      null, decode(nvl(male.cage_id,-1),nvl(female.cage_id,-2),'Mating','Separeted'),
	  'Embryo Transfer')
/


CREATE OR REPLACE VIEW CUS_ROOM_COLONIES_VW
AS
select
  c.id,
  c.colony_prefix,
  c.colony_name,
  count(m.id) live_mice,
  g.room_id,
  g.room_name
from
  mts_colony_info c,
  mts_mouse m,
  mts_cage_vw g
where
  m.colony_info_id = c.id and
  m.cage_id = g.cage_id
group by
  c.id,
  c.colony_prefix,
  c.colony_name,
  g.room_id,
  g.room_name
/

CREATE OR REPLACE VIEW CUS_ROOM_PREWEAN_LITTERS_VW
AS
select
  l.id,
  l.litter_name,
  l.birth_date,
  trunc(sysdate - l.birth_date) days_since_birth,
  c.room_id,
  c.room_name
from
  mts_litter_list_vw l,
  mts_cage_vw c,
  mts_mouse m
where
  l.mother_id = m.id and
  m.cage_id = c.cage_id and
  l.number_born > 0 and l.number_weaned = 0 and (l.number_used = 0 or l.number_used != l.number_pups)
/

CREATE OR REPLACE VIEW APP_CUSTOM_QUERY_COL_PREF_VW
AS
select
  c.id,
  c.custom_query_id,
  c.column_name,
  c.column_title,
  c.datatype,
  c.datatype_format,
  p.order_by,
  p.person_id
from
  app_custom_query_person_pref p,
  app_custom_query_column c
where
  c.id = p.query_column_id
union
select
  c.id,
  c.custom_query_id,
  c.column_name,
  c.column_title,
  c.datatype,
  c.datatype_format,
  c.order_by,
  p.person_id
from
  per_person p,
  app_custom_query_column c
where
  not exists (select null from app_custom_query_person_pref x, app_custom_query_column y where x.person_id = p.person_id and x.query_column_id = y.id and y.custom_query_id = c.custom_query_id)
/


DROP SEQUENCE MIG.APP_CUSTOM_QUERY_COL_SEQ;

CREATE SEQUENCE MIG.APP_CUSTOM_QUERY_COL_SEQ
  START WITH 52
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;


DROP SEQUENCE MIG.APP_CUSTOM_QUERY_SEQ;

CREATE SEQUENCE MIG.APP_CUSTOM_QUERY_SEQ
  START WITH 2
  MAXVALUE 999999999999999999999999999
  MINVALUE 0
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE OR REPLACE TRIGGER APP_CUSTOM_QUERY_TS
before insert on app_custom_query for each row
begin
  if :new.id is null then
    select app_custom_query_seq.nextval into :new.id from dual;
  end if;
end;
/

CREATE OR REPLACE TRIGGER APP_CUSTOM_QUERY_COLUMN_TS
before insert on app_custom_query_column for each row
begin
  if :new.id is null then
    select app_custom_query_col_seq.nextval into :new.id from dual;
  end if;
end;
/

INSERT INTO APP_CUSTOM_QUERY ( ID, QUERY_TITLE, QUERY_VIEW_NAME ) VALUES (
2, 'MIR Summary Statistics', 'MIR_SUMMARY_STATS_VW');
INSERT INTO APP_CUSTOM_QUERY ( ID, QUERY_TITLE, QUERY_VIEW_NAME ) VALUES (
3, 'Colonies by Room', 'CUS_ROOM_COLONIES_VW');
INSERT INTO APP_CUSTOM_QUERY ( ID, QUERY_TITLE, QUERY_VIEW_NAME ) VALUES (
4, 'Matings By Room', 'CUS_ROOM_BREEDINGS_VW');
INSERT INTO APP_CUSTOM_QUERY ( ID, QUERY_TITLE, QUERY_VIEW_NAME ) VALUES (
5, 'Prewean Litter By Room', 'CUS_ROOM_PREWEAN_LITTERS_VW');

INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
10, 2, 'id', 'MIR', NULL, 1, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
12, 2, 'parental_line', 'Parental Line', NULL, 2, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
13, 2, 'latest_mi_date', 'Latest MI Date', 'date', 3, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
14, 2, 'number_transferred', '# Transferred', NULL, 4, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
15, 2, 'number_born', '# Born', NULL, 5, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
16, 2, 'percent_born', '% Born', NULL, 6, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
17, 2, 'number_chimeric', '# Chimeric', NULL, 7, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
18, 2, 'percent_chimeric', '% Chimeric', NULL, 8, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
19, 2, 'number_male', '# Male', NULL, 9, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
20, 2, 'percent_male', '% Male', NULL, 10, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
21, 2, 'number_female', '# Female', NULL, 11, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
22, 2, 'number_male_100_percent', '# Male 100%', NULL, 12, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
23, 2, 'number_male_gt_80_percent', '# Male > 80%', NULL, 13, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
24, 2, 'number_male_40_to_80_percent', '# Male 40-80%', NULL, 14, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
25, 2, 'number_male_lt_40_percent', '# Male < 40%', NULL, 15, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
26, 2, 'f0_breedings', '# F0 matings', NULL, 16, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
27, 2, 'f0_breedings_with_offspring', '# F0 with offsping', NULL, 17, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
28, 2, 'percent_fertility', '% Fertility', NULL, 18, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
29, 2, 'f1_germ_line_mice', '# F1 Germline', NULL, 19, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
30, 2, 'f1_non_germ_line_mice', '# F1 Non-Germline', NULL, 20, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
31, 2, 'f1_total', '# F1', NULL, 21, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
32, 2, 'chimeras_with_glt', '# Chimeras with GLT', NULL, 22, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
33, 2, 'percent_glt', '% GLT', NULL, 23, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
34, 2, 'number_100_percent_glt', '# 100% GLT', NULL, 24, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
35, 2, 'number_gt_50_percent_glt', '# >50% GLT', NULL, 25, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
36, 2, 'number_btw_10_50_percent_glt', '# 10-50% GLT', NULL, 26, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
37, 2, 'number_lt_10_percent_glt', '# <10% GLT', NULL, 27, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
38, 3, 'id', 'Colony ID', 'hidden', NULL, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
39, 3, 'colony_name', 'Colony', NULL, 2, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
40, 3, 'colony_prefix', 'Prefix', NULL, 1, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
41, 3, 'live_mice', 'Live Mice', NULL, 3, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
42, 4, 'id', 'Options', 'href', 1, 'view_one_breeding.do?id=');
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
43, 4, 'breeding_name', 'Mating', NULL, 2, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
44, 4, 'start_date', 'Date Paired', 'date', 3, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
45, 4, 'status', 'Status', NULL, 4, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
46, 4, 'last_litter', 'Last Litter', NULL, 5, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
47, 4, 'days_in_mating', 'Days since setup', 'number', 6, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
48, 5, 'id', 'Options', 'href', 1, 'view_one_litter.do?id=');
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
49, 5, 'litter_name', 'Litter', NULL, 2, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
50, 5, 'birth_date', 'D.O.B.', 'date', 3, NULL);
INSERT INTO APP_CUSTOM_QUERY_COLUMN ( ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
ORDER_BY, DATATYPE_FORMAT ) VALUES (
51, 5, 'days_since_birth', 'Days since birth', 'number', 4, NULL);
COMMIT;

CREATE OR REPLACE VIEW MTS_MOUSE_CURRENT_19B_VW
AS
with max_id as (
  select
    p.*,
    row_number() over (partition by mouse_id order by start_date desc, id desc) row_number
  from
    mts_mouse_procedure p
  where
    protocol_id is not null
  )
select
  m.id,
  m.mouse_id,
  m.protocol_id,
  m.personal_licence_id,
  m.start_date,
  m.end_date,
  m.foreign_key_id,
  m.foreign_table_name,
  m.procedure_dict_id,
  d.name procedure,
  ppl.project_licence_id,
  ppl.licence_number,
  b.protocol_code,
  pil.pil_number
from
  lic_project_licence ppl,
  lic_protocol_19b b,
  lic_personal_licence pil,
  mts_procedure_dict d,
  max_id m
where
  m.row_number = 1 and
  m.protocol_id = b.id and
  b.project_licence_id = ppl.project_licence_id and
  m.personal_licence_id = pil.personal_licence_id(+) and
  m.procedure_dict_id = d.id
/

alter table mts_breeding drop column reservation_id;

CREATE OR REPLACE VIEW MTS_MOUSE_VW
AS
select
  m.id,
  m.litter_id,
  m.name,
  m.rfid_tag,
  m.edit_date,
  m.coat_colour_dict_id,
  c.name||decode(chim.percent_chimeric,null,null,' ('||chim.percent_chimeric||'%)') coat_colour,
  m.eye_colour_dict_id,
  e.name eye_colour,
  m.earmark_dict_id,
  ear.name earmark,
  m.earmark_left,
  m.earmark_right,
  m.birth_date,
  round((nvl(m.death_date,sysdate) - m.birth_date)/7,1) age_in_weeks,
  m.death_date,
  round((m.death_date - m.birth_date)/7,1) age_at_death,
  m.cause_of_death_dict_id,
  d.name cause_of_death,
  m.edited_by,
  m.wean_date,
  m.cage_id,
  l.cage_name,
  l.cage_barcode,
  l.rack_id,
  l.rack_name,
  l.room_id,
  l.room_name,
  m.current_owner_id,
  owner.first_name||' '||owner.last_name current_owner,
  b.project_licence_id current_project_licence_id,
  b.licence_number current_project_licence,
  b.protocol_id current_protocol_id,
  b.protocol_code current_protocol_code,
  m.check_number,
  m.gender_dict_id,
  s.name gender,
  m.mouse_strain_dict_id,
  t.name strain,
  m.status,
  m.creator_id,
  m.created_date,
  m.barcode,
  m.comments,
  m.is_non_breeder,
  m.is_sentinel,
  m.generation,
  colony.colony_name,
  colony.colony_prefix,
  m.colony_info_id,
  m.arrival_date,
  m.latest_plug_date,
  breeding.breeding_name,
  fetch_genotype(m.id) genotype,
  p.father_name,
  decode(m.generation,'F0',null,decode(p.male_id,null,null,fetch_genotype(p.male_id))) father_genotype,
  p.mother_name,
  decode(m.generation,'F0',null,decode(p.female_id,null,null,fetch_genotype(p.female_id))) mother_genotype
from
  mts_mouse m,
  mts_coat_colour_dict c,
  mts_eye_colour_dict e,
  mts_earmark_dict ear,
  mts_cause_of_death_dict d,
  per_person owner,
  mts_gender_dict s,
  mts_cage_vw l,
  mts_mouse_current_19b_mv b,
  typ_strain t,
  mts_colony_info colony,
  mts_current_breeding_mv breeding,
  mts_chimeric_mouse_data chim,
  (select b.male_id, b.female_id, l.id litter_id, decode(b.embryo_transfer_id,null,sire.name, null) father_name, decode(b.embryo_transfer_id,null,dam.name,null) mother_name
   from
    mts_litter l,
    mts_breeding b,
	mts_mouse sire,
	mts_mouse dam
   where
    l.breeding_id = b.id and
	b.male_id = sire.id and
	b.female_id = dam.id
  ) p
where
  m.coat_colour_dict_id = c.id(+) and
  m.eye_colour_dict_id = e.id(+) and
  m.earmark_dict_id = ear.id(+) and
  m.cause_of_death_dict_id = d.id(+) and
  m.current_owner_id = owner.person_id(+) and
  m.gender_dict_id = s.id(+) and
  m.cage_id = l.cage_id(+) and
  m.mouse_strain_dict_id = t.id(+) and
  m.colony_info_id = colony.id(+) and
  m.id = b.mouse_id(+) and
  m.id = breeding.mouse_id(+) and
  m.id = chim.mouse_id(+) and
  m.litter_id = p.litter_id(+)
/

INSERT INTO APP_COLUMN_PREFS ( ID, TABLE_NAME, COLUMN_NAME, COLUMN_TITLE, GETTER_METHOD, ORDER_BY,
DATATYPE ) VALUES (
41, 'mts_mouse_list_vw', 'father_name', 'Father Name', 'getFatherName', NULL, NULL);
INSERT INTO APP_COLUMN_PREFS ( ID, TABLE_NAME, COLUMN_NAME, COLUMN_TITLE, GETTER_METHOD, ORDER_BY,
DATATYPE ) VALUES (
42, 'mts_mouse_list_vw', 'mother_name', 'Mother Name', 'getMotherName', NULL, NULL);


CREATE TABLE GNM_BAC_TYPE_DICT
(
  ID           INTEGER,
  NAME         VARCHAR2(256 CHAR),
  DESCRIPTION  VARCHAR2(256 CHAR),
  ORDER_BY     NUMBER,
  ACTIVE       NUMBER(1)                        DEFAULT 1
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE GNM_BAC
(
  ID            INTEGER,
  NAME          VARCHAR2(256 CHAR),
  TYPE_ID       INTEGER,
  CREATOR_ID    INTEGER,
  CREATED_DATE  DATE,
  EDITED_BY     VARCHAR2(128 CHAR),
  EDIT_DATE     DATE,
  CHECK_NUMBER  NUMBER
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE GNM_BAC_LOCUS
(
  ID            INTEGER,
  BAC_ID        INTEGER,
  LOCUS_ID      INTEGER,
  CREATOR_ID    INTEGER,
  CREATED_DATE  DATE,
  EDITED_BY     VARCHAR2(128 CHAR),
  EDIT_DATE     DATE,
  CHECK_NUMBER  NUMBER
)
LOGGING
NOCOMPRESS
NOCACHE
NOPARALLEL
MONITORING;

CREATE OR REPLACE TRIGGER GNM_BAC_ta
before update or delete on GNM_BAC for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
declare
audit_action varchar2(10);
begin

if deleting then audit_action := 'deleted'; end if;
if updating then audit_action := 'updated'; end if;
if deleting or updating then
 insert into mig_audit.GNM_BAC(
    ID,
    NAME,
    TYPE_ID,
    CREATOR_ID,
    CREATED_DATE,
    EDITED_BY,
    EDIT_DATE,
    CHECK_NUMBER,
    AUDIT_ACTION)
 values (
    :old.ID,
    :old.NAME,
    :old.TYPE_ID,
    :old.CREATOR_ID,
    :old.CREATED_DATE,
    :old.EDITED_BY,
    :old.EDIT_DATE,
    :old.CHECK_NUMBER,
    AUDIT_ACTION);
end if;
end;
/
SHOW ERRORS;


CREATE OR REPLACE TRIGGER GNM_BAC_LOCUS_ta
before update or delete on GNM_BAC_LOCUS for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
declare
audit_action varchar2(10);
begin

if deleting then audit_action := 'deleted'; end if;
if updating then audit_action := 'updated'; end if;
if deleting or updating then
 insert into mig_audit.GNM_BAC_LOCUS(
    ID,
    BAC_ID,
    LOCUS_ID,
    CREATOR_ID,
    CREATED_DATE,
    EDITED_BY,
    EDIT_DATE,
    CHECK_NUMBER,
    AUDIT_ACTION)
 values (
    :old.ID,
    :old.BAC_ID,
    :old.LOCUS_ID,
    :old.CREATOR_ID,
    :old.CREATED_DATE,
    :old.EDITED_BY,
    :old.EDIT_DATE,
    :old.CHECK_NUMBER,
    AUDIT_ACTION);
end if;
end;
/
SHOW ERRORS;

create or replace trigger GNM_BAC_TYPE_DICT_ta
before update or delete on GNM_BAC_TYPE_DICT for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */

declare
audit_action varchar2(10);
begin

if deleting then audit_action := 'deleted'; end if;
if updating then audit_action := 'updated'; end if;
if deleting or updating then
 insert into mig_audit.GNM_BAC_TYPE_DICT(
    ID,
    NAME,
    DESCRIPTION,
    ORDER_BY,
    ACTIVE,
    AUDIT_ACTION)
 values (
    :old.ID,
    :old.NAME,
    :old.DESCRIPTION,
    :old.ORDER_BY,
    :old.ACTIVE,
    AUDIT_ACTION);
end if;
end;
/
SHOW ERRORS;

CREATE SEQUENCE GNM_BAC_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE GNM_BAC_LOCUS_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

Insert into GNM_BAC_TYPE_DICT (ID,NAME,DESCRIPTION,ORDER_BY,ACTIVE) values (1,'129S5',null,1,1);
Insert into GNM_BAC_TYPE_DICT (ID,NAME,DESCRIPTION,ORDER_BY,ACTIVE) values (2,'C57Bl/6J',null,2,1);
Insert into GNM_BAC_TYPE_DICT (ID,NAME,DESCRIPTION,ORDER_BY,ACTIVE) values (3,'MICER',null,3,1);


CREATE OR REPLACE VIEW HTL_SCAN_VW
AS
select
sc.id id,
sc.file_path,
sc.version_number,
sc.sweep_date,
sc.width,
sc.height,
bin.binary_data thumbnail,
sc.thumb_width,
sc.thumb_height,
sl.id slide_id,
st.name staining,
bt.name block_name,
bt.description block_description,
m.barcode mouse_barcode
from
htl_scan sc,
app_binary_files bin,
htl_slide sl,
htl_staining_type_dict st,
htl_block b,
htl_block_type bt,
htl_fixation f,
htl_necropsy n,
mts_mouse m
where
sc.thumbnail_id = bin.id
AND sc.slide_id = sl.id
AND sl.staining_type_dict_id = st.id
AND sl.block_id = b.id
AND b.block_type_id = bt.id
AND b.fixation_id = f.id
AND f.necropsy_id = n.id
AND n.mouse_id = m.id;

COMMIT;


