connect mig

CREATE OR REPLACE PACKAGE PHN AS
/******************************************************************************
   NAME:       PHN
   PURPOSE:

   REVISIONS:
   Ver        Date        Author           Description
   ---------  ----------  ---------------  ------------------------------------
    V3.0.39       18/04/2008             wl1 Created this package.
******************************************************************************/

PROCEDURE PHN_DELETE_EXPERIMENT_SET (IN_SET_ID number);

END PHN;
/

CREATE OR REPLACE PACKAGE BODY PHN AS
/******************************************************************************
   PHN_DELETE_EXPERIMENT_SET (IN_SET_ID number)
******************************************************************************/


PROCEDURE PHN_DELETE_EXPERIMENT_SET (IN_SET_ID number) IS

BEGIN

  delete from MTS_MOUSE_PROCEDURE where id in (
    select mp.id from phn_experiment e
    join MTS_MOUSE_PROCEDURE mp on e.ID = mp.FOREIGN_KEY_ID and mp.FOREIGN_TABLE_NAME = 'PHN_EXPERIMENT'
    where e.EXPERIMENT_SET_ID = IN_SET_ID
  );

  delete from PHN_OBSERVATION where id in (
    select o.id from PHN_EXPERIMENT e
    join PHN_OBSERVATION o on e.ID = o.EXPERIMENT_ID
    where e.EXPERIMENT_SET_ID = IN_SET_ID
  );

  delete from PHN_EXPERIMENT where EXPERIMENT_SET_ID = IN_SET_ID;

  delete from PHN_EXPERIMENT_SET where id = IN_SET_ID;

END;

END PHN;
/

CREATE OR REPLACE PACKAGE MTS AS
/******************************************************************************
   NAME:       MTS
   PURPOSE:

   REVISIONS:
   Ver        Date        Author           Description
   ---------  ----------  ---------------  ------------------------------------
   V3.0.39       18/04/2008             wl1 Created this package.
******************************************************************************/


  PROCEDURE mts_delete_colony(in_colony_id number);
  PROCEDURE mts_delete_mouse(in_mouse_id number);
  PROCEDURE mts_genotype_import;
  PROCEDURE MTS_MIR_MOVE_COLONY(IN_MIR_ID number, IN_COLONY_ID number);
  FUNCTION  MTS_NEXT_BREEDING_NUMBERS (in_colony_id number) return integer_list;
  FUNCTION fetch_cohort (in_mouse_id in number, in_delimiter in varchar2) return varchar2;
  FUNCTION fetch_genotype (in_mouse_id number) return varchar2;
  FUNCTION fetch_pipelines (in_mouse_id in number, in_delimiter in varchar2) return varchar2;
  FUNCTION fetch_simple_genotype (in_mouse_id number) return varchar2;
  FUNCTION FETCH_GENOTYPE_BY_ALLELE(in_mouse_id number, in_allele_id number) RETURN NUMBER;
  FUNCTION FETCH_COHORT_GENOTYPE(in_cohort_id number, in_allele_id number) RETURN NUMBER;

END MTS;
/

CREATE OR REPLACE PACKAGE BODY mts as

/* ====================================

  mts_delete_colony(in_colony_id number)

 ==================================== */

PROCEDURE mts_delete_colony(in_colony_id number) IS
BEGIN
  delete mts_colony_allele where colony_id = in_colony_id;
  delete mts_colony_behaviour where colony_id = in_colony_id;
  delete mts_colony_coat_colour where colony_id = in_colony_id;
  delete mts_colony_contact where colony_id = in_colony_id;
  delete mts_colony_cross where colony_id = in_colony_id;
  delete mts_colony_room where colony_id = in_colony_id;
  delete mts_colony_strain where colony_id = in_colony_id;
  delete mts_colony_info where id = in_colony_id;

END mts_delete_colony;

/* ====================================

  MTS_DELETE_MOUSE(IN_MOUSE_ID number)

 ==================================== */
PROCEDURE MTS_DELETE_MOUSE(IN_MOUSE_ID number) IS
BEGIN

  delete mts_mouse_procedure where mouse_id = in_mouse_id;

  delete mts_chimeric_mouse_data where mouse_id = in_mouse_id;

  delete mts_mouse_cage_history where mouse_id = in_mouse_id;

  delete mts_mouse_allele where mouse_id = in_mouse_id;

  delete mts_mouse where id = in_mouse_id;

END MTS_DELETE_MOUSE;


/* ====================================

  MTS_GENOTYPE_IMPORT

 ==================================== */

PROCEDURE MTS_GENOTYPE_IMPORT IS
cursor c_mice_to_genotype is
select *
from mts_genotype_import_data
where status is null
for update of status, status_date
;

cursor c_fetch_mouse_by_name(in_name varchar2) is
select *
from mts_mouse
where name = in_name;

v_mouse mts_mouse%rowtype;

v_status varchar2(4000);
BEGIN

  for i in c_mice_to_genotype loop
    v_status := '';
    open c_fetch_mouse_by_name(i.mouse_name);
 fetch c_fetch_mouse_by_name into v_mouse;

 if c_fetch_mouse_by_name%found then

     if i.genotype = '+/+' then
     delete mts_mouse_allele where mouse_id = v_mouse.id;
  v_status := 'Wildtype: mts_mouse_allele records deleted:'||sql%rowcount;
   elsif i.genotype = '-/-' then
     update mts_mouse_allele set genotype_dict_id = 3 where mouse_id = v_mouse.id;
     v_status := 'Hom: mts_mouse_allele records updated:'||sql%rowcount;
   elsif i.genotype = '-/+' or i.genotype = '+/-' then
     update mts_mouse_allele set genotype_dict_id = 2 where mouse_id = v_mouse.id;
     v_status := 'Het: mts_mouse_allele records updated:'||sql%rowcount;
   else
     v_status := 'Unknown genotype code';
   end if;
 else
   v_status := 'Mouse not found';
 end if;

 close c_fetch_mouse_by_name;

    update mts_genotype_import_data
 set status_date = systimestamp, status = v_status
 where current of c_mice_to_genotype;
  end loop;

END mts_genotype_import;


/* ====================================

  MTS_MIR_MOVE_COLONY(IN_MIR_ID number, IN_COLONY_ID number)

 ==================================== */
PROCEDURE MTS_MIR_MOVE_COLONY(IN_MIR_ID number, IN_COLONY_ID number) IS
cursor c_colony_info is
select * from mts_colony_info where id = in_colony_id;

t_colony_info mts_colony_info%rowtype;

cursor c_embryo_transfer_breedings is
select b.*
from
  mts_breeding b,
  mir_embryo_transfer_procedure et,
  mir_scheduled_micro_injection smi,
  mir_micro_injection_request mir
where
  b.embryo_transfer_id = et.id and
  et.scheduled_micro_injection_id = smi.id and
  smi.micro_injection_request_id = mir.id and
  mir.id = in_mir_id
order by b.id
for update of b.name_prefix,b.offspring_colony_id,b.breeding_number;

cursor c_embryo_transfer_recipients is
select m.*
from
  mts_mouse m,
  mts_breeding b,
  mir_embryo_transfer_procedure et,
  mir_scheduled_micro_injection smi,
  mir_micro_injection_request mir
where
  b.female_id = m.id and
  b.embryo_transfer_id = et.id and
  et.scheduled_micro_injection_id = smi.id and
  smi.micro_injection_request_id = mir.id and
  mir.id = in_mir_id
order by m.id
for update of m.colony_info_id;

cursor c_next_breeding_number is
select 1 + max(breeding_number)
from
  mts_breeding
where
  offspring_colony_id = in_colony_id;

t_next_breeding_number number;

t_old_offspring_colony_id number;

cursor c_embryo_transfer_litters is
select l.*, b.name_prefix||b.breeding_number||'.' new_prefix
from
  mts_litter l,
  mts_breeding b,
  mir_embryo_transfer_procedure et,
  mir_scheduled_micro_injection smi,
  mir_micro_injection_request mir
where
  l.breeding_id = b.id and
  b.embryo_transfer_id = et.id and
  et.scheduled_micro_injection_id = smi.id and
  smi.micro_injection_request_id = mir.id and
  mir.id = in_mir_id
order by l.id
for update of l.name_prefix;

cursor c_chimeras is
select m.*, l.name_prefix||l.litter_number||lower(substr(m.name,length(m.name))) new_name
from
  mts_mouse m,
  mts_litter l,
  mts_breeding b,
  mir_embryo_transfer_procedure et,
  mir_scheduled_micro_injection smi,
  mir_micro_injection_request mir
where
  m.litter_id = l.id and
  l.breeding_id = b.id and
  b.embryo_transfer_id = et.id and
  et.scheduled_micro_injection_id = smi.id and
  smi.micro_injection_request_id = mir.id and
  mir.id = in_mir_id
order by l.id
for update of m.colony_info_id, m.name;

cursor c_chimera_matings is
select cb.*
from
  mts_breeding cb,
  mts_mouse m,
  mts_litter l,
  mts_breeding b,
  mir_embryo_transfer_procedure et,
  mir_scheduled_micro_injection smi,
  mir_micro_injection_request mir
where
  cb.male_id = m.id and
  m.litter_id = l.id and
  l.breeding_id = b.id and
  b.embryo_transfer_id = et.id and
  et.scheduled_micro_injection_id = smi.id and
  smi.micro_injection_request_id = mir.id and
  mir.id = in_mir_id
order by cb.id
for update of cb.name_prefix,cb.offspring_colony_id,cb.breeding_number;

cursor c_chimera_mates is
select f.*
from
  mts_mouse f,
  mts_breeding cb,
  mts_mouse m,
  mts_litter l,
  mts_breeding b,
  mir_embryo_transfer_procedure et,
  mir_scheduled_micro_injection smi,
  mir_micro_injection_request mir
where
  cb.female_id = f.id and
  cb.male_id = m.id and
  m.litter_id = l.id and
  l.breeding_id = b.id and
  b.embryo_transfer_id = et.id and
  et.scheduled_micro_injection_id = smi.id and
  smi.micro_injection_request_id = mir.id and
  mir.id = in_mir_id
order by f.id
for update of f.colony_info_id;

cursor c_chimera_litters is
select cl.*,cb.name_prefix||cb.breeding_number||'.' new_prefix
from
  mts_litter cl,
  mts_breeding cb,
  mts_mouse m,
  mts_litter l,
  mts_breeding b,
  mir_embryo_transfer_procedure et,
  mir_scheduled_micro_injection smi,
  mir_micro_injection_request mir
where
  cl.breeding_id = cb.id and
  cb.male_id = m.id and
  m.litter_id = l.id and
  l.breeding_id = b.id and
  b.embryo_transfer_id = et.id and
  et.scheduled_micro_injection_id = smi.id and
  smi.micro_injection_request_id = mir.id and
  mir.id = in_mir_id
order by cl.id
for update of cl.name_prefix;

cursor c_chimera_offspring is
select co.*,cl.name_prefix||cl.litter_number||lower(substr(co.name,length(co.name))) new_name
from
  mts_mouse co,
  mts_litter cl,
  mts_breeding cb,
  mts_mouse m,
  mts_litter l,
  mts_breeding b,
  mir_embryo_transfer_procedure et,
  mir_scheduled_micro_injection smi,
  mir_micro_injection_request mir
where
  co.litter_id = cl.id and
  cl.breeding_id = cb.id and
  cb.male_id = m.id and
  m.litter_id = l.id and
  l.breeding_id = b.id and
  b.embryo_transfer_id = et.id and
  et.scheduled_micro_injection_id = smi.id and
  smi.micro_injection_request_id = mir.id and
  mir.id = in_mir_id
order by co.id
for update of co.colony_info_id, co.name;

BEGIN
  open c_colony_info;
  fetch c_colony_info into t_colony_info;
  close c_colony_info;

  --update colony for MIR
  dbms_output.put_line('updating mir '||in_mir_id||' to new colony id '||in_colony_id);

  update mir_micro_injection_request
  set colony_info_id = in_colony_id
  where id = in_mir_id;
  dbms_output.put_line('rows affected: '||sql%rowcount);

  -- update embryo transfer matings (colony, name and number)
  for b in c_embryo_transfer_breedings loop

   t_old_offspring_colony_id := b.offspring_colony_id;

   if nvl(t_old_offspring_colony_id,-1) != in_colony_id then

     open c_next_breeding_number;
     fetch c_next_breeding_number into t_next_breeding_number;
     close c_next_breeding_number;

     if t_next_breeding_number is null then
        t_next_breeding_number := 1;
     end if;

     dbms_output.put_line('updating breeding '||b.id||'('||b.breeding_number||')'||' setting breeding number, colony and name prefix  from '||b.breeding_number||','||b.offspring_colony_id||','||b.name_prefix||' to '||t_next_breeding_number||','||in_colony_id||','||t_colony_info.colony_prefix);
     update mts_breeding
     set
       offspring_colony_id = in_colony_id,
       name_prefix = t_colony_info.colony_prefix,
       breeding_number = t_next_breeding_number
     where current of c_embryo_transfer_breedings;
     dbms_output.put_line('rows affected: '||sql%rowcount);
      else
     dbms_output.put_line('updating breeding '||b.id||'('||b.breeding_number||')'||' setting colony and name prefix from '||b.offspring_colony_id||','||b.name_prefix||' to '||in_colony_id||','||t_colony_info.colony_prefix);
     update mts_breeding
    set
      offspring_colony_id = in_colony_id,
      name_prefix = t_colony_info.colony_prefix
    where current of c_embryo_transfer_breedings;
    dbms_output.put_line('rows affected: '||sql%rowcount);
   end if;

  end loop;

  -- update embryo transfer recipients
  for m in c_embryo_transfer_recipients loop
    dbms_output.put_line('updating et recipient '||m.id||'('||m.name||') setting colony '||in_colony_id);
   update mts_mouse
   set
     colony_info_id = in_colony_id
   where current of c_embryo_transfer_recipients;
   dbms_output.put_line('rows affected: '||sql%rowcount);
  end loop;

  -- update embryo transfer litters
  for l in c_embryo_transfer_litters loop
    dbms_output.put_line('updating et litter '||l.id||' seting name prefix from '||l.name_prefix||' to '||l.new_prefix);
    update mts_litter
   set
     name_prefix = l.new_prefix
   where current of c_embryo_transfer_litters;
   dbms_output.put_line('rows affected: '||sql%rowcount);
  end loop;

  -- update chimeras
  for m in c_chimeras loop
    dbms_output.put_line('updating chimera '||m.id||'('||m.name||') setting colony_id, name from '||m.colony_info_id||','||m.name||' to '||in_colony_id||','||m.new_name);
    update mts_mouse
   set
     colony_info_id = in_colony_id,
     name = m.new_name
   where current of c_chimeras;
   dbms_output.put_line('rows affected: '||sql%rowcount);
  end loop;

  -- update chimera matings
  for cm in c_chimera_matings loop

   t_old_offspring_colony_id := cm.offspring_colony_id;

   if nvl(t_old_offspring_colony_id,-1) != in_colony_id then

     open c_next_breeding_number;
     fetch c_next_breeding_number into t_next_breeding_number;
     close c_next_breeding_number;

     if t_next_breeding_number is null then
        t_next_breeding_number := 1;
     end if;

     dbms_output.put_line('updating chimera breeding '||cm.id||'('||cm.breeding_number||')'||' setting breeding number, colony and name prefix  from '||cm.breeding_number||','||cm.offspring_colony_id||','||cm.name_prefix||' to '||t_next_breeding_number||','||in_colony_id||','||t_colony_info.colony_prefix);
     update mts_breeding
     set
       offspring_colony_id = in_colony_id,
       name_prefix = t_colony_info.colony_prefix,
       breeding_number = t_next_breeding_number
     where current of c_chimera_matings;
     dbms_output.put_line('rows affected: '||sql%rowcount);
      else
     dbms_output.put_line('updating chimera breeding '||cm.id||'('||cm.breeding_number||')'||' setting colony and name prefix from '||cm.offspring_colony_id||','||cm.name_prefix||' to '||in_colony_id||','||t_colony_info.colony_prefix);
     update mts_breeding
    set
      offspring_colony_id = in_colony_id,
      name_prefix = t_colony_info.colony_prefix
    where current of c_chimera_matings;
    dbms_output.put_line('rows affected: '||sql%rowcount);
   end if;

  end loop;

  -- update chimera mates
  for m in c_chimera_mates loop
    dbms_output.put_line('updating chimera mate '||m.id||'('||m.name||') setting colony '||in_colony_id);
   update mts_mouse
   set
     colony_info_id = in_colony_id
   where current of c_chimera_mates;
   dbms_output.put_line('rows affected: '||sql%rowcount);
  end loop;

  -- update chimera litters
  for l in c_chimera_litters loop
    dbms_output.put_line('updating chimera litter '||l.id||' seting name prefix from '||l.name_prefix||' to '||l.new_prefix);
    update mts_litter
   set
     name_prefix = l.new_prefix
   where current of c_chimera_litters;
   dbms_output.put_line('rows affected: '||sql%rowcount);
  end loop;

  -- update chimera offspring
  for m in c_chimera_offspring loop
    dbms_output.put_line('updating F1 '||m.id||'('||m.name||') setting colony_id, name from '||m.colony_info_id||','||m.name||' to '||in_colony_id||','||m.new_name);
    update mts_mouse
   set
     colony_info_id = in_colony_id,
     name = m.new_name
   where current of c_chimera_offspring;
   dbms_output.put_line('rows affected: '||sql%rowcount);
  end loop;


END MTS_MIR_MOVE_COLONY;

/* ====================================

MTS_NEXT_BREEDING_NUMBERS (in_colony_id number) return integer_list

 ==================================== */


FUNCTION MTS_NEXT_BREEDING_NUMBERS (in_colony_id number) return integer_list IS

output_list integer_list := integer_list();

cursor c_colony_exists is
select count(*)
from mts_colony_info
where id = in_colony_id;

cursor c_last_breeding_number is
select max(breeding_number) max_number
from mts_breeding
where offspring_colony_id = in_colony_id;

cursor c_breeding_number_used(in_number number) is
select count(*) in_use
from mts_breeding
where offspring_colony_id = in_colony_id
and breeding_number = in_number;

cursor c_breeding_number_offset is
select offset
from mts_breeding_offset
where colony_info_id = in_colony_id;

n_colony_exists number;

n_last_breeding_number number;

n_breeding_number_used number;

n_breeding_number_offset number;

n_index number := 1;

BEGIN
     if in_colony_id is null then return null;
	 end if;

	 open c_colony_exists;
	 fetch c_colony_exists into n_colony_exists;
	 close c_colony_exists;
	 if n_colony_exists = 0 then return null;
	 end if;

	 open c_last_breeding_number;
	 fetch c_last_breeding_number into n_last_breeding_number;
	 close c_last_breeding_number;

	 if n_last_breeding_number is null then
	   n_last_breeding_number := 1;
	 end if;

	 if n_last_breeding_number = 1 then
	   open c_breeding_number_offset;
	   fetch  c_breeding_number_offset into n_breeding_number_offset;
	   close c_breeding_number_offset;
	 end if;

	 if n_breeding_number_offset is not null then
	   n_last_breeding_number := n_breeding_number_offset + n_last_breeding_number;
	 else
	   n_breeding_number_offset := 1;
	 end if;

	 for n in n_breeding_number_offset .. (n_last_breeding_number + 100) loop
	 	 open c_breeding_number_used(n);
		 fetch c_breeding_number_used into n_breeding_number_used;
		 close c_breeding_number_used;
		 if n_breeding_number_used = 0 then
		   output_list.extend;
		   output_list(n_index) := n;
		   n_index := n_index + 1;
		 end if;
	 end loop;

	 return output_list;
END mts_next_breeding_numbers;

/******************************************************************************
  fetch_pipelines (in_mouse_id in number, in_delimiter in varchar2) return varchar2
******************************************************************************/
function fetch_pipelines (in_mouse_id in number, in_delimiter in varchar2) return varchar2
is
  t_pipelines varchar2(2000);
begin
for i in (
  select
    p.name pipeline
  from
    mts_cohort_pipeline_dict p,
    mts_cohort_mouse m,
	mts_cohort c
  where
    c.pipeline_dict_id = p.id and
    m.cohort_id = c.id and
	m.mouse_id = in_mouse_id
) loop
    t_pipelines := t_pipelines || i.pipeline || in_delimiter;
  end loop;
  return substr(t_pipelines, 1, length(t_pipelines)-length(in_delimiter));
end;

/******************************************************************************
function fetch_cohort (in_mouse_id in number, in_delimiter in varchar2) return varchar2
******************************************************************************/

function fetch_cohort (in_mouse_id in number, in_delimiter in varchar2) return varchar2
is
  t_cohorts varchar2(2000);
begin

for i in (
  select
    c.cohort_name
  from
    mts_cohort_mouse m,
	mts_cohort c
  where
    m.cohort_id = c.id and
	m.mouse_id = in_mouse_id
) loop
    t_cohorts := t_cohorts || i.cohort_name || in_delimiter;
  end loop;

  return substr(t_cohorts, 1, length(t_cohorts)-length(in_delimiter));
end;

/******************************************************************************
fetch_genotype (in_mouse_id number) return varchar2
******************************************************************************/
function fetch_genotype (in_mouse_id number) return varchar2 is

cursor c_alleles is
select
  decode(c.percent_chimeric,
  null,
	  decode(m.genotype_dict_id,
	    1, '+/+', --wildtype
	 	2, decode(a.inheritance_mode_id, -- heterozygous
		   		1,a.short_allele_symbol||'/+', -- dominant
				3,a.short_allele_symbol||'/+', -- semi-dominant
				'+/'||a.short_allele_symbol),
	 	3, a.short_allele_symbol||'/'||a.short_allele_symbol, --homozygous
	 	4, a.short_allele_symbol||'-?'),
   0, '+/+', -- zero percent chimera
   c.percent_chimeric||'% '||a.short_allele_symbol --chimera
  ) genotype -- unknown
from
  mts_mouse_allele m,
  typ_modified_allele a,
  mts_chimeric_mouse_data c
where
  m.mouse_id = in_mouse_id and
  m.allele_id = a.id and
  m.mouse_id = c.mouse_id(+);

v_genotype varchar2(4000) := '';

begin

  for a in c_alleles loop
    v_genotype := v_genotype||a.genotype||' ';
  end loop;

  return trim(nvl(v_genotype,'+/+'));

end fetch_genotype;

/******************************************************************************
   fetch_simple_genotype (in_mouse_id number) return varchar2
******************************************************************************/


function fetch_simple_genotype (in_mouse_id number) return varchar2 is

cursor c_alleles is
select
  decode(c.percent_chimeric,
  null,
	  decode(m.genotype_dict_id,
	    1, '+/+', --wildtype
	 	2, decode(a.inheritance_mode_id, -- heterozygous
		   		1,'-/+', -- dominant
				3,'-/+', -- semi-dominant
				'+/-'),
	 	3, '-/-', --homozygous
	 	4, '?'),
   0, '+/+', -- zero percent chimera
   c.percent_chimeric||'%' --chimera
  ) genotype -- unknown
from
  mts_mouse_allele m,
  typ_modified_allele a,
  mts_chimeric_mouse_data c
where
  m.mouse_id = in_mouse_id and
  m.allele_id = a.id and
  m.mouse_id = c.mouse_id(+);

v_genotype varchar2(4000) := '';

begin

  -- just return the first allele found (for now)
  open c_alleles;
  fetch c_alleles into v_genotype;
  close c_alleles;

  return trim(nvl(v_genotype,'+/+'));

end fetch_simple_genotype;


/******************************************************************************
   FETCH_GENOTYPE_BY_ALLELE(in_mouse_id number, in_allele_id number)
******************************************************************************/
FUNCTION FETCH_GENOTYPE_BY_ALLELE(in_mouse_id number, in_allele_id number) RETURN NUMBER IS

cursor c_has_allele is
select genotype_dict_id
from
  mts_mouse_allele a
where
  a.mouse_id = in_mouse_id and
  a.allele_id = in_allele_id
;

t_genotype number;


BEGIN

  open c_has_allele;
  fetch c_has_allele into t_genotype;
  if c_has_allele%NOTFOUND then
    t_genotype := 1; --wildtype
  end if;
  close c_has_allele;

  return t_genotype;

END FETCH_GENOTYPE_BY_ALLELE;

/******************************************************************************
   FETCH_FETCH_COHORT_GENOTYPE(in_cohort_id number, in_allele_id number) RETURN NUMBER
******************************************************************************/

FUNCTION FETCH_COHORT_GENOTYPE(in_cohort_id number, in_allele_id number) RETURN NUMBER IS

cursor c_has_allele is
select distinct genotype_dict_id
from
  mts_mouse_allele a,
  mts_cohort_mouse c
where
  c.cohort_id = in_cohort_id and
  a.allele_id = in_allele_id and
  a.mouse_id = c.mouse_id
;

t_genotype number;

t_loop_index number := 1;

BEGIN

  for a in c_has_allele loop
    if t_loop_index > 1 then
	  t_genotype := -1;
	  exit;
	end if;
    t_genotype := a.genotype_dict_id;
	t_loop_index := t_loop_index + 1;
  end loop;

  if t_genotype is null then
    t_genotype := 1; --wildtype
  end if;

  return t_genotype;

END FETCH_COHORT_GENOTYPE;

end mts;
/

CREATE OR REPLACE PACKAGE MIR AS
/******************************************************************************
   NAME:       CRQ
   PURPOSE:

   REVISIONS:
   Ver        Date        Author           Description
   ---------  ----------  ---------------  ------------------------------------
   V3.0.39       18/04/2008             wl1 Created this package.
******************************************************************************/


  FUNCTION ADDALLELESYNONYMS (in_allele_id IN NUMBER) RETURN VARCHAR2;
  FUNCTION CALC_PERCENT_NUMBER (fraction float, total float) RETURN number;
  FUNCTION IN_RANGE (test_number number, lo_range number, hi_range number) RETURN varchar2;
  FUNCTION MIR_F0_STATUS(in_smi_id number) RETURN VARCHAR2;
  FUNCTION MIR_F1_STATUS(in_smi_id number) RETURN VARCHAR2;
END MIR;
/

CREATE OR REPLACE PACKAGE BODY MIR AS
/******************************************************************************
   ADDALLELESYNONYMS (in_allele_id IN NUMBER) RETURN VARCHAR2
******************************************************************************/
FUNCTION ADDALLELESYNONYMS (in_allele_id IN NUMBER) RETURN VARCHAR2
IS
alleleSynonymString VARCHAR2(2000);
BEGIN
FOR rowtarget IN(
 SELECT ALLELE_SYNONYM FROM TYP_ALLELE_SYNONYM WHERE ALLELE_ID = in_allele_id
)
LOOP
alleleSynonymString := alleleSynonymString || rowTarget.ALLELE_SYNONYM || ', ';
END LOOP;
RETURN SUBSTR(alleleSynonymString, 1, LENGTH(alleleSynonymString)-2);
 END ADDALLELESYNONYMS;


/******************************************************************************
   CALC_PERCENT_NUMBER (fraction float, total float) RETURN number
   ******************************************************************************/

 FUNCTION CALC_PERCENT_NUMBER (fraction float, total float) RETURN number IS

 /****
  Calculate the percent for a given fraction of a total.
  return null if total is zero
  *****/
BEGIN
  if total = 0 or total is null or fraction is null then return null;
  else
  	  return round((fraction/total)*100);
  end if;


END calc_percent_number;

/******************************************************************************
   CALC_IN_RANGE (test_number number, lo_range number, hi_range number) RETURN varchar2
   ******************************************************************************/

FUNCTION IN_RANGE (test_number number, lo_range number, hi_range number) RETURN varchar2 IS

BEGIN
  if test_number is null then return null;
  elsif test_number between lo_range and hi_range then return 'true';
  else return null;
  end if;
END in_range;
/******************************************************************************
   MIR_F0_STATUS(in_smi_id number) RETURN VARCHAR2
   ******************************************************************************/
FUNCTION MIR_F0_STATUS(in_smi_id number) RETURN VARCHAR2 IS

cursor c_f0_data is
select
  count(distinct b.female_id) embryo_recipients,
  count(decode(l.not_pregnant,1,1,null)) not_pregnant,
  count(m.id) male_chimeras,
  min(l.due_date) due_date
from
  mts_breeding b,
  mts_litter l,
  mir_embryo_transfer_procedure e,
  (
   select
     m.id,
  	 m.litter_id
   from
     mts_mouse m,
  	 mts_chimeric_mouse_data c
   where
     c.mouse_id = m.id and
  	 m.gender_dict_id = 2 and
 	 m.wean_date is not null and
	 c.percent_chimeric > 0
  ) m
where
  e.scheduled_micro_injection_id = in_smi_id and
  b.embryo_transfer_id = e.id and
  l.breeding_id = b.id and
  m.litter_id(+) = l.id
;

t_embryo_recipients number;
t_not_pregnant number;
t_male_chimera number;
t_due_date date;

t_return_string varchar2(50);

BEGIN
  open c_f0_data;
  fetch c_f0_data into t_embryo_recipients, t_not_pregnant, t_male_chimera, t_due_date;
  close c_f0_data;

  if nvl(t_embryo_recipients,0) = 0 then
    t_return_string := null;
  elsif t_embryo_recipients - t_not_pregnant = 0 then
    t_return_string := 'Failed: None Pregnant';
  elsif t_due_date + 21 > sysdate then
    t_return_string := null;
  else
    t_return_string := t_male_chimera||' Male Chimeras Weaned';
  end if;

  return t_return_string;

END MIR_F0_STATUS;


/******************************************************************************
   MIR_F1_STATUS(in_smi_id number) RETURN VARCHAR2
   ******************************************************************************/

FUNCTION MIR_F1_STATUS(in_smi_id number) RETURN VARCHAR2 IS

cursor c_f1_data is
select
  count(distinct decode(f1.gender_dict_id,1,f1.id,null)) f1_females,
  count(distinct decode(f1.gender_dict_id,2,f1.id,null)) f1_males,
  count(distinct f0b.id) f0_breedings
from
  mts_mouse f1,
  mts_mouse f0,
  mts_breeding f0b,
  mts_litter f1l,
  mts_breeding etb,
  mts_litter f0l,
  mir_embryo_transfer_procedure et,
  mts_mouse_allele f1a,
  mir_scheduled_micro_injection smi,
  mir_micro_injection_request mir
where
  et.id = etb.embryo_transfer_id and
  etb.id = f0l.breeding_id and
  f0.litter_id = f0l.id and
  f0.id = f0b.male_id and
  f0b.id = f1l.breeding_id and
  f1l.id = f1.litter_id and
  f1.id = f1a.mouse_id and
  f1a.genotype_dict_id = 2 /* heterozygous */ and
  smi.id = et.scheduled_micro_injection_id and
  mir.id = smi.micro_injection_request_id and
  mir.endpoint_dict_id = 1 /* f1 endpoint */ and
  smi.id = in_smi_id
;

t_f1_females number;
t_f1_males number;
t_f0_breedings number;

t_return_string varchar2(50);

BEGIN
	 open c_f1_data;
	 fetch c_f1_data into t_f1_females, t_f1_males, t_f0_breedings;
	 close c_f1_data;

	 if nvl(t_f0_breedings ,0) = 0 then
	   t_return_string := null;
	 else
	   t_return_string := t_f1_males + t_f1_females||' Hets';
	   if t_f1_males + t_f1_females > 0 then
	   	  t_return_string := t_return_string||' ('||t_f1_males||'M+'||t_f1_females||'F'||')';
	   end if;
	 end if;

	 return t_return_string;

END MIR_F1_STATUS;

END MIR;
/

CREATE OR REPLACE PACKAGE HTL AS
/******************************************************************************
   NAME:       HTL
   PURPOSE:

   REVISIONS:
   Ver        Date        Author           Description
   ---------  ----------  ---------------  ------------------------------------
   V3.0.39      18/04/2008             wl1 Created this package.
   ******************************************************************************/


 FUNCTION BLOCKTYPE_TISSUENAME (bt_id IN NUMBER) RETURN VARCHAR2;



END HTL;
/

CREATE OR REPLACE PACKAGE BODY HTL AS
/******************************************************************************
   BLOCKTYPE_TISSUENAME (bt_id IN NUMBER) RETURN VARCHAR2
   *****************************************************************************/
FUNCTION BLOCKTYPE_TISSUENAME (bt_id IN NUMBER) RETURN VARCHAR2
IS
tissueString VARCHAR2(2000);
BEGIN

FOR rowtarget IN(
  select t.name from HTL_TISSUE t
  join HTL_BLOCK_TYPE_2_TISSUE bt2t on bt2t.TISSUE_ID = t.ID
  where bt2t.BLOCK_TYPE_ID = bt_id
)
LOOP
tissueString := tissueString || rowtarget.name || ',' ||CHR(13);
END LOOP;
RETURN SUBSTR(tissueString, 1, LENGTH(tissueString)-2);
 END;

 END HTL;
/

CREATE OR REPLACE PACKAGE CRQ AS
/******************************************************************************
   NAME:       CRQ
   PURPOSE:

   REVISIONS:
   Ver        Date        Author           Description
   ---------  ----------  ---------------  ------------------------------------
   V3.0.39      18/04/2008             wl1 Created this package.
   ******************************************************************************/


  FUNCTION ADDALLELESFORCRYOREQUEST (cryo_req_id IN NUMBER) RETURN VARCHAR2;
  FUNCTION ADDHOMOZYGOUSLETHALS (cryo_req_id IN NUMBER) RETURN VARCHAR2;
  FUNCTION ADDSTRAINSFORCRYOREQUEST (cryo_req_id IN NUMBER) RETURN VARCHAR2;



END CRQ;
/

CREATE OR REPLACE PACKAGE BODY CRQ AS
/******************************************************************************
   ADDALLELESFORCRYOREQUEST (cryo_req_id IN NUMBER) RETURN VARCHAR2
   ******************************************************************************/
FUNCTION ADDALLELESFORCRYOREQUEST (cryo_req_id IN NUMBER) RETURN VARCHAR2
IS
testString VARCHAR2(2000);
BEGIN
FOR rowtarget IN(
 SELECT  tma.OFFICIAL_NAME_SUPERSCRIPT AS superScriptName, g.primary_name AS geneName FROM CRQ_CRYO_REQUEST ccr,
  MTS_COLONY_INFO mci,
  MTS_COLONY_ALLELE mca, TYP_MODIFIED_ALLELE tma, GNM_GENE g WHERE ccr.ID = cryo_req_id AND
  ccr.COLONY_ID = mci.ID AND
  mci.ID = mca.COLONY_ID AND
  mca.MODIFIED_ALLELE_ID = tma.ID AND
  tma.GENE_ID = g.ID
  )
LOOP
testString := testString || rowTarget.geneName || '('|| rowtarget.superScriptName || ')' || ',' || CHR(13);
END LOOP;
RETURN SUBSTR(testString, 1, LENGTH(testString)-2);
 END Addallelesforcryorequest;


/******************************************************************************
   FUNCTION ADDHOMOZYGOUSLETHALS (cryo_req_id IN NUMBER) RETURN VARCHAR2
   ******************************************************************************/
 FUNCTION ADDHOMOZYGOUSLETHALS (cryo_req_id IN NUMBER) RETURN VARCHAR2
IS
testString VARCHAR2(2000);
BEGIN
FOR rowtarget IN(
 SELECT tma.IS_HOMOZYGOUS_LETHAL AS isHomozygousLethal FROM CRQ_CRYO_REQUEST ccr, MTS_COLONY_INFO mci,
  MTS_COLONY_ALLELE mca, TYP_MODIFIED_ALLELE tma WHERE ccr.ID = cryo_req_id AND
  ccr.COLONY_ID = mci.ID AND
  mci.ID = mca.COLONY_ID AND
  mca.MODIFIED_ALLELE_ID = tma.ID
  )
LOOP
testString := testString || rowtarget.isHomozygousLethal || ',' || CHR(13);
END LOOP;
RETURN SUBSTR(testString, 1, LENGTH(testString)-2);
 END Addhomozygouslethals;

/******************************************************************************
   ADDSTRAINSFORCRYOREQUEST (cryo_req_id IN NUMBER)
   ******************************************************************************/

FUNCTION ADDSTRAINSFORCRYOREQUEST (cryo_req_id IN NUMBER) RETURN VARCHAR2
IS
testString VARCHAR2(2000);
BEGIN
FOR rowtarget IN(
 SELECT ts.NAME AS strain_name FROM CRQ_CRYO_REQUEST ccr, MTS_COLONY_INFO mci,
  MTS_COLONY_STRAIN mcs, TYP_STRAIN ts WHERE ccr.ID = cryo_req_id AND
  ccr.COLONY_ID = mci.ID AND
  mci.ID = mcs.COLONY_ID AND
  mcs.STRAIN_ID = ts.ID
  )
LOOP
testString := testString || rowtarget.strain_name || ',' ||CHR(13);
END LOOP;
RETURN SUBSTR(testString, 1, LENGTH(testString)-2);
 END Addstrainsforcryorequest;

END CRQ;
/


CREATE OR REPLACE FORCE VIEW MTS_MOUSE_VW
(ID, LITTER_ID, NAME, RFID_TAG, EDIT_DATE,
 COAT_COLOUR_DICT_ID, COAT_COLOUR, EYE_COLOUR_DICT_ID, EYE_COLOUR, EARMARK_DICT_ID,
 EARMARK, EARMARK_LEFT, EARMARK_RIGHT, BIRTH_DATE, AGE_IN_WEEKS,
 DEATH_DATE, AGE_AT_DEATH, CAUSE_OF_DEATH_DICT_ID, CAUSE_OF_DEATH, EDITED_BY,
 WEAN_DATE, CAGE_ID, CAGE_NAME, CAGE_BARCODE, RACK_ID,
 RACK_NAME, ROOM_ID, ROOM_NAME, CURRENT_OWNER_ID, CURRENT_OWNER,
 CURRENT_PROJECT_LICENCE_ID, CURRENT_PROJECT_LICENCE, CURRENT_PROTOCOL_ID, CURRENT_PROTOCOL_CODE, CHECK_NUMBER,
 GENDER_DICT_ID, GENDER, MOUSE_STRAIN_DICT_ID, STRAIN, STATUS,
 CREATOR_ID, CREATED_DATE, BARCODE, COMMENTS, IS_NON_BREEDER,
 IS_SENTINEL, GENERATION, COLONY_NAME, COLONY_PREFIX, COLONY_INFO_ID,
 ARRIVAL_DATE, LATEST_PLUG_DATE, BREEDING_NAME, GENOTYPE, FATHER_NAME,
 FATHER_GENOTYPE, MOTHER_NAME, MOTHER_GENOTYPE, COHORTS, PIPELINES)
AS
select
  m.id,
  m.litter_id,
  m.name,
  m.rfid_tag,
  m.edit_date,
  m.coat_colour_dict_id,
  c.name||decode(chim.percent_chimeric,null,null,' ('||chim.percent_chimeric||'%)') coat_colour,
  m.eye_colour_dict_id,
  e.name eye_colour,
  m.earmark_dict_id,
  ear.name earmark,
  m.earmark_left,
  m.earmark_right,
  m.birth_date,
  round((nvl(m.death_date,sysdate) - m.birth_date)/7,1) age_in_weeks,
  m.death_date,
  round((m.death_date - m.birth_date)/7,1) age_at_death,
  m.cause_of_death_dict_id,
  d.name cause_of_death,
  m.edited_by,
  m.wean_date,
  m.cage_id,
  l.cage_name,
  l.cage_barcode,
  l.rack_id,
  l.rack_name,
  l.room_id,
  l.room_name,
  m.current_owner_id,
  owner.first_name||' '||owner.last_name current_owner,
  b.project_licence_id current_project_licence_id,
  b.licence_number current_project_licence,
  b.protocol_id current_protocol_id,
  b.protocol_code current_protocol_code,
  m.check_number,
  m.gender_dict_id,
  s.name gender,
  m.mouse_strain_dict_id,
  t.name strain,
  m.status,
  m.creator_id,
  m.created_date,
  m.barcode,
  m.comments,
  m.is_non_breeder,
  m.is_sentinel,
  m.generation,
  colony.colony_name,
  colony.colony_prefix,
  m.colony_info_id,
  m.arrival_date,
  m.latest_plug_date,
  breeding.breeding_name,
  mts.fetch_genotype(m.id) genotype,
  p.father_name,
  decode(m.generation,'F0',null,decode(p.male_id,null,null,mts.fetch_genotype(p.male_id))) father_genotype,
  p.mother_name,
  decode(m.generation,'F0',null,decode(p.female_id,null,null,mts.fetch_genotype(p.female_id))) mother_genotype,
  mts.fetch_cohort(m.id,', ') cohorts,
  mts.fetch_pipelines(m.id,', ') pipelines
from
  mts_mouse m,
  mts_coat_colour_dict c,
  mts_eye_colour_dict e,
  mts_earmark_dict ear,
  mts_cause_of_death_dict d,
  per_person owner,
  mts_gender_dict s,
  mts_cage_vw l,
  mts_mouse_current_19b_mv b,
  typ_strain t,
  mts_colony_info colony,
  mts_current_breeding_mv breeding,
  mts_chimeric_mouse_data chim,
  (select b.male_id, b.female_id, l.id litter_id, decode(b.embryo_transfer_id,null,sire.name, null) father_name, decode(b.embryo_transfer_id,null,dam.name,null) mother_name
   from
    mts_litter l,
    mts_breeding b,
 mts_mouse sire,
 mts_mouse dam
   where
    l.breeding_id = b.id and
 b.male_id = sire.id and
 b.female_id = dam.id
  ) p
where
  m.coat_colour_dict_id = c.id(+) and
  m.eye_colour_dict_id = e.id(+) and
  m.earmark_dict_id = ear.id(+) and
  m.cause_of_death_dict_id = d.id(+) and
  m.current_owner_id = owner.person_id(+) and
  m.gender_dict_id = s.id(+) and
  m.cage_id = l.cage_id(+) and
  m.mouse_strain_dict_id = t.id(+) and
  m.colony_info_id = colony.id(+) and
  m.id = b.mouse_id(+) and
  m.id = breeding.mouse_id(+) and
  m.id = chim.mouse_id(+) and
  m.litter_id = p.litter_id(+);



CREATE OR REPLACE FORCE VIEW CRQ_CRYO_REQUEST_LIST_VW
(ID, STATUS_DICT_ID, STATUS, CANCEL_REASON, PERSON_ID,
 REQUESTER_NAME, TEAM_NUMBER, COLONY_INFO_ID, COLONY_NAME, COLONY_PREFIX,
 APPENDED_STRAINS, APPENDED_ALLELES, APPEND_HOMOZYGOUS_LETHAL, FEMALE_STRAIN, TOTAL_PLUGGED,
 TOTAL_SUPEROVULATED, TOTAL_ATTEMPTS, TOTAL_THAW_ATTEMPTS, TOTAL_FROZEN, TARGET_COUNT,
 CREATED_DATE)
AS
SELECT   ccr.ID, ccr.status_dict_id, crsd.NAME status, ccr.cancel_reason, p.person_id,
            p.first_name || ' ' || p.last_name AS requester_name,
            t.team_number, mci.ID colony_info_id, mci.colony_name,
            mci.colony_prefix,
            CRQ.Addstrainsforcryorequest (ccr.ID) appended_strains,
            CRQ.Addallelesforcryorequest (ccr.ID) appended_alleles,
            CRQ.Addhomozygouslethals (ccr.ID) append_homozygous_lethal,
            crstd.NAME female_strain,
            NVL (SUM (sjlv.total_plugged), 0) total_plugged,
            NVL (SUM (sjlv.total_superovulated), 0) total_superovulated,
            NVL (rac.total_attempts, 0) total_attempts,
   NVL (rat.TOTAL_THAW_ATTEMPTS, 0) total_thaw_attempts,
            NVL (SUM (sjlv.total_frozen_count), 0) total_frozen,
            NVL (ccr.target_count, 0) target_count, ccr.created_date
       FROM CRQ_CRYO_REQUEST ccr,
            MTS_COLONY_INFO mci,
            typ_strain crstd,
            crq_scheduled_job_list_vw sjlv,
            crq_req_attempt_count_list_vw rac,
   crq_thaw_attempt_count_list rat,
            CRQ_CRYO_REQUEST_STATUS_DICT crsd,
            PER_PERSON p,
            PER_TEAM t
      WHERE ccr.colony_id = mci.ID(+)
        AND ccr.ID = sjlv.cryo_request_id(+)
        AND ccr.ID = rac.ID(+)
  AND ccr.ID = rat.ID(+)
        AND ccr.status_dict_id = crsd.ID(+)
        AND ccr.female_strain_dict_id = crstd.ID(+)
        AND ccr.requester_id = p.person_id(+)
        AND p.team_id = t.ID(+)
        AND sjlv.status_id(+) ! = 4
        AND sjlv.cryo_request_id(+) IS NOT NULL
   GROUP BY ccr.ID,
            ccr.status_dict_id,
            rac.total_attempts,
   rat.TOTAL_THAW_ATTEMPTS,
            crsd.NAME,
            p.person_id,
            p.first_name || ' ' || p.last_name,
            t.team_number,
            mci.ID,
            mci.colony_name,
            mci.colony_prefix,
            crstd.NAME,
            ccr.target_count,
            ccr.created_date,
   ccr.cancel_reason;



CREATE OR REPLACE FORCE VIEW FAX_MOUSE_VW
(ID, MOUSE, COAT_COLOUR, EYE_COLOUR, EARMARK,
 BIRTH_DATE, AGE_IN_WEEKS, DEATH_DATE, CAUSE_OF_DEATH, WEAN_DATE,
 GENDER, STRAIN, BARCODE, COLONY, COLONY_PREFIX,
 GENOTYPE, COHORT_NAME, WEIGHT)
AS
SELECT m.id ,m.NAME mouse,
          c.NAME
       || DECODE (chim.percent_chimeric,
                  NULL, NULL,
                  ' (' || chim.percent_chimeric || '%)'
                 ) coat_colour,
       e.NAME eye_colour, ear.NAME earmark, m.birth_date,
       ROUND ((NVL (m.death_date, SYSDATE) - m.birth_date) / 7,
              1) age_in_weeks, m.death_date, d.NAME cause_of_death,
       m.wean_date, s.NAME gender, t.NAME strain, m.barcode,
       colony.colony_name colony, colony.colony_prefix colony_prefix,
       mts.fetch_genotype (m.ID) genotype, mts.fetch_cohort(m.ID, ':') cohort_name,
      w.weight_value||w.weight_units weight
  FROM mts_mouse m,
       mts_coat_colour_dict c,
       mts_eye_colour_dict e,
       mts_earmark_dict ear,
       mts_cause_of_death_dict d,
       mts_gender_dict s,
       typ_strain t,
       mts_colony_info colony,
       mts_chimeric_mouse_data chim,
    mts_mouse_current_weight_vw w
 WHERE m.coat_colour_dict_id = c.ID(+)
   AND m.eye_colour_dict_id = e.ID(+)
   AND m.earmark_dict_id = ear.ID(+)
   AND m.cause_of_death_dict_id = d.ID(+)
   AND m.gender_dict_id = s.ID(+)
   AND m.mouse_strain_dict_id = t.ID(+)
   AND m.colony_info_id = colony.ID(+)
   AND m.ID = chim.mouse_id(+)
   and m.id = w.mouse_id;



CREATE OR REPLACE FORCE VIEW REP_EMBRYO_TRANSFER_BIRTHS
(ID, MICRO_INJECTION_REQUEST_ID, BIRTH_DATE, CELL_LINE_NAME, CLONE_NAME,
 PUPS_BORN, BLASTS_TRANSFERRED, PERCENT_BORN_TRANSFERRED, CHIMERAS_BORN, PERCENT_CHIMERAS_BORN)
AS
select
  m.micro_injection_request_id id,
  m.micro_injection_request_id,
  min(l.birth_date) birth_date,
  cel.cell_line_name,
  cel.clone_name,
  sum(nvl(l.number_born,0)) pups_born,
  sum(nvl(et.number_left,0) + nvl(et.number_right,0)) blasts_transferred,
  mir.calc_percent_number(sum(nvl(l.number_born,0)), sum(nvl(et.number_left,0) + nvl(et.number_right,0))) percent_born_transferred,
  count(distinct ch.mouse_id) chimeras_born,
  mir.calc_percent_number(count(distinct ch.mouse_id),sum(nvl(l.number_born,0))) percent_chimeras_born
from
  mir_gene_to_embryo_transfer m,
  mts_litter l,
  mir_cell_line cel,
  mir_embryo_transfer_procedure et,
  (select
    m.litter_id,
 m.id mouse_id
   from
     mts_mouse m,
  mts_litter l,
  mts_chimeric_mouse_data c
   where
    m.id = c.mouse_id and
 m.litter_id = l.id
   ) ch
where
  m.breeding_id = l.breeding_id and
  m.embryo_transfer_id = et.id and
  m.cell_line_id = cel.id and
  ch.litter_id(+) = m.litter_id and
  l.birth_date < trunc(sysdate)-1
group by
  m.micro_injection_request_id,
  cel.cell_line_name,
  cel.clone_name;

CREATE OR REPLACE FORCE VIEW MIR_SUMMARY_STATS_VW
(ID, MI_REQUEST_ID, PARENTAL_LINE, LATEST_MI_DATE, NUMBER_TRANSFERRED,
 NUMBER_BORN, PERCENT_BORN, NUMBER_CHIMERIC, PERCENT_CHIMERIC, NUMBER_MALE,
 PERCENT_MALE, NUMBER_FEMALE, NUMBER_MALE_100_PERCENT, NUMBER_MALE_GT_80_PERCENT, NUMBER_MALE_40_TO_80_PERCENT,
 NUMBER_MALE_LT_40_PERCENT, F0_BREEDINGS, F0_BREEDINGS_WITH_OFFSPRING, PERCENT_FERTILITY, F1_GERM_LINE_MICE,
 F1_NON_GERM_LINE_MICE, F1_TOTAL, CHIMERAS_WITH_GLT, PERCENT_GLT, NUMBER_100_PERCENT_GLT,
 NUMBER_GT_50_PERCENT_GLT, NUMBER_BTW_10_50_PERCENT_GLT, NUMBER_LT_10_PERCENT_GLT)
AS
select
 s.mi_request_id id,
 s.mi_request_id,
 s.parental_line,
 s.latest_mi_date,
 s.number_transferred,
 s.number_born,
 mir.calc_percent_number(s.number_born, s.number_transferred) percent_born,
 s.number_chimeric,
 mir.calc_percent_number(s.number_chimeric, s.number_born) percent_chimeric,
 s.number_male,
 mir.calc_percent_number(s.number_male, s.number_chimeric) percent_male,
 s.number_female,
 s.number_100_percent number_male_100_percent,
 s.number_gt_80_percent number_male_gt_80_percent,
 s.number_40_to_80_percent number_male_40_to_80_percent,
 s.number_lt_40_percent number_male_lt_40_percent,
 s.f0_breedings,
 s.f0_breedings_with_offspring,
 mir.calc_percent_number(s.f0_breedings_with_offspring, s.f0_breedings) percent_fertility,
 s.f1_germ_line_mice,
 s.f1_non_germ_line_mice,
 s.f1_total,
 s.chimeras_with_glt,
 mir.calc_percent_number(s.chimeras_with_glt, s.f0_breedings) percent_glt,
 s.number_100_percent_glt,
 s.number_gt_50_percent_glt,
 s.number_btw_10_50_percent_glt,
 s.number_lt_10_percent_glt
from
  mir_combined_summary s;

CREATE OR REPLACE FORCE VIEW PHN_PIPELINE_4_ABC_VW
("Strain", "cohort_name", "gene_name", "run_date", "Mouse_name",
 "genotype", "age_in_weeks", "gender", MCH, MCV,
 PLT, HCT, HGB, RBC, WBC,
 MCHC, RDW, MPV, "percent_LYM", "percent_MON",
 "percent_GRA", "num_LYM", "num_MON", "num_GRA")
AS
select
t.name as Strain,
mc.COHORT_NAME,
gn.primary_name as gene_name,
r.run_date,
m.NAME as Mouse_Name,
mts.fetch_genotype(m.id) as genotype,
round((nvl(m.death_date,sysdate) - m.birth_date)/7,1) as age_in_weeks,
g.name as Gender,
avg(decode(p.id,8,d.value,null)) as MCH,
avg(decode(p.id,7,d.value,null)) as MCV,
avg(decode(p.id,6,d.value,null)) as PLT,
avg(decode(p.id,5,d.value,null)) as HCT,
avg(decode(p.id,4,d.value,null)) as HGB,
avg(decode(p.id,3,d.value,null)) as RBC,
avg(decode(p.id,2,d.value,null)) as WBC,
avg(decode(p.id,9,d.value,null)) as MCHC,
avg(decode(p.id,10,d.value,null)) as RDW,
avg(decode(p.id,11,d.value,null)) as MPV,
avg(decode(p.id,12,d.value,null)) as percent_LYM,
avg(decode(p.id,13,d.value,null)) as percent_MON,
avg(decode(p.id,14,d.value,null)) as percent_GRA,
avg(decode(p.id,15,d.value,null)) as num_LYM,
avg(decode(p.id,16,d.value,null)) as num_MON,
avg(decode(p.id,17,d.value,null)) as num_GRA
from mts_mouse m,
     phn_bloods_run r,
     phn_bloods_data d,
     phn_parameter_dict p,
     mts_gender_dict g,
     mts_cohort_mouse c,
     mts_cohort mc,
     mts_colony_info ci,
     mts_mouse_allele ma,
     mts_genotype_dict gd,
     mts_cohort_pipeline_dict pd,
     gnm_gene gn,
     typ_strain t,
     (select a.colony_id, t.gene_id
      from
      mts_colony_allele a,
      typ_modified_allele t
      where
      a.modified_allele_id = t.id
     ) z
where
     r.MOUSE_ID = m.ID
and m.MOUSE_STRAIN_DICT_ID = t.id(+)
and  m.id = c.MOUSE_ID
and  c.COHORT_ID = mc.ID
and  m.GENDER_DICT_ID = g.id
and  r.id = d.RUN_ID
and  d.PARAMETER_ID = p.ID
and r.INSTRUMENT_ID = 1
and m.id = c.mouse_id
and c.cohort_id = mc.id
and mc.PIPELINE_DICT_ID = pd.id
and pd.id = 4
and m.id = ma.mouse_id(+)
and ma.genotype_dict_id = gd.id(+)
and m.colony_info_id = ci.id
and ci.id = z.colony_id(+)
and gn.id(+) = z.gene_id
group by t.name,mc.cohort_name,gn.primary_name,r.run_date,m.name,mts.fetch_genotype(m.id),round((nvl(m.death_date,sysdate) - m.birth_date)/7,1),g.name
order by mc.cohort_name, m.name,g.name;

CREATE OR REPLACE FORCE VIEW MTS_PROCEDURE_NO_PHENO_DICT_VW
(ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE)
AS
SELECT ID,NAME,ORDER_BY,DESCRIPTION,ACTIVE
FROM MTS_PROCEDURE_DICT
WHERE IS_PHENOTYPING = 0;

CREATE OR REPLACE FORCE VIEW PHN_ABC_VW
("Strain", "cohort_name", "run_date", "mouse_name", "genotype",
 "age_in_weeks", "gender", "pipeline", MCH, MCV,
 PLT, HCT, HGB, RBC, WBC,
 MCHC, RDW, MPV, "percent_LYM", "percent_MON",
 "percent_GRA", "num_LYM", "num_MON", "num_GRA")
AS
select
t.name as strain,
mc.COHORT_NAME,
r.run_date assay_date,
m.NAME as Mouse_Name,
mts.fetch_genotype(m.id) as genotype,
round((nvl(m.death_date,sysdate) - m.birth_date)/7,1) as age_in_weeks,
g.name as Gender,
pd.name as pipeline,
avg(decode(p.id,8,decode(d.value,'0',null,d.value),null)) as MCH,
avg(decode(p.id,7,decode(d.value,'0',null,d.value),null)) as MCV,
avg(decode(p.id,6,decode(d.value,'0',null,d.value),null)) as PLT,
avg(decode(p.id,5,decode(d.value,'0',null,d.value),null)) as HCT,
avg(decode(p.id,4,decode(d.value,'0',null,d.value),null)) as HGB,
avg(decode(p.id,3,decode(d.value,'0',null,d.value),null)) as RBC,
avg(decode(p.id,2,decode(d.value,'0',null,d.value),null)) as WBC,
avg(decode(p.id,9,decode(d.value,'0',null,d.value),null)) as MCHC,
avg(decode(p.id,10,decode(d.value,'0',null,d.value),null)) as RDW,
avg(decode(p.id,11,decode(d.value,'0',null,d.value),null)) as MPV,
avg(decode(p.id,12,decode(d.value,'0',null,d.value),null)) as percent_LYM,
avg(decode(p.id,13,decode(d.value,'0',null,d.value),null)) as percent_MON,
avg(decode(p.id,14,decode(d.value,'0',null,d.value),null)) as percent_GRA,
avg(decode(p.id,15,decode(d.value,'0',null,d.value),null)) as num_LYM,
avg(decode(p.id,16,decode(d.value,'0',null,d.value),null)) as num_MON,
avg(decode(p.id,17,decode(d.value,'0',null,d.value),null)) as num_GRA
from mts_mouse_vw m,
     phn_bloods_run r,
     phn_bloods_data d,
     phn_parameter_dict p,
     mts_gender_dict g,
     mts_cohort_mouse c,
     mts_cohort mc,
     mts_mouse_allele ma,
     mts_genotype_dict gd,
     mts_cohort_pipeline_dict pd,
     typ_strain t
where
     r.MOUSE_ID = m.ID
and  m.id = c.MOUSE_ID
and m.MOUSE_STRAIN_DICT_ID = t.id(+)
and  c.COHORT_ID = mc.ID
and  m.GENDER_DICT_ID = g.id
and  r.id = d.RUN_ID
and  d.PARAMETER_ID = p.ID
and r.INSTRUMENT_ID = 1
and m.id = c.mouse_id
and ma.mouse_id(+) = m.id
and ma.genotype_dict_id = gd.id(+)
and mc.PIPELINE_DICT_ID = pd.id
group by t.name,mc.cohort_name,r.run_date,m.name,mts.fetch_genotype(m.id),round((nvl(m.death_date,sysdate) - m.birth_date)/7,1),g.name,pd.name
order by  pd.name,g.name, m.age_in_weeks, mc.cohort_name;

CREATE OR REPLACE FORCE VIEW PHN_PIPELINE_2_OLYMPUS_VW
("Strain", "cohort_name", "gene_name", "run_date", "Mouse_name",
 "genotype", "age_in_weeks", "gender", "Na", K,
 "Cl", "Gluc", "Trigs", "Chol", "Amy",
 NEFAC, TP, "Alb", "Ca", "Phos",
 "Iron", AST, ALP, ALT, "Creat",
 LDH, "Urea", "TBilC", CK, "Mg",
 HDL, LDL, UA, CO2)
AS
select
t.name as Strain,
mc.COHORT_NAME,
gn.primary_name as gene_name,
r.run_date,
m.NAME as Mouse_Name,
mts.fetch_genotype(m.id) as genotype,
round((nvl(m.death_date,sysdate) - m.birth_date)/7,1) as age_in_weeks,
g.name as Gender,
avg(decode(p.id,46,decode(d.value,'0',null,d.value),null)) as "Na",
avg(decode(p.id,47,decode(d.value,'0',null,d.value),null)) as "K",
avg(decode(p.id,48,decode(d.value,'0',null,d.value),null)) as "Cl",
avg(decode(p.id,51,decode(d.value,'0',null,d.value),null)) as "Gluc",
avg(decode(p.id,52,decode(d.value,'0',null,d.value),null)) as "Trigs",
avg(decode(p.id,53,decode(d.value,'0',null,d.value),null)) as "Chol",
avg(decode(p.id,54,decode(d.value,'0',null,d.value),null)) as "Amy",
avg(decode(p.id,55,decode(d.value,'0',null,d.value),null)) as "NEFAC",
avg(decode(p.id,56,decode(d.value,'0',null,d.value),null)) as "TP",
avg(decode(p.id,57,decode(d.value,'0',null,d.value),null)) as "Alb",
avg(decode(p.id,58,decode(d.value,'0',null,d.value),null)) as "Ca",
avg(decode(p.id,59,decode(d.value,'0',null,d.value),null)) as "Phos",
avg(decode(p.id,60,decode(d.value,'0',null,d.value),null)) as "Iron",
avg(decode(p.id,61,decode(d.value,'0',null,d.value),null)) as "AST",
avg(decode(p.id,62,decode(d.value,'0',null,d.value),null)) as "ALP",
avg(decode(p.id,63,decode(d.value,'0',null,d.value),null)) as "ALT",
avg(decode(p.id,64,decode(d.value,'0',null,d.value),null)) as "Creat",
avg(decode(p.id,65,decode(d.value,'0',null,d.value),null)) as "LDH",
avg(decode(p.id,66,decode(d.value,'0',null,d.value),null)) as "Urea",
avg(decode(p.id,67,decode(d.value,'0',null,d.value),null)) as "TBilC",
avg(decode(p.id,69,decode(d.value,'0',null,d.value),null)) as "CK",
avg(decode(p.id,70,decode(d.value,'0',null,d.value),null)) as "Mg",
avg(decode(p.id,71,decode(d.value,'0',null,d.value),null)) as "HDL",
avg(decode(p.id,72,decode(d.value,'0',null,d.value),null)) as "LDL",
avg(decode(p.id,73,decode(d.value,'0',null,d.value),null)) as "UA",
avg(decode(p.id,74,decode(d.value,'0',null,d.value),null)) as "CO2"
from mts_mouse m,
     phn_bloods_run r,
     phn_bloods_data d,
     phn_parameter_dict p,
     mts_gender_dict g,
     mts_cohort_mouse c,
     mts_cohort mc,
     mts_colony_info ci,
     mts_mouse_allele ma,
     mts_genotype_dict gd,
     gnm_gene gn,
     typ_strain t,
     (select a.colony_id, t.gene_id
      from
      mts_colony_allele a,
      typ_modified_allele t
      where
      a.modified_allele_id = t.id
     ) z
where
     r.MOUSE_ID = m.ID
and m.MOUSE_STRAIN_DICT_ID = t.id(+)
and  m.id = c.MOUSE_ID
and  c.COHORT_ID = mc.ID
and  m.GENDER_DICT_ID = g.id
and  r.id = d.RUN_ID
and  d.PARAMETER_ID = p.ID
and r.INSTRUMENT_ID = 2
and m.id = c.mouse_id
and c.cohort_id = mc.id
and mc.cohort_name like '%Pipeline 2%'
and m.id = ma.mouse_id(+)
and ma.genotype_dict_id = gd.id(+)
and m.colony_info_id = ci.id
and ci.id = z.colony_id(+)
and gn.id(+) = z.gene_id
group by t.name,mc.cohort_name,gn.primary_name,r.run_date,m.name,mts.fetch_genotype(m.id),round((nvl(m.death_date,sysdate) - m.birth_date)/7,1),g.name
order by mc.cohort_name, m.name,g.name;



CREATE OR REPLACE FORCE VIEW PHN_MUTANT_ALL_OLYM_VW
("Strain", "cohort_name", "run_date", "mouse_name", "genotype",
 "age_in_weeks", "gender", "pipeline", "Na", K,
 "Cl", "Gluc", "Trigs", "Chol", "Amy",
 NEFAC, TP, "Alb", "Ca", "Phos",
 "Iron", AST, ALP, ALT, "Creat",
 LDH, "Urea", "TBilC", CK, "Mg",
 HDL, LDL, UA, CO2)
AS
select
t.name as strain,
mc.COHORT_NAME,
r.run_date,
m.NAME as Mouse_Name,
mts.fetch_genotype(m.id) as genotype,
round((nvl(m.death_date,sysdate) - m.birth_date)/7,1) as age_in_weeks,
g.name as Gender,
pd.NAME as pipeline,
avg(decode(p.id,46,decode(d.value,'0',null,d.value),null)) as "Na",
avg(decode(p.id,47,decode(d.value,'0',null,d.value),null)) as "K",
avg(decode(p.id,48,decode(d.value,'0',null,d.value),null)) as "Cl",
avg(decode(p.id,51,decode(d.value,'0',null,d.value),null)) as "Gluc",
avg(decode(p.id,52,decode(d.value,'0',null,d.value),null)) as "Trigs",
avg(decode(p.id,53,decode(d.value,'0',null,d.value),null)) as "Chol",
avg(decode(p.id,54,decode(d.value,'0',null,d.value),null)) as "Amy",
avg(decode(p.id,55,decode(d.value,'0',null,d.value),null)) as "NEFAC",
avg(decode(p.id,56,decode(d.value,'0',null,d.value),null)) as "TP",
avg(decode(p.id,57,decode(d.value,'0',null,d.value),null)) as "Alb",
avg(decode(p.id,58,decode(d.value,'0',null,d.value),null)) as "Ca",
avg(decode(p.id,59,decode(d.value,'0',null,d.value),null)) as "Phos",
avg(decode(p.id,60,decode(d.value,'0',null,d.value),null)) as "Iron",
avg(decode(p.id,61,decode(d.value,'0',null,d.value),null)) as "AST",
avg(decode(p.id,62,decode(d.value,'0',null,d.value),null)) as "ALP",
avg(decode(p.id,63,decode(d.value,'0',null,d.value),null)) as "ALT",
avg(decode(p.id,64,decode(d.value,'0',null,d.value),null)) as "Creat",
avg(decode(p.id,65,decode(d.value,'0',null,d.value),null)) as "LDH",
avg(decode(p.id,66,decode(d.value,'0',null,d.value),null)) as "Urea",
avg(decode(p.id,67,decode(d.value,'0',null,d.value),null)) as "TBilC",
avg(decode(p.id,69,decode(d.value,'0',null,d.value),null)) as "CK",
avg(decode(p.id,70,decode(d.value,'0',null,d.value),null)) as "Mg",
avg(decode(p.id,71,decode(d.value,'0',null,d.value),null)) as "HDL",
avg(decode(p.id,72,decode(d.value,'0',null,d.value),null)) as "LDL",
avg(decode(p.id,73,decode(d.value,'0',null,d.value),null)) as "UA",
avg(decode(p.id,74,decode(d.value,'0',null,d.value),null)) as "CO2"
from mts_mouse m,
     phn_bloods_run r,
     phn_bloods_data d,
     phn_parameter_dict p,
     mts_gender_dict g,
     mts_cohort_mouse c,
     mts_cohort mc,
     mts_mouse_allele ma,
     mts_genotype_dict gd,
     mts_cohort_pipeline_dict pd,
     typ_strain t
where
     r.MOUSE_ID = m.ID
and m.MOUSE_STRAIN_DICT_ID = t.id(+)
and  m.id = c.MOUSE_ID
and  c.COHORT_ID = mc.ID
and  m.GENDER_DICT_ID = g.id
and  r.id = d.RUN_ID
and  d.PARAMETER_ID = p.ID
and r.INSTRUMENT_ID = 2
and m.id = c.mouse_id
and c.cohort_id = mc.id
and ma.mouse_id(+) = m.id
and ma.genotype_dict_id = gd.id(+)
and mc.cohort_name not like '%WT%'
and mc.PIPELINE_DICT_ID = pd.id
and pd.id in (1,2)
and r.run_date between to_date('29-OCT-07') and sysdate
group by t.name,mc.cohort_name,r.run_date,m.name,mts.fetch_genotype(m.id),round((nvl(m.death_date,sysdate) - m.birth_date)/7,1),g.name, pd.name
order by  pd.name,g.name,round((nvl(m.death_date,sysdate) - m.birth_date)/7,1), mc.cohort_name;

CREATE OR REPLACE FORCE VIEW PHN_PIPELINE_2_ABC_VW
("Strain", "cohort_name", "gene_name", "run_date", "Mouse_name",
 "genotype", "age_in_weeks", "gender", MCH, MCV,
 PLT, HCT, HGB, RBC, WBC,
 MCHC, RDW, MPV, "percent_LYM", "percent_MON",
 "percent_GRA", "num_LYM", "num_MON", "num_GRA")
AS
select
t.name as Strain,
mc.COHORT_NAME,
gn.primary_name as gene_name,
r.run_date,
m.NAME as Mouse_Name,
mts.fetch_genotype(m.id) as genotype,
round((nvl(m.death_date,sysdate) - m.birth_date)/7,1) as age_in_weeks,
g.name as Gender,
avg(decode(p.id,8,d.value,null)) as MCH,
avg(decode(p.id,7,d.value,null)) as MCV,
avg(decode(p.id,6,d.value,null)) as PLT,
avg(decode(p.id,5,d.value,null)) as HCT,
avg(decode(p.id,4,d.value,null)) as HGB,
avg(decode(p.id,3,d.value,null)) as RBC,
avg(decode(p.id,2,d.value,null)) as WBC,
avg(decode(p.id,9,d.value,null)) as MCHC,
avg(decode(p.id,10,d.value,null)) as RDW,
avg(decode(p.id,11,d.value,null)) as MPV,
avg(decode(p.id,12,d.value,null)) as percent_LYM,
avg(decode(p.id,13,d.value,null)) as percent_MON,
avg(decode(p.id,14,d.value,null)) as percent_GRA,
avg(decode(p.id,15,d.value,null)) as num_LYM,
avg(decode(p.id,16,d.value,null)) as num_MON,
avg(decode(p.id,17,d.value,null)) as num_GRA
from mts_mouse m,
     phn_bloods_run r,
     phn_bloods_data d,
     phn_parameter_dict p,
     mts_gender_dict g,
     mts_cohort_mouse c,
     mts_cohort mc,
     mts_colony_info ci,
     mts_mouse_allele ma,
     mts_genotype_dict gd,
     gnm_gene gn,
     typ_strain t,
     (select a.colony_id, t.gene_id
      from
      mts_colony_allele a,
      typ_modified_allele t
      where
      a.modified_allele_id = t.id
     ) z
where
     r.MOUSE_ID = m.ID
and m.MOUSE_STRAIN_DICT_ID = t.id(+)
and  m.id = c.MOUSE_ID
and  c.COHORT_ID = mc.ID
and  m.GENDER_DICT_ID = g.id
and  r.id = d.RUN_ID
and  d.PARAMETER_ID = p.ID
and r.INSTRUMENT_ID = 1
and m.id = c.mouse_id
and c.cohort_id = mc.id
and mc.cohort_name like '%Pipeline 2%'
and m.id = ma.mouse_id(+)
and ma.genotype_dict_id = gd.id(+)
and m.colony_info_id = ci.id
and ci.id = z.colony_id(+)
and gn.id(+) = z.gene_id
group by t.name,mc.cohort_name,gn.primary_name,r.run_date,m.name,mts.fetch_genotype(m.id),round((nvl(m.death_date,sysdate) - m.birth_date)/7,1),g.name
order by mc.cohort_name, m.name,g.name;




CREATE OR REPLACE FORCE VIEW PHN_WILDTYPE_ALL_OLYM_VW
("Strain", "cohort_name", "run_date", "mouse_name", "genotype",
 "age_in_weeks", "gender", "pipeline", "Na", K,
 "Cl", "Gluc", "Trigs", "Chol", "Amy",
 NEFAC, TP, "Alb", "Ca", "Phos",
 "Iron", AST, ALP, ALT, "Creat",
 LDH, "Urea", "TBilC", CK, "Mg",
 HDL, LDL, UA, CO2)
AS
select
t.name as strain,
mc.COHORT_NAME,
r.run_date,
m.NAME as Mouse_Name,
mts.fetch_genotype(m.id) as genotype,
round((nvl(m.death_date,sysdate) - m.birth_date)/7,1) as age_in_weeks,
g.name as Gender,
pd.NAME as pipeline,
avg(decode(p.id,46,decode(d.value,'0',null,d.value),null)) as "Na",
avg(decode(p.id,47,decode(d.value,'0',null,d.value),null)) as "K",
avg(decode(p.id,48,decode(d.value,'0',null,d.value),null)) as "Cl",
avg(decode(p.id,51,decode(d.value,'0',null,d.value),null)) as "Gluc",
avg(decode(p.id,52,decode(d.value,'0',null,d.value),null)) as "Trigs",
avg(decode(p.id,53,decode(d.value,'0',null,d.value),null)) as "Chol",
avg(decode(p.id,54,decode(d.value,'0',null,d.value),null)) as "Amy",
avg(decode(p.id,55,decode(d.value,'0',null,d.value),null)) as "NEFAC",
avg(decode(p.id,56,decode(d.value,'0',null,d.value),null)) as "TP",
avg(decode(p.id,57,decode(d.value,'0',null,d.value),null)) as "Alb",
avg(decode(p.id,58,decode(d.value,'0',null,d.value),null)) as "Ca",
avg(decode(p.id,59,decode(d.value,'0',null,d.value),null)) as "Phos",
avg(decode(p.id,60,decode(d.value,'0',null,d.value),null)) as "Iron",
avg(decode(p.id,61,decode(d.value,'0',null,d.value),null)) as "AST",
avg(decode(p.id,62,decode(d.value,'0',null,d.value),null)) as "ALP",
avg(decode(p.id,63,decode(d.value,'0',null,d.value),null)) as "ALT",
avg(decode(p.id,64,decode(d.value,'0',null,d.value),null)) as "Creat",
avg(decode(p.id,65,decode(d.value,'0',null,d.value),null)) as "LDH",
avg(decode(p.id,66,decode(d.value,'0',null,d.value),null)) as "Urea",
avg(decode(p.id,67,decode(d.value,'0',null,d.value),null)) as "TBilC",
avg(decode(p.id,69,decode(d.value,'0',null,d.value),null)) as "CK",
avg(decode(p.id,70,decode(d.value,'0',null,d.value),null)) as "Mg",
avg(decode(p.id,71,decode(d.value,'0',null,d.value),null)) as "HDL",
avg(decode(p.id,72,decode(d.value,'0',null,d.value),null)) as "LDL",
avg(decode(p.id,73,decode(d.value,'0',null,d.value),null)) as "UA",
avg(decode(p.id,74,decode(d.value,'0',null,d.value),null)) as "CO2"
from mts_mouse m,
     phn_bloods_run r,
     phn_bloods_data d,
     phn_parameter_dict p,
     mts_gender_dict g,
     mts_cohort_mouse c,
     mts_cohort mc,
     mts_mouse_allele ma,
     mts_genotype_dict gd,
     mts_cohort_pipeline_dict pd,
     typ_strain t
where
     r.MOUSE_ID = m.ID
and m.MOUSE_STRAIN_DICT_ID = t.id(+)
and  m.id = c.MOUSE_ID
and  c.COHORT_ID = mc.ID
and  m.GENDER_DICT_ID = g.id
and  r.id = d.RUN_ID
and  d.PARAMETER_ID = p.ID
and r.INSTRUMENT_ID = 2
and m.id = c.mouse_id
and c.cohort_id = mc.id
and ma.mouse_id(+) = m.id
and ma.genotype_dict_id = gd.id(+)
and mc.cohort_name like '%WT Cohort%'
and mc.PIPELINE_DICT_ID = pd.id
and pd.id in (1,2)
and r.run_date between to_date('29-OCT-07') and sysdate
group by t.name,mc.cohort_name,r.run_date,m.name,mts.fetch_genotype(m.id),round((nvl(m.death_date,sysdate) - m.birth_date)/7,1),g.name, pd.name
order by  pd.name,g.name,round((nvl(m.death_date,sysdate) - m.birth_date)/7,1), mc.cohort_name;



CREATE OR REPLACE FORCE VIEW HTL_BLOCK_TYPE_VW
(ID, DESCRIPTION, ACTIVE, NAME, ORDER_BY,
 CASSETTE_TYPE_DICT_ID, STANDARD_BLOCK, FULL_DESCIPTION)
AS
SELECT bt."ID", bt."DESCRIPTION", bt."ACTIVE", bt."NAME", bt."ORDER_BY",
       bt."CASSETTE_TYPE_DICT_ID", bt."STANDARD_BLOCK",
       NVL (htl.blocktype_tissuename (bt.ID), bt.description) full_desciption
  FROM htl_block_type bt;

CREATE OR REPLACE FORCE VIEW MTS_MOUSE_CURRENT_19B_VW
(ID, MOUSE_ID, PROTOCOL_ID, PERSONAL_LICENCE_ID, START_DATE,
 END_DATE, FOREIGN_KEY_ID, FOREIGN_TABLE_NAME, PROCEDURE_DICT_ID, PROCEDURE,
 PROJECT_LICENCE_ID, LICENCE_NUMBER, PROTOCOL_CODE, PIL_NUMBER)
AS
with max_id as (
  select
    p.*,
    row_number() over (partition by mouse_id order by start_date desc, id desc) row_number
  from
    mts_mouse_procedure p
  where
    protocol_id is not null
  )
select
  m.id,
  m.mouse_id,
  m.protocol_id,
  m.personal_licence_id,
  m.start_date,
  m.end_date,
  m.foreign_key_id,
  m.foreign_table_name,
  m.procedure_dict_id,
  d.name procedure,
  ppl.project_licence_id,
  ppl.licence_number,
  b.protocol_code,
  pil.pil_number
from
  lic_project_licence ppl,
  lic_protocol_19b b,
  lic_personal_licence pil,
  mts_procedure_dict d,
  max_id m
where
  m.row_number = 1 and
  m.protocol_id = b.id and
  b.project_licence_id = ppl.project_licence_id and
  m.personal_licence_id = pil.personal_licence_id(+) and
  m.procedure_dict_id = d.id;




CREATE OR REPLACE FORCE VIEW PHN_WILDTYPE_REFRANGE_VW
("Strain", "Genotype", "Gender", "Num_Samples", "Na Lower",
 "Na Upper", "K Lower", "K Upper", "Cl Lower", "Cl Upper",
 "Gluc Lower", "Gluc Upper", "Trigs Lower", "Trigs Upper", "Chol Lower",
 "Chol Upper", "Amy Lower", "Amy Upper", "NEFAC Lower", "NEFAC Upper",
 "TP Lower", "TP Upper", "Alb Lower", "Alb Upper", "Ca Lower",
 "Ca Upper", "Phos Lower", "Phos Upper", "Iron Lower", "Iron Upper",
 "AST Lower", "AST Upper", "ALP Lower", "ALP Upper", "ALT Lower",
 "ALT Upper", "Creat Lower", "Creat Upper", "LDH Lower", "LDH Upper",
 "Urea Lower", "Urea Upper", "TBilC Lower", "TBilC Upper", "CK Lower",
 "CK Upper", "Mg Lower", "Mg Upper", "HDL Lower", "HDL Upper",
 "LDL Lower", "LDL Upper", "UA Lower", "UA Upper", "CO2 Lower",
 "CO2 Upper")
AS
SELECT v.strain,nvl(v.genotype,'WT'), v.gender, count(v.gender),
PERCENTILE_CONT(0.975) WITHIN GROUP (ORDER BY "Na" DESC) as "Na: Lower Limit",
PERCENTILE_CONT(0.0275) WITHIN GROUP (ORDER BY "Na" DESC) as "Na: Upper Limit",
PERCENTILE_CONT(0.975) WITHIN GROUP (ORDER BY "K" DESC) as "K: Lower Limit",
PERCENTILE_CONT(0.0275) WITHIN GROUP (ORDER BY "K" DESC) as "K: Upper Limit",
PERCENTILE_CONT(0.975) WITHIN GROUP (ORDER BY "Cl" DESC) as "Cl: Lower Limit",
PERCENTILE_CONT(0.0275) WITHIN GROUP (ORDER BY "Cl" DESC) as "Cl: Upper Limit",
PERCENTILE_CONT(0.975) WITHIN GROUP (ORDER BY "Gluc" DESC) as "Gluc: Lower Limit",
PERCENTILE_CONT(0.0275) WITHIN GROUP (ORDER BY "Gluc" DESC) as "Gluc: Upper Limit",
PERCENTILE_CONT(0.975) WITHIN GROUP (ORDER BY "Trigs" DESC) as "Trigs: Lower Limit",
PERCENTILE_CONT(0.0275) WITHIN GROUP (ORDER BY "Trigs" DESC) as "Trigs: Upper Limit",
PERCENTILE_CONT(0.975) WITHIN GROUP (ORDER BY "Chol" DESC) as "Chol: Lower Limit",
PERCENTILE_CONT(0.0275) WITHIN GROUP (ORDER BY "Chol" DESC) as "Chol: Upper Limit",
PERCENTILE_CONT(0.975) WITHIN GROUP (ORDER BY "Amy" DESC) as "Amy: Lower Limit",
PERCENTILE_CONT(0.0275) WITHIN GROUP (ORDER BY "Amy" DESC) as "Amy: Upper Limit",
PERCENTILE_CONT(0.975) WITHIN GROUP (ORDER BY "NEFAC" DESC) as "NEFAC: Lower Limit",
PERCENTILE_CONT(0.0275) WITHIN GROUP (ORDER BY "NEFAC" DESC) as "NEFAC: Upper Limit",
PERCENTILE_CONT(0.975) WITHIN GROUP (ORDER BY "TP" DESC) as "TP: Lower Limit",
PERCENTILE_CONT(0.0275) WITHIN GROUP (ORDER BY "TP" DESC) as "TP: Upper Limit",
PERCENTILE_CONT(0.975) WITHIN GROUP (ORDER BY "Alb" DESC) as "Alb: Lower Limit",
PERCENTILE_CONT(0.0275) WITHIN GROUP (ORDER BY "Alb" DESC) as "Alb: Upper Limit",
PERCENTILE_CONT(0.975) WITHIN GROUP (ORDER BY "Ca" DESC) as "Ca: Lower Limit",
PERCENTILE_CONT(0.0275) WITHIN GROUP (ORDER BY "Ca" DESC) as "Ca: Upper Limit",
PERCENTILE_CONT(0.975) WITHIN GROUP (ORDER BY "Phos" DESC) as "Phos: Lower Limit",
PERCENTILE_CONT(0.0275) WITHIN GROUP (ORDER BY "Phos" DESC) as "Phos: Upper Limit",
PERCENTILE_CONT(0.975) WITHIN GROUP (ORDER BY "Iron" DESC) as "Iron: Lower Limit",
PERCENTILE_CONT(0.0275) WITHIN GROUP (ORDER BY "Iron" DESC) as "Iron: Upper Limit",
PERCENTILE_CONT(0.975) WITHIN GROUP (ORDER BY "AST" DESC) as "AST: Lower Limit",
PERCENTILE_CONT(0.0275) WITHIN GROUP (ORDER BY "AST" DESC) as "AST: Upper Limit",
PERCENTILE_CONT(0.975) WITHIN GROUP (ORDER BY "ALP" DESC) as "ALP: Lower Limit",
PERCENTILE_CONT(0.0275) WITHIN GROUP (ORDER BY "ALP" DESC) as "ALP: Upper Limit",
PERCENTILE_CONT(0.975) WITHIN GROUP (ORDER BY "ALT" DESC) as "ALT: Lower Limit",
PERCENTILE_CONT(0.0275) WITHIN GROUP (ORDER BY "ALT" DESC) as "ALT: Upper Limit",
PERCENTILE_CONT(0.975) WITHIN GROUP (ORDER BY "Creat" DESC) as "Creat: Lower Limit",
PERCENTILE_CONT(0.0275) WITHIN GROUP (ORDER BY "Creat" DESC) as "Creat: Upper Limit",
PERCENTILE_CONT(0.975) WITHIN GROUP (ORDER BY "LDH" DESC) as "LDH: Lower Limit",
PERCENTILE_CONT(0.0275) WITHIN GROUP (ORDER BY "LDH" DESC) as "LDH: Upper Limit",
PERCENTILE_CONT(0.975) WITHIN GROUP (ORDER BY "Urea" DESC) as "Urea: Lower Limit",
PERCENTILE_CONT(0.0275) WITHIN GROUP (ORDER BY "Urea" DESC) as "Urea: Upper Limit",
PERCENTILE_CONT(0.975) WITHIN GROUP (ORDER BY "TBilC" DESC) as "TBilC: Lower Limit",
PERCENTILE_CONT(0.0275) WITHIN GROUP (ORDER BY "TBilC" DESC) as "TBilC: Upper Limit",
PERCENTILE_CONT(0.975) WITHIN GROUP (ORDER BY "CK" DESC) as "CK: Lower Limit",
PERCENTILE_CONT(0.0275) WITHIN GROUP (ORDER BY "CK" DESC) as "CK: Upper Limit",
PERCENTILE_CONT(0.975) WITHIN GROUP (ORDER BY "Mg" DESC) as "Mg: Lower Limit",
PERCENTILE_CONT(0.0275) WITHIN GROUP (ORDER BY "Mg" DESC) as "Mg: Upper Limit",
PERCENTILE_CONT(0.975) WITHIN GROUP (ORDER BY "HDL" DESC) as "HDL: Lower Limit",
PERCENTILE_CONT(0.0275) WITHIN GROUP (ORDER BY "HDL" DESC) as "HDL: Upper Limit",
PERCENTILE_CONT(0.975) WITHIN GROUP (ORDER BY "LDL" DESC) as "LDL: Lower Limit",
PERCENTILE_CONT(0.0275) WITHIN GROUP (ORDER BY "LDL" DESC) as "LDL: Upper Limit",
PERCENTILE_CONT(0.975) WITHIN GROUP (ORDER BY "UA" DESC) as "UA: Lower Limit",
PERCENTILE_CONT(0.0275) WITHIN GROUP (ORDER BY "UA" DESC) as "UA: Upper Limit",
PERCENTILE_CONT(0.975) WITHIN GROUP (ORDER BY "CO2" DESC) as "CO2: Lower Limit",
PERCENTILE_CONT(0.0275) WITHIN GROUP (ORDER BY "CO2" DESC) as "CO2: Upper Limit"
FROM
(
  select
t.name as strain,
mc.COHORT_NAME,
r.run_date,
m.NAME as Mouse_Name,
mts.fetch_genotype(m.id) as genotype,
round((nvl(m.death_date,sysdate) - m.birth_date)/7,1) as age_in_weeks,
g.name as Gender,
avg(decode(p.id,46,decode(d.value,'0',null,d.value),null)) as "Na",
avg(decode(p.id,47,decode(d.value,'0',null,d.value),null)) as "K",
avg(decode(p.id,48,decode(d.value,'0',null,d.value),null)) as "Cl",
avg(decode(p.id,51,decode(d.value,'0',null,d.value),null)) as "Gluc",
avg(decode(p.id,52,decode(d.value,'0',null,d.value),null)) as "Trigs",
avg(decode(p.id,53,decode(d.value,'0',null,d.value),null)) as "Chol",
avg(decode(p.id,54,decode(d.value,'0',null,d.value),null)) as "Amy",
avg(decode(p.id,55,decode(d.value,'0',null,d.value),null)) as "NEFAC",
avg(decode(p.id,56,decode(d.value,'0',null,d.value),null)) as "TP",
avg(decode(p.id,57,decode(d.value,'0',null,d.value),null)) as "Alb",
avg(decode(p.id,58,decode(d.value,'0',null,d.value),null)) as "Ca",
avg(decode(p.id,59,decode(d.value,'0',null,d.value),null)) as "Phos",
avg(decode(p.id,60,decode(d.value,'0',null,d.value),null)) as "Iron",
avg(decode(p.id,61,decode(d.value,'0',null,d.value),null)) as "AST",
avg(decode(p.id,62,decode(d.value,'0',null,d.value),null)) as "ALP",
avg(decode(p.id,63,decode(d.value,'0',null,d.value),null)) as "ALT",
avg(decode(p.id,64,decode(d.value,'0',null,d.value),null)) as "Creat",
avg(decode(p.id,65,decode(d.value,'0',null,d.value),null)) as "LDH",
avg(decode(p.id,66,decode(d.value,'0',null,d.value),null)) as "Urea",
avg(decode(p.id,67,decode(d.value,'0',null,d.value),null)) as "TBilC",
avg(decode(p.id,69,decode(d.value,'0',null,d.value),null)) as "CK",
avg(decode(p.id,70,decode(d.value,'0',null,d.value),null)) as "Mg",
avg(decode(p.id,71,decode(d.value,'0',null,d.value),null)) as "HDL",
avg(decode(p.id,72,decode(d.value,'0',null,d.value),null)) as "LDL",
avg(decode(p.id,73,decode(d.value,'0',null,d.value),null)) as "UA",
avg(decode(p.id,74,decode(d.value,'0',null,d.value),null)) as "CO2"
from mts_mouse m,
     phn_bloods_run r,
     phn_bloods_data d,
     phn_parameter_dict p,
     mts_gender_dict g,
     mts_cohort_mouse c,
     mts_cohort mc,
     mts_mouse_allele ma,
     mts_genotype_dict gd,
     typ_strain t
where
     r.MOUSE_ID = m.ID
and m.MOUSE_STRAIN_DICT_ID = t.id(+)
and  m.id = c.MOUSE_ID
and  c.COHORT_ID = mc.ID
and  m.GENDER_DICT_ID = g.id
and  r.id = d.RUN_ID
and  d.PARAMETER_ID = p.ID
and r.INSTRUMENT_ID = 2
and m.id = c.mouse_id
and c.cohort_id = mc.id
and ma.mouse_id(+) = m.id
and ma.genotype_dict_id = gd.id(+)
and mc.cohort_name like '%WT Cohort%'
and mc.cohort_name not like '%HFC%'
and r.run_date between to_date('29-OCT-07') and sysdate
and t.name not like '%Taconic%'
group by t.name,mc.cohort_name,r.run_date,m.name,mts.fetch_genotype(m.id),round((nvl(m.death_date,sysdate) - m.birth_date)/7,1),g.name
order by  m.name,g.name
) v
GROUP BY v.strain, v.genotype,v.gender;


CREATE OR REPLACE FORCE VIEW PHN_OLYM_VW
(STRAIN, COHORT_NAME, GENE_NAME, ASSAY_DATE, MOUSE_NAME,
 MOUSE, GENOTYPE, AGE_IN_WEEKS, GENDER, GENDER_ID,
 BIRTH_DATE, PIPELINE, "Na", K, "Cl",
 "Gluc", "Trigs", "Chol", "Amy", NEFAC,
 TP, "Alb", "Ca", "Phos", "Iron",
 AST, ALP, ALT, "Creat", LDH,
 "Urea", "TBilC", CK, "Mg", HDL,
 LDL, UA, CO2)
AS
select

t.name as Strain,

mc.COHORT_NAME,

gn.primary_name as gene_name,

r.run_date assay_date,

m.NAME as Mouse_Name,

m.BARCODE as mouse,

mts.fetch_genotype(m.id) as genotype,

round((nvl(m.death_date,sysdate) - m.birth_date)/7,1) as age_in_weeks,

g.name as Gender,
g.id as gender_id,

m.BIRTH_DATE,

pd.NAME as pipeline,

avg(decode(p.id,46,decode(d.value,'0',null,d.value),null)) as "Na",

avg(decode(p.id,47,decode(d.value,'0',null,d.value),null)) as "K",

avg(decode(p.id,48,decode(d.value,'0',null,d.value),null)) as "Cl",

avg(decode(p.id,51,decode(d.value,'0',null,d.value),null)) as "Gluc",

avg(decode(p.id,52,decode(d.value,'0',null,d.value),null)) as "Trigs",

avg(decode(p.id,53,decode(d.value,'0',null,d.value),null)) as "Chol",

avg(decode(p.id,54,decode(d.value,'0',null,d.value),null)) as "Amy",

avg(decode(p.id,55,decode(d.value,'0',null,d.value),null)) as "NEFAC",

avg(decode(p.id,56,decode(d.value,'0',null,d.value),null)) as "TP",

avg(decode(p.id,57,decode(d.value,'0',null,d.value),null)) as "Alb",

avg(decode(p.id,58,decode(d.value,'0',null,d.value),null)) as "Ca",

avg(decode(p.id,59,decode(d.value,'0',null,d.value),null)) as "Phos",

avg(decode(p.id,60,decode(d.value,'0',null,d.value),null)) as "Iron",

avg(decode(p.id,61,decode(d.value,'0',null,d.value),null)) as "AST",

avg(decode(p.id,62,decode(d.value,'0',null,d.value),null)) as "ALP",

avg(decode(p.id,63,decode(d.value,'0',null,d.value),null)) as "ALT",

avg(decode(p.id,64,decode(d.value,'0',null,d.value),null)) as "Creat",

avg(decode(p.id,65,decode(d.value,'0',null,d.value),null)) as "LDH",

avg(decode(p.id,66,decode(d.value,'0',null,d.value),null)) as "Urea",

avg(decode(p.id,67,decode(d.value,'0',null,d.value),null)) as "TBilC",

avg(decode(p.id,69,decode(d.value,'0',null,d.value),null)) as "CK",

avg(decode(p.id,70,decode(d.value,'0',null,d.value),null)) as "Mg",

avg(decode(p.id,71,decode(d.value,'0',null,d.value),null)) as "HDL",

avg(decode(p.id,72,decode(d.value,'0',null,d.value),null)) as "LDL",

avg(decode(p.id,73,decode(d.value,'0',null,d.value),null)) as "UA",

avg(decode(p.id,74,decode(d.value,'0',null,d.value),null)) as "CO2"

from mts_mouse m,

     phn_bloods_run r,

     phn_bloods_data d,

     phn_parameter_dict p,

     mts_gender_dict g,

     mts_cohort_mouse c,

     mts_cohort mc,

     mts_colony_info ci,

     mts_mouse_allele ma,

     mts_genotype_dict gd,

     gnm_gene gn,

     typ_strain t,

     mts_cohort_pipeline_dict pd,

     (select a.colony_id, t.gene_id

      from

      mts_colony_allele a,

      typ_modified_allele t

      where

      a.modified_allele_id = t.id

     ) z

where

     r.MOUSE_ID = m.ID

and m.MOUSE_STRAIN_DICT_ID = t.id(+)

and  m.id = c.MOUSE_ID

and  c.COHORT_ID = mc.ID

and  m.GENDER_DICT_ID = g.id

and  r.id = d.RUN_ID

and  d.PARAMETER_ID = p.ID

and r.INSTRUMENT_ID = 2

and m.id = c.mouse_id

and c.cohort_id = mc.id

and mc.PIPELINE_DICT_ID = pd.id(+)

and m.id = ma.mouse_id(+)

and ma.genotype_dict_id = gd.id(+)

and m.colony_info_id = ci.id

and ci.id = z.colony_id(+)

and gn.id(+) = z.gene_id

and r.run_date between to_date('29-OCT-07') and sysdate
group by t.name,mc.cohort_name,gn.primary_name,r.run_date,m.name,m.BARCODE,mts.fetch_genotype(m.id),round((nvl(m.death_date,sysdate) - m.birth_date)/7,1),g.name,g.id,m.birth_date,pd.name

union

select

t.name as Strain,

mc.COHORT_NAME,

gn.primary_name as gene_name,

r.run_date assay_date,

m.NAME as Mouse_Name,

m.BARCODE as mouse,

mts.fetch_genotype(m.id) as genotype,

round((nvl(m.death_date,sysdate) - m.birth_date)/7,1) as age_in_weeks,

g.name as Gender,
g.id as gender_id,

m.BIRTH_DATE,

pd.name as pipeline,

avg(decode(p.id,46,decode(d.value,'0',null,d.value),null)) as "Na",

avg(decode(p.id,47,decode(d.value,'0',null,d.value),null)) as "K",

avg(decode(p.id,48,decode(d.value,'0',null,d.value),null)) as "Cl",

avg(decode(p.id,33,decode(d.value,'0',null,d.value),null)) as "Gluc",

avg(decode(p.id,24,decode(d.value,'0',null,d.value),null)) as "Trigs",

avg(decode(p.id,36,decode(d.value,'0',null,d.value),null)) as "Chol",

avg(decode(p.id,37,decode(d.value,'0',null,d.value),null)) as "Amy",

avg(decode(p.id,49,decode(d.value,'0',null,d.value),null)) as "NEFAC",

avg(decode(p.id,30,decode(d.value,'0',null,d.value),null)) as "TP",

avg(decode(p.id,31,decode(d.value,'0',null,d.value),null)) as "Alb",

avg(decode(p.id,27,decode(d.value,'0',null,d.value),null)) as "Ca",

avg(decode(p.id,28,decode(d.value,'0',null,d.value),null)) as "Phos",

avg(decode(p.id,41,decode(d.value,'0',null,d.value),null)) as "Iron",

avg(decode(p.id,22,decode(d.value,'0',null,d.value),null)) as "AST",

avg(decode(p.id,29,decode(d.value,'0',null,d.value),null)) as "ALP",

avg(decode(p.id,23,decode(d.value,'0',null,d.value),null)) as "ALT",

avg(decode(p.id,50,decode(d.value,'0',null,d.value),null)) as "Creat",

avg(decode(p.id,35,decode(d.value,'0',null,d.value),null)) as "LDH",

avg(decode(p.id,25,decode(d.value,'0',null,d.value),null)) as "Urea",

avg(decode(p.id,32,decode(d.value,'0',null,d.value),null)) as "TBilC",

avg(decode(p.id,42,decode(d.value,'0',null,d.value),null)) as "CK",

avg(decode(p.id,39,decode(d.value,'0',null,d.value),null)) as "Mg",

avg(decode(p.id,38,decode(d.value,'0',null,d.value),null)) as "HDL",

avg(decode(p.id,34,decode(d.value,'0',null,d.value),null)) as "LDL",

avg(decode(p.id,43,decode(d.value,'0',null,d.value),null)) as "UA",

avg(decode(p.id,40,decode(d.value,'0',null,d.value),null)) as "CO2"

from mts_mouse m,

     phn_bloods_run r,

     phn_bloods_data d,

     phn_parameter_dict p,

     mts_gender_dict g,

     mts_cohort_mouse c,

     mts_cohort mc,

     mts_colony_info ci,

     mts_mouse_allele ma,

     mts_genotype_dict gd,

     gnm_gene gn,

     typ_strain t,

     mts_cohort_pipeline_dict pd,

     (select a.colony_id, t.gene_id

      from

      mts_colony_allele a,

      typ_modified_allele t

      where

      a.modified_allele_id = t.id

     ) z

where

     r.MOUSE_ID = m.ID

and m.MOUSE_STRAIN_DICT_ID = t.id(+)

and  m.id = c.MOUSE_ID

and  c.COHORT_ID = mc.ID

and  m.GENDER_DICT_ID = g.id

and  r.id = d.RUN_ID

and  d.PARAMETER_ID = p.ID

and r.INSTRUMENT_ID = 2

and m.id = c.mouse_id

and c.cohort_id = mc.id

and mc.PIPELINE_DICT_ID = pd.id(+)

and m.id = ma.mouse_id(+)

and ma.genotype_dict_id = gd.id(+)

and m.colony_info_id = ci.id

and ci.id = z.colony_id(+)

and gn.id(+) = z.gene_id

and r.run_date < to_date('29-OCT-07')

group by t.name,mc.cohort_name,gn.primary_name,r.run_date,m.name,m.BARCODE,mts.fetch_genotype(m.id),round((nvl(m.death_date,sysdate) - m.birth_date)/7,1),g.name,g.id,m.birth_date,pd.name;

CREATE OR REPLACE FORCE VIEW PHN_PIPELINE_4_OLYMPUS_VW
("Strain", "cohort_name", "gene_name", "run_date", "Mouse_name",
 "genotype", "age_in_weeks", "gender", "Na", K,
 "Cl", "Gluc", "Trigs", "Chol", "Amy",
 NEFAC, TP, "Alb", "Ca", "Phos",
 "Iron", AST, ALP, ALT, "Creat",
 LDH, "Urea", "TBilC", CK, "Mg",
 HDL, LDL, UA, CO2)
AS
select
t.name as Strain,
mc.COHORT_NAME,
gn.primary_name as gene_name,
r.run_date,
m.NAME as Mouse_Name,
mts.fetch_genotype(m.id) as genotype,
round((nvl(m.death_date,sysdate) - m.birth_date)/7,1) as age_in_weeks,
g.name as Gender,
avg(decode(p.id,46,decode(d.value,'0',null,d.value),null)) as "Na",
avg(decode(p.id,47,decode(d.value,'0',null,d.value),null)) as "K",
avg(decode(p.id,48,decode(d.value,'0',null,d.value),null)) as "Cl",
avg(decode(p.id,51,decode(d.value,'0',null,d.value),null)) as "Gluc",
avg(decode(p.id,52,decode(d.value,'0',null,d.value),null)) as "Trigs",
avg(decode(p.id,53,decode(d.value,'0',null,d.value),null)) as "Chol",
avg(decode(p.id,54,decode(d.value,'0',null,d.value),null)) as "Amy",
avg(decode(p.id,55,decode(d.value,'0',null,d.value),null)) as "NEFAC",
avg(decode(p.id,56,decode(d.value,'0',null,d.value),null)) as "TP",
avg(decode(p.id,57,decode(d.value,'0',null,d.value),null)) as "Alb",
avg(decode(p.id,58,decode(d.value,'0',null,d.value),null)) as "Ca",
avg(decode(p.id,59,decode(d.value,'0',null,d.value),null)) as "Phos",
avg(decode(p.id,60,decode(d.value,'0',null,d.value),null)) as "Iron",
avg(decode(p.id,61,decode(d.value,'0',null,d.value),null)) as "AST",
avg(decode(p.id,62,decode(d.value,'0',null,d.value),null)) as "ALP",
avg(decode(p.id,63,decode(d.value,'0',null,d.value),null)) as "ALT",
avg(decode(p.id,64,decode(d.value,'0',null,d.value),null)) as "Creat",
avg(decode(p.id,65,decode(d.value,'0',null,d.value),null)) as "LDH",
avg(decode(p.id,66,decode(d.value,'0',null,d.value),null)) as "Urea",
avg(decode(p.id,67,decode(d.value,'0',null,d.value),null)) as "TBilC",
avg(decode(p.id,69,decode(d.value,'0',null,d.value),null)) as "CK",
avg(decode(p.id,70,decode(d.value,'0',null,d.value),null)) as "Mg",
avg(decode(p.id,71,decode(d.value,'0',null,d.value),null)) as "HDL",
avg(decode(p.id,72,decode(d.value,'0',null,d.value),null)) as "LDL",
avg(decode(p.id,73,decode(d.value,'0',null,d.value),null)) as "UA",
avg(decode(p.id,74,decode(d.value,'0',null,d.value),null)) as "CO2"
from mts_mouse m,
     phn_bloods_run r,
     phn_bloods_data d,
     phn_parameter_dict p,
     mts_gender_dict g,
     mts_cohort_mouse c,
     mts_cohort mc,
     mts_colony_info ci,
     mts_mouse_allele ma,
     mts_genotype_dict gd,
     mts_cohort_pipeline_dict pd,
     gnm_gene gn,
     typ_strain t,
     (select a.colony_id, t.gene_id
      from
      mts_colony_allele a,
      typ_modified_allele t
      where
      a.modified_allele_id = t.id
     ) z
where
     r.MOUSE_ID = m.ID
and m.MOUSE_STRAIN_DICT_ID = t.id(+)
and  m.id = c.MOUSE_ID
and  c.COHORT_ID = mc.ID
and  m.GENDER_DICT_ID = g.id
and  r.id = d.RUN_ID
and  d.PARAMETER_ID = p.ID
and r.INSTRUMENT_ID = 2
and m.id = c.mouse_id
and c.cohort_id = mc.id
and mc.PIPELINE_DICT_ID = pd.id
and pd.id = 4
and m.id = ma.mouse_id(+)
and ma.genotype_dict_id = gd.id(+)
and m.colony_info_id = ci.id
and ci.id = z.colony_id(+)
and gn.id(+) = z.gene_id
group by t.name,mc.cohort_name,gn.primary_name,r.run_date,m.name,mts.fetch_genotype(m.id),round((nvl(m.death_date,sysdate) - m.birth_date)/7,1),g.name
order by mc.cohort_name, m.name,g.name;

CREATE OR REPLACE FORCE VIEW PHN_PIPELINE_1_OLYMPUS_VW
("Strain", "cohort_name", "gene_name", "run_date", "Mouse_name",
 "genotype", "age_in_weeks", "gender", "Na", K,
 "Cl", "Gluc", "Trigs", "Chol", "Amy",
 NEFAC, TP, "Alb", "Ca", "Phos",
 "Iron", AST, ALP, ALT, "Creat",
 LDH, "Urea", "TBilC", CK, "Mg",
 HDL, LDL, UA, "Comments")
AS
select
t.name as Strain,
mc.COHORT_NAME,
gn.primary_name as gene_name,
r.run_date,
m.NAME as Mouse_Name,
mts.fetch_genotype(m.id) genotype,
round((nvl(m.death_date,sysdate) - m.birth_date)/7,1) as age_in_weeks,
g.name as Gender,
avg(decode(p.id,46,decode(d.value,'0',null,d.value),null)) as "Na",
avg(decode(p.id,47,decode(d.value,'0',null,d.value),null)) as "K",
avg(decode(p.id,48,decode(d.value,'0',null,d.value),null)) as "Cl",
avg(decode(p.id,51,decode(d.value,'0',null,d.value),null)) as "Gluc",
avg(decode(p.id,52,decode(d.value,'0',null,d.value),null)) as "Trigs",
avg(decode(p.id,53,decode(d.value,'0',null,d.value),null)) as "Chol",
avg(decode(p.id,54,decode(d.value,'0',null,d.value),null)) as "Amy",
avg(decode(p.id,55,decode(d.value,'0',null,d.value),null)) as "NEFAC",
avg(decode(p.id,56,decode(d.value,'0',null,d.value),null)) as "TP",
avg(decode(p.id,57,decode(d.value,'0',null,d.value),null)) as "Alb",
avg(decode(p.id,58,decode(d.value,'0',null,d.value),null)) as "Ca",
avg(decode(p.id,59,decode(d.value,'0',null,d.value),null)) as "Phos",
avg(decode(p.id,60,decode(d.value,'0',null,d.value),null)) as "Iron",
avg(decode(p.id,61,decode(d.value,'0',null,d.value),null)) as "AST",
avg(decode(p.id,62,decode(d.value,'0',null,d.value),null)) as "ALP",
avg(decode(p.id,63,decode(d.value,'0',null,d.value),null)) as "ALT",
avg(decode(p.id,64,decode(d.value,'0',null,d.value),null)) as "Creat",
avg(decode(p.id,65,decode(d.value,'0',null,d.value),null)) as "LDH",
avg(decode(p.id,66,decode(d.value,'0',null,d.value),null)) as "Urea",
avg(decode(p.id,67,decode(d.value,'0',null,d.value),null)) as "TBilC",
avg(decode(p.id,69,decode(d.value,'0',null,d.value),null)) as "CK",
avg(decode(p.id,70,decode(d.value,'0',null,d.value),null)) as "Mg",
avg(decode(p.id,71,decode(d.value,'0',null,d.value),null)) as "HDL",
avg(decode(p.id,72,decode(d.value,'0',null,d.value),null)) as "LDL",
avg(decode(p.id,73,decode(d.value,'0',null,d.value),null)) as "UA",
r.COMMENTS
from mts_mouse m,
     phn_bloods_run r,
     phn_bloods_data d,
     phn_parameter_dict p,
     mts_gender_dict g,
     mts_cohort_mouse c,
     mts_cohort mc,
     mts_colony_info ci,
     mts_mouse_allele ma,
     mts_genotype_dict gd,
     gnm_gene gn,
     typ_strain t,
     (select a.colony_id, t.gene_id
      from
      mts_colony_allele a,
      typ_modified_allele t
      where
      a.modified_allele_id = t.id
     ) z
where
     r.MOUSE_ID = m.ID
and m.MOUSE_STRAIN_DICT_ID = t.id(+)
and  m.id = c.MOUSE_ID
and  c.COHORT_ID = mc.ID
and  m.GENDER_DICT_ID = g.id
and  r.id = d.RUN_ID
and  d.PARAMETER_ID = p.ID
and r.INSTRUMENT_ID = 2
and m.id = c.mouse_id
and c.cohort_id = mc.id
and mc.cohort_name like '%Pipeline 1%'
and m.id = ma.mouse_id(+)
and ma.genotype_dict_id = gd.id(+)
and m.colony_info_id = ci.id
and ci.id = z.colony_id(+)
and gn.id(+) = z.gene_id
group by t.name,mc.cohort_name,gn.primary_name,r.run_date,m.name,mts.fetch_genotype(m.id), round((nvl(m.death_date,sysdate) - m.birth_date)/7,1), g.name, r.COMMENTS
order by mc.cohort_name, m.name,g.name;

CREATE OR REPLACE FORCE VIEW REP_MI_SUMMARY_STATS_VW
(ID, MI_REQUEST_ID, CELL_LINE_NAME, CLONE_NAME, CELL_LINE_STRAIN,
 GENE_NAME, ALLELE_NAME, LATEST_MI_DATE, NUMBER_TRANSFERRED, NUMBER_BORN,
 PERCENT_BORN, NUMBER_CHIMERIC, PERCENT_CHIMERIC, NUMBER_MALE, PERCENT_MALE,
 NUMBER_FEMALE, NUMBER_MALE_100_PERCENT, NUMBER_MALE_GT_80_PERCENT, NUMBER_MALE_40_TO_80_PERCENT, NUMBER_MALE_LT_40_PERCENT,
 F0_BREEDINGS, F0_BREEDINGS_WITH_OFFSPRING, PERCENT_FERTILITY, F1_GERM_LINE_MICE, F1_NON_GERM_LINE_MICE,
 F1_TOTAL, CHIMERAS_WITH_GLT, PERCENT_GLT, NUMBER_100_PERCENT_GLT, NUMBER_GT_50_PERCENT_GLT,
 NUMBER_BTW_10_50_PERCENT_GLT, NUMBER_LT_10_PERCENT_GLT)
AS
select
 s.mi_request_id id,
 s.mi_request_id,
 s.cell_line_name,
 s.clone_name,
 s.cell_line_strain,
 s.gene_name,
 s.allele_name,
 s.latest_mi_date,
 s.number_transferred,
 s.number_born,
 mir.calc_percent_number(s.number_born, s.number_transferred) percent_born,
 s.number_chimeric,
 mir.calc_percent_number(s.number_chimeric, s.number_born) percent_chimeric,
 s.number_male,
 mir.calc_percent_number(s.number_male, s.number_chimeric) percent_male,
 s.number_female,
 s.number_100_percent number_male_100_percent,
 s.number_gt_80_percent number_male_gt_80_percent,
 s.number_40_to_80_percent number_male_40_to_80_percent,
 s.number_lt_40_percent number_male_lt_40_percent,
 s.f0_breedings,
 s.f0_breedings_with_offspring,
 mir.calc_percent_number(s.f0_breedings_with_offspring, s.f0_breedings) percent_fertility,
 s.f1_germ_line_mice,
 s.f1_non_germ_line_mice,
 s.f1_total,
 s.chimeras_with_glt,
 mir.calc_percent_number(s.chimeras_with_glt, s.f0_breedings) percent_glt,
 s.number_100_percent_glt,
 s.number_gt_50_percent_glt,
 s.number_btw_10_50_percent_glt,
 s.number_lt_10_percent_glt
from
  mir_combined_summary_with_gene s;

CREATE OR REPLACE FORCE VIEW TYP_MODIFIED_ALLELE_LIST_VW
(ID, LOCUS_ID, MUTATION_NATURE_ID, MUTATION_NATURE, HTML_ALLELE_SYMBOL,
 INTERNAL_NAME, OFFICIAL_NAME_SUPERSCRIPT, MULTI_GENE_REGION, IS_HOMOZYGOUS_LETHAL, INHERITANCE_MODE_ID,
 INHERITANCE_MODE, HAS_ASSOCIATED_PHENOTYPE, PHENOTYPE_DESCRIPTION, MULTI_GENE_REGION_DESCRIP, ALLELE_DESCRIPTION,
 SHORT_ALLELE_SYMBOL, CREATED_DATE, CREATOR_ID, CREATOR_NAME, GENE_ID,
 GENE_NAME, ENSEMBL_ID, MULTIPLE_GENE_REGION_NAME, ALLELE_MAKER_ID, ALLELE_MAKER_NAME,
 EDIT_DATE, EDITED_BY, CHECK_NUMBER, HARMFUL_MUTANT, MUTATION_CLASS_DICT_ID,
 MUTATION_CLASS, EXTERNAL_MAKER_NAME, ALLELE_SYNONYMS)
AS
select distinct
  m.id,
  m.locus_id,
  m.mutation_nature_id,
  d2.name mutation_nature,
  '<i>'||nvl(g.primary_name,'(no gene)')||'<sup><font size=''-1''>'||nvl(m.official_name_superscript,'(no allele)')||'</font></sup></i>' html_allele_symbol,
  m.internal_name,
  m.official_name_superscript,
  m.multi_gene_region,
  m.is_homozygous_lethal,
  m.inheritance_mode_id,
  d1.name inheritance_mode,
  m.has_associated_phenotype,
  m.phenotype_description,
  m.multi_gene_region_descrip,
  m.allele_description,
  m.short_allele_symbol,
  m.created_date,
  m.creator_id,
  c.first_name||' '||c.last_name creator_name,
  m.gene_id,
  g.primary_name gene_name,
  g.ensembl_id,
  m.multiple_gene_region_name,
  m.allele_maker_id,
  p.first_name||' '||p.last_name allele_maker_name,
  m.edit_date,
  m.edited_by,
  m.check_number,
  m.harmful_mutant,
  m.mutation_class_dict_id,
  d3.name mutation_class,
  m.maker_name external_maker_name,
  mir.addallelesynonyms(m.id) allele_synonyms
from
  typ_modified_allele m,
  (select
    g.id gene_id,
    g.primary_name,
    b.primary_name ensembl_id
  from
    gnm_gene g,
    gnm_gene_build_gene b
  where
    g.primary_ensembl_build_gene_id = b.id(+)
  ) g,
  typ_inheritance_mode_dict d1,
  typ_mutation_nature_dict d2,
  typ_mutation_class_dict d3,
  per_person p,
  per_person c,
  typ_allele_synonym s
where
  m.gene_id = g.gene_id(+) and
  m.inheritance_mode_id = d1.id(+) and
  m.mutation_nature_id = d2.id(+) and
  m.mutation_class_dict_id = d3.id(+) and
  m.allele_maker_id = p.person_id(+) and
  m.creator_id = c.person_id(+) and
  m.id = s.allele_id(+);

CREATE OR REPLACE FORCE VIEW MIR_GERM_LINE_SUMMARY
(EMBRYO_TRANSFER_ID, F1_GERM_LINE, F1_NON_GERM_LINE, F1_TOTAL, CHIMERA_GLT,
 NUMBER_100_PERCENT_GLT, NUMBER_GT_50_PERCENT_GLT, NUMBER_BTW_10_50_PERCENT_GLT, NUMBER_LT_10_PERCENT_GLT)
AS
select
  embryo_transfer_id,
  sum(f1_germ_line) f1_germ_line,
  sum(f1_non_germ_line) f1_non_germ_line,
  sum(f1_total) f1_total,
  sum(chimera_glt) chimera_glt,
  sum(number_100_percent_glt) number_100_percent_glt,
  sum(number_gt_50_percent_glt) number_gt_50_percent_glt,
  sum(number_btw_10_50_percent_glt) number_btw_10_50_percent_glt,
  sum(number_lt_10_percent_glt) number_lt_10_percent_glt
from (
select
  embryo_transfer_id,
  sum(f1_germ_line) f1_germ_line,
  sum(f1_non_germ_line) f1_non_germ_line,
  sum(f1_total) f1_total,
  count(distinct chimera_glt) chimera_glt,
  count(mir.in_range(mir.calc_percent_number(f1_germ_line, f1_total),100,100)) number_100_percent_glt,
  count(mir.in_range(mir.calc_percent_number(f1_germ_line, f1_total),50.01,99.99)) number_gt_50_percent_glt,
  count(mir.in_range(mir.calc_percent_number(f1_germ_line, f1_total),10.1,50)) number_btw_10_50_percent_glt,
  decode(f1_germ_line,0,0,count(mir.in_range(mir.calc_percent_number(f1_germ_line, f1_total),0,10))) number_lt_10_percent_glt
from (
select
  b.embryo_transfer_id,
  nvl(count(distinct decode(m.coat_colour_dict_id,c.expected_coat_colour_dict_id,m.id,null)),0) f1_germ_line,
  nvl(count(distinct decode(m.coat_colour_dict_id,c.expected_coat_colour_dict_id,null,m.id)),0) f1_non_germ_line,
  count(distinct m.id) f1_total,
  decode(nvl(count(distinct decode(m.coat_colour_dict_id,c.expected_coat_colour_dict_id,m.id,null)),0),0,null,b.chimera_id) chimera_glt
from
  mir_f0_breeding2_summary b,
  mir_mi_summary c,
  mts_litter l,
  mts_breeding br,
  mts_mouse m
where
  b.embryo_transfer_id = c.embryo_transfer_id and
  br.id = l.breeding_id and
  br.male_id = b.chimera_id and
  m.litter_id = l.id
group by
  b.embryo_transfer_id,
  b.chimera_id
)
group by embryo_transfer_id,f1_germ_line
)
group by embryo_transfer_id;




CREATE OR REPLACE FORCE VIEW MIR_REQUEST_LIST_VW
(ID, REQUESTER_NAME, TEAM_NUMBER, CHIMERA_MATE_STRAIN_NAME, CHIMERA_MATE_STRAIN_ID,
 STRAIN_NAME, STRAIN_ID, CELL_LINE_NAME, CELL_LINE_ID, CLONE_NAME,
 ENDPOINT_NAME, ENDPOINT_ID, EMBRYO_STAGE_NAME, EMBRYO_STAGE_ID, EDIT_DATE,
 CREATED_DATE, PROJECT_LICENCE, WORKFLOW_PIPELINE, WORKFLOW_PIPELINE_ID, REQUESTER_ID,
 EXTERNAL_STATUS_DICT_ID, EXTERNAL_STATUS_NAME, SMI_COUNT, REQUESTER_PROVIDED_GENOTYPING, GENE_NAME,
 COLONY_INFO_ID, COLONY_NAME, COLONY_PREFIX)
AS
SELECT mir.ID, per.requester_name, per.team_number,
          cms.NAME chimera_mate_strain_name, cms.ID chimera_mate_strain_id,
          esline.NAME strain_name, esline.ID strain_id, cl.cell_line_name,
          cl.ID cell_line_id, cl.clone_name, ed.NAME endpoint_name,
          ed.ID endpoint_id, sd.NAME embryo_stage_name, sd.ID embryo_stage_id,
          mir.edit_date, mir.created_date, pl.ppl project_licence,
          aw.NAME workflow_pipeline, aw.ID workflow_pipeline_id,
          mir.requester_id requester_id, esd.ID external_status_dict_id,
          esd.NAME external_status_name,
          NVL (smi_table.smi_count, 0) smi_count,
          mir.requester_provided_genotyping,
    g.primary_name gene_name,
    col.id colony_info_id,
    col.colony_name,
    col.colony_prefix
     FROM mir_micro_injection_request mir,
          app_workflow_pipeline_dict aw,
          mir_chimera_mate_strain_dict cms,
          mir_cell_line_strain_dict esline,
          mir_target_endpoint_dict ed,
          (SELECT   micro_injection_request_id, COUNT (*) smi_count
               FROM mir_scheduled_micro_injection
           GROUP BY micro_injection_request_id) smi_table,
          (SELECT p.person_id,
                  p.first_name || ' ' || p.last_name requester_name,
                  tm.team_number
             FROM per_person p, per_team tm
            WHERE p.team_id = tm.ID(+)) per,
          mir_cell_line cl,
    typ_modified_allele tma,
          mir_embryo_stage_dict sd,
          lic_project_licence pl,
          mir_external_status_dict esd,
    mts_colony_info col ,
 gnm_gene g
    WHERE mir.endpoint_dict_id = ed.ID(+)
      AND aw.ID(+) = mir.workflow_pipeline_dict_id
      AND mir.donor_embryo_stage_dict_id = sd.ID(+)
      AND mir.chimera_mate_strain_dict_id = cms.ID(+)
      AND mir.requester_id = per.person_id(+)
      AND mir.cell_line_id = cl.ID(+)
      AND mir.project_licence_id = pl.project_licence_id(+)
      AND cl.cell_line_strain_dict_id = esline.ID(+)
      AND smi_table.micro_injection_request_id(+) = mir.ID
      AND mir.external_status_dict_id = esd.ID(+)
   AND mir.colony_info_id = col.id(+)
   and cl.modified_allele_id=tma.id(+)
   and tma.gene_id=g.id(+);

CREATE OR REPLACE FORCE VIEW CRQ_VIAL_SAMPLE_LIST_VW
(ID, COLONY_NAME, COLONY_ID, REQUEST_ID, FREEZE_DOWN_DATE,
 EMBRYO_COUNT, THAW_TEST_ID, EMBRYO_GRADE, EMBRYO_GRADE_DICT_ID, FREEZER_NAME,
 FREEZER_ID, TOWER_NAME, TOWER_ID, BOX_NAME, BOX_ID,
 VIAL_POSITION, TECHNICIAN_NAME, TECHNICIAN_ID, SAMPLE_ID, SCHEDULED_JOB_ID,
 CRYO_JOB_STATUS_DICT_ID, FEMALE_STRAIN_NAME, REQUESTED_FEMALE_STRAIN_NAME, FEMALE_STRAIN_ID, REQUESTED_FEMALE_STRAIN_ID)
AS
SELECT svw.vial_id ID, c.colony_name, c.colony_id, c.request_id,
       fds.freeze_down_date, fds.embryo_count, fds.thaw_test_id, gd.NAME embryo_grade,
       gd.ID embryo_grade_dict_id, svw.freezer_name, svw.freezer_id,
       svw.tower_name, svw.tower_id, svw.box_name, svw.box_id,
       svw.vial_position,
       (p.first_name || ' ' || p.last_name) technician_name,
       p.person_id technician_id, fds.ID sample_id, cr.ID scheduled_job_id,cr.cryo_job_status_dict_id,
    ts1.NAME female_strain_name, ts2.name requested_female_strain_name,ts1.id female_strain_id, ts2.id requested_female_strain_id
  FROM CRQ_FREEZE_DOWN_SAMPLE fds,
       CRQ_EMBRYO_HARVEST eh,
       CRQ_SCHEDULED_CRYO_PRV cr,
       PER_PERSON p,
       CRQ_LOCATION l,
       CRQ_VIAL v,
       crq_vial_location_vw svw,
       CRQ_EMBRYO_GRADE_DICT gd,
       (SELECT ci.colony_name, ci.ID colony_id, re.ID request_id,re.FEMALE_STRAIN_DICT_ID request_female_strain_dict_id
          FROM CRQ_CRYO_REQUEST re, MTS_COLONY_INFO ci
         WHERE re.colony_id = ci.ID) c ,
     TYP_STRAIN ts1,
     TYP_STRAIN ts2
 WHERE fds.embryo_harvest_id = eh.ID
   AND eh.scheduled_job_id = cr.ID(+)
   AND cr.cryo_request_id = c.request_id(+)
   AND p.person_id(+) = fds.technician_id
   AND l.vial_id = v.ID
   AND fds.location_id = l.ID
   AND svw.vial_id = v.ID
   AND fds.embryo_grade_dict_id = gd.ID
   AND eh.female_strain_id = ts1.ID (+)
   AND c.request_female_strain_dict_id = ts2.id(+);

CREATE OR REPLACE FORCE VIEW CRQ_SAMPLE_LIST_VW
(COLONY_NAME, COLONY_ID, REQUEST_ID, FREEZE_DOWN_DATE, EMBRYO_COUNT,
 EMBRYO_GRADE, EMBRYO_GRADE_DICT_ID, LOCATION_NAME, ID, TECHNICIAN_NAME,
 TECHNICIAN_ID, SAMPLE_ID, SCHEDULED_JOB_ID, CRYO_JOB_STATUS_DICT_ID, THAW_TEST_ID,
 STORAGE_TYPE, FEMALE_STRAIN_NAME, REQUESTED_FEMALE_STRAIN_NAME, FEMALE_STRAIN_ID, REQUESTED_FEMALE_STRAIN_ID)
AS
SELECT v.colony_name colony_name, v.colony_id colony_id,
          v.request_id request_id, v.freeze_down_date freeze_down_date,
          v.embryo_count embryo_count, v.embryo_grade embryo_grade,
          v.embryo_grade_dict_id embryo_grade_dict_id,
          (   'Freezer ' || v.freezer_name
           || ', Tower '
           || v.tower_name
           || ', Box '
           || v.box_name
           || ', Vial '
           || v.vial_position
          ) location_name,
          v.ID ID, v.technician_name technician_name,
          v.technician_id technician_id, v.sample_id, v.scheduled_job_id,
          v.cryo_job_status_dict_id, v.thaw_test_id, 'vial' storage_type,v.female_strain_name,v.requested_female_strain_name,v.female_strain_id,
    v.requested_female_strain_id
     FROM crq_vial_sample_list_vw v
   UNION
   SELECT s.colony_name colony_name, s.colony_id colony_id,
          s.request_id request_id, s.freeze_down_date freeze_down_date,
          s.embryo_count embryo_count, s.embryo_grade embryo_grade,
          s.embryo_grade_dict_id embryo_grade_dict_id,
          (   'Freezer ' || s.freezer_name
           || ', Canister '
           || s.canister_name
           || ', Goblet '
           || s.goblet_name
           || ', Wedge '
           || s.wedge_colour
          ) location_name,
          s.ID ID, s.technician_name technician_name,
          s.technician_id technician_id, s.sample_id, s.scheduled_job_id,
          s.cryo_job_status_dict_id, s.thaw_test_id, 'straw' storage_type,s.female_strain_name,s.requested_female_strain_name,s.female_strain_id,
    s.requested_female_strain_id
     FROM crq_straw_sample_list_vw s;

CREATE OR REPLACE FORCE VIEW REP_SIX_WEEK_OLD_CHIMERA_VW
(ID, NAME, COLONY_PREFIX, COLONY_NAME, CELL_LINE_NAME,
 CLONE_NAME, BIRTH_DATE, MATING_STATUS)
AS
select
  mo.id,
  mo.name,
  co.colony_prefix,
  co.colony_name,
  ch.cell_line_name,
  ch.clone_name,
  mo.birth_date,
  decode(br.breeding_id, null, 'Not in mating', 'In Mating') mating_status
from
  mts_mouse mo,
  mts_colony_info co,
  mts_chimeric_mouse_data_vw ch,
  mts_latest_breeding_vw br
where
  mo.colony_info_id = co.id and
  ch.mouse_id = mo.id and
  trunc(mo.birth_date) between trunc((sysdate-(7*14))) and trunc((sysdate-(7*6))) and
  br.mouse_id(+) = mo.id
order by 1;


DROP MATERIALIZED VIEW MIG.MIR_SMI_POST_ET_STATUS_MV;

CREATE MATERIALIZED VIEW MIG.MIR_SMI_POST_ET_STATUS_MV
TABLESPACE DATA_02
NOCACHE
LOGGING
NOCOMPRESS
NOPARALLEL
BUILD IMMEDIATE
REFRESH FORCE
START WITH TO_DATE('01-May-2008','dd-mon-yyyy')
NEXT trunc(sysdate) + 1
WITH PRIMARY KEY
AS
select
  smi.id,
  decode(med.id,2,mir.mir_f0_status(smi.id),1,mir.mir_f0_status(smi.id),null) f0_status,
  decode(med.id,1,mir.mir_f1_status(smi.id),null) f1_status
from
  mir_scheduled_micro_injection smi,
  mir_micro_injection_request mir,
  mir_target_endpoint_dict med
where mir.id = smi.micro_injection_request_id
   and mir.endpoint_dict_id = med.id;


