connect mig_audit

alter table mts_mouse_weight add sample_date date;

alter table mts_mouse drop column status;

alter table mts_cage drop column status;

connect mig

alter table mts_mouse_weight add sample_date date;

CREATE OR REPLACE FORCE VIEW MTS_ALL_MOUSE_WEIGHT_VW
(ID, MOUSE_ID, WEIGHT_VALUE, WEIGHT_UNITS, CHECK_NUMBER,
 CREATOR_ID, CREATED_DATE, EDITED_BY, EDIT_DATE, SAMPLE_DATE)
AS
select
  id,
  mouse_id,
  to_char(weight_value) weight_value,
  weight_units,
  check_number,
  creator_id,
  created_date,
  edited_by,
  edit_date,
  sample_date
from
  mts_mouse_weight mw
union
select
  po.id,
  pe.mouse_id,
  po.value weight_value,
  pt.units weight_units,
  po.check_number,
  po.creator_id,
  nvl(mp.start_date,ps.scheduled_date) created_date,
  po.edited_by,
  po.edit_date,
  nvl(mp.start_date,ps.scheduled_date) sample_date
from
  phn_observation po,
  phn_required_observation ro,
  phn_observation_type pt,
  phn_experiment pe,
  phn_experiment_set ps,
  mts_mouse_procedure mp
where
  po.required_observation_id = ro.id and
  ro.observation_type_id = pt.id and
  pt.id = 1 and
  po.experiment_id = pe.id and
  pe.experiment_set_id = ps.id and
  mp.foreign_key_id(+) = pe.id and
  mp.foreign_table_name(+) = 'PHN_EXPERIMENT' and
  po.value is not null
/


CREATE OR REPLACE FORCE VIEW MTS_MOUSE_CURRENT_WEIGHT_VW
(ID, MOUSE_ID, WEIGHT_VALUE, WEIGHT_UNITS, CHECK_NUMBER,
 CREATOR_ID, CREATED_DATE, EDITED_BY, EDIT_DATE, SAMPLE_DATE)
AS
with max_weights as (
  select mouse_id,max(sample_date) sample_date from mts_all_mouse_weight_vw group by mouse_id
)
select
  w.id,
  w.mouse_id,
  w.weight_value,
  w.weight_units,
  w.check_number,
  w.creator_id,
  w.created_date,
  w.edited_by,
  w.edit_date,
  w.sample_date
from
  mts_all_mouse_weight_vw w,
  max_weights mw
where
  w.mouse_id = mw.mouse_id and
  w.sample_date = mw.sample_date
/


CREATE OR REPLACE FORCE VIEW MTS_MOUSE_WEIGHT_VW
(BARCODE, CREATED_DATE, WEIGHT_VALUE, SAMPLE_DATE)
AS
select
  m.barcode,
  w.created_date,
  w.weight_value ,
  w.sample_date
from
  mts_mouse m,
  mts_mouse_weight w
where
  m.id = w.mouse_id
/

CREATE OR REPLACE TRIGGER MTS_MOUSE_WEIGHT_TA
before update or delete on MTS_MOUSE_WEIGHT for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
declare
audit_action varchar2(10);
begin

if deleting then audit_action := 'deleted'; end if;
if updating then audit_action := 'updated'; end if;
if deleting or updating then
 insert into mig_audit.MTS_MOUSE_WEIGHT(
    ID,
    MOUSE_ID,
    WEIGHT_VALUE,
    WEIGHT_UNITS,
    CHECK_NUMBER,
    CREATOR_ID,
    CREATED_DATE,
    EDITED_BY,
    EDIT_DATE,
	SAMPLE_DATE,
    AUDIT_ACTION)
 values (
    :old.ID,
    :old.MOUSE_ID,
    :old.WEIGHT_VALUE,
    :old.WEIGHT_UNITS,
    :old.CHECK_NUMBER,
    :old.CREATOR_ID,
    :old.CREATED_DATE,
    :old.EDITED_BY,
    :old.EDIT_DATE,
	:old.SAMPLE_DATE,
    AUDIT_ACTION);
end if;
end;
/

update mts_mouse_weight set sample_date = created_date where sample_date is null;

commit;

alter table mts_mouse drop column status;

CREATE OR REPLACE TRIGGER MTS_MOUSE_TA
before update or delete on MTS_MOUSE for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
declare
audit_action varchar2(10);
begin

if deleting then audit_action := 'deleted'; end if;
if updating then audit_action := 'updated'; end if;
if deleting or updating then
 insert into mig_audit.MTS_MOUSE(
    ID,
    LITTER_ID,
    NAME,
    EDIT_DATE,
    RFID_TAG,
    COAT_COLOUR_DICT_ID,
    EYE_COLOUR_DICT_ID,
    EARMARK_DICT_ID,
    BIRTH_DATE,
    DEATH_DATE,
    CAUSE_OF_DEATH_DICT_ID,
    EDITED_BY,
    WEAN_DATE,
    CAGE_ID,
    CURRENT_OWNER_ID,
    CHECK_NUMBER,
    GENDER_DICT_ID,
    MOUSE_STRAIN_DICT_ID,
    CREATOR_ID,
    CREATED_DATE,
    BARCODE,
    COMMENTS,
    SUPPLIER_DICT_ID,
    IS_NON_BREEDER,
    IS_SENTINEL,
    GENERATION,
    COLONY_INFO_ID,
    ARRIVAL_DATE,
    EARMARK_LEFT,
    EARMARK_RIGHT,
    IS_STERILE,
    LATEST_PLUG_DATE,
    AUDIT_ACTION)
 values (
    :old.ID,
    :old.LITTER_ID,
    :old.NAME,
    :old.EDIT_DATE,
    :old.RFID_TAG,
    :old.COAT_COLOUR_DICT_ID,
    :old.EYE_COLOUR_DICT_ID,
    :old.EARMARK_DICT_ID,
    :old.BIRTH_DATE,
    :old.DEATH_DATE,
    :old.CAUSE_OF_DEATH_DICT_ID,
    :old.EDITED_BY,
    :old.WEAN_DATE,
    :old.CAGE_ID,
    :old.CURRENT_OWNER_ID,
    :old.CHECK_NUMBER,
    :old.GENDER_DICT_ID,
    :old.MOUSE_STRAIN_DICT_ID,
    :old.CREATOR_ID,
    :old.CREATED_DATE,
    :old.BARCODE,
    :old.COMMENTS,
    :old.SUPPLIER_DICT_ID,
    :old.IS_NON_BREEDER,
    :old.IS_SENTINEL,
    :old.GENERATION,
    :old.COLONY_INFO_ID,
    :old.ARRIVAL_DATE,
    :old.EARMARK_LEFT,
    :old.EARMARK_RIGHT,
    :old.IS_STERILE,
    :old.LATEST_PLUG_DATE,
    AUDIT_ACTION);
end if;
end;
/

CREATE OR REPLACE FORCE VIEW MTS_MOUSE_VW
(ID, LITTER_ID, NAME, RFID_TAG, EDIT_DATE,
 COAT_COLOUR_DICT_ID, COAT_COLOUR, EYE_COLOUR_DICT_ID, EYE_COLOUR, EARMARK_DICT_ID,
 EARMARK, EARMARK_LEFT, EARMARK_RIGHT, BIRTH_DATE, AGE_IN_WEEKS,
 DEATH_DATE, AGE_AT_DEATH, CAUSE_OF_DEATH_DICT_ID, CAUSE_OF_DEATH, EDITED_BY,
 WEAN_DATE, CAGE_ID, CAGE_NAME, CAGE_BARCODE, RACK_ID,
 RACK_NAME, ROOM_ID, ROOM_NAME, CURRENT_OWNER_ID, CURRENT_OWNER,
 CURRENT_PROJECT_LICENCE_ID, CURRENT_PROJECT_LICENCE, CURRENT_PROTOCOL_ID, CURRENT_PROTOCOL_CODE, CHECK_NUMBER,
 GENDER_DICT_ID, GENDER, MOUSE_STRAIN_DICT_ID, STRAIN, STATUS,
 CREATOR_ID, CREATED_DATE, BARCODE, COMMENTS, IS_NON_BREEDER,
 IS_SENTINEL, GENERATION, COLONY_NAME, COLONY_PREFIX, COLONY_INFO_ID,
 ARRIVAL_DATE, LATEST_PLUG_DATE, BREEDING_NAME, GENOTYPE, FATHER_NAME,
 FATHER_GENOTYPE, MOTHER_NAME, MOTHER_GENOTYPE, COHORTS, PIPELINES)
AS
select
  m.id,
  m.litter_id,
  m.name,
  m.rfid_tag,
  m.edit_date,
  m.coat_colour_dict_id,
  c.name||decode(chim.percent_chimeric,null,null,' ('||chim.percent_chimeric||'%)') coat_colour,
  m.eye_colour_dict_id,
  e.name eye_colour,
  m.earmark_dict_id,
  ear.name earmark,
  m.earmark_left,
  m.earmark_right,
  m.birth_date,
  round((nvl(m.death_date,sysdate) - m.birth_date)/7,1) age_in_weeks,
  m.death_date,
  round((m.death_date - m.birth_date)/7,1) age_at_death,
  m.cause_of_death_dict_id,
  d.name cause_of_death,
  m.edited_by,
  m.wean_date,
  m.cage_id,
  l.cage_name,
  l.cage_barcode,
  l.rack_id,
  l.rack_name,
  l.room_id,
  l.room_name,
  m.current_owner_id,
  owner.first_name||' '||owner.last_name current_owner,
  b.project_licence_id current_project_licence_id,
  b.licence_number current_project_licence,
  b.protocol_id current_protocol_id,
  b.protocol_code current_protocol_code,
  m.check_number,
  m.gender_dict_id,
  s.name gender,
  m.mouse_strain_dict_id,
  t.name strain,
  decode(m.death_date,null,'Alive','Deceased') status,
  m.creator_id,
  m.created_date,
  m.barcode,
  m.comments,
  m.is_non_breeder,
  m.is_sentinel,
  m.generation,
  colony.colony_name,
  colony.colony_prefix,
  m.colony_info_id,
  m.arrival_date,
  m.latest_plug_date,
  breeding.breeding_name,
  mts.fetch_genotype(m.id) genotype,
  p.father_name,
  decode(m.generation,'F0',null,decode(p.male_id,null,null,mts.fetch_genotype(p.male_id))) father_genotype,
  p.mother_name,
  decode(m.generation,'F0',null,decode(p.female_id,null,null,mts.fetch_genotype(p.female_id))) mother_genotype,
  mts.fetch_cohort(m.id,', ') cohorts,
  mts.fetch_pipelines(m.id,', ') pipelines
from
  mts_mouse m,
  mts_coat_colour_dict c,
  mts_eye_colour_dict e,
  mts_earmark_dict ear,
  mts_cause_of_death_dict d,
  per_person owner,
  mts_gender_dict s,
  mts_cage_vw l,
  mts_mouse_current_19b_mv b,
  typ_strain t,
  mts_colony_info colony,
  mts_current_breeding_mv breeding,
  mts_chimeric_mouse_data chim,
  (select b.male_id, b.female_id, l.id litter_id, decode(b.embryo_transfer_id,null,sire.name, null) father_name, decode(b.embryo_transfer_id,null,dam.name,null) mother_name
   from
    mts_litter l,
    mts_breeding b,
 mts_mouse sire,
 mts_mouse dam
   where
    l.breeding_id = b.id and
 b.male_id = sire.id and
 b.female_id = dam.id
  ) p
where
  m.coat_colour_dict_id = c.id(+) and
  m.eye_colour_dict_id = e.id(+) and
  m.earmark_dict_id = ear.id(+) and
  m.cause_of_death_dict_id = d.id(+) and
  m.current_owner_id = owner.person_id(+) and
  m.gender_dict_id = s.id(+) and
  m.cage_id = l.cage_id(+) and
  m.mouse_strain_dict_id = t.id(+) and
  m.colony_info_id = colony.id(+) and
  m.id = b.mouse_id(+) and
  m.id = breeding.mouse_id(+) and
  m.id = chim.mouse_id(+) and
  m.litter_id = p.litter_id(+)
/

alter table mts_cage drop column status;

CREATE OR REPLACE TRIGGER MTS_CAGE_TA
before update or delete on MTS_CAGE for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
declare
audit_action varchar2(10);
begin

if deleting then audit_action := 'deleted'; end if;
if updating then audit_action := 'updated'; end if;
if deleting or updating then
 insert into mig_audit.MTS_CAGE(
    ID,
    RACK_ID,
    CHECK_NUMBER,
    COMMENTS,
    EDITED_BY,
    EDIT_DATE,
    CREATOR_ID,
    CREATED_DATE,
    BARCODE,
    NAME,
    LAST_CLEANED_DATE,
    AUDIT_ACTION)
 values (
    :old.ID,
    :old.RACK_ID,
    :old.CHECK_NUMBER,
    :old.COMMENTS,
    :old.EDITED_BY,
    :old.EDIT_DATE,
    :old.CREATOR_ID,
    :old.CREATED_DATE,
    :old.BARCODE,
    :old.NAME,
    :old.LAST_CLEANED_DATE,
    AUDIT_ACTION);
end if;
end;
/

alter table htl_crop rename column tile_edge to tile_edge_exponent;

alter table htl_crop add QC_LOCKED number;

alter table htl_crop add tiled number;

CREATE OR REPLACE VIEW HTL_CROP_VW
(MOUSE_ID, ALLELE, MOUSE_BARCODE, GENDER_DICT_ID, GENDER,
 ID, WIDTH, HEIGHT, RESIZED_IMAGE_PATH, CREATED_DATE,
 EDIT_DATE, FULL_IMAGE_PATH, QC_PASS, TILED, TISSUE_NAME,
 TISSUE_ID, SCAN_ID, SOURCE_BLOCK_ID, SOURCE_BLOCK_DESCRIPTION, SLIDE_ID,
 SLIDE_BARCODE, STAINING, STAINING_DICT_ID)
AS
SELECT
m.ID mouse_id,
Mts.Fetch_Genotype(m.ID) allele,
m.barcode mouse_barcode,
m.gender_dict_id,
mg.NAME gender,
c.ID ID,
c.width width,
c.height height,
c.resized_image_path,
c.created_date,
c.edit_date,
c.full_image_path,
c.qc_pass qc_pass,
c.tiled tiled,
t.NAME tissue_name,
t.ID tissue_id,
s.ID scan_id,
bt.ID source_block_id,
bt.description source_block_description,
sl.ID slide_id,
sl.barcode slide_barcode,
st.NAME staining,
st.ID staining_dict_id
FROM
HTL_CROP c,
HTL_TISSUE t,
HTL_CROP_JOB cj,
HTL_SCAN s,
HTL_SLIDE sl,
HTL_STAINING_TYPE_DICT st,
HTL_BLOCK b,
HTL_BLOCK_TYPE bt,
HTL_FIXATION f,
HTL_NECROPSY n,
MTS_MOUSE m,
MTS_GENDER_DICT mg
WHERE
c.crop_job_id = cj.ID
AND c.tissue_id = t.ID(+)
AND cj.scan_id = s.ID
AND s.slide_id = sl.ID
AND sl.staining_type_dict_id = st.ID
AND sl.block_id = b.ID
AND b.block_type_id = bt.ID
AND b.fixation_id = f.ID
AND f.necropsy_id = n.ID
AND n.mouse_id = m.ID
AND m.gender_dict_id = mg.ID
ORDER BY
n.mouse_id,
f.necropsy_id,
b.fixation_id,
sl.block_id,
s.slide_id,
cj.scan_id,
c.crop_job_id,
c.y_location
/

CREATE OR REPLACE VIEW HTL_SCAN_VW
(ID, STATUS_DICT_ID, STATUS, FILE_PATH, VERSION_NUMBER,
 SWEEP_DATE, WIDTH, HEIGHT, THUMBNAIL, THUMB_WIDTH,
 THUMB_HEIGHT, SLIDE_ID, STAINING, BLOCK_NAME, BLOCK_DESCRIPTION,
 MOUSE_BARCODE)
AS
SELECT
sc.ID ID,
sc.status_dict_id,
scStat.NAME status,
sc.file_path,
sc.version_number,
sc.sweep_date,
sc.width,
sc.height,
bin.binary_data thumbnail,
sc.thumb_width,
sc.thumb_height,
sl.ID slide_id,
st.NAME staining,
bt.NAME block_name,
bt.description block_description,
m.barcode mouse_barcode
FROM
HTL_SCAN sc,
HTL_SCAN_STATUS_DICT scStat,
APP_BINARY_FILES bin,
HTL_SLIDE sl,
HTL_STAINING_TYPE_DICT st,
HTL_BLOCK b,
HTL_BLOCK_TYPE bt,
HTL_FIXATION f,
HTL_NECROPSY n,
MTS_MOUSE m
WHERE
sc.status_dict_id = scStat.ID
AND sc.thumbnail_id = bin.ID
AND sc.slide_id = sl.ID
AND sl.staining_type_dict_id = st.ID
AND sl.block_id = b.ID
AND b.block_type_id = bt.ID
AND b.fixation_id = f.ID
AND f.necropsy_id = n.ID
AND n.mouse_id = m.ID
/

CREATE TABLE MIG.HTL_TILE
(
  ID                INTEGER,
  CROP_ID           INTEGER,
  ZOOM_LEVEL        INTEGER,
  ARRAY_INDEX       INTEGER,
  IMAGE             BLOB                        DEFAULT EMPTY_BLOB(),
  FORMAT_EXTENSION  VARCHAR2(5 BYTE)
);


CREATE UNIQUE INDEX MIG.HTL_TILE_PK ON MIG.HTL_TILE
(ID);


CREATE INDEX MIG.HTL_TILE_INDEX ON MIG.HTL_TILE
(CROP_ID);

DROP SEQUENCE MIG.HTL_TILE_SEQ;

CREATE SEQUENCE MIG.HTL_TILE_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

alter table app_custom_query_column add datatype_format_2 varchar2(512);

delete app_custom_query_column where custom_query_id = 11;

Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (109, 11, 'id', 'Mouse ID', 'hidden',
    NULL, NULL, NULL);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (110, 11, 'litter_id', 'Litter ID', 'hidden',
    NULL, NULL, NULL);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (111, 11, 'name', 'Name', 'href',
    1, 'view_one_mouse.do?id=', 'id');
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (112, 11, 'rfid_tag', 'RFID', NULL,
    NULL, NULL, NULL);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (115, 11, 'coat_colour', 'Coat', NULL,
    NULL, NULL, NULL);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (119, 11, 'earmark', 'Earclip', 'list',
    2, 'select id,name from mts_earmark_dict order by order_by', 'earmark_dict_id');
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (122, 11, 'birth_date', 'D.O.B.', 'date',
    5, NULL, NULL);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (123, 11, 'age_in_weeks', 'Age (weeks)', NULL,
    6, NULL, NULL);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (124, 11, 'death_date', 'D.O.D.', 'date',
    7, NULL, NULL);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (127, 11, 'cause_of_death', 'Fate', NULL,
    8, NULL, NULL);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (129, 11, 'wean_date', 'D.O.W.', 'date',
    9, NULL, NULL);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (130, 11, 'cage_id', 'Cage ID', 'hidden',
    NULL, NULL, NULL);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (132, 11, 'cage_barcode', 'Cage', 'href',
    10, 'view_one_cage.do?id=', 'cage_id');
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (134, 11, 'rack_name', 'Rack', NULL,
    11, NULL, NULL);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (136, 11, 'room_name', 'Room', NULL,
    12, NULL, NULL);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (138, 11, 'current_owner', 'Owner', NULL,
    13, NULL, NULL);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (140, 11, 'current_project_licence', 'PPL', NULL,
    14, NULL, NULL);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (142, 11, 'current_protocol_code', 'Protocol', NULL,
    15, NULL, NULL);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (145, 11, 'gender', 'Sex', 'list',
    NULL, 'select id,name from mts_gender_dict order by order_by', 'gender_dict_id');
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (147, 11, 'strain', 'G.Background', 'list',
    NULL, 'select id, name from typ_strain order by lower(name)', 'mouse_strain_dict_id');
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (148, 11, 'status', 'Status', NULL,
    NULL, NULL, NULL);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (151, 11, 'barcode', 'Barcode', NULL,
    NULL, NULL, NULL);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (152, 11, 'comments', 'Comments', NULL,
    NULL, NULL, NULL);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (155, 11, 'generation', 'Generation', NULL,
    3, NULL, NULL);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (156, 11, 'colony_name', 'Colony Name', NULL,
    NULL, NULL, NULL);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (157, 11, 'colony_prefix', 'Colony Prefix', NULL,
    NULL, NULL, NULL);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (158, 11, 'colony_info_id', 'Colony ID', 'hidden',
    NULL, NULL, NULL);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (161, 11, 'breeding_name', 'Current Mating', NULL,
    NULL, NULL, NULL);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (162, 11, 'genotype', 'Genotype', NULL,
    4, NULL, NULL);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (163, 11, 'father_name', 'Father', NULL,
    NULL, NULL, NULL);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (164, 11, 'father_genotype', 'Father Genotype', NULL,
    NULL, NULL, NULL);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (165, 11, 'mother_name', 'Mother', NULL,
    NULL, NULL, NULL);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (166, 11, 'mother_genotype', 'Mother Genotype', NULL,
    NULL, NULL, NULL);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (167, 11, 'cohorts', 'Cohort', NULL,
    NULL, NULL, NULL);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (168, 11, 'pipelines', 'Pipeline', NULL,
    NULL, NULL, NULL);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (169, 11, 'gender_dict_id', 'Gender ID', 'hidden',
    NULL, NULL, NULL);

update app_custom_query_column set datatype_format = 'view_one_mouse.do?id=', datatype_format_2 = 'id' where id = 2;

update app_custom_query_column set datatype_format = 'view_one_breeding.do?id=', datatype_format_2 = 'id' where id = 42;

update app_custom_query_column set datatype_format = 'view_one_litter.do?id=', datatype_format_2 = 'id' where id = 48;

update app_custom_query_column set datatype_format = 'view_one_mi_request.do?id=', datatype_format_2 = 'micro_injection_request_id' where id = 56;

update app_custom_query_column set datatype_format = 'view_one_breeding.do?id=', datatype_format_2 = 'id' where id = 59;

update app_custom_query_column set datatype_format = 'view_one_mi_request.do?id=', datatype_format_2 = 'id' where id = 69;

update app_custom_query_column set datatype_format = 'view_one_cage.do?id=', datatype_format_2 = 'cage_id' where id = 88;

update app_custom_query_column set datatype_format = 'view_one_mouse.do?id=', datatype_format_2 = 'id' where id = 89;

commit;

CREATE OR REPLACE VIEW APP_CUSTOM_QUERY_COL_PREF_VW
(ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE,
 DATATYPE_FORMAT, DATATYPE_FORMAT_2, ORDER_BY, PERSON_ID)
AS
select
  c.id,
  c.custom_query_id,
  c.column_name,
  c.column_title,
  c.datatype,
  c.datatype_format,
  c.datatype_format_2,
  p.order_by,
  p.person_id
from
  app_custom_query_person_pref p,
  app_custom_query_column c
where
  c.id = p.query_column_id
union
select
  c.id,
  c.custom_query_id,
  c.column_name,
  c.column_title,
  c.datatype,
  c.datatype_format,
  c.datatype_format_2,
  c.order_by,
  p.person_id
from
  per_person p,
  app_custom_query_column c
where
  not exists (select null from app_custom_query_person_pref x, app_custom_query_column y where x.person_id = p.person_id and x.query_column_id = y.id and y.custom_query_id = c.custom_query_id);

CREATE OR REPLACE VIEW MTS_MOUSE_HEALTH_VW
(ID, START_DATE, END_DATE, MOUSE_ID, MOUSE_NAME, 
 MOUSE_BARCODE, ROOM_NAME, ROOM_ID, RACK_NAME, RACK_ID, 
 CAGE_NAME, CAGE_ID, BODY_SYSTEM, BODY_SYSTEM_DICT_ID, BODY_SUBSYSTEM, 
 BODY_SUBSYSTEM_DICT_ID, HEALTH_CONCERN, HEALTH_CONCERN_DICT_ID, STATUS, EDIT_DATE, 
 MOUSE_STATUS)
AS 
select 
  h.id, 
  h.start_date, 
  h.end_date, 
  m.id mouse_id, 
  m.name mouse_name, 
  m.barcode mouse_barcode, 
  c.room_name, 
  c.room_id, 
  c.rack_name, 
  c.rack_id, 
  c.cage_name, 
  c.cage_id, 
  d1.name body_system, 
  h.body_system_dict_id, 
  d2.name body_subsystem, 
  h.body_subsystem_dict_id, 
  d3.name health_concern, 
  h.health_concern_dict_id, 
  h.status, 
  h.edit_date, 
  decode(m.death_date,null,'Alive','Deceased') mouse_status 
from 
  mts_mouse_health h, 
  mts_mouse m, 
  mts_cage_vw c, 
  mts_body_system_dict d1, 
  mts_body_subsystem_dict d2, 
  mts_health_concern_dict d3 
where 
  h.mouse_id = m.id and 
  m.cage_id = c.cage_id(+) and 
  h.body_system_dict_id = d1.id and 
  h.body_subsystem_dict_id = d2.id and 
  h.health_concern_dict_id = d3.id;

CREATE OR REPLACE VIEW MTS_COLONY_SUMMARY_VW
(COLONY_PREFIX, COLONY_NAME, GENERATION, LIVE_MOUSE_COUNT, LIVE_FEMALE_COUNT, 
 LIVE_MALE_COUNT, LIVE_FEMALE_WT_COUNT, LIVE_FEMALE_HET_COUNT, LIVE_FEMALE_HOM_COUNT, LIVE_FEMALE_UND_COUNT, 
 LIVE_MALE_WT_COUNT, LIVE_MALE_HET_COUNT, LIVE_MALE_HOM_COUNT, LIVE_MALE_UND_COUNT, TOTAL_MOUSE_COUNT, 
 ALL_FEMALE_COUNT, ALL_MALE_COUNT, ALL_FEMALE_WT_COUNT, ALL_FEMALE_HET_COUNT, ALL_FEMALE_HOM_COUNT, 
 ALL_FEMALE_UND_COUNT, ALL_MALE_WT_COUNT, ALL_MALE_HET_COUNT, ALL_MALE_HOM_COUNT, ALL_MALE_UND_COUNT)
AS 
select 
  c.colony_prefix, 
  c.colony_name, 
  nvl(m.generation,'?') generation, 
  count(decode(m.death_date,null,m.id,null)) live_mouse_count, 
  count(decode(m.death_date,null,decode(m.gender_dict_id,1,1,null),null)) live_female_count, 
  count(decode(m.death_date,null,decode(m.gender_dict_id,2,1,null),null)) live_male_count, 
  count(decode(m.death_date,null,decode(m.gender_dict_id,1,decode(a.genotype_dict_id,null,1,null),null),null)) live_female_wt_count, 
  count(decode(m.death_date,null,decode(m.gender_dict_id,1,decode(a.genotype_dict_id,2,1,null),null),null)) live_female_het_count, 
  count(decode(m.death_date,null,decode(m.gender_dict_id,1,decode(a.genotype_dict_id,3,1,null),null),null)) live_female_hom_count, 
  count(decode(m.death_date,null,decode(m.gender_dict_id,1,decode(a.genotype_dict_id,4,1,null),null),null)) live_female_und_count, 
  count(decode(m.death_date,null,decode(m.gender_dict_id,2,decode(a.genotype_dict_id,null,1,null),null),null)) live_male_wt_count, 
  count(decode(m.death_date,null,decode(m.gender_dict_id,2,decode(a.genotype_dict_id,2,1,null),null),null)) live_male_het_count, 
  count(decode(m.death_date,null,decode(m.gender_dict_id,2,decode(a.genotype_dict_id,3,1,null),null),null)) live_male_hom_count, 
  count(decode(m.death_date,null,decode(m.gender_dict_id,2,decode(a.genotype_dict_id,4,1,null),null),null)) live_male_und_count, 
  count(m.id) total_mouse_count, 
  count(decode(m.gender_dict_id,1,1,null)) all_female_count, 
  count(decode(m.gender_dict_id,2,1,null)) all_male_count, 
  count(decode(m.gender_dict_id,1,decode(a.genotype_dict_id,null,1,null),null)) all_female_wt_count, 
  count(decode(m.gender_dict_id,1,decode(a.genotype_dict_id,2,1,null),null)) all_female_het_count, 
  count(decode(m.gender_dict_id,1,decode(a.genotype_dict_id,3,1,null),null)) all_female_hom_count, 
  count(decode(m.gender_dict_id,1,decode(a.genotype_dict_id,4,1,null),null)) all_female_und_count, 
  count(decode(m.gender_dict_id,2,decode(a.genotype_dict_id,null,1,null),null)) all_male_wt_count, 
  count(decode(m.gender_dict_id,2,decode(a.genotype_dict_id,2,1,null),null)) all_male_het_count, 
  count(decode(m.gender_dict_id,2,decode(a.genotype_dict_id,3,1,null),null)) all_male_hom_count, 
  count(decode(m.gender_dict_id,2,decode(a.genotype_dict_id,4,1,null),null)) all_male_und_count 
from 
  mts_colony_info c, 
  mts_mouse m, 
  mts_mouse_allele a 
where 
  c.id = m.colony_info_id and 
  m.id = a.mouse_id(+) 
group by 
  c.colony_prefix, 
  c.colony_name, 
  m.generation 
order by 
  c.colony_prefix, 
  m.generation;

CREATE OR REPLACE VIEW MTS_COLONY_SUMMARY_SHORT_VW
AS 
select 
  c.colony_prefix, 
  c.colony_name,  
  count(decode(m.death_date,null,m.id,null)) live_mouse_count, 
  count(decode(m.death_date,null,decode(m.gender_dict_id,1,1,null),null)) live_female_count, 
  count(decode(m.death_date,null,decode(m.gender_dict_id,2,1,null),null)) live_male_count, 
  count(decode(m.death_date,null,decode(m.gender_dict_id,1,decode(a.genotype_dict_id,null,1,null),null),null)) live_female_wt_count, 
  count(decode(m.death_date,null,decode(m.gender_dict_id,1,decode(a.genotype_dict_id,2,1,null),null),null)) live_female_het_count, 
  count(decode(m.death_date,null,decode(m.gender_dict_id,1,decode(a.genotype_dict_id,3,1,null),null),null)) live_female_hom_count, 
  count(decode(m.death_date,null,decode(m.gender_dict_id,1,decode(a.genotype_dict_id,4,1,null),null),null)) live_female_und_count, 
  count(decode(m.death_date,null,decode(m.gender_dict_id,2,decode(a.genotype_dict_id,null,1,null),null),null)) live_male_wt_count, 
  count(decode(m.death_date,null,decode(m.gender_dict_id,2,decode(a.genotype_dict_id,2,1,null),null),null)) live_male_het_count, 
  count(decode(m.death_date,null,decode(m.gender_dict_id,2,decode(a.genotype_dict_id,3,1,null),null),null)) live_male_hom_count, 
  count(decode(m.death_date,null,decode(m.gender_dict_id,2,decode(a.genotype_dict_id,4,1,null),null),null)) live_male_und_count, 
  count(m.id) total_mouse_count, 
  count(decode(m.gender_dict_id,1,1,null)) all_female_count, 
  count(decode(m.gender_dict_id,2,1,null)) all_male_count, 
  count(decode(m.gender_dict_id,1,decode(a.genotype_dict_id,null,1,null),null)) all_female_wt_count, 
  count(decode(m.gender_dict_id,1,decode(a.genotype_dict_id,2,1,null),null)) all_female_het_count, 
  count(decode(m.gender_dict_id,1,decode(a.genotype_dict_id,3,1,null),null)) all_female_hom_count, 
  count(decode(m.gender_dict_id,1,decode(a.genotype_dict_id,4,1,null),null)) all_female_und_count, 
  count(decode(m.gender_dict_id,2,decode(a.genotype_dict_id,null,1,null),null)) all_male_wt_count, 
  count(decode(m.gender_dict_id,2,decode(a.genotype_dict_id,2,1,null),null)) all_male_het_count, 
  count(decode(m.gender_dict_id,2,decode(a.genotype_dict_id,3,1,null),null)) all_male_hom_count, 
  count(decode(m.gender_dict_id,2,decode(a.genotype_dict_id,4,1,null),null)) all_male_und_count 
from 
  mts_colony_info c, 
  mts_mouse m, 
  mts_mouse_allele a 
where 
  c.id = m.colony_info_id and 
  m.id = a.mouse_id(+) and c.PROJECT_LICENCE_ID = 99
group by 
  c.colony_prefix, 
  c.colony_name 
order by 
  c.colony_name;

Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE, 
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (170, 4, 'room_id', NULL, 'hidden', 
    NULL, NULL, NULL);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE, 
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (171, 3, 'room_id', NULL, 'hidden', 
    NULL, NULL, NULL);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE, 
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2)
 Values
   (172, 5, 'room_id', NULL, 'hidden', 
    NULL, NULL, NULL);
COMMIT;

