CREATE OR REPLACE VIEW REP_PHENOTYPE_COHORTS
(ID, COHORT_NAME, REASON, CREATED_DATE, TOTAL_MICE, LIVE_MICE, DEAD_MICE, PIPELINE, 
 PIPELINE_DICT_ID)
AS 
select 
  c.id, 
  c.cohort_name, 
  c.reason, 
  c.created_date,
  l.total_mice, 
  l.live_mice, 
  l.dead_mice, 
  p.name pipeline,
  c.pipeline_dict_id
from 
  mts_cohort c,
  (select 
    l.cohort_id, 
    count(m.id) total_mice, 
    count(decode(m.death_date,null,1,null)) live_mice, 
    count(decode(m.death_date,null,null,1)) dead_mice 
   from 
    mts_mouse m, 
    mts_cohort_mouse l 
   where 
     m.id = l.mouse_id
   group by 
     l.cohort_id
  ) l,
  mts_cohort_pipeline_dict p
where 
  c.id = l.cohort_id(+)
  and c.pipeline_dict_id = p.id(+) and
  c.cohort_type_id = 1
order by c.created_date desc;

alter table app_custom_query_column add (actual_query_column varchar2(30), list_query varchar2(512), is_display_column number(1), is_filter_column number(1));

CREATE OR REPLACE VIEW APP_CUSTOM_QUERY_COL_PREF_VW
(ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE, 
 DATATYPE_FORMAT, DATATYPE_FORMAT_2, IS_DISPLAY_COLUMN, IS_FILTER_COLUMN, LIST_QUERY, ACTUAL_QUERY_COLUMN, ORDER_BY, PERSON_ID)
AS 
select 
  c.id, 
  c.custom_query_id, 
  c.column_name, 
  c.column_title, 
  c.datatype, 
  c.datatype_format, 
  c.datatype_format_2, 
  c.is_display_column,
  c.is_filter_column,
  c.list_query,
  c.actual_query_column,  
  p.order_by, 
  p.person_id 
from 
  app_custom_query_person_pref p, 
  app_custom_query_column c 
where 
  c.id = p.query_column_id 
union 
select 
  c.id, 
  c.custom_query_id, 
  c.column_name, 
  c.column_title, 
  c.datatype, 
  c.datatype_format, 
  c.datatype_format_2, 
  c.is_display_column,
  c.is_filter_column,
  c.list_query,
  c.actual_query_column,  
  c.order_by, 
  p.person_id 
from 
  per_person p, 
  app_custom_query_column c 
where 
  not exists (select null from app_custom_query_person_pref x, app_custom_query_column y where x.person_id = p.person_id and x.query_column_id = y.id and y.custom_query_id = c.custom_query_id);

update app_custom_query_column set is_display_column = 1 where datatype not in ('hidden','exists') or datatype is null;

update app_custom_query_column set is_display_column = 0 where is_display_column is null;

update app_custom_query_column set is_filter_column = 1 where datatype not in ('hidden') or datatype is null;

update app_custom_query_column set is_filter_column = 0 where is_filter_column is null;

update app_custom_query_column set datatype=null, list_query = datatype_format, actual_query_column=datatype_format_2, datatype_format=null, datatype_format_2=null where datatype='list';

update app_custom_query_column set is_filter_column = 1 where datatype ='hidden' and custom_query_id in (3,4,5);

update app_custom_query_column set actual_query_column = datatype_format_2, datatype_format_2=null where datatype='exists';

Insert into APP_CUSTOM_QUERY
   (ID, QUERY_TITLE, QUERY_VIEW_NAME, DESCRIPTION, SYSTEM_QUERY, 
    CATEGORY)
 Values
   (12, 'Phenotyping Cohorts', 'REP_PHENOTYPE_COHORTS', 'List all phenotyping cohorts', 0, 
    'Mouse Tracking');
    
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE, 
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2, ACTUAL_QUERY_COLUMN, LIST_QUERY, 
    IS_DISPLAY_COLUMN, IS_FILTER_COLUMN)
 Values
   (app_custom_query_col_seq.nextval, 12, 'id', NULL, 'hidden', 
    NULL, NULL, NULL, NULL, NULL, 
    0, 0);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE, 
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2, ACTUAL_QUERY_COLUMN, LIST_QUERY, 
    IS_DISPLAY_COLUMN, IS_FILTER_COLUMN)
 Values
   (app_custom_query_col_seq.nextval, 12, 'cohort_name', 'Cohort Name', 'href', 
    1, 'view_one_cohort.do?id=', 'id', NULL, NULL, 
    1, 1);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE, 
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2, ACTUAL_QUERY_COLUMN, LIST_QUERY, 
    IS_DISPLAY_COLUMN, IS_FILTER_COLUMN)
 Values
   (app_custom_query_col_seq.nextval, 12, 'reason', 'Description', NULL, 
    9, NULL, NULL, NULL, NULL, 
    1, 1);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE, 
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2, ACTUAL_QUERY_COLUMN, LIST_QUERY, 
    IS_DISPLAY_COLUMN, IS_FILTER_COLUMN)
 Values
   (app_custom_query_col_seq.nextval, 12, 'created_date', 'Created Date', 'date', 
    8, NULL, NULL, NULL, NULL, 
    1, 1);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE, 
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2, ACTUAL_QUERY_COLUMN, LIST_QUERY, 
    IS_DISPLAY_COLUMN, IS_FILTER_COLUMN)
 Values
   (app_custom_query_col_seq.nextval, 12, 'colony_prefix', 'Colony Prefix', 'exists', 
    NULL, 'select null from mts_mouse m, mts_cohort_mouse c, mts_colony_info i where m.id = c.mouse_id and c.cohort_id = cq.id and m.colony_info_id = i.id and', NULL, 'i.colony_prefix', NULL, 
    0, 1);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE, 
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2, ACTUAL_QUERY_COLUMN, LIST_QUERY, 
    IS_DISPLAY_COLUMN, IS_FILTER_COLUMN)
 Values
   (app_custom_query_col_seq.nextval, 12, 'total_mice', 'Total Mice', 'number', 
    4, NULL, NULL, NULL, NULL, 
    1, 1);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE, 
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2, ACTUAL_QUERY_COLUMN, LIST_QUERY, 
    IS_DISPLAY_COLUMN, IS_FILTER_COLUMN)
 Values
   (app_custom_query_col_seq.nextval, 12, 'live_mice', 'Live Mice', 'number', 
    5, NULL, NULL, NULL, NULL, 
    1, 1);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE, 
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2, ACTUAL_QUERY_COLUMN, LIST_QUERY, 
    IS_DISPLAY_COLUMN, IS_FILTER_COLUMN)
 Values
   (app_custom_query_col_seq.nextval, 12, 'dead_mice', 'Dead Mice', 'number', 
    6, NULL, NULL, NULL, NULL, 
    1, 1);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE, 
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2, ACTUAL_QUERY_COLUMN, LIST_QUERY, 
    IS_DISPLAY_COLUMN, IS_FILTER_COLUMN)
 Values
   (app_custom_query_col_seq.nextval, 12, 'pipeline', 'Pipeline', NULL, 
    3, NULL, NULL, 'pipeline_dict_id', 'select id, name from mts_cohort_pipeline_dict order by order_by', 
    1, 1);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE, 
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2, ACTUAL_QUERY_COLUMN, LIST_QUERY, 
    IS_DISPLAY_COLUMN, IS_FILTER_COLUMN)
 Values
   (app_custom_query_col_seq.nextval, 12, 'pipeline_dict_id', NULL, 'hidden', 
    NULL, NULL, NULL, NULL, NULL, 
    0, 0);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE, 
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2, ACTUAL_QUERY_COLUMN, LIST_QUERY, 
    IS_DISPLAY_COLUMN, IS_FILTER_COLUMN)
 Values
   (app_custom_query_col_seq.nextval, 12, 'mouse_name', 'Mouse Name', 'exists', 
    NULL, 'select null from mts_mouse m, mts_cohort_mouse c where m.id = c.mouse_id and c.cohort_id = cq.id and', NULL, 'm.name', NULL, 
    0, 1);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE, 
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2, ACTUAL_QUERY_COLUMN, LIST_QUERY, 
    IS_DISPLAY_COLUMN, IS_FILTER_COLUMN)
 Values
   (app_custom_query_col_seq.nextval, 12, 'mouse_barcode', 'Mouse Barcode', 'exists', 
    NULL, 'select null from mts_mouse m, mts_cohort_mouse c where m.id = c.mouse_id and c.cohort_id = cq.id and', NULL, 'm.barcode', NULL, 
    0, 1);
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE, 
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2, ACTUAL_QUERY_COLUMN, LIST_QUERY, 
    IS_DISPLAY_COLUMN, IS_FILTER_COLUMN)
 Values
   (app_custom_query_col_seq.nextval, 12, 'cage_barcode', 'Cage Barcode', 'exists', 
    NULL, 'select null from mts_mouse m, mts_cohort_mouse c, mts_cage g where g.id = m.cage_id and m.id = c.mouse_id and c.cohort_id = cq.id and', NULL, 'g.barcode', NULL, 
    0, 1);
    
Insert into APP_CUSTOM_QUERY_COLUMN
   (ID, CUSTOM_QUERY_ID, COLUMN_NAME, COLUMN_TITLE, DATATYPE, 
    ORDER_BY, DATATYPE_FORMAT, DATATYPE_FORMAT_2, ACTUAL_QUERY_COLUMN, LIST_QUERY, 
    IS_DISPLAY_COLUMN, IS_FILTER_COLUMN)
 Values
   (APP_CUSTOM_QUERY_COL_seq.nextval, 11, 'mouse_genotype_id', 'Genotype Status', 'exists', 
    NULL, 'select null from 
(
select 
  a1.mouse_id,
  a1.genotype_dict_id
from
  mts_mouse_allele a1
union
select
  m1.id mouse_id,
  1 genotype_dict_id --wildtype
from
  mts_mouse m1 where not exists (select null from mts_mouse_allele a2 where a2.mouse_id = m1.id)
) a
where a.mouse_id = cq.id and', NULL, 'a.genotype_dict_id', 'select id, name from mts_genotype_dict where id < 5 order by order_by', 
    0, 1);    
    
COMMIT;

