connect mig

CREATE TABLE PHN_UPLOAD_MAPPING (
ID NUMBER NOT NULL ENABLE,
REQUIRED_OBSERVATION_ID NUMBER NOT NULL ENABLE,
FIELD_NAME VARCHAR2(255 CHAR) NOT NULL ENABLE,
NAME VARCHAR2(255 CHAR) NOT NULL ENABLE,
CREATED_DATE DATE,
CREATOR_ID NUMBER,
EDIT_DATE DATE,
EDITED_BY VARCHAR2(255 CHAR),
CHECK_NUMBER NUMBER,
CONSTRAINT PHN_UPLOAD_MAPPING_PK PRIMARY KEY (ID),
CONSTRAINT PHN_UPLOAD_MAPPING_FK1 FOREIGN KEY (REQUIRED_OBSERVATION_ID) REFERENCES PHN_REQUIRED_OBSERVATION(ID)
);

CREATE SEQUENCE  PHN_UPLOAD_MAPPING_SEQ  MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 NOCACHE  NOORDER  NOCYCLE;

create table phn_calorimetry_data (
ID NUMBER NOT NULL,
EXPERIMENT_ID NUMBER NOT NULL,
SAMPLE_TIME TIMESTAMP NOT NULL,
MINUTES_ELAPSED NUMBER NOT NULL,
CO2 NUMBER,
O2 NUMBER,
REF_CO2 NUMBER,
REF_O2 NUMBER,
CO2_DIFFERENCE NUMBER,
O2_DIFFERENCE NUMBER,
CUMULATIVE_FOOD_INTAKE NUMBER,
FLOW_RATE_IN NUMBER,
SAMPLE_FLOW_RATE_OUT NUMBER,
TEMPERATURE NUMBER,
RESPIRATORY_EXCHANGE_RATIO NUMBER,
VCO2_BODYWEIGHT NUMBER,
VCO2_LEAN_MASS NUMBER,
VCO2_ANIMAL NUMBER,
VO2_BODYWEIGHT NUMBER,
VO2_LEAN_MASS NUMBER,
VO2_ANIMAL NUMBER,
ENERGY_EXPEND_BODYWEIGHT NUMBER,
ENERGY_EXPEND_LEAN_MASS NUMBER,
ENERGY_EXPEND_ANIMAL NUMBER,
HEAT_BODYWEIGHT NUMBER,
HEAT_LEAN_MASS NUMBER,
HEAT_ANIMAL NUMBER,
XAXIS_ACTIVITY_COUNT NUMBER,
XAXIS_ACTIVITY_COUNT_TOTAL NUMBER,
YAXIS_ACTIVITY_COUNT NUMBER,
YAXIS_ACTIVITY_COUNT_TOTAL NUMBER,
CREATED_DATE DATE,
CREATOR_ID NUMBER,
EDIT_DATE DATE,
EDITED_BY VARCHAR2(255 CHAR),
CHECK_NUMBER NUMBER,
CONSTRAINT phn_calorimetry_data_pk PRIMARY KEY (id),
CONSTRAINT phn_calorimetry_data_fk1 FOREIGN KEY (EXPERIMENT_ID) REFERENCES PHN_EXPERIMENT(ID)
);


CREATE SEQUENCE  PHN_CALORIMETRY_DATA_SEQ MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 NOCACHE  NOORDER  NOCYCLE ;

CREATE OR REPLACE FORCE VIEW PHN_CALORIMETRY_DATA_BINNED_VW  AS
  SELECT experiment_id,
  round(sample_time, 'hh') time,
  avg(minutes_elapsed) avg_minutes_elapsed,
  count(id) samples,
  AVG(co2) co2,
  AVG(o2) o2,
  AVG(ref_co2) ref_co2,
  AVG(ref_o2) ref_o2,
  AVG(co2_difference) co2_difference,
  AVG(o2_difference) o2_difference,
  AVG(cumulative_food_intake) cumulative_food_intake,
  AVG(flow_rate_in) flow_rate_in,
  AVG(sample_flow_rate_out) sample_flow_rate_out,
  AVG(temperature) temperature,
  AVG(respiratory_exchange_ratio) respiratory_exchange_ratio,
  AVG(vco2_bodyweight) vco2_bodyweight,
  AVG(vco2_lean_mass) vco2_lean_mass,
  AVG(vco2_animal) vco2_animal,
  AVG(vo2_bodyweight) vo2_bodyweight,
  AVG(vo2_lean_mass) vo2_lean_mass,
  AVG(vo2_animal) vo2_animal,
  AVG(energy_expend_bodyweight) energy_expend_bodyweight,
  AVG(energy_expend_lean_mass) energy_expend_lean_mass,
  AVG(energy_expend_animal) energy_expend_animal,
  AVG(heat_bodyweight) heat_bodyweight,
  AVG(heat_lean_mass) heat_lean_mass,
  AVG(heat_animal) heat_animal,
  AVG(xaxis_activity_count) xaxis_activity_count,
  AVG(xaxis_activity_count_total) xaxis_activity_count_total,
  AVG(yaxis_activity_count) yaxis_activity_count,
  AVG(yaxis_activity_count_total) yaxis_activity_count_total
FROM phn_calorimetry_data
GROUP BY experiment_id,
  round(sample_time, 'hh');

create or replace view rep_calorimetry_binned_vw as
  select
e.*,
c.TIME,
c.SAMPLES,
c.CO2,
c.O2,
c.REF_CO2,
c.REF_O2,
c.CO2_DIFFERENCE,
c.O2_DIFFERENCE,
c.CUMULATIVE_FOOD_INTAKE,
c.FLOW_RATE_IN,
c.SAMPLE_FLOW_RATE_OUT,
c.TEMPERATURE,
c.RESPIRATORY_EXCHANGE_RATIO,
c.VCO2_BODYWEIGHT,
c.VCO2_LEAN_MASS,
c.VCO2_ANIMAL,
c.VO2_BODYWEIGHT,
c.VO2_LEAN_MASS,
c.VO2_ANIMAL,
c.ENERGY_EXPEND_BODYWEIGHT,
c.ENERGY_EXPEND_LEAN_MASS,
c.ENERGY_EXPEND_ANIMAL,
c.HEAT_BODYWEIGHT,
c.HEAT_LEAN_MASS,
c.HEAT_ANIMAL,
c.XAXIS_ACTIVITY_COUNT,
c.XAXIS_ACTIVITY_COUNT_TOTAL,
c.YAXIS_ACTIVITY_COUNT,
c.YAXIS_ACTIVITY_COUNT_TOTAL,
(e.experiment_id * 1e2) + (e.cohort_id * 1e9) + c.avg_minutes_elapsed as id
from PHN_EXPERIMENT_SUMMARY_VW e
join PHN_CALORIMETRY_DATA_BINNED_VW c on e.experiment_id = c.experiment_id;

create or replace view REP_CALORIMETRY_RAW_VW as
select
e.*,
c.SAMPLE_TIME,
c.MINUTES_ELAPSED,
c.CO2,
c.O2,
c.REF_CO2,
c.REF_O2,
c.CO2_DIFFERENCE,
c.O2_DIFFERENCE,
c.CUMULATIVE_FOOD_INTAKE,
c.FLOW_RATE_IN,
c.SAMPLE_FLOW_RATE_OUT,
c.TEMPERATURE,
c.RESPIRATORY_EXCHANGE_RATIO,
c.VCO2_BODYWEIGHT,
c.VCO2_LEAN_MASS,
c.VCO2_ANIMAL,
c.VO2_BODYWEIGHT,
c.VO2_LEAN_MASS,
c.VO2_ANIMAL,
c.ENERGY_EXPEND_BODYWEIGHT,
c.ENERGY_EXPEND_LEAN_MASS,
c.ENERGY_EXPEND_ANIMAL,
c.HEAT_BODYWEIGHT,
c.HEAT_LEAN_MASS,
c.HEAT_ANIMAL,
c.XAXIS_ACTIVITY_COUNT,
c.XAXIS_ACTIVITY_COUNT_TOTAL,
c.YAXIS_ACTIVITY_COUNT,
c.YAXIS_ACTIVITY_COUNT_TOTAL,
(e.experiment_id * 1e4) + (e.cohort_id * 1e9) + c.id as id
from PHN_CALORIMETRY_DATA c
join PHN_EXPERIMENT_SUMMARY_VW e
on c.experiment_id = e.experiment_id;

alter table phn_required_observation add IS_MACHINE_DATA number(1) default '0';
alter table phn_required_observation add IS_SERIES_DATA number(1) default '0';

Insert into PHN_UPLOAD_MAPPING (ID,REQUIRED_OBSERVATION_ID,FIELD_NAME,NAME,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) values (PHN_UPLOAD_MAPPING_SEQ.nextval, 741,'WEIGHT_AFTER','MGP_CALORIMETRY',null,null,null,null,null);
Insert into PHN_UPLOAD_MAPPING (ID,REQUIRED_OBSERVATION_ID,FIELD_NAME,NAME,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) values (PHN_UPLOAD_MAPPING_SEQ.nextval, 739,'BOX_NUMBER','MGP_CALORIMETRY',null,null,null,null,null);
Insert into PHN_UPLOAD_MAPPING (ID,REQUIRED_OBSERVATION_ID,FIELD_NAME,NAME,CREATED_DATE,CREATOR_ID,EDIT_DATE,EDITED_BY,CHECK_NUMBER) values (PHN_UPLOAD_MAPPING_SEQ.nextval, 740,'WEIGHT_BEFORE','MGP_CALORIMETRY',null,null,null,null,null);

alter table phn_std_operating_procedure add IS_HIDDEN number(1) default '0';

update phn_std_operating_procedure set is_hidden = 1, active = 1 where id = 147;

commit;

connect migpriv

create table mig_audit.PHN_CALORIMETRY_DATA as select * from mig.PHN_CALORIMETRY_DATA where 1 = 2;
alter table mig_audit.PHN_CALORIMETRY_DATA add (audit_timestamp timestamp(6) default systimestamp);
alter table mig_audit.PHN_CALORIMETRY_DATA add (os_user varchar2(30) default sys_context('USERENV','OS_USER'));
alter table mig_audit.PHN_CALORIMETRY_DATA add (audit_action varchar2(10));

create table mig_audit.PHN_UPLOAD_MAPPING as select * from mig.PHN_UPLOAD_MAPPING where 1 = 2;
alter table mig_audit.PHN_UPLOAD_MAPPING add (audit_timestamp timestamp(6) default systimestamp);
alter table mig_audit.PHN_UPLOAD_MAPPING add (os_user varchar2(30) default sys_context('USERENV','OS_USER'));
alter table mig_audit.PHN_UPLOAD_MAPPING add (audit_action varchar2(10));


connect mig_audit

grant insert on PHN_CALORIMETRY_DATA to mig;
grant insert on PHN_UPLOAD_MAPPING to mig;

alter table phn_required_observation add IS_MACHINE_DATA number(1);
alter table phn_required_observation add IS_SERIES_DATA number(1);
alter table phn_std_operating_procedure add IS_HIDDEN number(1);

connect mig

create or replace trigger PHN_CALORIMETRY_DATA_ta
before update or delete on PHN_CALORIMETRY_DATA for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */

declare
audit_action varchar2(10);
begin

if deleting then audit_action := 'deleted'; end if;
if updating then audit_action := 'updated'; end if;
if deleting or updating then
 insert into mig_audit.PHN_CALORIMETRY_DATA(
    ID,
    EXPERIMENT_ID,
    SAMPLE_TIME,
    MINUTES_ELAPSED,
    CO2,
    O2,
    REF_CO2,
    REF_O2,
    CO2_DIFFERENCE,
    O2_DIFFERENCE,
    CUMULATIVE_FOOD_INTAKE,
    FLOW_RATE_IN,
    SAMPLE_FLOW_RATE_OUT,
    TEMPERATURE,
    RESPIRATORY_EXCHANGE_RATIO,
    VCO2_BODYWEIGHT,
    VCO2_LEAN_MASS,
    VCO2_ANIMAL,
    VO2_BODYWEIGHT,
    VO2_LEAN_MASS,
    VO2_ANIMAL,
    ENERGY_EXPEND_BODYWEIGHT,
    ENERGY_EXPEND_LEAN_MASS,
    ENERGY_EXPEND_ANIMAL,
    HEAT_BODYWEIGHT,
    HEAT_LEAN_MASS,
    HEAT_ANIMAL,
    XAXIS_ACTIVITY_COUNT,
    XAXIS_ACTIVITY_COUNT_TOTAL,
    YAXIS_ACTIVITY_COUNT,
    YAXIS_ACTIVITY_COUNT_TOTAL,
    CREATED_DATE,
    CREATOR_ID,
    EDIT_DATE,
    EDITED_BY,
    CHECK_NUMBER,
    AUDIT_ACTION)
 values (
    :old.ID,
    :old.EXPERIMENT_ID,
    :old.SAMPLE_TIME,
    :old.MINUTES_ELAPSED,
    :old.CO2,
    :old.O2,
    :old.REF_CO2,
    :old.REF_O2,
    :old.CO2_DIFFERENCE,
    :old.O2_DIFFERENCE,
    :old.CUMULATIVE_FOOD_INTAKE,
    :old.FLOW_RATE_IN,
    :old.SAMPLE_FLOW_RATE_OUT,
    :old.TEMPERATURE,
    :old.RESPIRATORY_EXCHANGE_RATIO,
    :old.VCO2_BODYWEIGHT,
    :old.VCO2_LEAN_MASS,
    :old.VCO2_ANIMAL,
    :old.VO2_BODYWEIGHT,
    :old.VO2_LEAN_MASS,
    :old.VO2_ANIMAL,
    :old.ENERGY_EXPEND_BODYWEIGHT,
    :old.ENERGY_EXPEND_LEAN_MASS,
    :old.ENERGY_EXPEND_ANIMAL,
    :old.HEAT_BODYWEIGHT,
    :old.HEAT_LEAN_MASS,
    :old.HEAT_ANIMAL,
    :old.XAXIS_ACTIVITY_COUNT,
    :old.XAXIS_ACTIVITY_COUNT_TOTAL,
    :old.YAXIS_ACTIVITY_COUNT,
    :old.YAXIS_ACTIVITY_COUNT_TOTAL,
    :old.CREATED_DATE,
    :old.CREATOR_ID,
    :old.EDIT_DATE,
    :old.EDITED_BY,
    :old.CHECK_NUMBER,
    AUDIT_ACTION);
end if;
end;
/

create or replace trigger PHN_UPLOAD_MAPPING_ta
before update or delete on PHN_UPLOAD_MAPPING for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */

declare
audit_action varchar2(10);
begin

if deleting then audit_action := 'deleted'; end if;
if updating then audit_action := 'updated'; end if;
if deleting or updating then
 insert into mig_audit.PHN_UPLOAD_MAPPING(
    ID,
    REQUIRED_OBSERVATION_ID,
    FIELD_NAME,
    NAME,
    CREATED_DATE,
    CREATOR_ID,
    EDIT_DATE,
    EDITED_BY,
    CHECK_NUMBER,
    AUDIT_ACTION)
 values (
    :old.ID,
    :old.REQUIRED_OBSERVATION_ID,
    :old.FIELD_NAME,
    :old.NAME,
    :old.CREATED_DATE,
    :old.CREATOR_ID,
    :old.EDIT_DATE,
    :old.EDITED_BY,
    :old.CHECK_NUMBER,
    AUDIT_ACTION);
end if;
end;
/

create or replace trigger PHN_REQUIRED_OBSERVATION_ta
before update or delete on PHN_REQUIRED_OBSERVATION for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */

declare
audit_action varchar2(10);
begin

if deleting then audit_action := 'deleted'; end if;
if updating then audit_action := 'updated'; end if;
if deleting or updating then
 insert into mig_audit.PHN_REQUIRED_OBSERVATION(
    ID,
    OBSERVATION_TYPE_ID,
    ORDER_BY,
    DISPLAY_NAME,
    ACTIVE,
    CREATED_DATE,
    CREATOR_ID,
    EDIT_DATE,
    EDITED_BY,
    CHECK_NUMBER,
    SOP_ID,
    DEFAULT_VALUE,
    MANDATORY_OBSERVATION,
    SECTION_TITLE,
    IS_MACHINE_DATA,
    IS_SERIES_DATA,
    AUDIT_ACTION)
 values (
    :old.ID,
    :old.OBSERVATION_TYPE_ID,
    :old.ORDER_BY,
    :old.DISPLAY_NAME,
    :old.ACTIVE,
    :old.CREATED_DATE,
    :old.CREATOR_ID,
    :old.EDIT_DATE,
    :old.EDITED_BY,
    :old.CHECK_NUMBER,
    :old.SOP_ID,
    :old.DEFAULT_VALUE,
    :old.MANDATORY_OBSERVATION,
    :old.SECTION_TITLE,
    :old.IS_MACHINE_DATA,
    :old.IS_SERIES_DATA,
    AUDIT_ACTION);
end if;
end;
/


create or replace trigger PHN_STD_OPERATING_PROCEDURE_ta
before update or delete on PHN_STD_OPERATING_PROCEDURE for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */

declare
audit_action varchar2(10);
begin

if deleting then audit_action := 'deleted'; end if;
if updating then audit_action := 'updated'; end if;
if deleting or updating then
 insert into mig_audit.PHN_STD_OPERATING_PROCEDURE(
    ID,
    PROCEDURE_ID,
    NAME,
    ACTIVE,
    CREATED_DATE,
    CREATOR_ID,
    EDIT_DATE,
    EDITED_BY,
    CHECK_NUMBER,
    TERMINAL_PROCEDURE,
    IS_HIDDEN,
    AUDIT_ACTION)
 values (
    :old.ID,
    :old.PROCEDURE_ID,
    :old.NAME,
    :old.ACTIVE,
    :old.CREATED_DATE,
    :old.CREATOR_ID,
    :old.EDIT_DATE,
    :old.EDITED_BY,
    :old.CHECK_NUMBER,
    :old.TERMINAL_PROCEDURE,
    :old.IS_HIDDEN,
    AUDIT_ACTION);
end if;
end;
/
