connect mig

-- ** remove cohort link from experiment set **
CREATE OR REPLACE VIEW PHN_EXPERIMENT_SET_VIEW as
with
exp_total as (
    select experiment_set_id, count(id) as EXP_COUNT
    from PHN_EXPERIMENT group by experiment_set_id
),
exp_completed as (
    select experiment_set_id, count(id) as COMP_EXP_COUNT
    from PHN_EXPERIMENT where IS_COMPLETE = 1 group by experiment_set_id
),
work_start as (
    select pe.EXPERIMENT_SET_ID, min(mp.START_DATE) as PROCEDURE_DATE
    from MTS_MOUSE_PROCEDURE mp
    join PHN_EXPERIMENT pe on mp.FOREIGN_KEY_ID = pe.ID
    WHERE mp.FOREIGN_TABLE_NAME = 'PHN_EXPERIMENT'
    group by pe.EXPERIMENT_SET_ID
),
obs_count as (
    select e.EXPERIMENT_SET_ID, count(o.id) as obs_count
    from phn_experiment e
    join phn_observation o on e.id = o.EXPERIMENT_ID
    where LENGTH(o.value) > 0
    group by e.EXPERIMENT_SET_ID
),
cname as (select e.experiment_set_id group_key, c.cohort_name val
    from PHN_EXPERIMENT e
    join MTS_COHORT_MOUSE cm on cm.mouse_id = e.mouse_id
    join MTS_COHORT c on cm.cohort_id = c.id
    where c.cohort_type_id = 1 -- phenotyping cohorts
    group by e.experiment_set_id, c.cohort_name
    order by e.experiment_set_id, c.cohort_name),
cnameagg as ( -- from http://www.sqlsnippets.com/en/topic-12092.html
select group_key as experiment_set_id, substr( string, 2 ) as cohort_names
from  cname
WHERE  VAL IS NOT NULL
model
  return updated rows
  partition by ( group_key )
  dimension by ( row_number() over (partition by group_key order by val) as position )
  measures     ( cast( val as varchar2(1000) ) as string  ) -- Note 1
  rules
    upsert
    iterate( 6 )
      until ( presentv(string[iteration_number+2],1,0) = 0 )
    ( string[0] = string[0] || ',' || string[iteration_number+1] )
order by group_key
)
select es.id, es.IS_COMPLETE, ca.COHORT_NAMES, sop.NAME as SOP_NAME, es.sop_id, es.PPL_ID, es.PIL_ID, es.CREATOR_ID,
perl.LAST_NAME || ', ' || perl.FIRST_NAME || ' (' || pil.PIL_NUMBER || ')' as PERSONAL_LICENCE,
ppl.LICENCE_NUMBER || ' ' || ppl.TITLE as PROJECT_LICENCE,
per.LAST_NAME || ', ' || per.FIRST_NAME  as CREATOR_NAME,
nvl(et.EXP_COUNT,0) as EXP_COUNT,
nvl(ec.COMP_EXP_COUNT, 0) as COMP_EXP_COUNT,
nvl(ec.COMP_EXP_COUNT, 0) / et.EXP_COUNT as COMPLETION,
es.created_date,
ws.PROCEDURE_DATE,
sop.procedure_id,
oc.obs_count,
es.scheduled_date
from PHN_EXPERIMENT_SET es
join PHN_STD_OPERATING_PROCEDURE sop on es.SOP_ID = sop.ID
join LIC_PERSONAL_LICENCE pil on es.PIL_ID = pil.PERSONAL_LICENCE_ID
join LIC_PROJECT_LICENCE ppl on es.PPL_ID = ppl.PROJECT_LICENCE_ID
join PER_PERSON per on es.CREATOR_ID = per.PERSON_ID
join PER_PERSON perl on pil.PERSON_ID = perl.PERSON_ID
left outer join cnameagg ca on ca.experiment_set_id = es.ID
left outer join work_start ws on ws.EXPERIMENT_SET_ID = es.ID
left outer join obs_count oc on oc.EXPERIMENT_SET_ID = es.id
left outer join exp_total et on es.id = et.experiment_set_id
left outer join exp_completed ec on es.id = ec.experiment_set_id;

create or replace TRIGGER PHN_EXPERIMENT_SET_TA
before update or delete on PHN_EXPERIMENT_SET for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */

declare
audit_action varchar2(10);
begin

if deleting then audit_action := 'deleted'; end if;
if updating then audit_action := 'updated'; end if;
if deleting or updating then
 insert into mig_audit.PHN_EXPERIMENT_SET(
    ID,
    IS_COMPLETE,
    CREATED_DATE,
    CREATOR_ID,
    EDIT_DATE,
    EDITED_BY,
    CHECK_NUMBER,
    SOP_ID,
    PPL_ID,
    PIL_ID,
    SCHEDULED_DATE,
    AUDIT_ACTION)
 values (
    :old.ID,
    :old.IS_COMPLETE,
    :old.CREATED_DATE,
    :old.CREATOR_ID,
    :old.EDIT_DATE,
    :old.EDITED_BY,
    :old.CHECK_NUMBER,
    :old.SOP_ID,
    :old.PPL_ID,
    :old.PIL_ID,
    :old.SCHEDULED_DATE,
    AUDIT_ACTION);
end if;
end;
/

-- remove column
alter table PHN_EXPERIMENT_SET
drop column cohort_id;


-- ** Add rate information to calorimetry data **
alter table PHN_CALORIMETRY_DATA
 add (
  rate_xa number,
  rate_xt number,
  rate_ya number,
  rate_yt number,
  rate_feed number,
  feed_in_interval number
  );


-- fill in the missing rate data for existing records
declare
cursor rates(in_experiment_id number) is
select
  currCd.id,
  currCd.XAXIS_ACTIVITY_COUNT /((currCd.minutes_elapsed - prevCd.minutes_elapsed)/60) RATE_XA,
currCd.XAXIS_ACTIVITY_COUNT_TOTAL /((currCd.minutes_elapsed - prevCd.minutes_elapsed)/60) RATE_XT,
currCd.YAXIS_ACTIVITY_COUNT /((currCd.minutes_elapsed - prevCd.minutes_elapsed)/60) RATE_YA,
currCd.YAXIS_ACTIVITY_COUNT_TOTAL /((currCd.minutes_elapsed - prevCd.minutes_elapsed)/60) RATE_YT,
(currCd.CUMULATIVE_FOOD_INTAKE - prevCd.CUMULATIVE_FOOD_INTAKE) /((currCd.minutes_elapsed - prevCd.minutes_elapsed)/60) RATE_FEED,
currCd.CUMULATIVE_FOOD_INTAKE - prevCd.CUMULATIVE_FOOD_INTAKE FEED_IN_INTERVAL
from
  phn_calorimetry_data currCd join phn_calorimetry_data prevCd
  on currCd.experiment_id = prevCd.experiment_id and prevCd.minutes_elapsed = (
  select max(minutes_elapsed) from phn_calorimetry_data
  where experiment_id = currCd.experiment_id
  and minutes_elapsed < currCd.minutes_elapsed
)
where currCd.experiment_id = in_experiment_id
for update of currCd.rate_xa, currCd.rate_xt, currCd.rate_ya, currCd.rate_yt, currCd.rate_feed, currCd.feed_in_interval
;

t_rate_xa number;
t_rate_xt number;
t_rate_ya number;
t_rate_yt number;
t_rate_feed number;
t_feed_in_interval number;
t_id number;

cursor ids is
select distinct experiment_id
from phn_calorimetry_data
where rate_xa is null;

begin
  for i in ids loop
    open rates(i.experiment_id);
      loop exit when rates%NOTFOUND;
          fetch rates into t_id,t_rate_xa, t_rate_xt, t_rate_ya, t_rate_yt, t_rate_feed, t_feed_in_interval;
          update phn_calorimetry_data set rate_xa = t_rate_xa, rate_xt = t_rate_xt, rate_ya = t_rate_ya, rate_yt = t_rate_yt,
          rate_feed = t_rate_feed, feed_in_interval = t_feed_in_interval
          where id = t_id;
          dbms_output.put_line('id,rate:'||t_id || ' ' || t_rate_xa);
      end loop;
    close rates;
    commit;
    dbms_output.put_line('experiment_id:'||i.experiment_id);
  end loop;
end;
/

-- add the feed_in_interval value for the initial records
update phn_calorimetry_data set feed_in_interval = cumulative_food_intake where feed_in_interval is null;

-- reservation system

create table res_category_dict (
ID NUMBER,
NAME VARCHAR2(1024 CHAR),
DESCRIPTION VARCHAR2(2048 CHAR),
ACTIVE NUMBER(1,0) DEFAULT 1 NOT NULL ENABLE,
ORDER_BY NUMBER,
constraint res_category_dict_pk primary key (id)
);

create table res_purpose (
id number,
name varchar2(1024 char) not null,
category_id number not null,
edit_date DATE DEFAULT sysdate,
edited_by VARCHAR2(128 BYTE),
created_date DATE DEFAULT sysdate,
creator_id NUMBER,
check_number NUMBER,
constraint res_purpose_pk primary key (id),
constraint res_purpose_fk1 foreign key (category_id) references res_category_dict(id),
constraint res_purpose_fk2 foreign key (creator_id) references per_person(person_id)
);

CREATE SEQUENCE  RES_PURPOSE_SEQ  MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1;


create table res_reservation (
id number not null ,
purpose_id not null,
reserver_id not null,
team_id not null,
notify number(1) not null,
edit_date DATE DEFAULT sysdate,
edited_by VARCHAR2(128 BYTE),
created_date DATE DEFAULT sysdate,
creator_id NUMBER,
check_number NUMBER,
constraint res_reservation_pk primary key (id),
constraint res_reservation_fk1 foreign key (purpose_id) references res_purpose(id),
constraint res_reservation_fk2 foreign key (reserver_id) references per_person(person_id),
constraint res_reservation_fk3 foreign key (team_id) references per_team(id),
constraint res_reservation_fk4 foreign key (creator_id) references per_person(person_id)
);

CREATE SEQUENCE  RES_RESERVATION_SEQ  MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1;

create table res_mouse_reservation (
id number,
mouse_id number not null,
reservation_id number not null,
notification_sent number(1) not null,
edit_date DATE DEFAULT sysdate,
edited_by VARCHAR2(128 BYTE),
created_date DATE DEFAULT sysdate,
creator_id NUMBER,
check_number NUMBER,
constraint res_mouse_reservation_pk primary key (id),
constraint res_mouse_reservation_fk1 foreign key (mouse_id) references mts_mouse(id),
constraint res_mouse_reservation_fk2 foreign key (reservation_id) references res_reservation(id)
);

CREATE SEQUENCE  res_mouse_reservation_seq  MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1;

CREATE OR REPLACE VIEW MTS_MOUSE_VW as
 select
  m.id,
  m.litter_id,
  m.name,
  m.rfid_tag,
  m.edit_date,
  m.coat_colour_dict_id,
  c.name||decode(chim.percent_chimeric,null,null,' ('||chim.percent_chimeric||'%)') coat_colour,
  m.eye_colour_dict_id,
  e.name eye_colour,
  m.earmark_dict_id,
  ear.name earmark,
  m.birth_date,
  round((nvl(m.death_date,sysdate) - m.birth_date)/7,1) age_in_weeks,
  m.death_date,
  round((m.death_date - m.birth_date)/7,1) age_at_death,
  m.cause_of_death_dict_id,
  d.name cause_of_death,
  m.edited_by,
  m.wean_date,
  m.cage_id,
  l.cage_name,
  l.cage_barcode,
  l.rack_id,
  l.rack_name,
  l.room_id,
  l.room_name,
  m.current_owner_id,
  owner.first_name||' '||owner.last_name current_owner,
  b.project_licence_id current_project_licence_id,
  b.licence_number current_project_licence,
  b.protocol_id current_protocol_id,
  b.protocol_code current_protocol_code,
  m.check_number,
  m.gender_dict_id,
  s.name gender,
  m.mouse_strain_dict_id,
  t.name strain,
  decode(m.death_date,null,'Alive','Deceased') status,
  m.creator_id,
  m.created_date,
  m.barcode,
  m.comments,
  m.is_non_breeder,
  m.is_sentinel,
  m.generation,
  colony.colony_name,
  colony.colony_prefix,
  m.colony_info_id,
  m.arrival_date,
  m.latest_plug_date,
  breeding.breeding_name,
  mts.fetch_genotype(m.id) genotype,
  p.father_name,
  decode(m.generation,'F0',null,decode(p.male_id,null,null,mts.fetch_genotype(p.male_id))) father_genotype,
  p.mother_name,
  decode(m.generation,'F0',null,decode(p.female_id,null,null,mts.fetch_genotype(p.female_id))) mother_genotype,
  mts.fetch_cohort(m.id,', ') cohorts,
  mts.fetch_pipelines(m.id,', ') pipelines,
  decode(r.id,
    null, null,
    rc.name ||':' || p.name
  ) reservation,
  rc.name category,
  rc.id category_id,
  p.id purpose_id,
  r.reserver_id,
  r.team_id,
  p.name purpose,
  decode(rp.person_id,
    null, null,
    rp.first_name || ' ' || rp.last_name
  ) reserver,
  decode(rt.id,
    null,null,
    rt.team_number || ' - ' || rt.team_name
  ) reservation_team
from
  mts_mouse m,
  mts_coat_colour_dict c,
  mts_eye_colour_dict e,
  mts_earmark_dict ear,
  mts_cause_of_death_dict d,
  per_person owner,
  mts_gender_dict s,
  mts_cage_vw l,
  mts_mouse_current_19b_mv b,
  typ_strain t,
  mts_colony_info colony,
  mts_current_breeding_mv breeding,
  mts_chimeric_mouse_data chim,
  res_mouse_reservation mr,
  res_reservation r,
  res_purpose p,
  res_category_dict rc,
  per_team rt,
  per_person rp,
  (select b.male_id, b.female_id, l.id litter_id, decode(b.embryo_transfer_id,null,sire.name, null) father_name, decode(b.embryo_transfer_id,null,dam.name,null) mother_name
   from
    mts_litter l,
    mts_breeding b,
 mts_mouse sire,
 mts_mouse dam
   where
    l.breeding_id = b.id and
 b.male_id = sire.id and
 b.female_id = dam.id
  ) p
where
  m.coat_colour_dict_id = c.id(+) and
  m.eye_colour_dict_id = e.id(+) and
  m.earmark_dict_id = ear.id(+) and
  m.cause_of_death_dict_id = d.id(+) and
  m.current_owner_id = owner.person_id(+) and
  m.gender_dict_id = s.id(+) and
  m.cage_id = l.cage_id(+) and
  m.mouse_strain_dict_id = t.id(+) and
  m.colony_info_id = colony.id(+) and
  m.id = b.mouse_id(+) and
  m.id = breeding.mouse_id(+) and
  m.id = chim.mouse_id(+) and
  m.litter_id = p.litter_id(+) and
  m.id = mr.mouse_id(+) and
  mr.reservation_id = r.id(+) and
  r.purpose_id = p.id (+) and
  p.CATEGORY_ID = rc.id (+) and
  r.reserver_id = rp.person_id(+) and
  r.team_id = rt.id(+);

CREATE OR REPLACE VIEW REP_ALL_MICE AS
  select
  id,
  litter_id,
  name,
  rfid_tag,
  edit_date,
  coat_colour_dict_id,
  coat_colour,
  eye_colour_dict_id,
  eye_colour,
  earmark_dict_id,
  earmark,
  birth_date,
  age_in_weeks,
  death_date,
  age_at_death,
  cause_of_death_dict_id,
  cause_of_death,
  edited_by,
  wean_date,
  cage_id,
  cage_name,
  cage_barcode,
  rack_id,
  rack_name,
  room_id,
  room_name,
  current_owner_id,
  current_owner,
  current_project_licence_id,
  current_project_licence,
  current_protocol_id,
  current_protocol_code,
  check_number,
  gender_dict_id,
  gender,
  mouse_strain_dict_id,
  strain,
  status,
  creator_id,
  created_date,
  barcode,
  comments,
  is_non_breeder,
  is_sentinel,
  generation,
  colony_name,
  colony_prefix,
  colony_info_id,
  arrival_date,
  latest_plug_date,
  breeding_name,
  genotype,
  father_name,
  father_genotype,
  mother_name,
  mother_genotype,
  cohorts,
  pipelines,
  reservation,
  category,
  category_id,
  purpose_id,
  reserver_id,
  team_id,
  purpose,
  reserver,
  reservation_team
from
  mts_mouse_vw;

CREATE INDEX RES_MOUSE_RESERVATION_IND1 ON RES_MOUSE_RESERVATION (RESERVATION_ID) TABLESPACE INDEX_02;
CREATE INDEX RES_MOUSE_RESERVATION_IND2 ON RES_MOUSE_RESERVATION (MOUSE_ID) TABLESPACE INDEX_02;

CREATE INDEX RES_RESERVATION_IND1 ON RES_RESERVATION (PURPOSE_ID) TABLESPACE INDEX_02;
CREATE INDEX RES_RESERVATION_IND2 ON RES_RESERVATION (RESERVER_ID) TABLESPACE INDEX_02;
CREATE INDEX RES_RESERVATION_IND3 ON RES_RESERVATION (TEAM_ID) TABLESPACE INDEX_02;

alter table RES_MOUSE_RESERVATION add
CONSTRAINT RES_MOUSE_RESERVATION_U1 unique (mouse_id);

connect migpriv

create table mig_audit.RES_CATEGORY_DICT as select * from mig.RES_CATEGORY_DICT where 1 = 2;
alter table mig_audit.RES_CATEGORY_DICT add (audit_timestamp timestamp(6) default systimestamp);
alter table mig_audit.RES_CATEGORY_DICT add (os_user varchar2(30) default sys_context('USERENV','OS_USER'));
alter table mig_audit.RES_CATEGORY_DICT add (audit_action varchar2(10));

create table mig_audit.RES_MOUSE_RESERVATION as select * from mig.RES_MOUSE_RESERVATION where 1 = 2;
alter table mig_audit.RES_MOUSE_RESERVATION add (audit_timestamp timestamp(6) default systimestamp);
alter table mig_audit.RES_MOUSE_RESERVATION add (os_user varchar2(30) default sys_context('USERENV','OS_USER'));
alter table mig_audit.RES_MOUSE_RESERVATION add (audit_action varchar2(10));

create table mig_audit.RES_PURPOSE as select * from mig.RES_PURPOSE where 1 = 2;
alter table mig_audit.RES_PURPOSE add (audit_timestamp timestamp(6) default systimestamp);
alter table mig_audit.RES_PURPOSE add (os_user varchar2(30) default sys_context('USERENV','OS_USER'));
alter table mig_audit.RES_PURPOSE add (audit_action varchar2(10));

create table mig_audit.RES_RESERVATION as select * from mig.RES_RESERVATION where 1 = 2;
alter table mig_audit.RES_RESERVATION add (audit_timestamp timestamp(6) default systimestamp);
alter table mig_audit.RES_RESERVATION add (os_user varchar2(30) default sys_context('USERENV','OS_USER'));
alter table mig_audit.RES_RESERVATION add (audit_action varchar2(10));


connect mig_audit

alter table PHN_CALORIMETRY_DATA
 add (
  rate_xa number,
  rate_xt number,
  rate_ya number,
  rate_yt number,
  rate_feed number,
  feed_in_interval number
  );

grant insert on RES_CATEGORY_DICT to mig;
grant insert on RES_MOUSE_RESERVATION to mig;
grant insert on RES_PURPOSE to mig;
grant insert on RES_RESERVATION to mig;

connect mig

create or replace trigger RES_CATEGORY_DICT_ta
before update or delete on RES_CATEGORY_DICT for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */

declare
audit_action varchar2(10);
begin

if deleting then audit_action := 'deleted'; end if;
if updating then audit_action := 'updated'; end if;
if deleting or updating then
 insert into mig_audit.RES_CATEGORY_DICT(
    ID,
    NAME,
    DESCRIPTION,
    ACTIVE,
    ORDER_BY,
    AUDIT_ACTION)
 values (
    :old.ID,
    :old.NAME,
    :old.DESCRIPTION,
    :old.ACTIVE,
    :old.ORDER_BY,
    AUDIT_ACTION);
end if;
end;
/

create or replace trigger RES_MOUSE_RESERVATION_ta
before update or delete on RES_MOUSE_RESERVATION for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */

declare
audit_action varchar2(10);
begin

if deleting then audit_action := 'deleted'; end if;
if updating then audit_action := 'updated'; end if;
if deleting or updating then
 insert into mig_audit.RES_MOUSE_RESERVATION(
    ID,
    MOUSE_ID,
    RESERVATION_ID,
    NOTIFICATION_SENT,
    EDIT_DATE,
    EDITED_BY,
    CREATED_DATE,
    CREATOR_ID,
    CHECK_NUMBER,
    AUDIT_ACTION)
 values (
    :old.ID,
    :old.MOUSE_ID,
    :old.RESERVATION_ID,
    :old.NOTIFICATION_SENT,
    :old.EDIT_DATE,
    :old.EDITED_BY,
    :old.CREATED_DATE,
    :old.CREATOR_ID,
    :old.CHECK_NUMBER,
    AUDIT_ACTION);
end if;
end;
/

create or replace trigger RES_PURPOSE_ta
before update or delete on RES_PURPOSE for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */

declare
audit_action varchar2(10);
begin

if deleting then audit_action := 'deleted'; end if;
if updating then audit_action := 'updated'; end if;
if deleting or updating then
 insert into mig_audit.RES_PURPOSE(
    ID,
    NAME,
    CATEGORY_ID,
    EDIT_DATE,
    EDITED_BY,
    CREATED_DATE,
    CREATOR_ID,
    CHECK_NUMBER,
    AUDIT_ACTION)
 values (
    :old.ID,
    :old.NAME,
    :old.CATEGORY_ID,
    :old.EDIT_DATE,
    :old.EDITED_BY,
    :old.CREATED_DATE,
    :old.CREATOR_ID,
    :old.CHECK_NUMBER,
    AUDIT_ACTION);
end if;
end;
/

create or replace trigger RES_RESERVATION_ta
before update or delete on RES_RESERVATION for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */

declare
audit_action varchar2(10);
begin

if deleting then audit_action := 'deleted'; end if;
if updating then audit_action := 'updated'; end if;
if deleting or updating then
 insert into mig_audit.RES_RESERVATION(
    ID,
    PURPOSE_ID,
    RESERVER_ID,
    TEAM_ID,
    EDIT_DATE,
    EDITED_BY,
    CREATED_DATE,
    CREATOR_ID,
    CHECK_NUMBER,
    NOTIFY,
    AUDIT_ACTION)
 values (
    :old.ID,
    :old.PURPOSE_ID,
    :old.RESERVER_ID,
    :old.TEAM_ID,
    :old.EDIT_DATE,
    :old.EDITED_BY,
    :old.CREATED_DATE,
    :old.CREATOR_ID,
    :old.CHECK_NUMBER,
    :old.NOTIFY,
    AUDIT_ACTION);
end if;
end;
/


insert into APP_CUSTOM_QUERY_COLUMN
(id,custom_query_id,column_name,column_title,order_by,is_display_column,is_filter_column,actual_query_column,list_query)
values
(APP_CUSTOM_QUERY_COL_SEQ.NEXTVAL,11,'category','Reservation Category',16,1,1,'CATEGORY_ID','select id,name from res_category_dict order by order_by');

insert into APP_CUSTOM_QUERY_COLUMN
(id,custom_query_id,column_name,column_title,order_by,is_display_column,is_filter_column)
values
(APP_CUSTOM_QUERY_COL_SEQ.NEXTVAL,11,'purpose','Reservation Purpose',17,1,1);

insert into APP_CUSTOM_QUERY_COLUMN
(id,custom_query_id,column_name,column_title,order_by,is_display_column,is_filter_column)
values
(APP_CUSTOM_QUERY_COL_SEQ.NEXTVAL,11,'reserver','Reserver',18,1,1);

insert into APP_CUSTOM_QUERY_COLUMN
(id,custom_query_id,column_name,column_title,order_by,is_display_column,is_filter_column)
values
(APP_CUSTOM_QUERY_COL_SEQ.NEXTVAL,11,'reservation_team','Reserving Team',19,1,1);


insert into res_category_dict (id,name,active,order_by) values (1,'Phenotyping',1,3);
insert into res_category_dict (id,name,active,order_by) values (2,'Breeding',1,1);
insert into res_category_dict (id,name,active,order_by) values (3,'Distribution',1,2);

insert into res_purpose (id,name,category_id,created_date) values (RES_PURPOSE_SEQ.NEXTVAL, 'Metabolic and Cardiovascular', 1, sysdate);
insert into res_purpose (id,name,category_id,created_date) values (RES_PURPOSE_SEQ.NEXTVAL, 'Behaviour, Sensory and Immunology', 1, sysdate);
insert into res_purpose (id,name,category_id,created_date) values (RES_PURPOSE_SEQ.NEXTVAL, 'Fertility', 1, sysdate);
insert into res_purpose (id,name,category_id,created_date) values (RES_PURPOSE_SEQ.NEXTVAL, 'Expression', 1, sysdate);
insert into res_purpose (id,name,category_id,created_date) values (RES_PURPOSE_SEQ.NEXTVAL, 'Irradiation', 1, sysdate);
insert into res_purpose (id,name,category_id,created_date) values (RES_PURPOSE_SEQ.NEXTVAL, 'Brain Analysis', 1, sysdate);
insert into res_purpose (id,name,category_id,created_date) values (RES_PURPOSE_SEQ.NEXTVAL, 'Infection', 1, sysdate);
insert into res_purpose (id,name,category_id,created_date) values (RES_PURPOSE_SEQ.NEXTVAL, 'Recessive Lethality', 1, sysdate);
insert into res_purpose (id,name,category_id,created_date) values (RES_PURPOSE_SEQ.NEXTVAL, 'Pilot Study', 1, sysdate);
insert into res_purpose (id,name,category_id,created_date) values (RES_PURPOSE_SEQ.NEXTVAL, 'Embryo Generation', 1, sysdate);

insert into res_purpose (id,name,category_id,created_date) values (RES_PURPOSE_SEQ.NEXTVAL, 'Future Breeding Stock', 2, sysdate);
insert into res_purpose (id,name,category_id,created_date) values (RES_PURPOSE_SEQ.NEXTVAL, 'Homozygous Viability', 2, sysdate);
insert into res_purpose (id,name,category_id,created_date) values (RES_PURPOSE_SEQ.NEXTVAL, 'Expansion Breeding', 2, sysdate);
insert into res_purpose (id,name,category_id,created_date) values (RES_PURPOSE_SEQ.NEXTVAL, 'Cohort Generation', 2, sysdate);
insert into res_purpose (id,name,category_id,created_date) values (RES_PURPOSE_SEQ.NEXTVAL, 'Nucleus Production', 2, sysdate);

insert into res_purpose (id,name,category_id,created_date) values (RES_PURPOSE_SEQ.NEXTVAL, 'Transfer', 3, sysdate);
insert into res_purpose (id,name,category_id,created_date) values (RES_PURPOSE_SEQ.NEXTVAL, 'Export', 3, sysdate);

Insert into APP_COLUMN_PREFS (ID,TABLE_NAME,COLUMN_NAME,COLUMN_TITLE,GETTER_METHOD,ORDER_BY,DATATYPE,CUSTOM_QUERY_ID) values (APP_COLUMN_PREFS_SEQ.NEXTVAL,'mts_mouse_list_vw','reservation','Reservation','getReservation',null,null,null);

CREATE OR REPLACE FORCE VIEW PHN_CALORIMETRY_DATA_BINNED_VW  AS
  SELECT experiment_id,
  round(sample_time, 'hh') time,
  avg(minutes_elapsed) avg_minutes_elapsed,
  count(id) samples,
  AVG(co2) co2,
  AVG(o2) o2,
  AVG(ref_co2) ref_co2,
  AVG(ref_o2) ref_o2,
  AVG(co2_difference) co2_difference,
  AVG(o2_difference) o2_difference,
  AVG(cumulative_food_intake) cumulative_food_intake,
  AVG(flow_rate_in) flow_rate_in,
  AVG(sample_flow_rate_out) sample_flow_rate_out,
  AVG(temperature) temperature,
  AVG(respiratory_exchange_ratio) respiratory_exchange_ratio,
  AVG(vco2_bodyweight) vco2_bodyweight,
  AVG(vco2_lean_mass) vco2_lean_mass,
  AVG(vco2_animal) vco2_animal,
  AVG(vo2_bodyweight) vo2_bodyweight,
  AVG(vo2_lean_mass) vo2_lean_mass,
  AVG(vo2_animal) vo2_animal,
  AVG(energy_expend_bodyweight) energy_expend_bodyweight,
  AVG(energy_expend_lean_mass) energy_expend_lean_mass,
  AVG(energy_expend_animal) energy_expend_animal,
  AVG(heat_bodyweight) heat_bodyweight,
  AVG(heat_lean_mass) heat_lean_mass,
  AVG(heat_animal) heat_animal,
  AVG(xaxis_activity_count) xaxis_activity_count,
  AVG(xaxis_activity_count_total) xaxis_activity_count_total,
  AVG(yaxis_activity_count) yaxis_activity_count,
  AVG(yaxis_activity_count_total) yaxis_activity_count_total,
  AVG(rate_xa) xaxis_activity_rate,
  AVG(rate_ya) yaxis_activity_rate,
  AVG(rate_xt) xaxis_activity_total_rate,
  AVG(rate_yt) yaxis_activity_total_rate,
  AVG(rate_feed) food_intake_rate
FROM phn_calorimetry_data
GROUP BY experiment_id,
  round(sample_time, 'hh')
 ;

CREATE OR REPLACE FORCE VIEW REP_CALORIMETRY_RAW_VW AS
  select
e.*,
c.SAMPLE_TIME,
c.MINUTES_ELAPSED,
c.CO2,
c.O2,
c.REF_CO2,
c.REF_O2,
c.CO2_DIFFERENCE,
c.O2_DIFFERENCE,
c.CUMULATIVE_FOOD_INTAKE,
c.FLOW_RATE_IN,
c.SAMPLE_FLOW_RATE_OUT,
c.TEMPERATURE,
c.RESPIRATORY_EXCHANGE_RATIO,
c.VCO2_BODYWEIGHT,
c.VCO2_LEAN_MASS,
c.VCO2_ANIMAL,
c.VO2_BODYWEIGHT,
c.VO2_LEAN_MASS,
c.VO2_ANIMAL,
c.ENERGY_EXPEND_BODYWEIGHT,
c.ENERGY_EXPEND_LEAN_MASS,
c.ENERGY_EXPEND_ANIMAL,
c.HEAT_BODYWEIGHT,
c.HEAT_LEAN_MASS,
c.HEAT_ANIMAL,
c.XAXIS_ACTIVITY_COUNT,
c.XAXIS_ACTIVITY_COUNT_TOTAL,
c.YAXIS_ACTIVITY_COUNT,
c.YAXIS_ACTIVITY_COUNT_TOTAL,
c.RATE_XA,
c.RATE_XT,
c.RATE_YA,
c.RATE_YT,
c.RATE_FEED,
(e.experiment_id * 1e4) + (e.cohort_id * 1e9) + c.id as id,
box.value BOX,
ro.name BAD_FOOD_DATA
from PHN_CALORIMETRY_DATA c
join PHN_EXPERIMENT_SUMMARY_VW e
join PHN_OBSERVATION box on e.experiment_id = box.experiment_id and box.required_observation_id = 739
join PHN_OBSERVATION o on e.experiment_id = o.experiment_id and o.required_observation_id = 807
join PHN_RESTRICTED_OPTION ro on o.value = to_char(ro.id)
on c.experiment_id = e.experiment_id
where e.is_complete = 1
 ;

CREATE OR REPLACE FORCE VIEW REP_CALORIMETRY_BINNED_VW AS
  select
e.*,
c.TIME,
c.SAMPLES,
c.CO2,
c.O2,
c.REF_CO2,
c.REF_O2,
c.CO2_DIFFERENCE,
c.O2_DIFFERENCE,
c.CUMULATIVE_FOOD_INTAKE,
c.FLOW_RATE_IN,
c.SAMPLE_FLOW_RATE_OUT,
c.TEMPERATURE,
c.RESPIRATORY_EXCHANGE_RATIO,
c.VCO2_BODYWEIGHT,
c.VCO2_LEAN_MASS,
c.VCO2_ANIMAL,
c.VO2_BODYWEIGHT,
c.VO2_LEAN_MASS,
c.VO2_ANIMAL,
c.ENERGY_EXPEND_BODYWEIGHT,
c.ENERGY_EXPEND_LEAN_MASS,
c.ENERGY_EXPEND_ANIMAL,
c.HEAT_BODYWEIGHT,
c.HEAT_LEAN_MASS,
c.HEAT_ANIMAL,
c.XAXIS_ACTIVITY_COUNT,
c.XAXIS_ACTIVITY_COUNT_TOTAL,
c.YAXIS_ACTIVITY_COUNT,
c.YAXIS_ACTIVITY_COUNT_TOTAL,
c.XAXIS_ACTIVITY_RATE,
c.YAXIS_ACTIVITY_RATE,
c.XAXIS_ACTIVITY_TOTAL_RATE,
c.YAXIS_ACTIVITY_TOTAL_RATE,
c.FOOD_INTAKE_RATE,
(e.experiment_id * 1e9) + (e.cohort_id * 1e2) + trunc(c.avg_minutes_elapsed) as id,
box.value box,
ro.name BAD_FOOD_DATA
from PHN_EXPERIMENT_SUMMARY_VW e
join PHN_CALORIMETRY_DATA_BINNED_VW c on e.experiment_id = c.experiment_id
join PHN_OBSERVATION box on e.experiment_id = box.experiment_id and box.required_observation_id = 739
join PHN_OBSERVATION o on e.experiment_id = o.experiment_id and o.required_observation_id = 807
join PHN_RESTRICTED_OPTION ro on o.value = to_char(ro.id)
where e.is_complete = 1
 ;

insert into APP_CUSTOM_QUERY_COLUMN (id, custom_query_id,column_name,column_title,is_display_column,is_filter_column)
values
(APP_CUSTOM_QUERY_COL_SEQ.NEXTVAL,35,'XAXIS_ACTIVITY_RATE','X-activity Rate Ambulatory',1,1);

insert into APP_CUSTOM_QUERY_COLUMN (id, custom_query_id,column_name,column_title,is_display_column,is_filter_column)
values
(APP_CUSTOM_QUERY_COL_SEQ.NEXTVAL,35,'YAXIS_ACTIVITY_RATE','Y-activity Rate Ambulatory',1,1);
insert into APP_CUSTOM_QUERY_COLUMN (id, custom_query_id,column_name,column_title,is_display_column,is_filter_column)
values
(APP_CUSTOM_QUERY_COL_SEQ.NEXTVAL,35,'XAXIS_ACTIVITY_TOTAL_RATE','X-activity Rate Ambulatory Total',1,1);
insert into APP_CUSTOM_QUERY_COLUMN (id, custom_query_id,column_name,column_title,is_display_column,is_filter_column)
values
(APP_CUSTOM_QUERY_COL_SEQ.NEXTVAL,35,'YAXIS_ACTIVITY_TOTAL_RATE','Y-activity Rate Ambulatory Total',1,1);
insert into APP_CUSTOM_QUERY_COLUMN (id, custom_query_id,column_name,column_title,is_display_column,is_filter_column)
values
(APP_CUSTOM_QUERY_COL_SEQ.NEXTVAL,35,'FOOD_INTAKE_RATE','Food Intake Rate',1,1);
insert into APP_CUSTOM_QUERY_COLUMN (id, custom_query_id,column_name,column_title,is_display_column,is_filter_column)
values
(APP_CUSTOM_QUERY_COL_SEQ.NEXTVAL,35,'BAD_FOOD_DATA','Ignore Food Data',1,1);

insert into APP_CUSTOM_QUERY_COLUMN (id, custom_query_id,column_name,column_title,is_display_column,is_filter_column)
values
(APP_CUSTOM_QUERY_COL_SEQ.NEXTVAL,32,'RATE_XA','X-activity Rate Ambulatory',1,1);

insert into APP_CUSTOM_QUERY_COLUMN (id, custom_query_id,column_name,column_title,is_display_column,is_filter_column)
values
(APP_CUSTOM_QUERY_COL_SEQ.NEXTVAL,32,'RATE_XT','X-activity Rate Ambulatory Total',1,1);

insert into APP_CUSTOM_QUERY_COLUMN (id, custom_query_id,column_name,column_title,is_display_column,is_filter_column)
values
(APP_CUSTOM_QUERY_COL_SEQ.NEXTVAL,32,'RATE_YA','Y-activity Rate Ambulatory ',1,1);

insert into APP_CUSTOM_QUERY_COLUMN (id, custom_query_id,column_name,column_title,is_display_column,is_filter_column)
values
(APP_CUSTOM_QUERY_COL_SEQ.NEXTVAL,32,'RATE_YT','Y-activity Rate Ambulatory Total',1,1);

insert into APP_CUSTOM_QUERY_COLUMN (id, custom_query_id,column_name,column_title,is_display_column,is_filter_column)
values
(APP_CUSTOM_QUERY_COL_SEQ.NEXTVAL,32,'RATE_FEED','Feed Intake Rate',1,1);

insert into APP_CUSTOM_QUERY_COLUMN (id, custom_query_id,column_name,column_title,is_display_column,is_filter_column)
values
(APP_CUSTOM_QUERY_COL_SEQ.NEXTVAL,32,'BAD_FOOD_DATA','Ignore Food Data',1,1);


commit;