package uk.ac.sanger.mig.abr;

import java.math.BigInteger;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;

/**
 * This class defines several static methods for the purpose of converting some data into a hex
 * colour code. When passed the same data these methods should return the same value everytime.
 *
 * Example:
 *
 * 	String colourCode = ColourGenerator.hexColourCode("Some test data");
 *
 * @author holroyd
 *
 */
public class ColourGenerator {

	/**
	 * Generates an Hex string from the passed in data. The Hex string is consistent, it will always
	 * return the same string for the same data. Converts the data into a hexidecimal MD5 hash and
	 * returns the first 6 characters.
	 *
	 * @param data -
	 *            the data to generate as an Hex.
	 * @return hex - the six character Hex string representing the data.
	 * @throws NoSuchAlgorithmException -
	 *             thrown if MD5 not available.
	 */
	public static String hexColourCode(String data) throws NoSuchAlgorithmException {
		MessageDigest digest = java.security.MessageDigest.getInstance("MD5");
		digest.update(data.getBytes(), 0, data.length());
		String md5Hash = new BigInteger(1, digest.digest()).toString(16);
		return md5Hash.substring(0, 6);
	}


	/**
	 * Convenience method that allows an int to be converted into a hexidecimal colour.
	 *
	 * @param data -
	 *            the int to convert into the MD5 hexidecimal colour value.
	 * @return hexColour - the 6 character hexidecimal colour code.
	 * @throws NoSuchAlgorithmException -
	 *             thrown if MD5 not available.
	 */
	public static String hexColourCode(int data) throws NoSuchAlgorithmException {
		return ColourGenerator.hexColourCode(Integer.toString(data));
	}

}
