package uk.ac.sanger.mig.abr;

import java.security.NoSuchAlgorithmException;
import ChartDirector.Chart;
import ChartDirector.LineLayer;
import ChartDirector.XYChart;



/**
 * This class generates the control charts for ABR : calibration
 * chart and click chart
 * dataX is the X values for the calibration(index 0) and click (index 1)charts
 * dataY are the Y values for calibration(index 0), click 1(index 1) and click 2(index 2)
 *
 *The index values are assigned as constants.
 *
 * @author wl1
 *
 */
public class ControlChart {

	private double[][] dataX;
	private double[][] dataY;//IN ORDER

	public static final int CALIBRATION_INDEX = 0;
	public static final int CLICK_INDEX_X = 1;
	public static final int CLICK1_INDEX_Y = 1;
	public static final int CLICK2_INDEX_Y = 2;

	public static final int CHART_X = 300;
	public static final int CHART_Y = 350;
	public static final int PLOT_X = 230;
	public static final int PLOT_Y = 280;

	public static final String CLICK1_LABEL = "Click 1";
	public static final String CLICK2_LABEL = "Click 2";


	public double[][] getDataY() {
		return dataY;
	}

	public void setDataY(double[][] dataY) {
		this.dataY = dataY;
	}

	public double[][] getDataX() {
		return dataX;
	}

	public void setDataX(double[][] dataX) {
		this.dataX = dataX;
	}

	public ControlChart(double[][] dataX, double[][] dataY) {
		this.dataX = dataX;
		this.dataY = dataY;
	}

	public XYChart createClickChart() throws NoSuchAlgorithmException{
		String[] xlabels = {"0","2","4","6","8","10","12","14","16","18","20"};

		//create chart
		XYChart c = new XYChart(CHART_X, CHART_Y);
		// set drawing area, white background, grey axis lines.
		c.setPlotArea(10,20, PLOT_X,PLOT_Y, 0xffffff, -1, 0xbdbdbe, 0xbdbdbe, Chart.Transparent);
		c.addTitle("Click 1 & 2 at 100 Hz,70 SPL","",10);

		//x and y axis
		c.xAxis().setLabels(xlabels);
		c.xAxis().setLinearScale2(dataX[CLICK_INDEX_X][0],dataX[CLICK_INDEX_X][dataX[CLICK_INDEX_X].length-1],xlabels);
		c.xAxis().setWidth(1);
		c.yAxis().setWidth(1);
		c.xAxis().setColors(0x000000,0x9e0000,0X000000,0x9e0000);//x label color red, title color black
		c.yAxis().setColors(0x000000,0x9e0000,0X000000,0x9e0000);
		c.yAxis().setLabelFormat("");
		c.xAxis().setLabelFormat("");
		c.xAxis().setTitle("ms", "Arial", 8);

		//add x, y datasets values
		LineLayer layer1 = c.addLineLayer();
		layer1.setXData(dataX[CLICK_INDEX_X]);
		layer1.addDataSet(dataY[CLICK1_INDEX_Y],0xFF0A0A);
		layer1.addDataSet(dataY[CLICK2_INDEX_Y],0x0A0AFF);

		//add the colored lines and their labels(click 1 and click 2)
		c.layout();
		int x = c.getXCoor(dataX[CLICK_INDEX_X][dataX[CLICK_INDEX_X].length-1]);
        int y = PLOT_Y/2;
		c.addLine(x+5,y,x+25,y,0xFF0A0A,2);
		c.addText(x+25,y-5, CLICK1_LABEL,"",8,0xFF0A0A);
        c.addLine(x+5,y-5,x+25,y-5,0x0A0AFF,2);
	    c.addText(x+25,y-15, CLICK2_LABEL,"",8,0x0A0AFF);

        return c;
	}

	public XYChart createCalibrationChart() throws NoSuchAlgorithmException{
		//create chart
		XYChart c = new XYChart(CHART_X, CHART_Y);

		// set drawing area, white background, grey axis lines.
		c.setPlotArea(45,20, PLOT_X,PLOT_Y, 0xffffff, -1, 0xbdbdbe, 0xbdbdbe, Chart.Transparent);
		c.addTitle("Calibration","",10);

		// x axis uses log scale
		c.xAxis().setLogScale(dataX[CALIBRATION_INDEX][0],dataX[CALIBRATION_INDEX][dataX[CALIBRATION_INDEX].length-1],Chart.LogTick);
		c.xAxis().setWidth(1);
		c.yAxis().setWidth(1);
		c.xAxis().setColors(0x000000,0x9e0000,0X000000,0x9e0000);//x label color red, title color black
		c.yAxis().setColors(0x000000,0x9e0000,0X000000,0x9e0000);
		// y axis, no scale
		c.yAxis().setAutoScale(0, 0, 0);
		c.xAxis().setTitle("Hz", "Arial", 8);
		c.yAxis().setTitle("dB","Arial", 8);

		LineLayer layer1 = c.addLineLayer();
		layer1.setXData(dataX[CALIBRATION_INDEX]);
		layer1.addDataSet(dataY[CALIBRATION_INDEX],0xFF0A0A);

		return c;
	}
}
