/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.abr;

import java.util.Date;

import uk.ac.sanger.mig.common.PaginatedSearchBean;

/**
 * This class serves as wrapper around domain object POJO for searching on particular fields that are set.
 * It also inherits orderBy and sortOrder methods from SortableSearchBean enabling sort functionlity.
 *
 * If you also need pagination functionality, subclass PaginatedSearchBean which extends SortableSearchBean
 *
 * NOTE: Using wrapper is just one appraoch to search bean. You could alternatively created a standalone
 * search bean that effectively mimics all of the fields with getters and setters of your domain object POJO.
 */

public class MouseAbrListViewSearchBean extends PaginatedSearchBean  {

	  	private Long experimentId;
	    private Long mouseId;
	    private String anaesthetic;
	    private Float anaestheticDose;
	    private String anaestheticRoute;
	    private String inductionTime;
	    private Date experimentDate;
	    private Float weight;
	    private String includeExperiment;
	    private String comments;
	    private String mouseBarcode;
	    private Date mouseBirthDate;
	    private String rfidTag;
	    private String earClip;
	    private String genotype;
	    private String shortAlleleSymbol;
	    private String officialNameSuperscript;
	    private String colonyPrefix;
	    private String genePrimaryName;
	    private Long personalLicenceId;
	    private String pilNumber;
	    private Long userId;
	    private String userName;
	    private Long projectLicenceId;
	    private String pplNumber;
	    private String protocolCode;
	    private Boolean processStatus;
	    private String mouseName;
	    private String status;
	    private String wildtype;

		public String getWildtype() {
			return wildtype;
		}
		public void setWildtype(String wildtype) {
			this.wildtype = wildtype;
		}
		public String getStatus() {
			return status;
		}
		public void setStatus(String status) {
			this.status = status;
		}
		public String getMouseName() {
			return mouseName;
		}
		public void setMouseName(String mouseName) {
			this.mouseName = mouseName;
		}
		public String getAnaesthetic() {
			return anaesthetic;
		}
		public void setAnaesthetic(String anaesthetic) {
			this.anaesthetic = anaesthetic;
		}
		public Float getAnaestheticDose() {
			return anaestheticDose;
		}
		public void setAnaestheticDose(Float anaestheticDose) {
			this.anaestheticDose = anaestheticDose;
		}
		public String getAnaestheticRoute() {
			return anaestheticRoute;
		}
		public void setAnaestheticRoute(String anaestheticRoute) {
			this.anaestheticRoute = anaestheticRoute;
		}
		public String getColonyPrefix() {
			return colonyPrefix;
		}
		public void setColonyPrefix(String colonyPrefix) {
			this.colonyPrefix = colonyPrefix;
		}
		public String getComments() {
			return comments;
		}
		public void setComments(String comments) {
			this.comments = comments;
		}
		public String getEarClip() {
			return earClip;
		}
		public void setEarClip(String earClip) {
			this.earClip = earClip;
		}
		public Date getExperimentDate() {
			return experimentDate;
		}
		public void setExperimentDate(Date experimentDate) {
			this.experimentDate = experimentDate;
		}
		public Long getExperimentId() {
			return experimentId;
		}
		public void setExperimentId(Long experimentId) {
			this.experimentId = experimentId;
		}
		public String getGenePrimaryName() {
			return genePrimaryName;
		}
		public void setGenePrimaryName(String genePrimaryName) {
			this.genePrimaryName = genePrimaryName;
		}
		public String getGenotype() {
			return genotype;
		}
		public void setGenotype(String genotype) {
			this.genotype = genotype;
		}

		public String getIncludeExperiment() {
			return includeExperiment;
		}
		public void setIncludeExperiment(String includeExperiment) {
			this.includeExperiment = includeExperiment;
		}
		public String getInductionTime() {
			return inductionTime;
		}
		public void setInductionTime(String inductionTime) {
			this.inductionTime = inductionTime;
		}
		public String getMouseBarcode() {
			return mouseBarcode;
		}
		public void setMouseBarcode(String mouseBarcode) {
			this.mouseBarcode = mouseBarcode;
		}
		public Date getMouseBirthDate() {
			return mouseBirthDate;
		}
		public void setMouseBirthDate(Date mouseBirthDate) {
			this.mouseBirthDate = mouseBirthDate;
		}
		public Long getMouseId() {
			return mouseId;
		}
		public void setMouseId(Long mouseId) {
			this.mouseId = mouseId;
		}
		public String getOfficialNameSuperscript() {
			return officialNameSuperscript;
		}
		public void setOfficialNameSuperscript(String officialNameSuperscript) {
			this.officialNameSuperscript = officialNameSuperscript;
		}
		public Long getPersonalLicenceId() {
			return personalLicenceId;
		}
		public void setPersonalLicenceId(Long personalLicenceId) {
			this.personalLicenceId = personalLicenceId;
		}
		public String getPilNumber() {
			return pilNumber;
		}
		public void setPilNumber(String pilNumber) {
			this.pilNumber = pilNumber;
		}
		public String getPplNumber() {
			return pplNumber;
		}
		public void setPplNumber(String pplNumber) {
			this.pplNumber = pplNumber;
		}

		public Boolean getProcessStatus() {
			return processStatus;
		}
		public void setProcessStatus(Boolean processStatus) {
			this.processStatus = processStatus;
		}
		public Long getProjectLicenceId() {
			return projectLicenceId;
		}
		public void setProjectLicenceId(Long projectLicenceId) {
			this.projectLicenceId = projectLicenceId;
		}
		public String getProtocolCode() {
			return protocolCode;
		}
		public void setProtocolCode(String protocolCode) {
			this.protocolCode = protocolCode;
		}
		public String getRfidTag() {
			return rfidTag;
		}
		public void setRfidTag(String rfidTag) {
			this.rfidTag = rfidTag;
		}
		public String getShortAlleleSymbol() {
			return shortAlleleSymbol;
		}
		public void setShortAlleleSymbol(String shortAlleleSymbol) {
			this.shortAlleleSymbol = shortAlleleSymbol;
		}
		public Long getUserId() {
			return userId;
		}
		public void setUserId(Long userId) {
			this.userId = userId;
		}
		public String getUserName() {
			return userName;
		}
		public void setUserName(String userName) {
			this.userName = userName;
		}
		public Float getWeight() {
			return weight;
		}
		public void setWeight(Float weight) {
			this.weight = weight;
		}

}