package uk.ac.sanger.mig.abr;

import java.security.NoSuchAlgorithmException;
import java.util.List;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import uk.ac.sanger.mig.abr.parser.NotAnAbrTestBlockException;
import ChartDirector.Chart;
import ChartDirector.MultiChart;

/**
 * This class generateds all diagrams: The multiple chart includes all frequency diagrama,
 * the click diagram and the calibration diagram
 *
 * freqCharts are the list of all frequency diagrams. Each diagram has all traces (waveforms)
 * corrsponding to it.
 *
 * controlChart has calibration and click charts.
 *
 * @author wl1
 *
 */
public class MouseChart
{
	protected final static Log logger = LogFactory.getLog(MouseChart.class);
	private List<FrequencyChart> freqCharts;
	private ControlChart controlChart;

	public static final double DEFAULT_X_GRID = 14;
	public static final double FULL_X_GRID = 20;
	public static final int OFFSET = 50;

	public List<FrequencyChart> getFreqCharts() {
		return freqCharts;
	}

	public void setFreqCharts(List<FrequencyChart> freqCharts) {
		this.freqCharts = freqCharts;
	}

	public byte[] createMultipleChart() throws NumberFormatException, NotAnAbrTestBlockException, NoSuchAlgorithmException {
		int freqSize = freqCharts.size();
		MultiChart m = new MultiChart((int)(freqSize*FrequencyChart.PLOT_SIZE_X+OFFSET),FrequencyChart.CHART_SIZE_Y);

		for(int i=0;i<freqSize;i++){
			m.addChart((int)(i*FrequencyChart.PLOT_SIZE_X),0,freqCharts.get(i).createDefaultSingleChartForMultiple());
		}
		return m.makeChart(Chart.JPG);
	}

	public byte[] createClickChart() throws NoSuchAlgorithmException{
		return controlChart.createClickChart().makeChart(Chart.JPG);
	}

	public byte[] createCalibrationChart() throws NoSuchAlgorithmException{
		return controlChart.createCalibrationChart().makeChart(Chart.JPG);
	}

	public ControlChart getControlChart() {
		return controlChart;
	}

	public void setControlChart(ControlChart controlChart) {
		this.controlChart = controlChart;
	}

	public static double getDefaultXRatio(){
		return DEFAULT_X_GRID/FULL_X_GRID;
	}
}