/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.abr.controllers;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.abr.FreqExperiment;
import uk.ac.sanger.mig.abr.FrequencyChart;
import uk.ac.sanger.mig.abr.MouseChart;
import uk.ac.sanger.mig.abr.forms.AbrMouseForm;
import uk.ac.sanger.mig.abr.parser.FileParser;
import uk.ac.sanger.mig.abr.parser.Frequency;
import uk.ac.sanger.mig.abr.parser.Level;
import uk.ac.sanger.mig.abr.services.FreqExperimentService;
import uk.ac.sanger.mig.abr.services.MouseAbrService;
import uk.ac.sanger.mig.abr.views.MouseAbrListView;
import uk.ac.sanger.mig.common.AbstractCancellableFormController;
import uk.ac.sanger.mig.common.RequestUtils;

public class AnalysisMouseFormController extends AbstractCancellableFormController {

	private MouseAbrService			mouseAbrService;
	private FreqExperimentService	freqExperimentService;


	public void setMouseAbrService(MouseAbrService mouseAbrService) {
		this.mouseAbrService = mouseAbrService;
	}


	@Override
	protected ModelAndView handleInvalidSubmit(HttpServletRequest request, HttpServletResponse response) throws Exception {
		return new ModelAndView("errors/handle_invalid_submit");
	}


	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors)
			throws Exception {

		AbrMouseForm form = (AbrMouseForm) command;
		Long phnId = mouseAbrService.storeAnalysisData(form, RequestUtils.getUser(request));

		String viewString = getSuccessView() + "currentRecordId=" + phnId
				+ "&bypassForm=true&paginated=true&newQuery=true&orderBy=experiment_Date&orderDesc=true";

		return new ModelAndView(viewString);

	}


	@Override
	protected Object formBackingObject(HttpServletRequest request) throws Exception {
		AbrMouseForm form = (AbrMouseForm) createCommand();

		Long expId = ServletRequestUtils.getRequiredLongParameter(request, "expId");
		MouseAbrListView abrListView = mouseAbrService.fetchAbrMouseByExpId(expId);

		List<FreqExperiment> freqExperiments = new ArrayList<FreqExperiment>(freqExperimentService.fetchByPhnExperimentId(expId, null));
		FileParser fp = mouseAbrService.fetchAbrFileByExperimentId(expId);
		List<Frequency> frequencyBlocks = new ArrayList<Frequency>(fp.getAbrTraceBlocksByFrequencyLevel());
		List<Level> abrBlocks = new ArrayList<Level>(frequencyBlocks.get(0).getLevels());
		int[] levels = new int[abrBlocks.size()];
		int j = 0;
		for (int i = abrBlocks.size() - 1; i >= 0; i--) {
			levels[j] = abrBlocks.get(i).getLevel();
			j++;
		}
		form.setFrequencyLevels(FileParser.extractFrequencyLevelsForDisplay(frequencyBlocks));
		form.setLevels(levels);
		form.setMouseAbrListView(abrListView);
		form.setFreqExperiments(freqExperiments);
		form.setUserComments(abrListView.getUserComments());
		form.setExperimentComments(fp.getUserComments());

		if (abrListView.getIncludeExperiment().equalsIgnoreCase("yes")) {
			form.setInclude(Boolean.TRUE);
		} else {
			form.setInclude(Boolean.FALSE);
		}

		return form;
	}


	@Override
	protected Map referenceData(HttpServletRequest request, Object command, Errors errors) throws Exception {

		AbrMouseForm form = (AbrMouseForm) command;
		Map<String, Object> referenceData = new HashMap<String, Object>();
		int chartWidth = (FrequencyChart.PLOT_SIZE_X * form.getFreqExperiments().size()) + MouseChart.OFFSET;

		referenceData.put("mouseName", form.getMouseAbrListView().getMouseName());
		referenceData.put("expId", form.getMouseAbrListView().getExperimentId());
		referenceData.put("fileId", form.getMouseAbrListView().getFileId());
		referenceData.put("calibrationChartId", form.getMouseAbrListView().getCalibrationChartId());
		referenceData.put("clickChartId", form.getMouseAbrListView().getClickChartId());
		referenceData.put("levels", form.getLevels());
		referenceData.put("chartWidth", chartWidth);
		referenceData.put("singleChartWidth", FrequencyChart.PLOT_SIZE_X);
		referenceData.put("singleChartHeight", FrequencyChart.PLOT_SIZE_Y);
		referenceData.put("enlargedFreqWidth", FrequencyChart.CHART_SIZE_X_ENLARGED);
		referenceData.put("enlargedFreqHeight", FrequencyChart.CHART_SIZE_Y_ENLARGED);

		return referenceData;
	}


	public void setFreqExperimentService(FreqExperimentService freqExperimentService) {
		this.freqExperimentService = freqExperimentService;
	}
}