package uk.ac.sanger.mig.abr.controllers;

import java.text.SimpleDateFormat;
import java.util.Collection;
import java.util.Date;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.propertyeditors.CustomDateEditor;
import org.springframework.beans.propertyeditors.CustomNumberEditor;
import org.springframework.validation.BindException;
import org.springframework.web.bind.ServletRequestDataBinder;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.SimpleFormController;

import uk.ac.sanger.mig.abr.forms.AbrFileUploadForm;
import uk.ac.sanger.mig.abr.services.MouseAbrService;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.mousetracking.Mouse;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.phenotyping.datacapture.Experiment;
import uk.ac.sanger.mig.phenotyping.datacapture.StdOperatingProcedure;
import uk.ac.sanger.mig.phenotyping.datacapture.UploadMapping;
import uk.ac.sanger.mig.phenotyping.datacapture.services.ExperimentService;
import uk.ac.sanger.mig.phenotyping.datacapture.services.UploadMappingService;

public class EditAbrFileController extends SimpleFormController {

	private MouseAbrService			mouseAbrService;
	private UploadMappingService	uploadMappingService;
	private ExperimentService		experimentService;
	private String					cageView;


	public void setMouseAbrService(MouseAbrService mouseAbrService) {
		this.mouseAbrService = mouseAbrService;
	}


	public void setCageView(String cageView) {
		this.cageView = cageView;
	}


	public void setUploadMappingService(UploadMappingService uploadMappingService) {
		this.uploadMappingService = uploadMappingService;
	}


	public void setExperimentService(ExperimentService experimentService) {
		this.experimentService = experimentService;
	}


	@Override
	protected void initBinder(HttpServletRequest request, ServletRequestDataBinder binder) throws Exception {
		binder.registerCustomEditor(Long.class, new CustomNumberEditor(Long.class, true));
		binder.registerCustomEditor(Double.class, new CustomNumberEditor(Integer.class, true));
		binder.registerCustomEditor(Integer.class, new CustomNumberEditor(Double.class, true));
		binder.registerCustomEditor(Date.class, new CustomDateEditor(new SimpleDateFormat("dd-MMM-yyyy"), true));
	}


	@Override
	protected Object formBackingObject(HttpServletRequest request) throws Exception {
		String message = ServletRequestUtils.getStringParameter(request, "message");
		AbrFileUploadForm form = (AbrFileUploadForm) createCommand();
		Long experimentId = ServletRequestUtils.getLongParameter(request, "expId");
		if (experimentId != null) {
			loadPreviouslyUplodaedExperiment(form, experimentId);
		}
		form.setMessage(message);
		StdOperatingProcedure sop = uploadMappingService.fetchActiveSopForUploadType(
				UploadMappingService.Type.ABR_UPLOAD, ComponentMap
						.of(StdOperatingProcedure.Component.REQUIRED_OBSERVATIONS));
		Collection<UploadMapping> uploadMappings = uploadMappingService.fetchBySopIdAndName(sop.getId(),
				UploadMappingService.Type.ABR_UPLOAD);
		form.setSop(sop);
		form.setUploadMappings(uploadMappings);
		return form;
	}


	private void loadPreviouslyUplodaedExperiment(AbrFileUploadForm form, Long experimentId) {
		form.setPreviouslyUploadedBinaryFile(mouseAbrService.fetchAbrFileByExperimentId(experimentId, false));
		form.setPreviouslyUploadedExperiment(experimentService.fetchById(experimentId, ComponentMap
				.of(Experiment.Component.MOUSE)));
	}


	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, Object command,
			BindException errors) throws Exception {
		AbrFileUploadForm form = (AbrFileUploadForm) command;
		Person user = RequestUtils.getUser(request);
		Experiment experiment = mouseAbrService.storeExperimentFileAndCharts(form, user);
		Mouse mouse = experiment.getMouse();
		return new ModelAndView(getSuccessViewUrl(mouse, form.getBinaryFile().getFileName(), experiment.getId(), form
				.isCageView()));
	}


	public String getSuccessViewUrl(Mouse mouse, String filename, Long experimentId, boolean isCageView) {
		String successViewUrl = null;
		String message = "File " + filename + " successfully uploaded.";
		if (isCageView) {
			if (mouse.isAlive() && mouse.getCageId() != null) {
				successViewUrl = getCageView() + "?id=" + mouse.getCageId();
			} else {
				message = message + " No cage view available - the mouse is deceased.";
				successViewUrl = getSuccessView() + "?expId=" + experimentId + "&message=" + message;
			}
		} else {
			successViewUrl = getSuccessView() + "?expId=" + experimentId + "&message=" + message;
		}
		return successViewUrl;
	}


	public String getCageView() {
		return cageView;
	}

}
