/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.abr.controllers;
import java.util.Collection;
import java.util.HashMap;
import java.util.Map;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.servlet.ModelAndView;
import uk.ac.sanger.mig.abr.MouseAbrListViewSearchBean;
import uk.ac.sanger.mig.abr.services.MouseAbrService;
import uk.ac.sanger.mig.abr.views.MouseAbrListView;
import uk.ac.sanger.mig.common.AbstractSearchFormController;


public class SearchAbrMiceController extends AbstractSearchFormController {

	private MouseAbrService mouseAbrService;


	public void setMouseAbrService(MouseAbrService mouseAbrService) {
		this.mouseAbrService = mouseAbrService;
	}


	@Override
	protected ModelAndView onSearch(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		MouseAbrListViewSearchBean searchBean = (MouseAbrListViewSearchBean)command;
		searchBean.setQueryName("searchAbrExp");
		Map<String, Object> model = new HashMap<String, Object>();
		Collection<MouseAbrListView> abrMiceViews = mouseAbrService.search(searchBean);
		model.put("abrMiceExp", abrMiceViews);

		return showForm(request, errors, getSuccessView(), model);
	}

	@Override
	protected Map<String, Object> referenceData(HttpServletRequest request, Object command, Errors errors) throws Exception {

		Map<String, Object> referenceData = new HashMap<String, Object>();

		String[] statuses  = new String[2];
		statuses[0] = "In Process";
		statuses[1] = "Completed";

		String[] wildtypes  = new String[5];
		wildtypes[0] = "+/+";
		wildtypes[1] = "-/-";
		wildtypes[2] = "+/-";
		wildtypes[3] = "-/+";
		wildtypes[4] = "?";

		String[] include = new String[2];
		include[0]="Yes";
		include[1]="No";



		referenceData.put("statuses", statuses);
		referenceData.put("wildtypes", wildtypes);
		referenceData.put("include", include);

		return referenceData;
	}
}
