/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


package uk.ac.sanger.mig.abr.controllers;
import java.util.Collection;
import java.util.HashMap;
import java.util.Map;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.ParameterizableViewController;
import ChartDirector.BaseChart;

import uk.ac.sanger.mig.abr.dao.rowmappers.AbrThresholdLineData;
import uk.ac.sanger.mig.abr.graph.AbrLineChart;
import uk.ac.sanger.mig.abr.graph.AbrPipelineGraph;
import uk.ac.sanger.mig.abr.services.MouseAbrService;
import uk.ac.sanger.mig.alleles.Allele;
import uk.ac.sanger.mig.alleles.services.AlleleService;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.mousetracking.CohortPipelineDictionary;
import uk.ac.sanger.mig.reporting.ChartDataSearchBean;
import uk.ac.sanger.mig.reporting.ChartDisplay;
import uk.ac.sanger.mig.reporting.DrawableChart;
import uk.ac.sanger.mig.reporting.GraphMetaData;
import uk.ac.sanger.mig.reporting.Range;
import uk.ac.sanger.mig.reporting.RepPageSubgroup;
import uk.ac.sanger.mig.reporting.services.GraphMetaDataService;
import uk.ac.sanger.mig.reporting.services.LineRangeService;
import uk.ac.sanger.mig.reporting.services.RepPageSubgroupService;

public class ViewABRGraphsController extends ParameterizableViewController {

	private RepPageSubgroupService repPageSubgroupService;
	private AlleleService alleleService;
	private GraphMetaDataService graphMetaDataService;
	private LineRangeService lineRangeService;
	private MouseAbrService abrService;
	private String errorView;


	public void setErrorView(String errorView) {
		this.errorView = errorView;
	}

	protected ModelAndView handleRequestInternal(HttpServletRequest request, HttpServletResponse response) throws Exception {


		Long alleleId = ServletRequestUtils.getRequiredLongParameter(request, "alleleId");
		Map<String,Object> model = new HashMap<String,Object>();
		AbrPipelineGraph mgpGraph = null;
		AbrPipelineGraph t27Graph = null;

		ChartDataSearchBean searchBean = new ChartDataSearchBean();
		ChartDisplay data = new AbrThresholdLineData();
		searchBean.setAlleleId(alleleId);

		GraphMetaData g = graphMetaDataService.fetchById(MouseAbrService.ABR_GRAPH_METADATA_ID, null);
		searchBean.setPipelineId(CohortPipelineDictionary.MGP_PIPELINE2);
		data = abrService.fetchAbrChartData(searchBean);
		if(data != null && data.getData().size()>0){
			try{
				mgpGraph = new AbrPipelineGraph(data,"MGP Pipeline 2");

				Long strainId = getStrainIdFromChartData(data.getData());
				if(strainId != null) {
					Collection<? extends Range> ranges = null;
					ranges = lineRangeService.fetchByMetaDataStrainPipelineId(g.getId(),strainId,CohortPipelineDictionary.MGP_PIPELINE2);

					data.setRefRange(ranges);
					data.setStatBackgroundId(g.getStatBackgroundId());
					data.setTitle(g.getTitle());
					data.setXAxisTitle(g.getXaxisTitle());
					data.setYAxisTitle(g.getYaxisTitle());
					AbrLineChart chart = new AbrLineChart(getServletContext(),data,g);
					BaseChart bc = chart.getChart();

					// make the image.
					bc.makeSession(request, "linechart_"+CohortPipelineDictionary.MGP_PIPELINE2);
					String imageMap = bc.getHTMLImageMap("", "", "title='{field0}  [{value}] '");

					model.put("imageMap2", imageMap);
					model.put("graphIdP2",CohortPipelineDictionary.MGP_PIPELINE2);
				}
			}catch(RuntimeException exception){
				return new ModelAndView(errorView);
			}
		}
		model.put("ages", abrService.fetchGraphAges(alleleId,CohortPipelineDictionary.MGP_PIPELINE2));
		searchBean.setPipelineId(CohortPipelineDictionary.T27_PIPELINE);
		data = abrService.fetchAbrChartData(searchBean);
		if(data != null && data.getData().size()>0){
			try{
				t27Graph = new AbrPipelineGraph(data,"T27 Pipeline");

				Long strainId = getStrainIdFromChartData(data.getData());
				if(strainId != null) {
					Collection<? extends Range> ranges = null;

					ranges = lineRangeService.fetchByMetaDataStrainPipelineId(g.getId(),strainId, CohortPipelineDictionary.T27_PIPELINE);

					data.setRefRange(ranges);
					data.setStatBackgroundId(g.getStatBackgroundId());
					data.setTitle(g.getTitle());
					data.setXAxisTitle(g.getXaxisTitle());
					data.setYAxisTitle(g.getYaxisTitle());
					AbrLineChart chart = new AbrLineChart(getServletContext(),data,g);
					BaseChart bc = chart.getChart();

					// make the image.
					bc.makeSession(request, "linechart_"+CohortPipelineDictionary.T27_PIPELINE);

					String imageMap = bc.getHTMLImageMap("", "", "title='{field0}  [{value}] '");
					model.put("imageMap27", imageMap);
					model.put("graphIdP27",13L);
				}
			}catch(RuntimeException exception){
				return new ModelAndView(errorView);
			}
		}
		model.put("mgpGraph", mgpGraph);
		model.put("t27Graph", t27Graph);
		RepPageSubgroup abrsubgroup  = repPageSubgroupService.fetchById(MouseAbrService.ABR_SUBGROUP_ID, null);
		model.put("abr",abrsubgroup);
		model.put("alleleId",alleleId);
		Allele allele = alleleService.fetchById(alleleId, ComponentMap.of(Allele.Component.GENE));
		model.put("allele", allele.getHtmlAlleleSymbol());
		model.put("gene", allele.getMigGene().getPrimaryName());

		return new ModelAndView(getViewName(), model);

	}

	private Long getStrainIdFromChartData(Collection<DrawableChart> data) {

		for(DrawableChart s : data) {
			return s.getStrainId();
		}
		return null;
	}

	public void setGraphMetaDataService(GraphMetaDataService graphMetaDataService) {
		this.graphMetaDataService = graphMetaDataService;
	}

	public void setLineRangeService(LineRangeService lineRangeService) {
		this.lineRangeService = lineRangeService;
	}

	public void setAlleleService(AlleleService alleleService) {
		this.alleleService = alleleService;
	}

	public void setRepPageSubgroupService(
			RepPageSubgroupService repPageSubgroupService) {
		this.repPageSubgroupService = repPageSubgroupService;
	}

	public void setAbrService(MouseAbrService abrService) {
		this.abrService = abrService;
	}
}




