/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.abr.dao;
import java.util.ArrayList;
import java.util.Collection;
import uk.ac.sanger.mig.abr.AbrCohortSetListViewSearchBean;
import uk.ac.sanger.mig.abr.views.AbrCohortSetListView;
import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.common.PaginatedSearchUtils;

import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;


public class AbrCohortSetViewDaoSpringImpl extends AbstractDaoSpringImpl<AbrCohortSetListView> implements AbrCohortSetViewDao {
	private PaginatedSearchUtils<AbrCohortSetListView>	listPaginator;

	public void setListPaginator(PaginatedSearchUtils<AbrCohortSetListView> listPaginator) {
		this.listPaginator = listPaginator;
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, AbrCohortSetListView abrCohortSetView) {
		sql.addStringParam(abrCohortSetView.getHtmlAlleleSymbol(), "HTML_ALLELE_SYMBOL");
		sql.addStringParam(abrCohortSetView.getGeneName(), "GENE_NAME");
		sql.addLongParam(abrCohortSetView.getAlleleId(), "ALLELE_ID");
		sql.addIntParam(abrCohortSetView.getMicecount(), "MICECOUNT");
		sql.addIntParam(abrCohortSetView.getMicecountI(), "MICECOUNT_I");
		sql.addLongParam(abrCohortSetView.getId(), "ID");
	}

	public Collection<AbrCohortSetListView> search(AbrCohortSetListViewSearchBean bean) {
		Collection<Object> bindVariables = new ArrayList<Object>();
		String sql = constructSearchSql(bean, bindVariables, this.getTableName());
		return listPaginator.fetchSearchResults(sql, bindVariables, bean, this.getRowMapper());
	}

	private String constructSearchSql(AbrCohortSetListViewSearchBean bean, Collection<Object> bindVariables,
			String tableName) {

		String selectSql = " select v.* ";
		String fromSql = " from " + tableName + " v ";
		String whereSql = " where 1=1 ";

		if(bean.getGeneAlleleName() != null){
			whereSql += " and lower(v.HTML_ALLELE_SYMBOL) like lower('%'||?||'%')";
			bindVariables.add(bean.getGeneAlleleName());
		}

		String orderBySql = "";
		if (bean.getOrderBy() != null && bean.getOrderBy().length() > 0) {
			orderBySql += " order by " + bean.getOrderBy();
			if (bean.isOrderDesc()) {
				orderBySql += " desc ";
			}
		}

		String sql = selectSql + fromSql + whereSql + orderBySql;
		logger.debug(sql);

		return sql;
	}
}