/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.abr.dao;

import java.util.Collection;

import uk.ac.sanger.mig.abr.FreqExperiment;
import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.mousetracking.Cage;

public class FreqExperimentDaoSpringImpl extends AbstractDaoSpringImpl<FreqExperiment> implements FreqExperimentDao {


	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, FreqExperiment feqExperiment) {
		sql.addLongParam(feqExperiment.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(feqExperiment.getCreatedDate(), "CREATED_DATE");
		sql.addStringParam(feqExperiment.getEditedBy(), "EDITED_BY");
		sql.addDateParam(feqExperiment.getEditDate(), "EDIT_DATE");
		sql.addLongParam(feqExperiment.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(feqExperiment.getPhnExperimentId(), "PHN_EXPERIMENT_ID");
		sql.addIntParam(feqExperiment.getFrequence(), "FREQUENCE");
		sql.addIntParam(feqExperiment.getThreshold(), "THRESHOLD");
		sql.addLongParam(feqExperiment.getId(), "ID");
	}

	public Collection<FreqExperiment> fetchByPhnExperimentId(Long experimentId) {
		String sql = "select * from aud_freq_experiment where phn_experiment_id = ? order by id";
		return fetchCollection(sql, experimentId);
	}

}