/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.abr.dao;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.common.PaginatedSearchUtils;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.reporting.ChartDataSearchBean;
import uk.ac.sanger.mig.reporting.ChartDisplay;

import uk.ac.sanger.mig.abr.MouseAbrListViewSearchBean;
import uk.ac.sanger.mig.abr.dao.rowmappers.AbrThresholdLineData;
import uk.ac.sanger.mig.abr.views.MouseAbrListView;

public class MouseAbrViewDaoSpringImpl extends AbstractDaoSpringImpl<MouseAbrListView> implements MouseAbrViewDao {
	private PaginatedSearchUtils<MouseAbrListView>	listPaginator;
	private String									graphTableName;


	public void setGraphTableName(String graphTableName) {
		this.graphTableName = graphTableName;
	}


	public void setListPaginator(PaginatedSearchUtils<MouseAbrListView> listPaginator) {
		this.listPaginator = listPaginator;
	}


	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, MouseAbrListView mouseAbrView) {
		sql.addLongParam(mouseAbrView.getExperimentId(), "ID");
		sql.addLongParam(mouseAbrView.getMouseId(), "MOUSE_ID");
		sql.addStringParam(mouseAbrView.getAnaesthetic(), "ANAESTHETIC");
		sql.addFloatParam(mouseAbrView.getAnaestheticDose(), "ANAESTHETIC_DOSE");
		sql.addStringParam(mouseAbrView.getAnaestheticRoute(), "ANAESTHETIC_ROUTE");
		sql.addStringParam(mouseAbrView.getInductionTime(), "INDUCTION_TIME");
		sql.addDateParam(mouseAbrView.getExperimentDate(), "EXPERIMENT_DATE");
		sql.addFloatParam(mouseAbrView.getWeight(), "WEIGHT");
		sql.addStringParam(mouseAbrView.getIncludeExperiment(), "INCLUDE_EXPERIMENT");
		sql.addStringParam(mouseAbrView.getComments(), "COMMENTS");
		sql.addStringParam(mouseAbrView.getMouseBarcode(), "MOUSE_BARCODE");
		sql.addDateParam(mouseAbrView.getMouseBirthDate(), "MOUSE_BIRTH_DATE");
		sql.addStringParam(mouseAbrView.getRfidTag(), "RFID_TAG");
		sql.addStringParam(mouseAbrView.getEarClip(), "EAR_CLIP");
		sql.addStringParam(mouseAbrView.getGenotype(), "GENOTYPE");
		sql.addStringParam(mouseAbrView.getShortAlleleSymbol(), "SHORT_ALLELE_SYMBOL");
		sql.addStringParam(mouseAbrView.getOfficialNameSuperscript(), "OFFICIAL_NAME_SUPERSCRIPT");
		sql.addStringParam(mouseAbrView.getColonyPrefix(), "COLONY_PREFIX");
		sql.addStringParam(mouseAbrView.getGenePrimaryName(), "GENE_PRIMARY_NAME");
		sql.addLongParam(mouseAbrView.getPersonalLicenceId(), "PERSONAL_LICENCE_ID");
		sql.addStringParam(mouseAbrView.getPilNumber(), "PIL_NUMBER");
		sql.addLongParam(mouseAbrView.getUserId(), "USER_ID");
		sql.addStringParam(mouseAbrView.getUserName(), "USER_NAME");
		sql.addLongParam(mouseAbrView.getProjectLicenceId(), "PROJECT_LICENCE_ID");
		sql.addStringParam(mouseAbrView.getPplNumber(), "PPL_NUMBER");
		sql.addStringParam(mouseAbrView.getProtocolCode(), "PROTOCOL_CODE");
		sql.addStringParam(mouseAbrView.getProcessStatus(), "PROCESS_STATUS");
		sql.addLongParam(mouseAbrView.getGenotypeId(), "GENOTYPE_ID");
		sql.addDoubleParam(mouseAbrView.getAgeInWeeks(), "AGE_IN_WEEKS");
		sql.addLongParam(mouseAbrView.getBinaryFileId(), "BINARY_FILE_ID");
	}


	public Collection<MouseAbrListView> search(MouseAbrListViewSearchBean bean) {
		Collection<Object> bindVariables = new ArrayList<Object>();
		String sql = constructSearchSql(bean, bindVariables, this.getTableName());
		return listPaginator.fetchSearchResults(sql, bindVariables, bean, this.getRowMapper());
	}


	public ChartDisplay fetchAbrChartData(ChartDataSearchBean bean) {

		Collection<Object> bindVariables = new ArrayList<Object>();

		String selectSql = "select experiment_id, mouse_name,gender_id, genotype_id, genotype, "
				+ "strain_id, plot_column, x_label as xLabel,age_in_weeks from " + this.graphTableName;

		String whereSql = " where 1=1";

		if (!bean.getAlleleId().equals("")) {

			whereSql += " and allele_id = ? ";
			bindVariables.add(bean.getAlleleId());
		}

		if (!bean.getPipelineId().equals("")) {
			whereSql += " and pipeline_id = ? ";
			bindVariables.add(bean.getPipelineId());
		}

		whereSql += " and include = 'Yes' and process_status='Completed'";
		String orderBySql = "order by genotype_id,gender_id,mouse_name,xlabel";

		String sql = selectSql + whereSql + orderBySql;

		AbrThresholdLineData data = new AbrThresholdLineData();
		getJdbcTemplate().query(sql, bindVariables.toArray(), data);
		return data;
	}


	private String constructSearchSql(MouseAbrListViewSearchBean bean, Collection<Object> bindVariables, String tableName) {

		String selectSql = " select m.* ";
		String fromSql = " from " + tableName + " m ";
		String whereSql = " where 1=1 ";

		// experiment ID

		if (bean.getExperimentId() != null) {
			whereSql += " and m.id = ? ";
			bindVariables.add(bean.getExperimentId());
		}
		// mouse ID
		if (bean.getMouseId() != null) {
			whereSql += " and m.mouse_id = ? ";
			bindVariables.add(bean.getMouseId());
		}

		if (bean.getMouseBarcode() != null) {
			whereSql += " and m.mouse_barcode = ? ";
			bindVariables.add(bean.getMouseBarcode());
		}

		if (bean.getIncludeExperiment() != null) {
			whereSql += " and m.include_experiment = ? ";
			bindVariables.add(bean.getIncludeExperiment());
		}

		if (bean.getMouseName() != null) {
			whereSql += " and lower(m.mouse_name) = lower(?) ";
			bindVariables.add(bean.getMouseName());
		}

		if (bean.getStatus() != null && !bean.getStatus().equals("")) {
			whereSql += " and m.process_status = ? ";
			bindVariables.add(bean.getStatus());
		}

		if (bean.getColonyPrefix() != null) {
			whereSql += " and lower(m.colony_prefix) = lower(?) ";
			bindVariables.add(bean.getColonyPrefix());
		}

		if (bean.getGenePrimaryName() != null) {
			whereSql += " and lower(m.gene_primary_name) = lower(?) ";
			bindVariables.add(bean.getGenePrimaryName());
		}

		if (bean.getExperimentDate() != null) {
			whereSql += " and m.experiment_date = ? ";
			bindVariables.add(defaultDateFormat.format(bean.getExperimentDate()));
		}
		if (bean.getWildtype() != null) {
			whereSql += " and m.simple_genotype = ? ";
			bindVariables.add(bean.getWildtype());
		}

		String orderBySql = "";

		if (bean.getOrderBy() != null && bean.getOrderBy().length() > 0) {
			orderBySql += " order by " + bean.getOrderBy();
			if (bean.isOrderDesc()) {
				orderBySql += " desc ";
			}
		}

		String sql = selectSql + fromSql + whereSql + orderBySql;

		logger.debug(sql);

		return sql;
	}


	public MouseAbrListView fetchAbrMouseById(Long mouseId) {
		String sql = " select v.* from  phn_abr_mouse_view v where v.mouse_id=?";
		return fetchOne(sql, mouseId);
	}


	public Collection<MouseAbrListView> fetchAbrAges(Long alleleId, Long pipelineId) {

		String sql = "select V.* from PHN_ABR_EXPERIMENT_VW v,mts_cohort_set s,MTS_COHORT_SET_ELEMENT e,MTS_COHORT_MOUSE m,mts_cohort c "
				+ "where S.ALLELE_ID = ? and e.set_id = s.id and e.cohort_id = M.COHORT_ID "
				+ "and m.cohort_id = c.id and M.MOUSE_ID=V.MOUSE_ID and C.PIPELINE_DICT_ID = ? and V.INCLUDE_EXPERIMENT='Yes' "
				+ "and V.PROCESS_STATUS='Completed'";

		Collection<MouseAbrListView> expList = getSimpleJdbcTemplate().query(sql, this.getRowMapper(), alleleId, pipelineId);

		return (expList != null) ? expList : new ArrayList<MouseAbrListView>();

	}
}
