/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.abr.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.abr.views.MouseAbrListView;


public class MouseAbrListViewRowMapper implements ParameterizedRowMapper<MouseAbrListView> {

	public MouseAbrListView mapRow(ResultSet rs, int rowNum) throws SQLException {

		MouseAbrListView mouseAbrView = new MouseAbrListView();


		mouseAbrView.setExperimentId(rs.getLong("ID"));
		if(rs.wasNull())mouseAbrView.setExperimentId(null);

		mouseAbrView.setMouseId(rs.getLong("MOUSE_ID"));
		if(rs.wasNull())mouseAbrView.setMouseId(null);

		mouseAbrView.setAnaesthetic(rs.getString("ANAESTHETIC"));

		mouseAbrView.setAnaestheticDose(rs.getFloat("ANAESTHETIC_DOSE"));
		if(rs.wasNull()) mouseAbrView.setAnaestheticDose(null);

		mouseAbrView.setAnaestheticRoute(rs.getString("ANAESTHETIC_ROUTE"));

		mouseAbrView.setInductionTime(rs.getString("INDUCTION_TIME"));

		mouseAbrView.setExperimentDate(rs.getTimestamp("EXPERIMENT_DATE"));

		mouseAbrView.setWeight(rs.getFloat("WEIGHT"));
		if(rs.wasNull()) mouseAbrView.setWeight(null);

		mouseAbrView.setIncludeExperiment(rs.getString("INCLUDE_EXPERIMENT"));

		mouseAbrView.setComments(rs.getString("COMMENTS"));

		mouseAbrView.setMouseBarcode(rs.getString("MOUSE_BARCODE"));

		mouseAbrView.setMouseBirthDate(rs.getTimestamp("MOUSE_BIRTH_DATE"));

		mouseAbrView.setRfidTag(rs.getString("RFID_TAG"));

		mouseAbrView.setSex(rs.getString("MOUSE_GENDER"));

		mouseAbrView.setEarClip(rs.getString("EAR_CLIP"));

		mouseAbrView.setGenotype(rs.getString("GENOTYPE"));

		mouseAbrView.setShortAlleleSymbol(rs.getString("SHORT_ALLELE_SYMBOL"));

		mouseAbrView.setOfficialNameSuperscript(rs.getString("OFFICIAL_NAME_SUPERSCRIPT"));

		mouseAbrView.setColonyPrefix(rs.getString("COLONY_PREFIX"));

		mouseAbrView.setGenePrimaryName(rs.getString("GENE_PRIMARY_NAME"));

		mouseAbrView.setPersonalLicenceId(rs.getLong("PERSONAL_LICENCE_ID"));
		if(rs.wasNull()) mouseAbrView.setPersonalLicenceId(null);

		mouseAbrView.setPilNumber(rs.getString("PIL_NUMBER"));

		mouseAbrView.setUserId(rs.getLong("USER_ID"));
		if(rs.wasNull()) mouseAbrView.setUserId(null);

		mouseAbrView.setUserName(rs.getString("USER_NAME"));

		mouseAbrView.setProjectLicenceId(rs.getLong("PROJECT_LICENCE_ID"));
		if(rs.wasNull()) mouseAbrView.setProjectLicenceId(null);

		mouseAbrView.setPplNumber(rs.getString("PPL_NUMBER"));

		mouseAbrView.setProtocolCode(rs.getString("PROTOCOL_CODE"));

		mouseAbrView.setProcessStatus(rs.getString("PROCESS_STATUS"));

		mouseAbrView.setMouseName(rs.getString("MOUSE_NAME"));

		mouseAbrView.setFileId(rs.getLong("MOUSE_FILE_ID"));
		if(rs.wasNull())mouseAbrView.setFileId(null);

		mouseAbrView.setCalibrationChartId(rs.getLong("MOUSE_CALI_CHART_ID"));
		if(rs.wasNull())mouseAbrView.setCalibrationChartId(null);

		mouseAbrView.setClickChartId(rs.getLong("MOUSE_CLICK_CHART_ID"));
		if(rs.wasNull())mouseAbrView.setClickChartId(null);

		mouseAbrView.setUserComments(rs.getString("USER_COMMENTS"));

		mouseAbrView.setGenotypeId(rs.getLong("GENOTYPE_ID"));
		if(rs.wasNull())mouseAbrView.setGenotypeId(null);

		mouseAbrView.setAgeInWeeks(rs.getDouble("AGE_IN_WEEKS"));
		if(rs.wasNull())mouseAbrView.setAgeInWeeks(null);

		mouseAbrView.setBinaryFileId(rs.getLong("BINARY_FILE_ID"));

		return mouseAbrView;

	}
}