package uk.ac.sanger.mig.abr.forms;

import java.util.ArrayList;
import java.util.Collection;

import org.springframework.web.multipart.MultipartFile;

import uk.ac.sanger.mig.abr.parser.FileParser;
import uk.ac.sanger.mig.filesupport.BinaryFile;
import uk.ac.sanger.mig.filesupport.forms.FileUploadForm;
import uk.ac.sanger.mig.phenotyping.datacapture.Experiment;
import uk.ac.sanger.mig.phenotyping.datacapture.Observation;
import uk.ac.sanger.mig.phenotyping.datacapture.RequiredObservation;
import uk.ac.sanger.mig.phenotyping.datacapture.StdOperatingProcedure;
import uk.ac.sanger.mig.phenotyping.datacapture.UploadMapping;

public class AbrFileUploadForm extends FileUploadForm {

	private StdOperatingProcedure		sop;
	private FileParser					fileParser;
	private Collection<UploadMapping>	uploadMappings;
	private Experiment					experiment;
	private Collection<Observation>		observations;
	private Experiment					previouslyUploadedExperiment;
	private BinaryFile					previouslyUploadedBinaryFile;
	private boolean						cageView;
	private String						message;


	public boolean isCageView() {
		return cageView;
	}


	public void setCageView(boolean cageView) {
		this.cageView = cageView;
	}


	public AbrFileUploadForm() {
		super();
		this.experiment = new Experiment();
		this.experiment.setComplete(false);
		this.observations = new ArrayList<Observation>();
	}


	/**
	 * Overrides the FileUploadForm method to set the file description as the new binary file is
	 * instantiated.
	 */
	@Override
	public void setUploadFile(MultipartFile file) {
		super.setUploadFile(file);
		if (this.getBinaryFile() != null)
			this.getBinaryFile().setFileDescription("ABR Experiment file");
	}


	public StdOperatingProcedure getSop() {
		return sop;
	}


	public void setSop(StdOperatingProcedure sop) {
		this.sop = sop;
	}


	public FileParser getFileParser() {
		return fileParser;
	}


	public void setFileParser(FileParser fileParser) {
		this.fileParser = fileParser;
	}


	public Collection<RequiredObservation> getRequiredObservations() {
		return this.sop.getRequiredObservations();
	}


	public void setExperiment(Experiment experiment) {
		this.experiment = experiment;
	}


	public Experiment getExperiment() {
		return experiment;
	}


	/**
	 * @return the observations
	 */
	public Collection<Observation> getObservations() {
		return observations;
	}


	/**
	 * @param observations
	 *            the observations to set
	 */
	public void setObservations(Collection<Observation> observations) {
		this.observations = observations;
	}


	public void addObservation(Observation observation) {
		this.observations.add(observation);
	}


	public Collection<UploadMapping> getUploadMappings() {
		return uploadMappings;
	}


	public void setUploadMappings(Collection<UploadMapping> uploadMappings) {
		this.uploadMappings = uploadMappings;
	}


	public Experiment getPreviouslyUploadedExperiment() {
		return previouslyUploadedExperiment;
	}


	public void setPreviouslyUploadedExperiment(Experiment previouslyUploadedExperiment) {
		this.previouslyUploadedExperiment = previouslyUploadedExperiment;
	}


	public BinaryFile getPreviouslyUploadedBinaryFile() {
		return previouslyUploadedBinaryFile;
	}


	public void setPreviouslyUploadedBinaryFile(BinaryFile previouslyUploadedBinaryFile) {
		this.previouslyUploadedBinaryFile = previouslyUploadedBinaryFile;
	}


	public String getMessage() {
		return message;
	}


	public void setMessage(String message) {
		this.message = message;
	}

}
