package uk.ac.sanger.mig.abr.graph;
/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

import java.util.ArrayList;
import java.util.HashMap;

import javax.servlet.ServletContext;

import ChartDirector.BoxWhiskerLayer;
import ChartDirector.Chart;
import ChartDirector.LineLayer;
import ChartDirector.MultiChart;
import ChartDirector.XYChart;

import uk.ac.sanger.mig.mousetracking.GenotypeDictionary;
import uk.ac.sanger.mig.reporting.ChartDisplay;
import uk.ac.sanger.mig.reporting.GraphMetaData;
import uk.ac.sanger.mig.reporting.services.ChartUtils;

/**
 * Class to generate Line grahs.
 * Produces 4 graphs split by gender. One averaged with SEM whiskers and
 * one with the raw data lines for each mouse.
 *
 * @author mng
 *
 */
public class AbrLineChart {

	// Display totals or male/female split.
	private enum DISPLAY_MODE {
		TOTAL,
		SPLIT
	};
	public final static int X_GAP = 410;
	public final static int Y_GAP = 415;
	private DISPLAY_MODE displayMode =  DISPLAY_MODE.SPLIT;
	private ServletContext servletContext;
	private MultiChart chart;


	public MultiChart getChart() {
		return chart;
	}


	/**
	 * No excuses, this is nasty, invloves lots of mappings in the utils class to get rows from the db
	 * back to double[] at the correct xAxis index.
	 *
	 * @param servletContext
	 * @param displayData
	 * @param g
	 */
	public AbrLineChart(ServletContext servletContext, ChartDisplay displayData, GraphMetaData g) {

		ChartUtils utils = new ChartUtils(displayData);
		this.servletContext = servletContext;
		if(displayMode ==  DISPLAY_MODE.SPLIT) {
			String[] xLabels = utils.getUniqueXLabels(g.isTimeAxis());
			String hetAllCount = utils.abrDataSetCount(GenotypeDictionary.HETEROZYGOUS);
			String homAllCount = utils.abrDataSetCount(GenotypeDictionary.HOMOZYGOUS);
			String wtAllCount = utils.abrDataSetCount(GenotypeDictionary.WILDTYPE);

			/**
			 * RAW Data : Each mouse plotted as a single line +  average data in the middle
			 */
			//extrem case: 3 details diagram and 1 average diagram
			if(Integer.parseInt(hetAllCount) >0 && Integer.parseInt(homAllCount) >0 && Integer.parseInt(wtAllCount) >0){
				chart = new MultiChart(X_GAP*3,830);
			}else{
				chart = new MultiChart(X_GAP*3-10,415);
			}
			chart.setBackground(0x0f0f0f);
			chart.setTransparentColor(0x0f0f0f);
			createStandChart(hetAllCount, homAllCount, wtAllCount, displayData, xLabels, g);
		}else if(displayMode == DISPLAY_MODE.TOTAL){
			chart = new MultiChart(560, 480);
			// make a total chart.
			//chart.addChart();
		}
	}

	public void createStandChart(String hetAllCount, String homAllCount, String wtAllCount, ChartDisplay displayData, String[] xLabels, GraphMetaData g){

		ChartUtils utils = new ChartUtils(displayData);
		int wtCount = Integer.parseInt(wtAllCount);
		int hetCount = Integer.parseInt(hetAllCount);
		int homCount = Integer.parseInt(homAllCount);

		if(wtCount>0){
			int i = 0;
			if(homCount>0 && hetCount>0){
				chart.addChart(i*X_GAP, 0, createMiceLineChart("Mutant - Hom", displayData.getXAxisTitle(),
						displayData.getYAxisTitle(), xLabels,
						homAllCount,
						utils.fetchAbrLineData(GenotypeDictionary.HOMOZYGOUS, false),
						utils.fetchAbrLineData(GenotypeDictionary.HOMOZYGOUS,true),
						utils.fetchAbrLineRangeData(),
						utils.getAbrStandardError(GenotypeDictionary.HOMOZYGOUS,homCount),
						g.isXPadding(), g.isTimeAxis(), g.isScientificYAxis(),g.isXAxisAsLabels(), GenotypeDictionary.HOMOZYGOUS)
				);
				i++;
				chart.addChart(i*X_GAP, 0, createAverageLineChart("Mutant and Control", displayData.getXAxisTitle(),
						displayData.getYAxisTitle(), xLabels,
						wtAllCount,
						hetAllCount,
						homAllCount,
						utils.fetchAbrLineData(GenotypeDictionary.WILDTYPE, true),
						utils.fetchAbrLineData(GenotypeDictionary.HETEROZYGOUS, true),
						utils.fetchAbrLineData(GenotypeDictionary.HOMOZYGOUS, true),
						utils.fetchAbrLineRangeData(),
						utils.getAbrStandardError(GenotypeDictionary.WILDTYPE,wtCount),
						utils.getAbrStandardError(GenotypeDictionary.HETEROZYGOUS,hetCount),
						utils.getAbrStandardError(GenotypeDictionary.HOMOZYGOUS,homCount),
						g.isXPadding(), g.isTimeAxis(), g.isScientificYAxis(),g.isXAxisAsLabels())
				);
				i++;
				chart.addChart(i*X_GAP, 0, createMiceLineChart("Control", displayData.getXAxisTitle(),
						displayData.getYAxisTitle(), xLabels,
						wtAllCount,
						utils.fetchAbrLineData(GenotypeDictionary.WILDTYPE, false),
						utils.fetchAbrLineData(GenotypeDictionary.WILDTYPE, true),
						utils.fetchAbrLineRangeData(),
						utils.getAbrStandardError(GenotypeDictionary.WILDTYPE,wtCount),
						g.isXPadding(), g.isTimeAxis(), g.isScientificYAxis(),g.isXAxisAsLabels(), GenotypeDictionary.WILDTYPE)
				);

				chart.addChart(0, Y_GAP, createMiceLineChart("Mutant - Het", displayData.getXAxisTitle(),
						displayData.getYAxisTitle(), xLabels,
						hetAllCount,
						utils.fetchAbrLineData(GenotypeDictionary.HETEROZYGOUS,false),
						utils.fetchAbrLineData(GenotypeDictionary.HETEROZYGOUS,true),
						utils.fetchAbrLineRangeData(),
						utils.getAbrStandardError(GenotypeDictionary.HETEROZYGOUS,hetCount),
						g.isXPadding(), g.isTimeAxis(), g.isScientificYAxis(),g.isXAxisAsLabels(), GenotypeDictionary.HETEROZYGOUS)
				);

			}else{
				if(homCount>0){
					chart.addChart(i*X_GAP, 0, createMiceLineChart("Mutant", displayData.getXAxisTitle(),
							displayData.getYAxisTitle(), xLabels,
							homAllCount,
							utils.fetchAbrLineData(GenotypeDictionary.HOMOZYGOUS,false),
							utils.fetchAbrLineData(GenotypeDictionary.HOMOZYGOUS,true),
							utils.fetchAbrLineRangeData(),
							utils.getAbrStandardError(GenotypeDictionary.HOMOZYGOUS,homCount),
							g.isXPadding(), g.isTimeAxis(), g.isScientificYAxis(),g.isXAxisAsLabels(), GenotypeDictionary.HOMOZYGOUS)
					);
					i++;
				}
				if(hetCount>0){
					chart.addChart(i*X_GAP, 0, createMiceLineChart("Mutant", displayData.getXAxisTitle(),
							displayData.getYAxisTitle(), xLabels,
							hetAllCount,
							utils.fetchAbrLineData(GenotypeDictionary.HETEROZYGOUS,false),
							utils.fetchAbrLineData(GenotypeDictionary.HETEROZYGOUS,true),
							utils.fetchAbrLineRangeData(),
							utils.getAbrStandardError(GenotypeDictionary.HETEROZYGOUS,hetCount),
							g.isXPadding(), g.isTimeAxis(), g.isScientificYAxis(),g.isXAxisAsLabels(), GenotypeDictionary.HETEROZYGOUS)
					);
					i++;
				}
				chart.addChart(i*X_GAP, 0, createAverageLineChart("Mutant and Control", displayData.getXAxisTitle(),
						displayData.getYAxisTitle(), xLabels,
						wtAllCount,
						hetAllCount,
						homAllCount,
						utils.fetchAbrLineData(GenotypeDictionary.WILDTYPE,true),
						utils.fetchAbrLineData(GenotypeDictionary.HETEROZYGOUS,true),
						utils.fetchAbrLineData(GenotypeDictionary.HOMOZYGOUS,true),
						utils.fetchAbrLineRangeData(),
						utils.getAbrStandardError(GenotypeDictionary.WILDTYPE,wtCount),
						utils.getAbrStandardError(GenotypeDictionary.HETEROZYGOUS,hetCount),
						utils.getAbrStandardError(GenotypeDictionary.HOMOZYGOUS,homCount),
						g.isXPadding(), g.isTimeAxis(), g.isScientificYAxis(),g.isXAxisAsLabels())
				);
				i++;

				chart.addChart(i*X_GAP, 0, createMiceLineChart("Control", displayData.getXAxisTitle(),
						displayData.getYAxisTitle(), xLabels,
						wtAllCount,
						utils.fetchAbrLineData(GenotypeDictionary.WILDTYPE, false),
						utils.fetchAbrLineData(GenotypeDictionary.WILDTYPE, true),
						utils.fetchAbrLineRangeData(),
						utils.getAbrStandardError(GenotypeDictionary.WILDTYPE,wtCount),
						g.isXPadding(), g.isTimeAxis(), g.isScientificYAxis(),g.isXAxisAsLabels(),GenotypeDictionary.WILDTYPE)
				);
			}

		}else{
			chart.addChart(0, 0, createMiceLineChart("Mutant", displayData.getXAxisTitle(),
					displayData.getYAxisTitle(), xLabels,
					homAllCount,
					utils.fetchAbrLineData(GenotypeDictionary.HOMOZYGOUS, false),
					utils.fetchAbrLineData(GenotypeDictionary.HOMOZYGOUS, true),
					utils.fetchAbrLineRangeData(),
					utils.getAbrStandardError(GenotypeDictionary.HOMOZYGOUS,homCount),
					g.isXPadding(), g.isTimeAxis(), g.isScientificYAxis(),g.isXAxisAsLabels(), GenotypeDictionary.HOMOZYGOUS)
			);

			chart.addChart(X_GAP, 0, createAverageLineChart("Mutant and Control", displayData.getXAxisTitle(),
					displayData.getYAxisTitle(), xLabels,
					wtAllCount,
					hetAllCount,
					homAllCount,
					utils.fetchAbrLineData(GenotypeDictionary.WILDTYPE, true),
					utils.fetchAbrLineData(GenotypeDictionary.HETEROZYGOUS, true),
					utils.fetchAbrLineData(GenotypeDictionary.HOMOZYGOUS, true),
					utils.fetchAbrLineRangeData(),
					utils.getAbrStandardError(GenotypeDictionary.WILDTYPE,wtCount),
					utils.getAbrStandardError(GenotypeDictionary.HETEROZYGOUS,hetCount),
					utils.getAbrStandardError(GenotypeDictionary.HOMOZYGOUS,homCount),
					g.isXPadding(), g.isTimeAxis(), g.isScientificYAxis(),g.isXAxisAsLabels())
			);

			chart.addChart(2*X_GAP, 0, createMiceLineChart("Control", displayData.getXAxisTitle(),
					displayData.getYAxisTitle(), xLabels,
					hetAllCount,
					utils.fetchAbrLineData(GenotypeDictionary.HETEROZYGOUS, false),
					utils.fetchAbrLineData(GenotypeDictionary.HETEROZYGOUS, true),
					utils.fetchAbrLineRangeData(),
					utils.getAbrStandardError(GenotypeDictionary.HETEROZYGOUS,hetCount),
					g.isXPadding(), g.isTimeAxis(), g.isScientificYAxis(),g.isXAxisAsLabels(), GenotypeDictionary.HETEROZYGOUS)
			);
		}
	}

	public XYChart createMiceLineChart(String title, String xAxis, String yAxis, String[] xLabels,
			String miceNum,
			HashMap<String,double[]> miceRawData,
			HashMap<String,double[]> miceAverageData,
			ArrayList<double[]> refRanges, ArrayList<double[]> sError,
			boolean addPadding, boolean timeAxis, boolean scientificYaxis, boolean useXAxisLabels,Long genotypeId
	)
	{
		double[] xDataFromLabels = getXDataFromLabels(xLabels);

		// create chart, grey background.
		XYChart c = new XYChart(X_GAP-10, 400, 0xffffff, 0x004869);
		// set drawing area, white background, grey axis lines.
		c.setPlotArea(55, 60, 325, 290, 0xffffff, -1, 0xbdbdbd, 0xbdbdbd, Chart.Transparent);

		// Add legend. white background, raised edges. Fake legend entries.
		String legendAxis = null;
		int lineSymbol = Chart.Cross2Symbol;
		int color = 0x000000;
		if(genotypeId.equals(GenotypeDictionary.HETEROZYGOUS)){
			legendAxis = "Het (n="+miceNum+")";
			lineSymbol = Chart.TriangleSymbol;
			color = 0x0000ff;
			c.addScatterLayer(new double[]{}, new double[]{}, legendAxis, lineSymbol, 7, 0x0000ff);
		}else if(genotypeId.equals(GenotypeDictionary.HOMOZYGOUS)){
			legendAxis = "Hom (n="+miceNum+")";
			lineSymbol = Chart.DiamondSymbol;
			color = 0xff0000;
			c.addScatterLayer(new double[]{}, new double[]{}, legendAxis, lineSymbol, 8, 0xff0000);
		}else if(genotypeId.equals(GenotypeDictionary.WILDTYPE)){
			legendAxis = "+/+ (n="+miceNum+")";
			color = 0x00ff00;
			lineSymbol = Chart.SquareSymbol;
			c.addScatterLayer(new double[]{}, new double[]{}, legendAxis, lineSymbol, 7, 0x00ff00);
		}
		c.addLegend(150, 25, false, "Arial", 10).setBackground(0xffffff, 0xffffff,0);

		// Add title, white text, black glass effect background.
		c.addTitle(title, "Arial", 15, 0xffffff).setBackground(0x004869);

		// Add sanger image to top left corner.
		//	c.addText(2, 1, "<*block,valign=absmiddle*><*img=dna.png*>" );

		// add X axis title
		c.xAxis().setTitle(xAxis, "Arial", 10);

		if(addPadding) {
			// use this only to indicate that the xAxis need not include zero.(3rd arg)
			c.xAxis().setAutoScale(0, 0, 0);
			// override the 1st/2nd args above to set left and right margins to 70px
			c.xAxis().setMargin(30, 30);
		}

		// add y axis title
		c.yAxis().setTitle(yAxis,"Arial", 10);

		if(scientificYaxis) {
			c.yAxis().setLabelFormat("{value|G}");
		}

		// set line widths and colors of the axis.
		c.xAxis().setWidth(2);
		c.yAxis().setWidth(2);
		c.xAxis().setColors(0x000000,0x8d0017,0X000000,0x8d0017);
		c.yAxis().setColors(0x000000,0x8d0017,0X000000,0x8d0017);

		c.yAxis().setLinearScale(0,100);
		c.yAxis().setMargin(0,0);

		// set the X axis labels.
		if(useXAxisLabels) {
			if(!timeAxis) {
				c.xAxis().setLabels(generateXAxisLabels(xLabels));

			}else{
				c.xAxis().setLabels(xLabels);
				if(xLabels.length > 10) {
					c.xAxis().setLabelStyle().setFontAngle(45.0);
				}
			}
		}

		// if the first dataset is not click(100), plot everything as lines
		if(!xLabels[0].equals("100")){
			if(miceRawData != null) {

				for(String mouse : miceRawData.keySet()) {
					LineLayer layer1 = c.addLineLayer();
					layer1.addDataSet(miceRawData.get(mouse), c.dashLineColor(0x000000, Chart.DashLine),legendAxis).setDataSymbol(lineSymbol, 5);
					if(!timeAxis) {layer1.setXData(xDataFromLabels);}
					layer1.setGapColor(color);
					layer1.setLegend(Chart.NoLegend);
					layer1.addExtraField(getExtraLabels(mouse,xLabels.length));// adds the mouse name for the image map.
				}
			}

			if(miceAverageData != null) {
				for(String mouse : miceAverageData.keySet()) {
					LineLayer layer1 = c.addLineLayer();
					layer1.addDataSet(miceAverageData.get(mouse), color,legendAxis).setDataSymbol(lineSymbol, 10);
					if(!timeAxis) {layer1.setXData(xDataFromLabels);}
					layer1.setGapColor(color);
					layer1.setLegend(Chart.NoLegend);
					layer1.setLineWidth(2);
					layer1.addExtraField(getExtraLabels(mouse,xLabels.length));// adds the mouse name for the image map.
				}
			}
		}else{
			int length = xDataFromLabels.length;
			double[] clickx = {xDataFromLabels[0]};
			double[] xData = new double[length-1];
			System.arraycopy(xDataFromLabels, 1, xData, 0, length-1);

			//if include the click, get rid of it from the line
			if(miceRawData != null) {

				for(String mouse : miceRawData.keySet()) {
					double[] clicky = {miceRawData.get(mouse)[0]};
					double[] lineData = new double[length-1];
					System.arraycopy(miceRawData.get(mouse), 1, lineData, 0, length-1);
					LineLayer layer1 = c.addLineLayer();
					layer1.addDataSet(lineData, c.dashLineColor(0x000000, Chart.DashLine),legendAxis).setDataSymbol(lineSymbol, 5);

					if(!timeAxis) {layer1.setXData(xData);}
					layer1.setGapColor(color);
					layer1.setLegend(Chart.NoLegend);
					layer1.addExtraField(getExtraLabels(mouse,xLabels.length));// adds the mouse name for the image map.
					c.addScatterLayer(clickx, clicky, "", lineSymbol, 5, 0x000000);

				}
			}
			if(miceAverageData != null) {
				for(String mouse : miceAverageData.keySet()) {
					double[] clicky = {miceAverageData.get(mouse)[0]};
					double[] lineDataA = new double[length-1];
					System.arraycopy(miceAverageData.get(mouse), 1, lineDataA, 0, length-1);
					LineLayer layer1 = c.addLineLayer();
					layer1.addDataSet(lineDataA, color,legendAxis).setDataSymbol(lineSymbol, 10);
					if(!timeAxis) {layer1.setXData(xData);}
					layer1.setGapColor(color);
					layer1.setLegend(Chart.NoLegend);
					layer1.setLineWidth(2);
					layer1.addExtraField(getExtraLabels(mouse,xLabels.length));// adds the mouse name for the image map.
					c.addScatterLayer(clickx, clicky, "", lineSymbol, 10, color);
				}
			}
		}
		if(refRanges != null && refRanges.size() != 0) {
			// whisker error bars.
			if(sError != null && sError.size() >0) {
				addWhiskerLayer(c,xLabels,sError.get(0),sError.get(1),color,timeAxis);
			}
		}

		return c;
	}

	public XYChart createAverageLineChart(String title, String xAxis, String yAxis, String[] xLabels,
			String numWT, String numHet, String numHom,
			HashMap<String,double[]> wt2, HashMap<String,double[]> het2, HashMap<String,double[]> hom2,
			ArrayList<double[]> refRanges, ArrayList<double[]> wtError, ArrayList<double[]> hetError, ArrayList<double[]> homError,
			boolean addPadding, boolean timeAxis, boolean scientificYaxis, boolean useXAxisLabels
	)
	{
		String legend_axis1 = "WT (n="+numWT+")";
		String legend_axis2 = "Het (n="+numHet+")";
		String legend_axis3 = "Hom (n="+numHom+")";

		double[] xDataFromLabels = getXDataFromLabels(xLabels);

		XYChart c = new XYChart(X_GAP-10, 400, 0xffffff, 0x004869);
		// set drawing area, white background, grey axis lines.
		c.setPlotArea(55, 60, 325, 290, 0xffffff, -1, 0xbdbdbd, 0xbdbdbd, Chart.Transparent);

		// Add legend. white background, raised edges. Fake legend entries.
		int i = 0;
		if(Integer.parseInt(numWT)>0){
			c.addScatterLayer(new double[]{}, new double[]{}, legend_axis1, Chart.SquareSymbol, 7, 0x00ff00);
			i++;
		}
		if(Integer.parseInt(numHet)>0){
			c.addScatterLayer(new double[]{}, new double[]{}, legend_axis2, Chart.TriangleSymbol, 7, 0x0000ff);
			i++;
		}
		if(Integer.parseInt(numHom)>0){
			c.addScatterLayer(new double[]{}, new double[]{}, legend_axis3, Chart.DiamondSymbol, 8, 0xff0000);
			i++;
		}

		int legendX = 110;
		if(i==3){
			legendX = 80;
		}
		c.addLegend(legendX, 25, false, "Arial", 10).setBackground(0xffffff, 0xffffff,0);

		// Add title, white text, black glass effect background.
		c.addTitle(title, "Arial", 15, 0xffffff).setBackground(0x004869);


		// Add sanger image to top left corner.
		c.addText(2, 1, "<*block,valign=absmiddle*><*img=dna.png*>" );

		// add X axis title
		c.xAxis().setTitle(xAxis, "Arial", 10);


		if(addPadding) {
			// use this only to indicate that the xAxis need not include zero.(3rd arg)
			c.xAxis().setAutoScale(0, 0, 0);
			// override the 1st/2nd args above to set left and right margins to 70px
			c.xAxis().setMargin(30, 30);
		}

		// add y axis title
		c.yAxis().setTitle(yAxis,"Arial", 10);

		if(scientificYaxis) {
			c.yAxis().setLabelFormat("{value|G}");
		}

		// set line widths and colors of the axis.
		c.xAxis().setWidth(2);
		c.yAxis().setWidth(2);
		c.xAxis().setColors(0x000000,0x8d0017,0X000000,0x8d0017);
		c.yAxis().setColors(0x000000,0x8d0017,0X000000,0x8d0017);

		c.yAxis().setLinearScale(0,100);
		c.yAxis().setMargin(0,0);



		// set the X axis labels.
		if(useXAxisLabels) {
			if(!timeAxis) {
				String x[] = generateXAxisLabels(xLabels);
				c.xAxis().setLabels(x);
			}else{
				c.xAxis().setLabels(xLabels);
				if(xLabels.length > 10) {
					c.xAxis().setLabelStyle().setFontAngle(45.0);
				}
			}
		}
		int length = xDataFromLabels.length;
		double[] clickx = {xDataFromLabels[0]};
		double[] xData = {};
		if(xDataFromLabels[0]==100){
			xData = new double[length-1];
			System.arraycopy(xDataFromLabels, 1, xData, 0, length-1);
		}else{
			xData = xDataFromLabels;
		}

		// add data lines, dont include them on the legend or we'll end up with multiples.
		// legend entries are faked above.
		if(wt2 != null) {
			for(String mouse : wt2.keySet()) {
				LineLayer layer1 = c.addLineLayer();
				if(xDataFromLabels[0]==100){
					double[] clicky = {wt2.get(mouse)[0]};
					double[] lineDataA = new double[length-1];
					System.arraycopy(wt2.get(mouse), 1, lineDataA, 0, length-1);
					layer1.addDataSet(lineDataA, 0x00ff00,legend_axis1).setDataSymbol(Chart.SquareSymbol, 7);
					c.addScatterLayer(clickx, clicky, "", Chart.SquareSymbol, 7, 0x00ff00);
				}else{
					layer1.addDataSet(wt2.get(mouse), 0x00ff00,legend_axis1).setDataSymbol(Chart.SquareSymbol, 7);
				}
				if(!timeAxis) {layer1.setXData(xData);}
				layer1.setGapColor(0x00ff00);
				layer1.setLegend(Chart.NoLegend);
				layer1.addExtraField(getExtraLabels(mouse,xLabels.length));// adds the mouse name for the image map.

			}
		}
		if(het2 != null) {
			for(String mouse :  het2.keySet()) {
				LineLayer layer2 = c.addLineLayer();
				if(xDataFromLabels[0]==100){
					double[] lineDataA = new double[length-1];
					double[] clicky = {het2.get(mouse)[0]};
					System.arraycopy(het2.get(mouse), 1, lineDataA, 0, length-1);
					layer2.addDataSet(lineDataA, 0x0000ff,legend_axis2).setDataSymbol(Chart.TriangleSymbol, 7);
					c.addScatterLayer(clickx, clicky, "", Chart.TriangleSymbol, 7, 0x0000ff);
				}else{
					layer2.addDataSet(het2.get(mouse), 0x0000ff,legend_axis2).setDataSymbol(Chart.TriangleSymbol, 7);
				}
				if(!timeAxis) {layer2.setXData(xData);}
				layer2.setGapColor(0x0000ff);
				layer2.setLegend(Chart.NoLegend);
				layer2.addExtraField(getExtraLabels(mouse,xLabels.length));// adds the mouse name for the image map.

			}
		}
		if(hom2 != null) {
			for(String mouse :  hom2.keySet()) {
				LineLayer layer3 = c.addLineLayer();
				if(xDataFromLabels[0]==100){
					double[] clicky = {hom2.get(mouse)[0]};
					double[] lineDataA = new double[length-1];
					System.arraycopy(hom2.get(mouse), 1, lineDataA, 0, length-1);
					layer3.addDataSet(lineDataA, 0xff0000,legend_axis3).setDataSymbol(Chart.DiamondSymbol, 8);
					c.addScatterLayer(clickx, clicky, "", Chart.DiamondSymbol, 7, 0xff0000);
				}else{
					layer3.addDataSet(hom2.get(mouse), 0xff0000,legend_axis3).setDataSymbol(Chart.DiamondSymbol, 8);
				}
				if(!timeAxis) {layer3.setXData(xData);}
				layer3.setGapColor(0xff0000);
				layer3.setLegend(Chart.NoLegend);
				layer3.addExtraField(getExtraLabels(mouse,xLabels.length));// adds the mouse name for the image map.

			}
		}

		if(refRanges != null && refRanges.size() != 0) {
			// whisker error bars.
			if(wtError != null && wtError.size() >0) {
				addWhiskerLayer(c,xLabels,wtError.get(0),wtError.get(1),0x00ff00,timeAxis);
			}
			if(hetError != null && hetError.size() >0) {
				addWhiskerLayer(c,xLabels,hetError.get(0),hetError.get(1),0x0000ff,timeAxis);
			}
			if(homError != null && homError.size() >0) {
				addWhiskerLayer(c,xLabels,homError.get(0),homError.get(1), 0xff0000,timeAxis);
			}


			// add dashed lines for mean.
			double[] meanL =  {};
			double[] sd1 = {};
			double[] sd2 ={};
			double[] sd3 = {};
			double[] sd4 ={};

			if(xLabels[0].equals("100")){
				meanL = new double[length];
				System.arraycopy(refRanges.get(2), 1, meanL, 0, length-1);
				sd1 = new double[length];
				System.arraycopy(refRanges.get(3), 1, sd1, 0, length-1);
				sd2 = new double[length];
				System.arraycopy(refRanges.get(1), 1, sd2, 0, length-1);
				sd3 = new double[length];
				System.arraycopy(refRanges.get(4), 1, sd3, 0, length-1);
				sd4 = new double[length];
				System.arraycopy(refRanges.get(0), 1, sd4, 0, length-1);
			}else{
				meanL = refRanges.get(2);
				sd1= refRanges.get(3);
				sd2 = refRanges.get(1);
				sd3 = refRanges.get(4);
				sd4 = refRanges.get(0);
			}
			LineLayer meanlayer = c.addLineLayer(meanL,c.dashLineColor(0x8d0017, Chart.DashLine));
			if(!timeAxis) {meanlayer.setXData(xData);}

			// Add a new line layer to the chart
			LineLayer layer = c.addLineLayer2();
			if(!timeAxis) {layer.setXData(xData);}
			// Add the upper border of the percentile zone
			layer.addDataSet(sd1, c.dashLineColor(0x8d0017, Chart.DashLine), "+1sd");

			// Add the lower border of the percentile zone
			layer.addDataSet(sd2, c.dashLineColor(0x8d0017, Chart.DashLine), "-1sd");

			// Color the region between the percentile zone lines
			c.addInterLineLayer(layer.getLine(0), layer.getLine(1), 0xddf6a4);

			// Add the upper border of the outer 2.5% percentile zone
			layer.addDataSet(sd3, c.dashLineColor(0x8d0017, Chart.DashLine), "+2sd");

			// Add the lower border of the outer 2.5% percentile zone
			layer.addDataSet(sd4, c.dashLineColor(0x8d0017, Chart.DashLine), "-2sd");

			// Color the region between the percentile zone lines
			c.addInterLineLayer(layer.getLine(1), layer.getLine(3), 0xccf284);

			// Color the region between the percentile zone lines
			c.addInterLineLayer(layer.getLine(0), layer.getLine(2), 0xccf284);

			// dont show layer in legend box
			layer.setLegend(Chart.NoLegend);
		}
		return c;

	}


	/**
	 * Method to generate mouseName for image map. One String array with the same mouse name mapped
	 * for every xAxis point.
	 *
	 * @param mouseName
	 * @param len
	 * @return String[]
	 */
	private String[] getExtraLabels(String mouseName, int len) {
		String[] ret = new String[len];
		for(int i = 0; i<len; i++) {
			ret[i] = mouseName;
		}
		return ret;
	}

	private boolean isListed(int i, String[] labels) {
		String test = new String(i+"");

		for(int j= 0; j<labels.length; j++) {
			if(labels[j].equals(test)) {
				return true;
			}
		}
		return false;

	}

	/**
	 * Draw the SEM whiskers.
	 */
	private void addWhiskerLayer(XYChart c, String[] labels, double[] high, double[]low, int color, boolean timeAxis) {
		if(high != null && low != null) {
			BoxWhiskerLayer errLayer = c.addBoxWhiskerLayer(null, null, high, low, null,
					Chart.Transparent, color);
			errLayer.setLineWidth(2);
			errLayer.setDataGap(0.7);

			if(!timeAxis) {
				errLayer.setXData(getXDataFromLabels(labels));
			}
		}
	}

	/**
	 *  gets the the xAxis data for the labels,
	 *
	 *  Used for setXData so i can put the labels at specific points insted of chart director
	 *  working it out itself.
	 *
	 */
	private double[] getXDataFromLabels(String[] labels) {
		double[] xData = new double[labels.length];

		for(int i=0; i<labels.length;i++) {
			Double d;
			try {
				d = Double.valueOf(labels[i]);
				if(d != null) {
					double val = d.doubleValue();
					xData[i] = val;
				}
			} catch (NumberFormatException e) {
			}
		}
		return xData;
	}

	/**
	 * Creates the xAxis labels, uses isListed to see if its a label we want to see.
	 * eg. in the case of ipGTT, we only want to see 0,15,30,60 & 120 on the axis.. but to space
	 * appropriately, the labels array contains the strings 0..120, i just choose the ones
	 * needed to be seen.
	 *
	 * @param labels
	 * @return
	 */


	private String[] generateXAxisLabels(String[] labels) {

		int labelLen = labels.length;

		int first = 0;
		int last = 0;
		try {
			first = Integer.parseInt(labels[0]);
			last = Integer.parseInt(labels[labelLen-1]);
		} catch (NumberFormatException e) {
			return null;
		}

		ArrayList<String> newLabels = new ArrayList<String>();

		for(int i = first; i<=last; i++) {
			if(isListed(i,labels)) {
				if(i>1000){
					newLabels.add(new String(i/1000+"")); // valid and i want to see it.
				}else{
					newLabels.add(new String("click"+""));
				}
			} else {
				newLabels.add(new String("")); // ignore it.
			}
		}
		return newLabels.toArray(new String[newLabels.size()]);
	}


}

