package uk.ac.sanger.mig.abr.parser;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

/*
 *****************************************************
 * Class name: BlockAttribute
 * User: holroyd
 * Date: Aug 5, 2008
 * Time: 10:38:33 AM
 *****************************************************
 */

public class BlockAttribute {

	private String				attributeName;
	private String				attributeValue;
	private int					index;

	public BlockAttribute(String attributeName, String attributeValue) {
		this.attributeName = attributeName;
		this.attributeValue = attributeValue;
		this.index = -1;
		extractAttributeName();
	}


	private String extractAttributeName() {
		Matcher m = Pattern.compile("^(.*)_(\\d+)$").matcher(this.attributeName);
		if (m.matches()) {
			this.attributeName = m.group(1);
			this.index = Integer.parseInt(m.group(2));
		}
		return attributeName;
	}


	/**
	 * Returns true if this attribute is a trace data attribute, otherwise returns false. A trace
	 * data attributes name will being with "TraceData_" and is suffixed with a number.
	 *
	 * @return true - attribute is a trace data attribute, false - is not a trace data attribute.
	 */
	public boolean isTraceDataAttribute() {
		return this.attributeName.equals(Block.TRACE_DATA);
	}


	/**
	 * Returns the block attribute name.
	 *
	 * @return String blockName
	 */
	public String getAttributeName() {
		return attributeName;
	}


	/**
	 * Returns the block attributes value.
	 *
	 * @return String blockValue
	 */
	public String getAttributeValue() {
		return attributeValue;
	}


	public int getIndex() {
		return index;
	}

}
