package uk.ac.sanger.mig.abr.parser;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Comparator;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class Frequency {

	private int						frequency;
	private Map<Integer, Level>		levels;

	static final Comparator<Level>	LEVEL_ASC_ORDER	= new Comparator<Level>() {
														public int compare(Level l1, Level l2) {
															if (l1.getLevel() < l2.getLevel())
																return -1;
															if (l1.getLevel() > l2.getLevel())
																return 1;
															return 0;
														}
													};


	public Frequency(int frequency) {
		this.frequency = frequency;
		this.levels = new HashMap<Integer, Level>();
	}


	public int getFrequency() {
		return frequency;
	}


	/**
	 * Creates a new level and adds it to the map. The map uses the levels integer value as the key
	 * and the Level object as the value.
	 *
	 * @param level -
	 *            the integer value used to create the new Level.
	 * @return new Level object.
	 */
	private Level addLevel(Integer level) {
		if (!this.levels.containsKey(level)) {
			this.levels.put(level, new Level(level.intValue(), this));
		}
		return this.levels.get(level);
	}


	/**
	 * Creates a new Level object and adds the passed block to it.
	 *
	 * @param l
	 * @param block
	 */
	public void addLevelBlock(Integer l, Block block) {
		Level level = this.addLevel(l);
		level.addBlock(block);
	}


	public Collection<Level> getLevels() {
		List<Level> sortedLevels = new ArrayList<Level>(this.levels.values());
		Collections.sort(sortedLevels, LEVEL_ASC_ORDER);
		return sortedLevels;
	}


	public int getTotalNumberDataPoints() {
		int totalNumberDataPoints = 0;
		for (Level level : this.getLevels()) {
			for (Block block : level.getBlocks()) {
				totalNumberDataPoints += block.getBlockTraceInfo().getNumberPoints();
			}
		}
		return totalNumberDataPoints;
	}


	public int[] getLevelValues() {
		List<Level> levels = new ArrayList<Level>(this.getLevels());
		int[] levelValues = new int[levels.size()];
		for (int i = 0; i < levels.size(); i++) {
			levelValues[i] = levels.get(i).getLevel();
		}
		return levelValues;
	}


	public String getFrequencyTitle() {
		return (this.frequency / 1000) < 1 ? "100 Hz" : this.frequency / 1000 + "K Hz";
	}

}
