/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.abr.services;


import java.security.NoSuchAlgorithmException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Map;
import java.util.TreeMap;

import ChartDirector.ArrayMath;
import uk.ac.sanger.mig.abr.ControlChart;
import uk.ac.sanger.mig.abr.FrequencyChart;
import uk.ac.sanger.mig.abr.MouseChart;

import uk.ac.sanger.mig.abr.parser.Block;
import uk.ac.sanger.mig.abr.parser.FileParser;
import uk.ac.sanger.mig.abr.parser.Frequency;
import uk.ac.sanger.mig.abr.parser.Level;
import uk.ac.sanger.mig.abr.parser.NotAnAbrTestBlockException;

/**
 * @author wl1
 *
 */
public class ChartServiceImpl implements ChartService{

	public double caculateFinalOffsetFromParser(FileParser fp) throws NumberFormatException, NotAnAbrTestBlockException{
		List<Frequency> frequencies = new ArrayList<Frequency>(fp.getAbrTraceBlocksByFrequencyLevel());
		Map<Integer,List<Double>> offsets = new TreeMap<Integer, List<Double>>();

		double offset = 0;
		for(int j=0;j<frequencies.size();j++){
			Frequency f=frequencies.get(j);
			List<Level> traceLines = new ArrayList<Level>(f.getLevels());
			for(int i=0;i<traceLines.size();i++){
				ArrayMath temp= new ArrayMath(traceLines.get(i).getBlock().getDataPoints());

				double o1 = temp.max()-temp.min();
				if(offsets.containsKey(traceLines.get(i).getLevel())){
					offsets.get(traceLines.get(i).getLevel()).add(o1);
				}else{
					List<Double> l = new ArrayList<Double>();
					l.add(o1);
					offsets.put(traceLines.get(i).getLevel(), l);
				}
			}
		}
		double[] finalOffset = new double[offsets.size()];
		int l=0;
		for(Integer i:offsets.keySet()){
			finalOffset[l]=(Collections.max(offsets.get(i)));
			l++;
		}
		offset = new ArrayMath(finalOffset).avg();
		return offset;
	}


	public FrequencyChart caculateFreqChartFromParser(Frequency f,boolean recordY,double offset) throws NumberFormatException, NotAnAbrTestBlockException, NoSuchAlgorithmException
	{
		int frequencyValue = f.getFrequency();
		List<Level> abrBlocks = new ArrayList<Level>(f.getLevels());
		int numberPoints = abrBlocks.get(0).getBlock().getBlockTraceInfo().getNumberPoints();
		int[] levels = new int[abrBlocks.size()];
		double[] dataX = new double[numberPoints];
		double[][] dataYArray = new double[abrBlocks.size()][numberPoints];
		double xInterval = abrBlocks.get(0).getBlock().getBlockTraceInfo().getBinSize();
		String frequencyTitle = "";

		for(int i=0;i<abrBlocks.size();i++){
			if(recordY){
				levels[i]=abrBlocks.get(i).getLevel();
			}
			double[] dataY = abrBlocks.get(i).getBlock().getDataPoints();
			for(int j=0;j<numberPoints;j++){
				dataYArray[i][j] = (dataY[j]+offset*i)*2;
			}
		}
		dataX[0] = 0;

		for(int i=1;i<numberPoints;i++){
			dataX[i]= dataX[i-1]+xInterval;
		}

		if((frequencyValue/1000)<1){
			frequencyTitle = "Click";
		}else{
			frequencyTitle = frequencyValue/1000+" kHz";
		}

		FrequencyChart freqChart = new FrequencyChart(dataX, dataYArray,frequencyTitle,recordY,levels,xInterval);
		return freqChart;
	}

	private double caculateEnlargedFreqOffset(Frequency f){
		double[] offset = new double[f.getLevels().size()];
		List<Level> abrBlocks = new ArrayList<Level>(f.getLevels());
		ArrayMath temp = null;
		int i=0;
		for(Level level: abrBlocks){
			temp= new ArrayMath(level.getBlock().getDataPoints());
			offset[i]=temp.max();
			i++;
		}
		temp= new ArrayMath(offset);
		return temp.max()+0.25;
	}

	public FrequencyChart enlargeFreqChartFromParser(FileParser fp,int freqIndex)throws NumberFormatException, NotAnAbrTestBlockException, NoSuchAlgorithmException{

		List<Frequency> frequencyBlocks =
			new ArrayList<Frequency>(fp.getAbrTraceBlocksByFrequencyLevel());
		double offset = caculateEnlargedFreqOffset(frequencyBlocks.get(freqIndex));

		FrequencyChart frequencyChart = caculateFreqChartFromParser(frequencyBlocks.get(freqIndex),true,offset);

		return frequencyChart;
	}

	public List<FrequencyChart> caculateFreqChartListFromParser(List<Frequency> frequencyBlocks, double offset) throws NumberFormatException, NoSuchAlgorithmException, NotAnAbrTestBlockException{

		List<FrequencyChart> fCharts = new ArrayList<FrequencyChart>();
		for(int i=0;i<frequencyBlocks.size();i++){
			if(i<frequencyBlocks.size()-1){
				fCharts.add(caculateFreqChartFromParser(frequencyBlocks.get(i),false,offset));
			}else{
				fCharts.add(caculateFreqChartFromParser(frequencyBlocks.get(i),true,offset));
			}
		}
		return fCharts;
	}

	public ControlChart caculateOtherChartFromParser(FileParser fp){
		Block click1 = fp.getStartClickBlock();
		Block click2 = fp.getEndClickBlock();
		Block calibration = fp.getCalibrationTraceBlock();
		int clickDataPointsNo = click1.getBlockTraceInfo().getNumberPoints();
		int calibrationDataPointNo = calibration.getBlockTraceInfo().getNumberPoints();
		double clickBinSize = click1.getBlockTraceInfo().getBinSize();
		double calBinSize = calibration.getBlockTraceInfo().getBinSize();
		double[][] xValue = new double[2][];
		double[][] yValue = new double[3][];

		xValue[ControlChart.CALIBRATION_INDEX]= new double[calibrationDataPointNo];
		xValue[ControlChart.CLICK_INDEX_X]= new double[clickDataPointsNo];
		xValue[ControlChart.CALIBRATION_INDEX][0]=calibration.getBlockTraceInfo().getStart();
		xValue[ControlChart.CLICK_INDEX_X][0]=0;

	    for(int i=1;i<calibrationDataPointNo;i++){
	    	//calibration x
	    	xValue[ControlChart.CALIBRATION_INDEX][i] =
	    		xValue[ControlChart.CALIBRATION_INDEX][i-1]+calBinSize;
	    }

	    for(int i=1;i<clickDataPointsNo;i++){
	    	xValue[ControlChart.CLICK_INDEX_X][i] =
	    		xValue[ControlChart.CLICK_INDEX_X][i-1]+clickBinSize;
	    }

	    yValue[ControlChart.CALIBRATION_INDEX] = calibration.getDataPoints();
	    yValue[ControlChart.CLICK1_INDEX_Y] = click1.getDataPoints();
	    yValue[ControlChart.CLICK2_INDEX_Y] = click2.getDataPoints();
        return new ControlChart(xValue,yValue);
	}



	public byte[] createDefualtMouseChart(FileParser fp) throws NumberFormatException, NotAnAbrTestBlockException, NoSuchAlgorithmException {
		List<Frequency> frequencyBlocks =
			new ArrayList<Frequency>(fp.getAbrTraceBlocksByFrequencyLevel());

		MouseChart mouseChart = new MouseChart();
		double offset = caculateFinalOffsetFromParser(fp);
		List<FrequencyChart> fCharts = caculateFreqChartListFromParser(frequencyBlocks,offset);
        mouseChart.setFreqCharts(fCharts);
        return mouseChart.createMultipleChart();
	}

	public MouseChart createMouseChart(FileParser fp) throws NumberFormatException, NotAnAbrTestBlockException, NoSuchAlgorithmException {
		List<Frequency> frequencyBlocks =
			new ArrayList<Frequency>(fp.getAbrTraceBlocksByFrequencyLevel());

		MouseChart mouseChart = new MouseChart();
		double offset = caculateFinalOffsetFromParser(fp);
		List<FrequencyChart> fCharts = caculateFreqChartListFromParser(frequencyBlocks,offset);
        mouseChart.setFreqCharts(fCharts);

        ControlChart  controlChart = caculateOtherChartFromParser(fp);
        mouseChart.setControlChart(controlChart);

        return mouseChart;
	}
}
