/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.allelerequest;

import java.util.Collection;
import java.util.Date;

import uk.ac.sanger.mig.common.ComponentEnum;
import uk.ac.sanger.mig.common.DataObject;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.designrequest.Design;
import uk.ac.sanger.mig.gene.MigGene;
import uk.ac.sanger.mig.havanarequest.HavanaRequest;
import uk.ac.sanger.mig.personnel.Person;

public class AlleleRequest extends DataObject implements Comparable<AlleleRequest> {
	
	private String comments;
	private String knockoutAvailable;
	private String knockoutReference;
	private String mutationPlan;
	private int priority;
	private String reasoning;
	private Long researcherId;
	private String researcherName;
	private String reviewComments;
	private String modTypeOtherExplanation;
	private Date editDate;
	private Date createdDate;
    private Date submitToQueueDate;
	private String editedBy;
	private boolean unexpectedPhenotypeOk;
	private boolean mgpPhenotypingRequired;
	private String genePublications;
	private String mousePublications;
	private MigGene migGene;
	private Long migGeneId;
	private DictionaryEntry source;
	private Long sourceDictId;
	private String seeAlso;
	private DictionaryEntry status;
	private Long statusDictId;
	private DictionaryEntry targetEndpoint;
	private Long targetEndpointDictId;
	private DictionaryEntry modType;
	private Long modTypeDictId;
	private Person requestOwner;
	private Collection<Long> designIds;
	private Collection<Design> designs;
	private HavanaRequest havanaRequest;
	
    public int compareTo(AlleleRequest a) {
    	AlleleRequest b = this;
    	if(a.getId() < b.getId()) return 1;
    	if(a.getId() > b.getId()) return -1;
    	return 0;
	}
    
	public enum Component implements ComponentEnum {
      ALL_COMPONENTS,
      DESIGNS,
      GENE,
      HAVANA_REQUEST      
      //add additional component enums here as needed for this AuthenticatedDataObject
	}
	
	public String getModTypeOtherExplanation() {
		return  modTypeOtherExplanation;
	}
	
	public void setModTypeOtherExplanation(String modTypeOtherExplanation) {
		this.modTypeOtherExplanation = modTypeOtherExplanation;
	}
	
	public String getComments() {
		return comments;
	}
	
	public void setComments(String comments) {
		this.comments = comments;
	}
	
	public String getKnockoutAvailable() {
		return knockoutAvailable;
	}
	
	public void setKnockoutAvailable(String knockoutAvailable) {
		this.knockoutAvailable = knockoutAvailable;
	}
	
	public String getKnockoutReference() {
		return knockoutReference;
	}
	
	public void setKnockoutReference(String knockoutReference) {
		this.knockoutReference = knockoutReference;
	}
	
	public String getMutationPlan() {
		return mutationPlan;
	}
	
	public void setMutationPlan(String mutationPlan) {
		this.mutationPlan = mutationPlan;
	}
	
	public int getPriority() {
		return priority;
	}
	
	public void setPriority(int priority) {
		this.priority = priority;
	}
	
	public String getReasoning() {
		return reasoning;
	}
	
	public void setReasoning(String reasoning) {
		this.reasoning = reasoning;
	}
	
	public Person getRequestOwner() {
		return requestOwner;
	}

	public void setRequestOwner(Person requestOwner) {
		this.requestOwner = requestOwner;
	}

	public Long getResearcherId() {
		return researcherId;
	}
	
	public void setResearcherId(Long researcherId) {
		this.researcherId = researcherId;
	}
	
	public String getResearcherName() {
		return researcherName;
	}
	
	public void setResearcherName(String researcherName) {
		this.researcherName = researcherName;
	}
	
	public String getReviewComments() {
		return reviewComments;
	}
	
	public void setReviewComments(String reviewComments) {
		this.reviewComments = reviewComments;
	}
	
	public Date getEditDate() {
		return editDate;
	}
	
	public void setEditDate(Date editDate) {
		this.editDate = editDate;
	}
	
	public String getEditedBy() {
		return editedBy;
	}

	public void setEditedBy(String editedBy) {
		this.editedBy = editedBy;
	}

	public boolean isUnexpectedPhenotypeOk() {
		return unexpectedPhenotypeOk;
	}
	
	public void setUnexpectedPhenotypeOk(boolean unexpectedPhenotypeOk) {
		this.unexpectedPhenotypeOk = unexpectedPhenotypeOk;
	}
	
	public boolean isMgpPhenotypingRequired() {
		return mgpPhenotypingRequired;
	}

	public void setMgpPhenotypingRequired(boolean mgpPhenotypingRequired) {
		this.mgpPhenotypingRequired = mgpPhenotypingRequired;
	}
	
	public String getGenePublications() {
		return genePublications;
	}

	public void setGenePublications(String genePublications) {
		this.genePublications = genePublications;
	}

	public String getMousePublications() {
		return mousePublications;
	}

	public void setMousePublications(String mousePublications) {
		this.mousePublications = mousePublications;
	}

	public MigGene getMigGene() {
		return migGene;
	}

	public void setMigGene(MigGene migGene) {
		this.migGene = migGene;
	}

	public DictionaryEntry getStatus() {
		return status;
	}

	public void setStatus(DictionaryEntry status) {
		this.status = status;
	}

	public DictionaryEntry getTargetEndpoint() {
		return targetEndpoint;
	}

	public void setTargetEndpoint(DictionaryEntry targetEndpoint) {
		this.targetEndpoint = targetEndpoint;
	}

	public DictionaryEntry getSource() {
		return source;
	}

	public void setSource(DictionaryEntry source) {
		this.source = source;
	}

	public DictionaryEntry getModType() {
		return modType;
	}

	public void setModType(DictionaryEntry modType) {
		this.modType = modType;
	}

	public Collection<Long> getDesignIds() {
		return designIds;
	}

	public void setDesignIds(Collection<Long> designIds) {
		this.designIds = designIds;
	}

	public Collection<Design> getDesigns() {
		return designs;
	}

	public void setDesigns(Collection<Design> designs) {
		this.designs = designs;
	}

	public HavanaRequest getHavanaRequest() {
		return havanaRequest;
	}

	public void setHavanaRequest(HavanaRequest havanaRequest) {
		this.havanaRequest = havanaRequest;
	}

	public Date getSubmitToQueueDate() {
		return submitToQueueDate;
	}

	public void setSubmitToQueueDate(Date submitToQueueDate) {
		this.submitToQueueDate = submitToQueueDate;
	}

	public Long getModTypeDictId() {
		return modTypeDictId;
	}

	public void setModTypeDictId(Long modTypeDictId) {
		this.modTypeDictId = modTypeDictId;
	}

	public Long getSourceDictId() {
		return sourceDictId;
	}

	public void setSourceDictId(Long sourceDictId) {
		this.sourceDictId = sourceDictId;
	}

	public Long getTargetEndpointDictId() {
		return targetEndpointDictId;
	}

	public void setTargetEndpointDictId(Long targetEndpointDictId) {
		this.targetEndpointDictId = targetEndpointDictId;
	}

	public Long getMigGeneId() {
		return migGeneId;
	}

	public void setMigGeneId(Long migGeneId) {
		this.migGeneId = migGeneId;
	}

	public Long getStatusDictId() {
		return statusDictId;
	}

	public void setStatusDictId(Long statusDictId) {
		this.statusDictId = statusDictId;
	}

	public String getSeeAlso() {
		return seeAlso;
	}

	public void setSeeAlso(String seeAlso) {
		this.seeAlso = seeAlso;
	}

	public Date getCreatedDate() {
		return this.createdDate;
	}

	public void setCreatedDate(Date createdDate) {
		this.createdDate = createdDate;
	}
	
	
	
}
