/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.allelerequest.controllers;

import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.allelerequest.AlleleRequest;
import uk.ac.sanger.mig.allelerequest.AlleleRequestSearchBean;
import uk.ac.sanger.mig.allelerequest.dao.AlleleRequestDao;
import uk.ac.sanger.mig.allelerequest.views.AlleleRequestListView;
import uk.ac.sanger.mig.common.AbstractSearchFormController;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.database.DictionaryDao;

public class AlleleRequestListController extends AbstractSearchFormController {
	
	private AlleleRequestDao<AlleleRequest> alleleRequestDao;
	
	private DictionaryDao dictionaryDao; 
	private String excelView;
	
	public void setAlleleRequestDao(AlleleRequestDao<AlleleRequest> alleleRequestDao) {
		this.alleleRequestDao = alleleRequestDao;
	}
	
	public void setDictionaryDao(DictionaryDao dictionaryDao) {
		this.dictionaryDao = dictionaryDao;
	}
	
	public String getExcelView() {
		return excelView;
	}
	
	public void setExcelView(String excelView) {
		this.excelView = excelView;
	}
	
	@Override
	protected ModelAndView onSearch(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		AlleleRequestSearchBean searchBean = (AlleleRequestSearchBean)command;
		searchBean.setQueryName("listAlleleRequests");
		
		searchBean.setRecordSetLength( 12 ); //so full list viewable in one page
		
		Map<String, Object> model = referenceData(request);		
		
		Collection<AlleleRequestListView> results = alleleRequestDao.search(searchBean);
		model.put("results", results);
		
		boolean isExcelView = ServletRequestUtils.getBooleanParameter(request, "excel",false);
		String returnView = null;
		
		if(isExcelView) {
			returnView = getExcelView();
		}
		else {
			returnView = getSuccessView();
		}
		
		return new ModelAndView(returnView,model);
		
	}
	
	protected Map<String, Object> referenceData(HttpServletRequest request) throws Exception {
		Map<String, Object> model = new HashMap<String, Object>();	
		ArrayList<String> filters = new ArrayList<String>();
		filters.add( "Request Number" );
		filters.add( "Gene Name" );
		filters.add( "Ensembl ID" );
		filters.add( "Submitter Name");
		filters.add( "Researcher Name");
		filters.add( "See Also");
		Collection<DictionaryEntry> statuses = dictionaryDao.fetchDictionaryByTableName("arq_allele_request_status_dict", false);
		model.put("statuses", statuses);
		
		Collection<DictionaryEntry> sources = dictionaryDao.fetchDictionaryByTableName("arq_allele_request_source_dict", false);
		DictionaryEntry item = new DictionaryEntry();
		item.setId(-5L);
		item.setName("All (excluding EUCOMM)");
		sources.add(item);
		model.put("sources", sources);
		model.put("filters",filters);
		request.getSession(true).setAttribute("geneSet", null); //null out since we're in Allele (not Gene) List mode		
		
		return model;
	}
}
