/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.allelerequest.dao;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.allelerequest.views.AlleleRequestListView;

public class AlleleRequestListViewRowMapper implements ParameterizedRowMapper<AlleleRequestListView> {

	public AlleleRequestListView mapRow(ResultSet rs, int rowNum) throws SQLException {

		AlleleRequestListView alleleRequest = new AlleleRequestListView();

		alleleRequest.setId(rs.getLong("ID"));
		alleleRequest.setEditDate(rs.getDate("EDIT_DATE"));
		alleleRequest.setCreatedDate(rs.getDate("CREATED_DATE"));
		alleleRequest.setComments(rs.getString("COMMENTS"));
		alleleRequest.setResearcherId(rs.getLong("RESEARCHER_PERSON_ID"));
		alleleRequest.setReasoning(rs.getString("REQUEST_REASONING"));
		alleleRequest.setMutationPlan(rs.getString("MUTATION_PLAN"));
		alleleRequest.setUnexpectedPhenotypeOk(rs.getBoolean("UNEXPECTED_PHENOTYPE_OK"));
		alleleRequest.setKnockoutAvailable(rs.getString("KNOCKOUT_EXISTS"));
		alleleRequest.setKnockoutReference(rs.getString("KNOCKOUT_EXISTS_REFERENCE"));
		alleleRequest.setPriority(rs.getInt("REQUEST_PRIORITY"));
		alleleRequest.setComments(rs.getString("REVIEW_COMMENTS"));
		alleleRequest.setResearcherName(rs.getString("RESEARCHER_NAME"));
		alleleRequest.setModTypeOtherExplanation(rs.getString("ALLELE_MOD_OTHER_EXPLN"));
		alleleRequest.setGenePublications(rs.getString("GENE_PUBLICATIONS"));
		alleleRequest.setMousePublications(rs.getString("MOUSE_PUBLICATIONS"));
		alleleRequest.setMgpPhenotypingRequired(rs.getBoolean("MGP_PHENOTYPING_REQUIRED"));
		alleleRequest.setRequestOwnerId(rs.getLong("requester_person_id"));
		alleleRequest.setUserName(rs.getString("user_name"));
		alleleRequest.setModTypeName(rs.getString("MOD_TYPE"));
		alleleRequest.setModTypeId(rs.getLong("ALLELE_MOD_TYPE_DICT_ID"));
		alleleRequest.setSourceId(rs.getLong("request_source_dict_id"));
		alleleRequest.setSourceName(rs.getString("source"));
		alleleRequest.setStatusId(rs.getLong("STATUS_DICT_ID"));
		alleleRequest.setStatusName(rs.getString("status"));
		alleleRequest.setStatusDescription(rs.getString("description"));
		alleleRequest.setTargetEndpointId(rs.getLong("target_endpoint_dict_id"));
		alleleRequest.setTargetEndpointName(rs.getString("target_endpoint"));
		alleleRequest.setGeneId(rs.getLong("gene_id"));
		alleleRequest.setGeneName(rs.getString("gene_name"));
		alleleRequest.setEnsemblId(rs.getString("ensembl_id"));
		alleleRequest.setInCurrentEnsembl(rs.getBoolean("IN_CURRENT_ENSEMBL"));
		alleleRequest.setScore(rs.getString("score"));
		alleleRequest.setCountDesigns(rs.getInt("DESIGN_COUNT"));
		alleleRequest.setPrimaryId(rs.getString("PRIMARY_ID"));
		alleleRequest.setVegaId(rs.getString("VEGA_ID"));
		alleleRequest.setSeeAlso(rs.getString("SEE_ALSO"));
		alleleRequest.setInCurrentVega(rs.getBoolean("IN_CURRENT_VEGA"));

		return alleleRequest;
	}

}
