/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.allelerequest.dao;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.allelerequest.AlleleRequest;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.gene.MigGene;
import uk.ac.sanger.mig.gene.services.MigGeneService;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.personnel.services.PersonService;

public class AlleleRequestRowMapper implements ParameterizedRowMapper<AlleleRequest> {
	
	private DictionaryService dictionaryService;
	private PersonService personService;
	private MigGeneService migGeneService;

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}
	
	public void setMigGeneService(MigGeneService migGeneService) {
		this.migGeneService = migGeneService;
	}

	public void setPersonService(PersonService personService) {
		this.personService = personService;
	}

	public AlleleRequest mapRow(ResultSet rs, int rowNum) throws SQLException {

		AlleleRequest alleleRequest = new AlleleRequest();
		
		alleleRequest.setId(rs.getLong("ID"));
		alleleRequest.setEditDate(rs.getDate("EDIT_DATE"));
		alleleRequest.setComments(rs.getString("COMMENTS"));
		alleleRequest.setResearcherId(rs.getLong("RESEARCHER_PERSON_ID"));
		alleleRequest.setReasoning(rs.getString("REQUEST_REASONING"));
		alleleRequest.setMutationPlan(rs.getString("MUTATION_PLAN"));
		alleleRequest.setUnexpectedPhenotypeOk(rs.getBoolean("UNEXPECTED_PHENOTYPE_OK"));
		alleleRequest.setKnockoutAvailable(rs.getString("KNOCKOUT_EXISTS"));
		alleleRequest.setKnockoutReference(rs.getString("KNOCKOUT_EXISTS_REFERENCE"));
		alleleRequest.setPriority(rs.getInt("REQUEST_PRIORITY"));
		alleleRequest.setReviewComments(rs.getString("REVIEW_COMMENTS"));
		alleleRequest.setResearcherName(rs.getString("RESEARCHER_NAME"));
		alleleRequest.setModTypeOtherExplanation(rs.getString("ALLELE_MOD_OTHER_EXPLN"));
		alleleRequest.setGenePublications(rs.getString("GENE_PUBLICATIONS"));
		alleleRequest.setMousePublications(rs.getString("MOUSE_PUBLICATIONS"));
		alleleRequest.setMgpPhenotypingRequired(rs.getBoolean("MGP_PHENOTYPING_REQUIRED"));
		alleleRequest.setSeeAlso(rs.getString("SEE_ALSO"));
		alleleRequest.setStatusDictId(rs.getLong("STATUS_DICT_ID"));
		if(rs.wasNull()) alleleRequest.setStatusDictId(null);
		alleleRequest.setStatus(dictionaryService.fetchEntry(DictionaryEnum.ALLELE_REQUEST_STATUS, alleleRequest.getStatusDictId()));
		alleleRequest.setModTypeDictId(rs.getLong("ALLELE_MOD_TYPE_DICT_ID"));
		if(rs.wasNull()) alleleRequest.setModTypeDictId(null);		
		alleleRequest.setModType(dictionaryService.fetchEntry(DictionaryEnum.ALLELE_REQUEST_MOD_TYPE, alleleRequest.getModTypeDictId()));
		alleleRequest.setTargetEndpointDictId(rs.getLong("TARGET_ENDPOINT_DICT_ID"));
		if(rs.wasNull()) alleleRequest.setTargetEndpointDictId(null);		
		alleleRequest.setTargetEndpoint(dictionaryService.fetchEntry(DictionaryEnum.ALLELE_REQUEST_TARGET_ENDPOINT, alleleRequest.getTargetEndpointDictId()));
		alleleRequest.setSourceDictId(rs.getLong("REQUEST_SOURCE_DICT_ID"));
		if(rs.wasNull()) alleleRequest.setSourceDictId(null);
		alleleRequest.setSource(dictionaryService.fetchEntry(DictionaryEnum.ALLELE_REQUEST_SOURCE, alleleRequest.getSourceDictId()));
		alleleRequest.setMigGeneId(rs.getLong("GENE_ID"));
		if(rs.wasNull()){alleleRequest.setMigGeneId(null);}
		else{alleleRequest.setMigGene(migGeneService.fetchById(rs.getLong("GENE_ID"), ComponentMap.of(MigGene.Component.ALL_COMPONENTS)));}
		alleleRequest.setRequestOwner(personService.fetchById(rs.getLong("REQUESTER_PERSON_ID"), ComponentMap.of(Person.Component.ALL_COMPONENTS)));
		
		return alleleRequest;
	}
}
