/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.alleles;

import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.common.PaginatedSearchBean;


public class AlleleSearchBean extends PaginatedSearchBean {
	
	public enum FilterOptions {
		ENTERED_BY("Entered By"),
		GENE_ID("Gene ID"),
		GENE_NAME("Gene/Allele Name"),
		ALLELE_SYNONYM("Allele Synonym");
		
		private String displayText;
		
		private FilterOptions(String displayText) {
			this.displayText = displayText;
		}
		
		public String getDisplayText() {
			return displayText;
		}
		
		public String getName() {
			return name();
		}
	}	 
	
	private Allele allele;
	private String filterByOption;
	private String filterByValue;
	
	public AlleleSearchBean() {
		allele = new Allele();
		allele.setMutationNature(new DictionaryEntry());
		allele.setInheritanceMode(new DictionaryEntry());
	}

	public Allele getAllele() {
		return allele;
	}

	public void setAllele(Allele allele) {
		this.allele = allele;
	}

	public String getFilterByOption() {
		return filterByOption;
	}

	public void setFilterByOption(String filterByOption) {
		this.filterByOption = filterByOption;
	}

	public String getFilterByValue() {
		return filterByValue;
	}

	public void setFilterByValue(String filterByValue) {
		this.filterByValue = filterByValue;
	}	
}
