/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.alleles.controllers;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.ParameterizableViewController;

import uk.ac.sanger.mig.alleles.services.AlleleService;
import uk.ac.sanger.mig.charting.ChartData;
import ChartDirector.Chart;
import ChartDirector.PieChart;
import ChartDirector.TextBox;

public class AlleleMutationNatureController extends
		ParameterizableViewController {
	
	private AlleleService alleleService;
	private SimpleDateFormat dateFormat = new SimpleDateFormat("EEE, d MMM yyyy");
	
	protected ModelAndView handleRequestInternal(HttpServletRequest request, HttpServletResponse response) throws Exception {
		ChartData chartData =  alleleService.fetchMutationNatureChartData();			
		Map<String,Object> model = new HashMap<String, Object>();	
		
		int total = 0;
		for(double data : chartData.getData(0)) {
			total += data;
		}		

		//Pie formatting
		String titleText = "Alleles by Mutation Nature as of " + dateFormat.format(new Date()) + ", Total = " + total;
		PieChart chart = new PieChart(1200, 600, 0xE9EDF1, 0x000000, 1);
		chart.setPieSize(600, 370, 200);
		chart.set3D(20);
		chart.setLabelLayout(Chart.SideLayout);
		chart.setRoundedFrame();
		chart.setLineColor(Chart.SameAsMainColor, 0x000000);
		chart.setStartAngle(0, false);
				
		//Title
		TextBox title = chart.addTitle(titleText, "Arial Bold", 15);
		TextBox clickInfo = chart.addTitle2(2, "Click a label or pie slice to view alleles for that mutation nature", "", 8);
		title.setBackground(0xCBDCED, 0x000000, Chart.glassEffect());
		clickInfo.setMargin(10);
		
		//Label formatting
		TextBox labels = chart.setLabelStyle();
		labels.setBackground(Chart.SameAsMainColor, Chart.Transparent, Chart.glassEffect());
		labels.setRoundedCorners(5);
		labels.setMaxWidth(300);
		chart.setLabelFormat("{label} ({value})<*br*>{percent|1}%");
			
		//Generate chart
		chart.setData(chartData.getData(0), chartData.getLabels());
		chart.addExtraField(chartData.getExtraFields());		
		String imageId = "alleleMutationnatureClassPiechart" + new Date().getTime();
		chart.makeSession(request, imageId);
		model.put("imageId", imageId);
		model.put("imageMap", chart.getHTMLImageMap("list_allele_info.do", "bypassForm=true&allele.mutationNatureDictId={field0}&newQuery=true&paginated=true&allRecords=false&suppressValidation=true&recordSetOffset=1&recordSetLength=25&orderDesc=false&retrieveFromSession=false", "title='Click to show list of alleles for mutation nature {label}'"));
		
		return new ModelAndView(getViewName(),model);		
	}
	
	public void setalleleService(AlleleService alleleService) {
		this.alleleService = alleleService;
	}
}
