/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.alleles.dao;

import java.util.Collection;

import uk.ac.sanger.mig.alleles.PrimerPair;
import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;

public class PrimerPairDaoSpringImpl extends AbstractDaoSpringImpl<PrimerPair> implements PrimerPairDao {
	
	public Collection <PrimerPair> fetchPrimerPairsByGenotypeTestId(Long genotypeTestId) {
		String sql = "SELECT * FROM typ_genotyping_primer_pair WHERE genotype_test_id = ?";		
		Collection<PrimerPair> primerPairs = getSimpleJdbcTemplate().query(sql, getRowMapper(), genotypeTestId);
		return primerPairs;
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, PrimerPair primerPair) {
		sql.addStringParam(primerPair.getFivePrimeForward(), "FIVE_PRIME_FORWARD");
		sql.addStringParam(primerPair.getThreePrimeReverse(), "THREE_PRIME_REVERSE");
		sql.addLongParam(primerPair.getPrimerPairTypeId(), "PRIMER_PAIR_TYPE_ID");
		sql.addIntParam(primerPair.getExpectedSize(), "EXPECTED_SIZE");
		sql.addFloatParam(primerPair.getMeltTemp(), "MELT_TEMP");
		sql.addLongParam(primerPair.getGenotypeTestId(), "GENOTYPE_TEST_ID");
		sql.addLongParam(primerPair.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(primerPair.getCreatedDate(), "CREATED_DATE");
		sql.addStringParam(primerPair.getEditedBy(), "EDITED_BY");
		sql.addDateParam(primerPair.getEditDate(), "EDIT_DATE");
		sql.addLongParam(primerPair.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(primerPair.getId(), "ID");
	}
}
