/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.alleles.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.alleles.view.AlleleListView;


public class AlleleListViewRowMapper implements ParameterizedRowMapper<AlleleListView> {

	public AlleleListView mapRow(ResultSet rs, int rowNum) throws SQLException {
		
		AlleleListView alleleListView = new AlleleListView();		

		alleleListView.setId(rs.getLong("ID"));
		alleleListView.setLocusId(rs.getLong("LOCUS_ID"));
		if(rs.wasNull()) alleleListView.setLocusId(null);
		alleleListView.setMutationNatureId(rs.getLong("MUTATION_NATURE_ID"));
		if(rs.wasNull()) alleleListView.setMutationNatureId(null);
		alleleListView.setMutationNature(rs.getString("MUTATION_NATURE"));
		alleleListView.setInternalName(rs.getString("INTERNAL_NAME"));
		alleleListView.setOfficialNameSuperscript(rs.getString("OFFICIAL_NAME_SUPERSCRIPT"));
		alleleListView.setHtmlAlleleSymbol(rs.getString("HTML_ALLELE_SYMBOL"));
		alleleListView.setMultiGeneRegion(rs.getBoolean("MULTI_GENE_REGION"));
		alleleListView.setIsHomozygousLethal(rs.getString("IS_HOMOZYGOUS_LETHAL"));
		alleleListView.setInheritanceModeId(rs.getLong("INHERITANCE_MODE_ID"));
		if(rs.wasNull()) alleleListView.setInheritanceModeId(null);
		alleleListView.setInheritanceMode(rs.getString("INHERITANCE_MODE"));
		alleleListView.setHasAssociatedPhenotype(rs.getString("HAS_ASSOCIATED_PHENOTYPE"));
		alleleListView.setPhenotypeDescription(rs.getString("PHENOTYPE_DESCRIPTION"));
		alleleListView.setMultiGeneRegionDescrip(rs.getString("MULTI_GENE_REGION_DESCRIP"));
		alleleListView.setAlleleDescription(rs.getString("ALLELE_DESCRIPTION"));
		alleleListView.setShortAlleleSymbol(rs.getString("SHORT_ALLELE_SYMBOL"));
		alleleListView.setCreatedDate(rs.getTimestamp("CREATED_DATE"));
		alleleListView.setCreatorId(rs.getLong("CREATOR_ID"));
		if(rs.wasNull()) alleleListView.setCreatorId(null);
		alleleListView.setGeneId(rs.getLong("GENE_ID"));
		if(rs.wasNull()) alleleListView.setGeneId(null);
		alleleListView.setGeneName(rs.getString("GENE_NAME"));
		alleleListView.setEnsemblId(rs.getString("ENSEMBL_ID"));
		alleleListView.setMultipleGeneRegionName(rs.getString("MULTIPLE_GENE_REGION_NAME"));
		alleleListView.setAlleleMakerId(rs.getLong("ALLELE_MAKER_ID"));
		if(rs.wasNull()) alleleListView.setAlleleMakerId(null);
		alleleListView.setAlleleMakerName(rs.getString("ALLELE_MAKER_NAME"));
		alleleListView.setEditDate(rs.getTimestamp("EDIT_DATE"));
		alleleListView.setEditedBy(rs.getString("EDITED_BY"));
		alleleListView.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) alleleListView.setCheckNumber(null);
		alleleListView.setHarmfulMutant(rs.getBoolean("HARMFUL_MUTANT"));
		alleleListView.setMutationClassDictId(rs.getLong("MUTATION_CLASS_DICT_ID"));
		if(rs.wasNull()) alleleListView.setMutationClassDictId(null);	
		alleleListView.setMutationClass(rs.getString("MUTATION_CLASS"));
		alleleListView.setExternalMakerName(rs.getString("EXTERNAL_MAKER_NAME"));
		alleleListView.setCreatorName(rs.getString("CREATOR_NAME"));
		alleleListView.setAlleleSynonyms(rs.getString("ALLELE_SYNONYMS"));
		
		return alleleListView;
		
	}
}