/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.alleles.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.alleles.Allele;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;

public class AlleleRowMapper implements ParameterizedRowMapper<Allele> {

	private DictionaryService dictionaryService;

	public DictionaryService getDictionaryService() {
		return dictionaryService;
	}

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	public Allele mapRow(ResultSet rs, int rowNum) throws SQLException {

		Allele allele = new Allele();

		allele.setDescriptionUri(rs.getString("DESCRIPTION_URI"));
		allele.setId(rs.getLong("ID") );
		allele.setMultiGeneRegion(rs.getBoolean("MULTI_GENE_REGION"));
		allele.setMultiGeneRegionDescrip(rs.getString("MULTI_GENE_REGION_DESCRIP"));
		allele.setLocusId(rs.getLong("LOCUS_ID") );
		if(rs.wasNull()) allele.setLocusId(null);
		allele.setInternalName(rs.getString("INTERNAL_NAME"));
		allele.setOfficialNameSuperscript(rs.getString("OFFICIAL_NAME_SUPERSCRIPT"));
		allele.setMigGeneId(rs.getLong("GENE_ID"));
		if(rs.wasNull()) allele.setMigGeneId(null);
		allele.setWhetherHomozygousLethal(rs.getString("IS_HOMOZYGOUS_LETHAL"));
		allele.setHasAssociatedPhenotype(rs.getString("HAS_ASSOCIATED_PHENOTYPE"));
		allele.setPhenotypeDescription(rs.getString("PHENOTYPE_DESCRIPTION"));
		allele.setInheritanceModeDictId(rs.getLong("INHERITANCE_MODE_ID"));
		if(rs.wasNull()) allele.setInheritanceModeDictId(null);
		allele.setInheritanceMode(dictionaryService.fetchEntry(DictionaryEnum.ALLELE_INHERITANCE_MODE_DICT, allele.getInheritanceModeDictId()));
		allele.setMutationNatureDictId(rs.getLong("MUTATION_NATURE_ID"));
		if(rs.wasNull()) allele.setMutationNatureDictId(null);
		allele.setMutationNature(dictionaryService.fetchEntry(DictionaryEnum.ALLELE_MUTATION_NATURE_DICT, allele.getMutationNatureDictId()));
		allele.setAlleleDescription(rs.getString("ALLELE_DESCRIPTION"));
		allele.setAlleleMakerId(rs.getLong("ALLELE_MAKER_ID"));
		if(rs.wasNull()) allele.setAlleleMakerId(null);
		allele.setExternalMakerName(rs.getString("MAKER_NAME"));
		allele.setCreatorId(rs.getLong("CREATOR_ID"));
		if(rs.wasNull()) allele.setCreatorId(null);
		allele.setCreatedDate(rs.getDate("CREATED_DATE"));
		allele.setShortAlleleSymbol(rs.getString("SHORT_ALLELE_SYMBOL"));
		allele.setMultipleGeneName(rs.getString("MULTIPLE_GENE_REGION_NAME"));
		allele.setEditDate(rs.getDate("EDIT_DATE"));
		allele.setEditedBy(rs.getString("EDITED_BY"));
		allele.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) allele.setCheckNumber(null);
		allele.setMutationClassDictId(rs.getLong("MUTATION_CLASS_DICT_ID"));
		if(rs.wasNull()) allele.setMutationClass(null);
		allele.setMutationClass(dictionaryService.fetchEntry(DictionaryEnum.ALLELE_MUTATION_CLASS_DICT, allele.getMutationClassDictId()));

		return allele;
	}
}
