/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.alleles.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.alleles.PrimerPair;

public class PrimerPairRowMapper implements ParameterizedRowMapper<PrimerPair> {

	public PrimerPair mapRow(ResultSet rs, int rowNum) throws SQLException {
		
		 PrimerPair primerPair = new PrimerPair();
		 
		 primerPair.setId(rs.getLong("ID"));
		 primerPair.setFivePrimeForward(rs.getString("FIVE_PRIME_FORWARD"));
		 primerPair.setThreePrimeReverse(rs.getString("THREE_PRIME_REVERSE"));
		 primerPair.setPrimerPairTypeId(rs.getLong("PRIMER_PAIR_TYPE_ID"));
		 if(rs.wasNull()) primerPair.setPrimerPairTypeId(null);
		 primerPair.setExpectedSize(rs.getInt("EXPECTED_SIZE"));
		 if(rs.wasNull()) primerPair.setExpectedSize(null);
		 primerPair.setMeltTemp(rs.getFloat("MELT_TEMP"));
		 if(rs.wasNull()) primerPair.setMeltTemp(null);
		 primerPair.setCreatorId(rs.getLong("CREATOR_ID"));
		 if(rs.wasNull()) primerPair.setCreatorId(null);
		 primerPair.setCreatedDate(rs.getDate("CREATED_DATE"));
		 primerPair.setEditedBy(rs.getString("EDITED_BY"));
		 primerPair.setEditDate(rs.getDate("EDIT_DATE"));
		 primerPair.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		 if(rs.wasNull()) primerPair.setCheckNumber(null);
		 
		 return primerPair;
	}
}
