/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.alleles.services;

import java.util.Collection;
import java.util.regex.Pattern;

import uk.ac.sanger.mig.alleles.Allele;
import uk.ac.sanger.mig.alleles.AlleleSearchBean;
import uk.ac.sanger.mig.alleles.forms.AlleleInfoForm;
import uk.ac.sanger.mig.alleles.view.AlleleListView;
import uk.ac.sanger.mig.charting.ChartData;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.mirequest.InvalidTeam87InfoException;
import uk.ac.sanger.mig.personnel.Person;

public interface AlleleService {

	public static final Long HARMFUL_MUTATION = 3L;

	public static final Long DOMINANT_ALLELE = 1L;

	public static final Long SEMIDOMINANT_ALLELE = 3L;

	public static final Long RECESSIVE_ALLELE = 2L;

	public static final Long UNKNOWN_INHERITANCE_MODE_ALLELE = 5L;

	/**
	 * Returns the unique Allele for a given gene and official name,
	 * or null of none exists.
	 *
	 * @param geneId
	 * @param officialName
	 * @param requiredComponents
	 * @return
	 */
	public Allele fetchBySuperscriptAndGeneId( Long geneId, String officialName,
			ComponentMap requiredComponents);

	/**
	 * Returns an Allele with MigGene attached if the allele has a valid gene id..
	 *
	 * Tests if the Allele already exists based on its gene id and official name,
	 * and if it does, returns that Allele (with non-null id) as the working allele.
	 *
	 * Otherwise, returns a new Team 87 Allele (with null id) populated with EPD/Team 87
	 * defaults on null fields (non-null fields are left unchanged).
	 *
	 * @param team87Allele
	 * @return working allele
	 * @throws InvalidTeam87InfoException if teamAllele gene id is not null and does
	 * not resolve to MigGene
	 */
	public Allele deriveEpdAllele( Allele newAllele ) throws InvalidTeam87InfoException;

	public Long store(Allele allele, Person person);

	public Long storeComplete(AlleleInfoForm alleleForm, Person person);

	public Allele fetchById(Long id, ComponentMap requiredComponents);

	public Collection<Allele> fetch(AlleleSearchBean alleleSearchBean, ComponentMap requiredComponents);

	public Collection<AlleleListView> search(AlleleSearchBean alleleSearchBean);

	public Collection<AlleleListView> lookup(String geneOrAlleleName);

	public void inflateAlleleComponents(Allele allele);

	public ChartData fetchMutationNatureChartData();

	public Collection<Allele> fetchAllByGeneId(Long geneId);
}
