/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
package uk.ac.sanger.mig.alleles.services;

import java.util.Collection;

import uk.ac.sanger.mig.alleles.AlleleSynonym;
import uk.ac.sanger.mig.alleles.dao.AlleleSynonymDao;
import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.personnel.Person;

public class AlleleSynonymServiceImpl extends AbstractServiceImpl<AlleleSynonym> implements AlleleSynonymService {
	
	private AlleleSynonymDao alleleSynonymDao;
	
	public void setAlleleSynonymDao(AlleleSynonymDao alleleSynonymDao) {
		this.alleleSynonymDao = alleleSynonymDao;
	}

	public Long storeAuthenticated(AlleleSynonym alleleSynonym, Person user) {
		if(alleleSynonym == null) {
			throw new RuntimeException("Cannot save a null alleleSynonym");
		}
		
		return alleleSynonymDao.store(alleleSynonym, user);
	}
	
	public AlleleSynonym fetchById(Long alleleSynonymId, ComponentMap requiredComponents) {
		AlleleSynonym alleleSynonym = alleleSynonymDao.fetchById(alleleSynonymId);
		
		if(alleleSynonym != null)
			attachComponents(alleleSynonym, requiredComponents);
		
		return alleleSynonym;
	}

	@Override
	protected void attachComponents(AlleleSynonym alleleSynonym, ComponentMap requiredComponents) {
		if(alleleSynonym == null) {
			throw new RuntimeException("Cannot attach components to null alleleSynonym");
		}		
		
		boolean fetchAll = false;
		
		if(requiredComponents != null) {
			
			if(requiredComponents.containsKey(AlleleSynonym.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}	
		}
	}

	public Collection <AlleleSynonym> fetchByAlleleId(Long alleleId, ComponentMap componentMap) {

		Collection<AlleleSynonym> alleleSynonyms = alleleSynonymDao.fetchByAlleleId(alleleId, componentMap);
		
		attachComponents(alleleSynonyms, componentMap);
		
		return alleleSynonyms;
	}

	public int deleteAlleleSynonym(AlleleSynonym alleleSynonym, Person user) {
		return alleleSynonymDao.delete(alleleSynonym, user);		
	}
}
								