/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.alleles.validators;

import org.springframework.validation.Errors;
import org.springframework.validation.ValidationUtils;
import org.springframework.validation.Validator;

import uk.ac.sanger.mig.alleles.AlleleSynonym;
import uk.ac.sanger.mig.alleles.forms.AlleleSynonymForm;

public class AlleleSynonymFormValidator implements Validator {

	public boolean supports(Class clazz) {
		return AlleleSynonymForm.class.equals(clazz);
	}

	public void validate(Object commandForm, Errors errors) {	

		AlleleSynonymForm alleleSynonymForm = (AlleleSynonymForm)commandForm;
		AlleleSynonym alleleSynonym = alleleSynonymForm.getAlleleSynonym();

		ValidationUtils.rejectIfEmptyOrWhitespace(errors, "alleleSynonym.alleleSynonym", null, "Please specify Allele Synonym.");
		
		if (alleleSynonym.getAlleleSynonymText() != null) {
			if (alleleSynonym.getAlleleSynonymText().length() > 30) {
				errors.rejectValue("alleleSynonym.alleleSynonym", "", "* Allele Synonym can be a maximum of 30 characters in length *");
			}
		}
	}
}
