/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.alleles.view;


import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.LookupListElement;
import uk.ac.sanger.mig.common.LookupListUtil;

public class AlleleListView extends AuthenticatedDataObject implements LookupListElement {
     
    private Long locusId;        
    private Long mutationNatureId;        
    private String mutationNature;        
    private String internalName;        
    private String officialNameSuperscript;  
    private String htmlAlleleSymbol;
    private boolean multiGeneRegion;        
    private String isHomozygousLethal;        
    private Long inheritanceModeId;        
    private String inheritanceMode;        
    private String hasAssociatedPhenotype;        
    private String phenotypeDescription;        
    private String multiGeneRegionDescrip;        
    private String alleleDescription;        
    private String shortAlleleSymbol;        
    private Long geneId;        
    private String geneName;        
    private String ensemblId;        
    private String multipleGeneRegionName;        
    private Long alleleMakerId;        
    private String alleleMakerName;        
    private boolean harmfulMutant;        
    private Long mutationClassDictId;        
    private String mutationClass;        
    private String externalMakerName;
    private String creatorName;
    private String alleleSynonyms;
    
	public String getAlleleDescription() {
		return alleleDescription;
	}
	public void setAlleleDescription(String alleleDescription) {
		this.alleleDescription = alleleDescription;
	}
	public Long getAlleleMakerId() {
		return alleleMakerId;
	}
	public void setAlleleMakerId(Long alleleMakerId) {
		this.alleleMakerId = alleleMakerId;
	}
	public String getAlleleMakerName() {
		return alleleMakerName;
	}
	public void setAlleleMakerName(String alleleMakerName) {
		this.alleleMakerName = alleleMakerName;
	}
	public String getEnsemblId() {
		return ensemblId;
	}
	public void setEnsemblId(String ensemblId) {
		this.ensemblId = ensemblId;
	}
	public Long getGeneId() {
		return geneId;
	}
	public void setGeneId(Long geneId) {
		this.geneId = geneId;
	}
	public String getGeneName() {
		return geneName;
	}
	public void setGeneName(String geneName) {
		this.geneName = geneName;
	}
	public boolean isHarmfulMutant() {
		return harmfulMutant;
	}
	public void setHarmfulMutant(boolean harmfulMutant) {
		this.harmfulMutant = harmfulMutant;
	}
	public String getHasAssociatedPhenotype() {
		return hasAssociatedPhenotype;
	}
	public void setHasAssociatedPhenotype(String hasAssociatedPhenotype) {
		this.hasAssociatedPhenotype = hasAssociatedPhenotype;
	}
	public String getInheritanceMode() {
		return inheritanceMode;
	}
	public void setInheritanceMode(String inheritanceMode) {
		this.inheritanceMode = inheritanceMode;
	}
	public Long getInheritanceModeId() {
		return inheritanceModeId;
	}
	public void setInheritanceModeId(Long inheritanceModeId) {
		this.inheritanceModeId = inheritanceModeId;
	}
	public String getInternalName() {
		return internalName;
	}
	public void setInternalName(String internalName) {
		this.internalName = internalName;
	}
	public String getIsHomozygousLethal() {
		return isHomozygousLethal;
	}
	public void setIsHomozygousLethal(String isHomozygousLethal) {
		this.isHomozygousLethal = isHomozygousLethal;
	}
	public Long getLocusId() {
		return locusId;
	}
	public void setLocusId(Long locusId) {
		this.locusId = locusId;
	}
	public String getExternalMakerName() {
		return externalMakerName;
	}
	public void setExternalMakerName(String makerName) {
		this.externalMakerName = makerName;
	}
	public boolean isMultiGeneRegion() {
		return multiGeneRegion;
	}
	public void setMultiGeneRegion(boolean multiGeneRegion) {
		this.multiGeneRegion = multiGeneRegion;
	}
	public String getMultiGeneRegionDescrip() {
		return multiGeneRegionDescrip;
	}
	public void setMultiGeneRegionDescrip(String multiGeneRegionDescrip) {
		this.multiGeneRegionDescrip = multiGeneRegionDescrip;
	}
	public String getMultipleGeneRegionName() {
		return multipleGeneRegionName;
	}
	public void setMultipleGeneRegionName(String multipleGeneRegionName) {
		this.multipleGeneRegionName = multipleGeneRegionName;
	}
	public String getMutationClass() {
		return mutationClass;
	}
	public void setMutationClass(String mutationClass) {
		this.mutationClass = mutationClass;
	}
	public Long getMutationClassDictId() {
		return mutationClassDictId;
	}
	public void setMutationClassDictId(Long mutationClassDictId) {
		this.mutationClassDictId = mutationClassDictId;
	}
	public String getMutationNature() {
		return mutationNature;
	}
	public void setMutationNature(String mutationName) {
		this.mutationNature = mutationName;
	}
	public Long getMutationNatureId() {
		return mutationNatureId;
	}
	public void setMutationNatureId(Long mutationNatureId) {
		this.mutationNatureId = mutationNatureId;
	}
	public String getOfficialNameSuperscript() {
		return officialNameSuperscript;
	}
	public void setOfficialNameSuperscript(String officialNameSuperscript) {
		this.officialNameSuperscript = officialNameSuperscript;
	}
	public String getPhenotypeDescription() {
		return phenotypeDescription;
	}
	public void setPhenotypeDescription(String phenotypeDescription) {
		this.phenotypeDescription = phenotypeDescription;
	}
	public String getShortAlleleSymbol() {
		return shortAlleleSymbol;
	}
	public void setShortAlleleSymbol(String shortAlleleSymbol) {
		this.shortAlleleSymbol = shortAlleleSymbol;
	}
	public String getHtmlAlleleSymbol() {
		return htmlAlleleSymbol;
	}
	public void setHtmlAlleleSymbol(String htmlAlleleSymbol) {
		this.htmlAlleleSymbol = htmlAlleleSymbol;
	}
	public String getCreatorName() {
		return creatorName;
	}
	public void setCreatorName(String creatorName) {
		this.creatorName = creatorName;
	}
	public String getDisplayText() {
		String displayText;
		if(geneName == null || geneName.equals("")) {
			displayText = "(No Gene)";
		}
		else {
			displayText = geneName;
		}
		displayText += "<" + officialNameSuperscript + ">";
		return displayText;
	}
	public String getElementData() {
		return LookupListUtil.format("alleleId", getId()) +
		LookupListUtil.format("officialNameSuperscript", officialNameSuperscript) +
		LookupListUtil.format("primaryName", (geneName == null) ? "" : geneName);
	}
	public void setDisplayText(String displayText) {
		// TODO Auto-generated method stub
		
	}
	public void setElementData(String elementData) {
		// TODO Auto-generated method stub
		
	}
	public String getAlleleSynonyms() {
		return alleleSynonyms;
	}
	public void setAlleleSynonyms(String alleleSynonyms) {
		this.alleleSynonyms = alleleSynonyms;
	}
}