/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.animalrequest.dao;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.animalrequest.AnimalRequest;
import uk.ac.sanger.mig.animalrequest.AnimalRequestSearchBean;
import uk.ac.sanger.mig.animalrequest.dao.rowmappers.AnimalRequestListViewRowMapper;
import uk.ac.sanger.mig.animalrequest.views.AnimalRequestListView;
import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.common.PaginatedSearchUtils;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;

public class AnimalRequestDaoSpringImpl extends AbstractDaoSpringImpl<AnimalRequest> implements AnimalRequestDao {

	private PaginatedSearchUtils<AnimalRequestListView> paginator;
	private AnimalRequestListViewRowMapper animalRequestListViewRowMapper;
	
	public void setPaginator(PaginatedSearchUtils<AnimalRequestListView> paginator) {
		this.paginator = paginator;
	}

	public void setAnimalRequestListViewRowMapper(
			AnimalRequestListViewRowMapper animalRequestListViewRowMapper) {
		this.animalRequestListViewRowMapper = animalRequestListViewRowMapper;
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, AnimalRequest animalRequest) {
		sql.addLongParam(animalRequest.getProjectLicenceId(), "PROJECT_LICENCE_ID");
		sql.addStringParam(animalRequest.getRequestReason(), "REQUEST_REASON");
		sql.addLongParam(animalRequest.getStrainId(), "STRAIN_ID");
		sql.addIntParam(animalRequest.getNumMalesNeeded(), "NUM_MALES_NEEDED");
		sql.addIntParam(animalRequest.getNumFemalesNeeded(), "NUM_FEMALES_NEEDED");
		sql.addDateParam(animalRequest.getDateRequired(), "DATE_REQUIRED");
		sql.addDateParam(animalRequest.getEndDate(), "END_DATE");
		sql.addLongParam(animalRequest.getDestinationRoomId(), "DESTINATION_ROOM_ID");
		sql.addStringParam(animalRequest.getStandingOrderDay(), "STANDING_ORDER_DAY");
		sql.addStringParam(animalRequest.getStandingOrderFrequency(), "STANDING_ORDER_FREQ");
		sql.addIntParam(animalRequest.getNumberInCage(), "NUMBER_IN_CAGE");
		sql.addBooleanParam(animalRequest.getRederivationReq(), "REDERIVATION_REQUESTED");
		sql.addStringParam(animalRequest.getComments(), "COMMENTS");
		sql.addStringParam(animalRequest.getEmbryoAge(), "EMBRYO_AGE_NEEDED");
		sql.addStringParam(animalRequest.getAgeOrWeightUnits(), "AGE_OR_WEIGHT_UNITS");
		sql.addStringParam(animalRequest.getAgeOrWeight(), "AGE_OR_WEIGHT");
		sql.addStringParam(animalRequest.getFundingSource(), "FUNDING_SOURCE");
		sql.addLongParam(animalRequest.getStatusDictId(), "STATUS_DICT_ID");
		sql.addStringParam(animalRequest.getDevelopmentEndpoint(), "DEVELOPMENT_ENDPOINT");
		sql.addDateParam(animalRequest.getCreatedDate(), "CREATED_DATE");
		sql.addStringParam(animalRequest.getEditedBy(), "EDITED_BY");
		sql.addDateParam(animalRequest.getEditDate(), "EDIT_DATE");
		sql.addLongParam(animalRequest.getRequestOwnerId(), "REQUEST_ORIGINATOR_ID");
		sql.addLongParam(animalRequest.getCreatorId(), "CREATOR_ID");
		sql.addLongParam(animalRequest.getCheckNumber(), "CHECK_NUMBER");
		sql.addBooleanParam(animalRequest.isPseudoPregnantFemale(), "PSEUDO_PREGNANT_FEMALE");	
		sql.addLongParam(animalRequest.getGroupDictId(), "GROUP_DICT_ID");
		
		sql.addLongParam(animalRequest.getId(), "ID");
	}
	
	public Collection<AnimalRequestListView> search(AnimalRequestSearchBean searchBean) {
		Collection<Object> bindVariables = new ArrayList<Object>();
		AnimalRequest animalRequest = searchBean.getAnimalRequest();

		StringBuffer sql = new StringBuffer();		
		sql.append(" select * from req_animal_request_list_vw where 1=1 ");

		// search by status id
		if(animalRequest.getStatusDictId() != null) {
			sql.append(" and status_dict_id = ? ");
			bindVariables.add(animalRequest.getStatusDictId());
		}

		if( animalRequest.getGroupDictId() != null ) {
			sql.append(" and group_dict_id = ? " );
			bindVariables.add( animalRequest.getGroupDictId() );
		}
		
		if(searchBean.getOrderBy() != null && searchBean.getOrderBy().length() > 0) {
			sql.append(" order by " + searchBean.getOrderBy());
			if(searchBean.isOrderDesc()) {
				sql.append(" desc ");
			}
		}	
		else {
			sql.append(" order by id");
		}

		return paginator.fetchSearchResults(
				sql.toString(), 
				bindVariables, 
				searchBean, 
				animalRequestListViewRowMapper);
	}	

	public Collection<AnimalRequest> fetch(AnimalRequestSearchBean searchBean) {
		Collection<Object> bindVariables = new ArrayList<Object>();
		AnimalRequest animalRequest = searchBean.getAnimalRequest();

		StringBuffer sql = new StringBuffer();		
		sql.append(" select * from req_animal_request c where 1=1 ");

		// search by status id
		if(animalRequest.getStatusDictId() != 0 ) {
			sql.append(" and c.status_dict_id = ? ");
			bindVariables.add(animalRequest.getStatusDictId());
		}

		if(searchBean.getOrderBy() != null && searchBean.getOrderBy().length() > 0) {
			sql.append(" order by " + searchBean.getOrderBy());
			if(searchBean.isOrderDesc()) {
				sql.append(" desc ");
			}
		}		

		Collection<AnimalRequest> animalRequests = 
			getSimpleJdbcTemplate().query(
					sql.toString(), 
					getRowMapper(),
					bindVariables.toArray());

		return (animalRequests == null) ? new ArrayList<AnimalRequest>() : animalRequests;
	}

}
