/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.animalrequest.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.animalrequest.views.AnimalRequestListView;

public class AnimalRequestListViewRowMapper implements ParameterizedRowMapper<AnimalRequestListView> {

	public AnimalRequestListView mapRow(ResultSet rs, int rowNum) throws SQLException {

		AnimalRequestListView animalRequestListView = new AnimalRequestListView();


		animalRequestListView.setId(rs.getLong("ID"));

		animalRequestListView.setProjectLicenceId(rs.getInt("PROJECT_LICENCE_ID"));

		animalRequestListView.setPplHolder(rs.getString("PPL_HOLDER"));

		animalRequestListView.setRequestReason(rs.getString("REQUEST_REASON"));

		animalRequestListView.setStrainId(rs.getInt("STRAIN_ID"));

		animalRequestListView.setStrain(rs.getString("STRAIN"));

		animalRequestListView.setNumMalesNeeded(rs.getInt("NUM_MALES_NEEDED"));

		animalRequestListView.setNumFemalesNeeded(rs.getInt("NUM_FEMALES_NEEDED"));

		animalRequestListView.setDateRequired(rs.getTimestamp("DATE_REQUIRED"));

		animalRequestListView.setDestinationRoomId(rs.getInt("DESTINATION_ROOM_ID"));

		animalRequestListView.setDestinationRoom(rs.getString("DESTINATION_ROOM"));

		animalRequestListView.setStandingOrderFreq(rs.getString("STANDING_ORDER_FREQ"));

		animalRequestListView.setStandingOrderDay(rs.getString("STANDING_ORDER_DAY"));

		animalRequestListView.setNumberInCage(rs.getInt("NUMBER_IN_CAGE"));

		animalRequestListView.setRederivationRequested(rs.getBoolean("REDERIVATION_REQUESTED"));

		animalRequestListView.setComments(rs.getString("COMMENTS"));

		animalRequestListView.setEmbryoAgeNeeded(rs.getString("EMBRYO_AGE_NEEDED"));

		animalRequestListView.setAgeOrWeightUnits(rs.getString("AGE_OR_WEIGHT_UNITS"));

		animalRequestListView.setAgeOrWeight(rs.getString("AGE_OR_WEIGHT"));

		animalRequestListView.setFundingSource(rs.getString("FUNDING_SOURCE"));

		animalRequestListView.setStatusDictId(rs.getInt("STATUS_DICT_ID"));

		animalRequestListView.setStatus(rs.getString("STATUS"));

		animalRequestListView.setDevelopmentEndpoint(rs.getString("DEVELOPMENT_ENDPOINT"));

		animalRequestListView.setCreatedDate(rs.getTimestamp("CREATED_DATE"));

		animalRequestListView.setEditedBy(rs.getString("EDITED_BY"));

		animalRequestListView.setEditDate(rs.getTimestamp("EDIT_DATE"));

		animalRequestListView.setRequestOriginatorId(rs.getInt("REQUEST_ORIGINATOR_ID"));

		animalRequestListView.setRequester(rs.getString("REQUESTER"));

		animalRequestListView.setTeamNumber(rs.getInt("TEAM_NUMBER"));

		animalRequestListView.setCreatorId(rs.getLong("CREATOR_ID"));

		animalRequestListView.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) animalRequestListView.setCheckNumber(null);		

		animalRequestListView.setPseudoPregnantFemale(rs.getBoolean("PSEUDO_PREGNANT_FEMALE"));

		animalRequestListView.setEndDate(rs.getTimestamp("END_DATE"));

		animalRequestListView.setGroupDictId(rs.getLong("GROUP_DICT_ID"));
		
		animalRequestListView.setGroupDictName(rs.getString("GROUP_DICT_NAME"));
		
		return animalRequestListView;

	}
}