/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.animalrequest.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.animalrequest.AnimalRequest;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;

public class AnimalRequestRowMapper implements ParameterizedRowMapper<AnimalRequest> {
	
	private DictionaryService dictionaryService;
	
	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	public AnimalRequest mapRow(ResultSet rs, int rowNum) throws SQLException {
		AnimalRequest animalRequest = new AnimalRequest();		
		
		animalRequest.setId(rs.getLong("ID"));

		animalRequest.setProjectLicenceId(rs.getLong("PROJECT_LICENCE_ID"));
		if(rs.wasNull()) animalRequest.setProjectLicenceId(null);		

		animalRequest.setRequestReason(rs.getString("REQUEST_REASON"));

		animalRequest.setStrainId(rs.getLong("STRAIN_ID"));
		if(rs.wasNull()) animalRequest.setStrainId(null);		
		animalRequest.setStrain(dictionaryService.fetchEntry(DictionaryEnum.MOUSE_STRAIN, animalRequest.getStrainId()));

		animalRequest.setGroupDictId(rs.getLong("GROUP_DICT_ID"));
		if(rs.wasNull()) animalRequest.setGroupDictId(null);	
		
		animalRequest.setGroupDict(dictionaryService.fetchEntry(DictionaryEnum.MOUSE_WILDTYPE_GROUP_DICT, 
				animalRequest.getGroupDictId()));
		
		animalRequest.setNumMalesNeeded(rs.getInt("NUM_MALES_NEEDED"));

		animalRequest.setNumFemalesNeeded(rs.getInt("NUM_FEMALES_NEEDED"));

		animalRequest.setDateRequired(rs.getTimestamp("DATE_REQUIRED"));
		animalRequest.setEndDate(rs.getTimestamp("END_DATE"));

		animalRequest.setDestinationRoomId(rs.getLong("DESTINATION_ROOM_ID"));
		if(rs.wasNull()) animalRequest.setDestinationRoomId(null);		

		animalRequest.setStandingOrderFrequency(rs.getString("STANDING_ORDER_FREQ"));

		animalRequest.setStandingOrderDay(rs.getString("STANDING_ORDER_DAY"));

		animalRequest.setNumberInCage(rs.getInt("NUMBER_IN_CAGE"));
		
		animalRequest.setRederivationReq(rs.getBoolean("REDERIVATION_REQUESTED"));

		animalRequest.setComments(rs.getString("COMMENTS"));

		animalRequest.setEmbryoAge(rs.getString("EMBRYO_AGE_NEEDED"));

		animalRequest.setAgeOrWeightUnits(rs.getString("AGE_OR_WEIGHT_UNITS"));

		animalRequest.setAgeOrWeight(rs.getString("AGE_OR_WEIGHT"));

		animalRequest.setFundingSource(rs.getString("FUNDING_SOURCE"));

		animalRequest.setStatusDictId(rs.getLong("STATUS_DICT_ID"));
		if(rs.wasNull()) animalRequest.setStatusDictId(null);	
		animalRequest.setStatus(dictionaryService.fetchEntry(DictionaryEnum.WILDTYPE_REQUEST_STATUS, animalRequest.getStatusDictId()));
		
		animalRequest.setDevelopmentEndpoint(rs.getString("DEVELOPMENT_ENDPOINT"));

		animalRequest.setCreatedDate(rs.getTimestamp("CREATED_DATE"));

		animalRequest.setEditedBy(rs.getString("EDITED_BY"));

		animalRequest.setEditDate(rs.getTimestamp("EDIT_DATE"));

		animalRequest.setRequestOwnerId(rs.getLong("REQUEST_ORIGINATOR_ID"));
		if(rs.wasNull()) animalRequest.setRequestOwnerId(null);				

		animalRequest.setCreatorId(rs.getLong("CREATOR_ID"));
		if(rs.wasNull()) animalRequest.setCreatorId(null);	
		
		animalRequest.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) animalRequest.setCheckNumber(null);
		
		animalRequest.setPseudoPregnantFemale(rs.getBoolean("PSEUDO_PREGNANT_FEMALE"));
		
		return animalRequest;
	}
}
