/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.annotation;

import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.ComponentEnum;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.database.TableMetadataEnum;

/**
 * @author ae1
 *
 */
public class Annotation extends AuthenticatedDataObject {

	public enum Component implements ComponentEnum {
		ALL_COMPONENTS,
		CREATOR
	}

	private String termName;
	private String termId;
	private Long ontologyDictId;
	private DictionaryEntry ontologyDict;
    private TableMetadataEnum foreignTableName;
    private Long foreignKeyId;

	public String getTermId() {
		return this.termId;
	}
	public void setTermId(String termId) {
		this.termId = termId;
	}
	public String getTermName() {
		return this.termName;
	}
	public void setTermName(String termName) {
		this.termName = termName;
	}
	public DictionaryEntry getOntologyDict() {
		return this.ontologyDict;
	}
	public void setOntologyDict(DictionaryEntry ontologyDict) {
		this.ontologyDict = ontologyDict;
	}
	public Long getOntologyDictId() {
		return this.ontologyDictId;
	}
	public void setOntologyDictId(Long ontologyDictId) {
		this.ontologyDictId = ontologyDictId;
	}
	public Long getForeignKeyId() {
		return this.foreignKeyId;
	}
	public void setForeignKeyId(Long foreignKeyId) {
		this.foreignKeyId = foreignKeyId;
	}
	public TableMetadataEnum getForeignTableName() {
		return this.foreignTableName;
	}
	public void setForeignTableName(TableMetadataEnum foreignTableName) {
		this.foreignTableName = foreignTableName;
	}
	@Override
	public int hashCode() {
		final int PRIME = 31;
		int result = super.hashCode();
		result = PRIME * result + ((this.foreignKeyId == null) ? 0 : this.foreignKeyId.hashCode());
		result = PRIME * result + ((this.foreignTableName == null) ? 0 : this.foreignTableName.hashCode());
		result = PRIME * result + ((this.ontologyDictId == null) ? 0 : this.ontologyDictId.hashCode());
		result = PRIME * result + ((this.termId == null) ? 0 : this.termId.hashCode());
		return result;
	}
	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (!super.equals(obj))
			return false;
		if (getClass() != obj.getClass())
			return false;
		final Annotation other = (Annotation) obj;
		if (this.foreignKeyId == null) {
			if (other.foreignKeyId != null)
				return false;
		} else if (!this.foreignKeyId.equals(other.foreignKeyId))
			return false;
		if (this.foreignTableName == null) {
			if (other.foreignTableName != null)
				return false;
		} else if (!this.foreignTableName.equals(other.foreignTableName))
			return false;
		if (this.ontologyDictId == null) {
			if (other.ontologyDictId != null)
				return false;
		} else if (!this.ontologyDictId.equals(other.ontologyDictId))
			return false;
		if (this.termId == null) {
			if (other.termId != null)
				return false;
		} else if (!this.termId.equals(other.termId))
			return false;
		return true;
	}



}
