/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.annotation.controllers;

import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.Controller;

import uk.ac.sanger.mig.annotation.services.OntologyLookupService;

/**
 *
 * This class is responsible for handling requests for image tiles.
 *
 * @author ae1
 *
 */
public class OntologyLookupController implements Controller {

	private OntologyLookupService ontologyLookupService;
	private OntologyLookupView ontologyLookupView;

	public ModelAndView handleRequest(HttpServletRequest request, HttpServletResponse response) throws Exception {

		String partialName    	= ServletRequestUtils.getStringParameter(request, "q", null);
		String ontologyName 	= ServletRequestUtils.getRequiredStringParameter(request, "ontologyName");
		boolean reverseKeyOrder = ServletRequestUtils.getBooleanParameter(request, "reverseKeyOrder" , false);

		Map lookupTerms = ontologyLookupService.getTermsByName(partialName, ontologyName, reverseKeyOrder);

		return new ModelAndView(ontologyLookupView, ontologyLookupView.getModelName(), lookupTerms);
	}

	public void setOntologyLookupService(OntologyLookupService ontologyLookupService) {
		this.ontologyLookupService = ontologyLookupService;
	}

	public void setOntologyLookupView(OntologyLookupView ontologyLookupView) {
		this.ontologyLookupView = ontologyLookupView;
	}









}