/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.annotation.dao;

import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.database.TableMetadataEnum;
import uk.ac.sanger.mig.annotation.Annotation;

public class AnnotationDaoSpringImpl extends AbstractDaoSpringImpl<Annotation> implements AnnotationDao {



	public Collection<Annotation> fetchByTableAndForeignKey(
			TableMetadataEnum table, Long foreignKeyId) {

		String sql = "select * from "+getTableName()+" a where A.FOREIGN_TABLE_NAME = ? and A.FOREIGN_KEY_ID = ?";

		return fetchCollection(sql, table.toString(), foreignKeyId);
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, Annotation annotation) {
		sql.addLongParam(annotation.getId(), "ID");
		sql.addStringParam(annotation.getTermName(), "TERM_NAME");
		sql.addStringParam(annotation.getTermId(), "TERM_ID");
		sql.addLongParam(annotation.getOntologyDictId(), "ONTOLOGY_DICT_ID");
		sql.addDateParam(annotation.getEditDate(), "EDIT_DATE");
		sql.addStringParam(annotation.getEditedBy(), "EDITED_BY");
		sql.addDateParam(annotation.getCreatedDate(), "CREATED_DATE");
		sql.addLongParam(annotation.getCreatorId(), "CREATOR_ID");
		sql.addLongParam(annotation.getCheckNumber(), "CHECK_NUMBER");
		sql.addEnumParam(annotation.getForeignTableName(), "FOREIGN_TABLE_NAME");
		sql.addLongParam(annotation.getForeignKeyId(), "FOREIGN_KEY_ID");
	}

}