package uk.ac.sanger.mig.annotation.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.annotation.Annotation;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.database.TableMetadataEnum;

public class AnnotationMapper implements ParameterizedRowMapper<Annotation> {

	private DictionaryService dictionaryService;

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	public Annotation mapRow(ResultSet rs, int rowNum) throws SQLException {

		Annotation annotation = new Annotation();
		annotation.setId(rs.getLong("ID"));

		annotation.setTermName(rs.getString("TERM_NAME"));
		annotation.setTermId(rs.getString("TERM_ID"));

		annotation.setOntologyDictId(rs.getLong("ONTOLOGY_DICT_ID"));

		if(rs.wasNull()) {
			annotation.setOntologyDictId(null);
		} else {
			DictionaryEntry ontologyDict = dictionaryService.fetchEntry(
					DictionaryEnum.ANN_ONTOLOGY_DICT, annotation.getOntologyDictId());
			annotation.setOntologyDict(ontologyDict);
		}

		annotation.setEditDate(rs.getDate("EDIT_DATE"));
		annotation.setEditedBy(rs.getString("EDITED_BY"));
		annotation.setCreatedDate(rs.getDate("CREATED_DATE"));

		annotation.setCreatorId(rs.getLong("CREATOR_ID"));
		if(rs.wasNull()) {annotation.setCreatorId(null);}

		annotation.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) {annotation.setCheckNumber(null);}

		annotation.setForeignTableName(Enum.valueOf(TableMetadataEnum.class,
					rs.getString("FOREIGN_TABLE_NAME")));

		annotation.setForeignKeyId(rs.getLong("FOREIGN_KEY_ID"));
		if(rs.wasNull()) {annotation.setForeignKeyId(null);}

		return annotation;

	}



}