/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.annotation.services;

import java.rmi.RemoteException;
import java.util.Map;
import java.util.Properties;

import javax.xml.rpc.ServiceException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import uk.ac.ebi.ook.web.services.QueryService;

/**
 * @author ae1
 *
 */
public class OntologyLookupServiceImpl implements OntologyLookupService {

	protected Log logger = LogFactory.getLog(this.getClass());

	private QueryService queryService;

	public OntologyLookupServiceImpl(String proxyHost, String proxyPort, boolean isProxy) {

		Properties props= new Properties(System.getProperties());
	    props.put("http.proxySet", Boolean.valueOf(isProxy).toString());
	    props.put("http.proxyHost", proxyHost);     //the host and port need to be configured
	    props.put("http.proxyPort", proxyPort);     //for your network environment.
	    Properties newprops = new Properties(props);
	    System.setProperties(newprops);
	}


	public String fetchByTermId(String termId, String ontologyName)
				throws RemoteException, ServiceException {

		return queryService.getOntologyQuery().getTermById(termId, ontologyName);

	}

	public Map getTermsByName(String partialName, String ontologyName, boolean reverseKeyOrder)
				throws RemoteException, ServiceException {

		logger.debug("Querying " + partialName + " " + ontologyName);

		return queryService.getOntologyQuery().getTermsByName(partialName,
				ontologyName, reverseKeyOrder);

	}


	public void setQueryService(QueryService queryService) {

		this.queryService = queryService;

/*
		Map m = null;

		System.out.println("testing OLS...");

		try {

			m = getTermsByName("hepa", "MPATH", true);

			for(Object key : m.keySet() ) {

				System.out.println(key + ":" + m.get(key));

				Map m1 = queryService.getOntologyQuery().getTermMetadata((String)key, "MPATH");

				for(Object key1 : m1.keySet()) {

					System.out.println("-->" + key1 + ":" + m1.get(key1));

				}

				System.out.println();
			}

		} catch(Exception e) {}

*/
	}



}
