/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.charting;

/**
 * ChartData is a genetic interface for generating charts using ChartDirector.
 * A variable number of datasets can be included and accessed via an array.
 * 
 * ExtraFields and ExtraFields2 follow the nomenclature used by ChartDirector.
 *
 * ChartDirector uses double[] arrays to plot chart data, and string[] arrays for labels
 * 
 */
public interface ChartData {

	/**
	 * Returns a String array of labels (e.g. for labelling pie-charts or the x-axis of an XY graph)
	 * @return
	 */
	public String[] getLabels();
	
	/**
	 * Returns a double array of datapoints for a chart.
	 * @param dataSetIndex the dataset to be returned (starting at zero)
	 * @return
	 */
	public double[] getData(int dataSetIndex);
	
	/**
	 * Returns a String array of additional data (e.g. the primary key of a label)
	 * @return
	 */
	public String[] getExtraFields();
	
	/**
	 * Returns a String array of additional further data (e.g. a URL for a data-point)
	 * @return
	 */
	public String[] getExtraFields2();
	
}
