/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.colony.controllers;

import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.propertyeditors.CustomBooleanEditor;
import org.springframework.validation.BindException;
import org.springframework.web.bind.ServletRequestDataBinder;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.CancellableFormController;

import uk.ac.sanger.mig.colony.ColonyCross;
import uk.ac.sanger.mig.colony.forms.ColonyCrossForm;
import uk.ac.sanger.mig.colony.services.ColonyInfoService;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.personnel.Person;

public class ColonyCrossFormController extends CancellableFormController {
	
	private ColonyInfoService colonyInfoService;

	public void setColonyInfoService(ColonyInfoService colonyInfoService) {
		this.colonyInfoService = colonyInfoService;
	}

	@Override
	protected void initBinder(HttpServletRequest httpServletRequest, ServletRequestDataBinder binder) {	
	
		// Create and register Boolean binder for Boolean values which also allows null values
		CustomBooleanEditor customBooleanEditor = new CustomBooleanEditor(true);
		binder.registerCustomEditor(Boolean.class, customBooleanEditor);		
	}
	
	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		ColonyCrossForm form = (ColonyCrossForm)command;
		
		ColonyCross colonyCross = form.getColonyCross();
		Person person = RequestUtils.getUser(request);
		
		colonyInfoService.storeColonyCross(colonyCross, person);
		
		return new ModelAndView(getSuccessView() + colonyCross.getColonyId());
	}

	@Override
	protected Map referenceData(HttpServletRequest request) throws Exception {
		Map<String, Object> referenceData = new HashMap<String, Object>();
		
		//Yes/No list
		Map<Boolean, String> yesNo = new HashMap<Boolean, String>();
		yesNo.put(false,"No");	
		yesNo.put(true,"Yes");	
		referenceData.put("yesNo",yesNo);
		
		return referenceData;
	}

	@Override
	protected Object formBackingObject(HttpServletRequest request) throws Exception {
		Long colonyId = ServletRequestUtils.getRequiredLongParameter(request, "colonyInfoId");
		
		ColonyCrossForm form = new ColonyCrossForm();
		form.setColonyCross(new ColonyCross());
		form.getColonyCross().setColonyId(colonyId);
		
		return form;
	}

	@Override
	protected ModelAndView onCancel(HttpServletRequest request, HttpServletResponse response, Object command) throws Exception {
		ColonyCrossForm form = (ColonyCrossForm)command;		
		ColonyCross colonyCross = form.getColonyCross();
		return new ModelAndView(getSuccessView() + colonyCross.getColonyId());
	}	
}
