/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.colony.controllers;

import java.util.Collection;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.colony.ColonyInfoSearchBean;
import uk.ac.sanger.mig.colony.services.ColonyInfoService;
import uk.ac.sanger.mig.colony.views.ColonyInfoListView;
import uk.ac.sanger.mig.common.AbstractSearchFormController;
import uk.ac.sanger.mig.licensing.ProjectLicence;
import uk.ac.sanger.mig.licensing.services.ProjectLicenceService;

public class ColonyInfoListController extends AbstractSearchFormController {

	private ColonyInfoService colonyInfoService;	
	private ProjectLicenceService projectLicenceService;

	public void setColonyInfoService(ColonyInfoService colonyInfoService) {
		this.colonyInfoService = colonyInfoService;
	}

	public void setProjectLicenceService(ProjectLicenceService projectLicenceService) {
		this.projectLicenceService = projectLicenceService;
	}

	@Override
	protected ModelAndView onSearch(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		ColonyInfoSearchBean searchBean = (ColonyInfoSearchBean)command;
		searchBean.setQueryName("listColonies");
		
		Collection<ColonyInfoListView> colonies = colonyInfoService.search(searchBean);
		
		Map<String, Object> model = new HashMap<String, Object>();
		model.put("colonies", colonies);
		
		return showForm(request, errors, getFormView(), model);
	}

	@Override
	protected Map referenceData(HttpServletRequest request, Object command, Errors errors) throws Exception {
		Map<String, Object> referenceData = new HashMap<String, Object>();
		
		Collection<ProjectLicence> ppls = projectLicenceService.fetchAll(null);
		referenceData.put("ppls", ppls);
		
		Set<String> stringMatchModes = new HashSet<String>();
		stringMatchModes.add("Starts With");
		stringMatchModes.add("Contains");
		stringMatchModes.add("Ends With");
		referenceData.put("stringMatchModes", stringMatchModes);
		
		return referenceData;
	}
	
}
