/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.colony.controllers;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.ParameterizableViewController;

import uk.ac.sanger.mig.colony.ColonyAllele;
import uk.ac.sanger.mig.colony.ColonyBehaviour;
import uk.ac.sanger.mig.colony.ColonyCoatColour;
import uk.ac.sanger.mig.colony.ColonyContact;
import uk.ac.sanger.mig.colony.ColonyCross;
import uk.ac.sanger.mig.colony.ColonyRoom;
import uk.ac.sanger.mig.colony.ColonyStrain;
import uk.ac.sanger.mig.colony.services.ColonyInfoService;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.filesupport.BinaryFile;
import uk.ac.sanger.mig.personnel.Person;

public class DeleteColonyChildController extends ParameterizableViewController {
	
	private ColonyInfoService colonyInfoService;

	public void setColonyInfoService(ColonyInfoService colonyInfoService) {
		this.colonyInfoService = colonyInfoService;
	}

	@Override
	protected ModelAndView handleRequestInternal(HttpServletRequest request, HttpServletResponse response) throws Exception {
		
		Long id = ServletRequestUtils.getRequiredLongParameter(request, "id");
		Long colonyInfoId = ServletRequestUtils.getRequiredLongParameter(request, "colonyInfoId");
		String childElement = ServletRequestUtils.getRequiredStringParameter(request, "childElement");
		
		Person person = RequestUtils.getUser(request);
		
		if(childElement.equalsIgnoreCase("allele")) {
			ColonyAllele colonyAllele = colonyInfoService.fetchColonyAllele(id, null);			
			if(colonyAllele != null) {
				colonyInfoService.deleteColonyAllele(colonyAllele, person);				
			}
		}
		else if(childElement.equalsIgnoreCase("behaviour")) {
			ColonyBehaviour colonyBehaviour = colonyInfoService.fetchColonyBehaviour(id, null);			
			if(colonyBehaviour != null) {
				colonyInfoService.deleteColonyBehaviour(colonyBehaviour, person);				
			}
		}
		else if(childElement.equalsIgnoreCase("coatColour")) {
			ColonyCoatColour colonyCoatColour = colonyInfoService.fetchColonyCoatColour(id, null);			
			if(colonyCoatColour != null) {
				colonyInfoService.deleteColonyCoatColour(colonyCoatColour, person);				
			}
		}
		else if(childElement.equalsIgnoreCase("contact")) {
			ColonyContact colonyContact = colonyInfoService.fetchColonyContact(id, null);			
			if(colonyContact != null) {
				colonyInfoService.deleteColonyContact(colonyContact, person);				
			}
		}
		else if(childElement.equalsIgnoreCase("cross")) {
			ColonyCross colonyCross = colonyInfoService.fetchColonyCross(id, null);			
			if(colonyCross != null) {
				colonyInfoService.deleteColonyCross(colonyCross, person);				
			}
		}
		else if(childElement.equalsIgnoreCase("file")) {
			BinaryFile binaryFile = colonyInfoService.fetchColonyFile(id, null);			
			if(binaryFile != null) {
				colonyInfoService.deleteColonyFile(binaryFile, person);				
			}
		}
		else if(childElement.equalsIgnoreCase("room")) {
			ColonyRoom colonyRoom = colonyInfoService.fetchColonyRoom(id, null);			
			if(colonyRoom != null) {
				colonyInfoService.deleteColonyRoom(colonyRoom, person);				
			}
		}
		else if(childElement.equalsIgnoreCase("strain")) {
			ColonyStrain colonyAllele = colonyInfoService.fetchColonyStrain(id, null);			
			if(colonyAllele != null) {
				colonyInfoService.deleteColonyStrain(colonyAllele, person);				
			}
		}
		
		return new ModelAndView(getViewName() + colonyInfoId);
	}	
}
