/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.colony.dao;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.colony.ColonyContact;
import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;

public class ColonyContactDaoSpringImpl extends AbstractDaoSpringImpl<ColonyContact> implements ColonyContactDao {

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, ColonyContact colonyContact) {
		sql.addLongParam(colonyContact.getPersonId(), "PERSON_ID");
		sql.addLongParam(colonyContact.getColonyId(), "COLONY_ID");
		sql.addStringParam(colonyContact.getReason(), "REASON");
		sql.addStringParam(colonyContact.getEditedBy(), "EDITED_BY");
		sql.addDateParam(colonyContact.getEditDate(), "EDIT_DATE");
		sql.addLongParam(colonyContact.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(colonyContact.getContactTypeDictId(), "COLONY_CONTACT_TYPE_DICT_ID");
		sql.addLongParam(colonyContact.getId(), "ID");
	}
	
	public Collection<ColonyContact> fetchByColonyId(Long colonyId) {
		String sql = " select * from mts_colony_contact where colony_id = ? ";
		Collection<ColonyContact> colonyContacts = getSimpleJdbcTemplate().query(sql, getRowMapper(), colonyId);
		return (colonyContacts == null) ? new ArrayList<ColonyContact>() : colonyContacts;
	}
	
	public boolean checkContactExists(Long colonyId, Long personId) {
		String sql = " select count(*) from mts_colony_contact where colony_id = ? and person_id = ? ";
		int personCount = getSimpleJdbcTemplate().queryForInt(sql, colonyId, personId);
		return ( personCount == 0 ) ? false : true ;
	}
	
	public boolean checkContactTypeExists(Long colonyId, Long contactTypeDictId) {
		String sql = " select count(*) from mts_colony_contact where colony_id = ? and colony_contact_type_dict_id = ? ";
		int personCount = getSimpleJdbcTemplate().queryForInt(sql, colonyId, contactTypeDictId);
		return ( personCount == 0 ) ? false : true ;		
	}
	
	public boolean allowDuplicateContactType(Long contactTypeDictId) {
		String sql = " select nvl(allow_duplicate_in_colony,0) allow_duplicate_in_colony from mts_colony_contact_type_dict where id = ? ";
		int intValue = getSimpleJdbcTemplate().queryForInt(sql, contactTypeDictId);
		return ( intValue == 0 ) ? false : true ;		
	}	
}
