/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.colony.dao;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.colony.ColonyCross;
import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;

public class ColonyCrossDaoSpringImpl extends AbstractDaoSpringImpl<ColonyCross> implements ColonyCrossDao {

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, ColonyCross colonyCross) {
		sql.addStringParam(colonyCross.getPhenotypeText(), "PHENOTYPE_TEXT");
		sql.addStringParam(colonyCross.getGenotypeText(), "GENOTYPE_TEXT");
		sql.addStringParam(colonyCross.getDelimitedAlleleIds(), "DELIMITED_ALLELE_IDS");
		sql.addLongParam(colonyCross.getColonyId(), "COLONY_ID");
		sql.addBooleanParam(colonyCross.getLethal(), "IS_LETHAL");
		sql.addStringParam(colonyCross.getEditedBy(), "EDITED_BY");
		sql.addDateParam(colonyCross.getEditDate(), "EDIT_DATE");
		sql.addLongParam(colonyCross.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(colonyCross.getId(), "ID");
	}

	public Collection<ColonyCross>  fetchByColonyId( Long colonyId) {
		String sql = " select * from mts_colony_cross where colony_id = ? ";		
		Collection<ColonyCross> colonyCrosses = getSimpleJdbcTemplate().query(sql, getRowMapper(), colonyId);
		return (colonyCrosses == null) ? new ArrayList<ColonyCross>() : colonyCrosses;
	}
}
