/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.colony.dao;

import java.util.Collection;
import java.util.List;

import uk.ac.sanger.mig.colony.ColonyInfo;
import uk.ac.sanger.mig.colony.ColonyInfoSearchBean;
import uk.ac.sanger.mig.colony.views.ColonyInfoListView;
import uk.ac.sanger.mig.database.TypedDao;

public interface ColonyInfoDao extends TypedDao<ColonyInfo> {

	public Collection<ColonyInfoListView> search(ColonyInfoSearchBean searchBean);

	/**
	 * Return colony information records ordered by lowercase colony name.
	 * @param excludeEmpty if true, colonies with no mice will be excluded
	 *
	 * @return Collection of ColonyInfo records
	 */
	public Collection<ColonyInfo> fetchForLookup(boolean excludeEmpty);

	/**
	 * Checks if the input colony name is being used in a different record
	 * @param colonyInfoId the primary key to compare against
	 * @param colonyName the colony name to check
	 * @return true if a record other than the input colonyInfoId is using the input colonyName, otherwise false.
	 */
	public boolean colonyNameExists(Long colonyInfoId, String colonyName);

	/**
	 * Checks if the input colony prefix is being used in a different record
	 * @param colonyInfoId the primary key to compare against
	 * @param colonyPrefix the colony prefix to check
	 * @return true if a record other than the input colonyInfoId is using the input colonyPrefix, otherwise false.
	 */
	public boolean colonyPrefixExists(Long colonyInfoId, String colonyPrefix);


	/**
	 * Returns a sorted ascending List of prefixes given the
	 * lexicographical comparison criteria.
	 *
	 * @param from
	 * @param to
	 * @return
	 */
	public List<String> fetchUsedPrefixes(String greaterThanInclusive, String lessThanInclusive);

}