/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.colony.dao;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.colony.ColonyStrain;
import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;

public class ColonyStrainDaoSpringImpl extends AbstractDaoSpringImpl<ColonyStrain> implements ColonyStrainDao {

	public Float fetchTotalPercent(Long colonyId) {
		String sql = "select nvl(sum(percent),0) total from mts_colony_strain where colony_id = ?";

		Float total = getSimpleJdbcTemplate().queryForObject(sql, Float.class, colonyId);

		return total;
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, ColonyStrain colonyStrain) {
		sql.addLongParam(colonyStrain.getStrainId(), "STRAIN_ID");
		sql.addLongParam(colonyStrain.getColonyId(), "COLONY_ID");
		sql.addStringParam(colonyStrain.getEditedBy(), "EDITED_BY");
		sql.addDateParam(colonyStrain.getEditDate(), "EDIT_DATE");
		sql.addLongParam(colonyStrain.getCheckNumber(), "CHECK_NUMBER");
		sql.addStringParam(colonyStrain.getComments(), "COMMENTS");
		sql.addLongParam(colonyStrain.getId(), "ID");
	}

	public Collection<ColonyStrain> fetchByColonyId(Long colonyId) {
		String sql = " select * from mts_colony_strain where colony_id = ? ";
		Collection<ColonyStrain> colonyStrains = getSimpleJdbcTemplate().query(sql, getRowMapper(), colonyId);
		return (colonyStrains == null) ? new ArrayList<ColonyStrain>() : colonyStrains;
	}

	public Boolean checkExists(Long colonyId, Long strainId, Long colonyStrainId) {
		Collection<Object> bindVariables = new ArrayList<Object>();
		bindVariables.add(colonyId);
		bindVariables.add(strainId);

		String sql = " select count(*) from mts_colony_strain where colony_id = ? and strain_id = ? ";
		if(colonyStrainId != null) {
			sql += " and id != ? ";
			bindVariables.add(colonyStrainId);
		}
		int strainCount = getSimpleJdbcTemplate().queryForInt(sql, bindVariables.toArray(new Object[0]));
		return ( strainCount == 0 ) ? false : true ;
	}
}