/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.colony.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.colony.ColonyContact;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;

public class ColonyContactRowMapper implements ParameterizedRowMapper<ColonyContact> {
	
	private DictionaryService dictionaryService;

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	public ColonyContact mapRow(ResultSet rs, int rowNum) throws SQLException {
		
		ColonyContact colonyContact = new ColonyContact();
		
		colonyContact.setId(rs.getLong("ID"));
		colonyContact.setPersonId(rs.getLong("PERSON_ID"));
		if(rs.wasNull()) colonyContact.setPersonId(null);		
		colonyContact.setColonyId(rs.getLong("COLONY_ID"));
		if(rs.wasNull()) colonyContact.setColonyId(null);		
		colonyContact.setReason(rs.getString("REASON"));
		colonyContact.setEditedBy(rs.getString("EDITED_BY"));
		colonyContact.setEditDate(rs.getDate("EDIT_DATE"));
		colonyContact.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) colonyContact.setCheckNumber(null);	
		colonyContact.setContactTypeDictId(rs.getLong("COLONY_CONTACT_TYPE_DICT_ID"));
		if(rs.wasNull()) colonyContact.setContactTypeDictId(null);
		
		colonyContact.setContactType(dictionaryService.fetchEntry(DictionaryEnum.COLONY_CONTACT_TYPE, colonyContact.getContactTypeDictId()));
		
		return colonyContact;		
	}
}