/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.colony.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.colony.views.ColonyInfoListView;

public class ColonyInfoListViewRowMapper implements ParameterizedRowMapper<ColonyInfoListView> {

	public ColonyInfoListView mapRow(ResultSet rs, int rowNum) throws SQLException {
		
		ColonyInfoListView colonyInfoListView = new ColonyInfoListView();
		
		colonyInfoListView.setId(rs.getLong("ID"));
		colonyInfoListView.setColonyName(rs.getString("COLONY_NAME"));
		colonyInfoListView.setProjectLicenceId(rs.getInt("PROJECT_LICENCE_ID"));
		colonyInfoListView.setCardColourDictId(rs.getInt("CARD_COLOUR_DICT_ID"));
		colonyInfoListView.setCardColour(rs.getString("CARD_COLOUR"));
		colonyInfoListView.setAverageLitterSize(rs.getInt("AVERAGE_LITTER_SIZE"));
		colonyInfoListView.setBreedingLifespanWeeks(rs.getString("BREEDING_LIFESPAN_WEEKS"));
		colonyInfoListView.setImmuneStatus(rs.getString("IMMUNE_STATUS"));
		colonyInfoListView.setDiet(rs.getString("DIET"));
		colonyInfoListView.setHousingSystem(rs.getString("HOUSING_SYSTEM"));
		colonyInfoListView.setEnvironmentalEnrichment(rs.getString("ENVIRONMENTAL_ENRICHMENT"));
		colonyInfoListView.setColonyOrigin(rs.getString("COLONY_ORIGIN"));
		colonyInfoListView.setPlaceOfOrigin(rs.getString("PLACE_OF_ORIGIN"));
		colonyInfoListView.setDateOfImport(rs.getDate("DATE_OF_IMPORT"));
		colonyInfoListView.setDateOfRederivation(rs.getDate("DATE_OF_REDERIVATION"));
		colonyInfoListView.setRederivationMethod(rs.getString("REDERIVATION_METHOD"));
		colonyInfoListView.setEditedBy(rs.getString("EDITED_BY"));
		colonyInfoListView.setEditDate(rs.getDate("EDIT_DATE"));
		colonyInfoListView.setWelfareAssessmentPerformed(rs.getBoolean("WELFARE_ASSESSMENT_PERFORMED"));
		colonyInfoListView.setWtsiOrigin(rs.getBoolean("WTSI_ORIGIN"));
		colonyInfoListView.setColonyPrefix(rs.getString("COLONY_PREFIX"));
		colonyInfoListView.setModeOfInheritance(rs.getString("MODE_OF_INHERITANCE"));
		colonyInfoListView.setPplHolder(rs.getString("PPL_HOLDER"));
		colonyInfoListView.setCreatedBy(rs.getLong("CREATED_BY"));
		colonyInfoListView.setCreatedDate(rs.getDate("CREATED_DATE"));
		
		return colonyInfoListView;
		
	}
}