/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.colony.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.colony.ColonyInfo;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;

public class ColonyInfoRowMapper implements ParameterizedRowMapper<ColonyInfo> {

	private DictionaryService dictionaryService;

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	public ColonyInfo mapRow(ResultSet rs, int rowNum) throws SQLException {

		ColonyInfo colonyInfo = new ColonyInfo();

		colonyInfo.setId(rs.getLong("ID"));
		colonyInfo.setColonyName(rs.getString("COLONY_NAME"));
		colonyInfo.setProjectLicenceId(rs.getLong("PROJECT_LICENCE_ID"));
		if(rs.wasNull()) colonyInfo.setProjectLicenceId(null);
		colonyInfo.setCardColourDictId(rs.getLong("CARD_COLOUR_DICT_ID"));
		if(rs.wasNull()) colonyInfo.setCardColourDictId(null);
		colonyInfo.setColonyManagement(rs.getString("COLONY_MANAGEMENT"));
		colonyInfo.setAverageLitterSize(rs.getInt("AVERAGE_LITTER_SIZE"));
		if(rs.wasNull()) colonyInfo.setAverageLitterSize(null);
		colonyInfo.setBreedingLifespanWeeks(rs.getFloat("BREEDING_LIFESPAN_WEEKS"));
		if(rs.wasNull()) colonyInfo.setBreedingLifespanWeeks(null);
		colonyInfo.setImmuneStatus(rs.getString("IMMUNE_STATUS"));
		colonyInfo.setOtherAbnormalities(rs.getString("OTHER_ABNORMALITIES"));
		colonyInfo.setWelfareAssessment(rs.getString("WELFARE_ASSESSMENT"));
		colonyInfo.setHusbandryRecommendations(rs.getString("HUSBANDRY_RECOMMENDATIONS"));
		colonyInfo.setDiet(rs.getString("DIET"));
		colonyInfo.setHousingSystem(rs.getString("HOUSING_SYSTEM"));
		colonyInfo.setEnvironmentalEnrichment(rs.getString("ENVIRONMENTAL_ENRICHMENT"));
		colonyInfo.setMiscNotes(rs.getString("MISC_NOTES"));
		colonyInfo.setColonyOrigin(rs.getString("COLONY_ORIGIN"));
		colonyInfo.setPlaceOfOrigin(rs.getString("PLACE_OF_ORIGIN"));
		colonyInfo.setDateOfImport(rs.getDate("DATE_OF_IMPORT"));
		colonyInfo.setDateOfRederivation(rs.getDate("DATE_OF_REDERIVATION"));
		colonyInfo.setRederivationMethod(rs.getString("REDERIVATION_METHOD"));
		colonyInfo.setEditedBy(rs.getString("EDITED_BY"));
		colonyInfo.setEditDate(rs.getDate("EDIT_DATE"));
		colonyInfo.setWelfareAssessmentPerformed(rs.getBoolean("WELFARE_ASSESSMENT_PERFORMED"));
		colonyInfo.setWtsiOrigin(rs.getBoolean("WTSI_ORIGIN"));
		colonyInfo.setColonyPrefix(rs.getString("COLONY_PREFIX"));
		colonyInfo.setModeOfInheritance(rs.getString("MODE_OF_INHERITANCE"));
		colonyInfo.setAssessingPhenotype(rs.getString("ASSESSING_PHENOTYPE"));
		colonyInfo.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) colonyInfo.setCheckNumber(null);
		colonyInfo.setCreatorId(rs.getLong("CREATED_BY"));
		colonyInfo.setCreatedDate(rs.getDate("CREATED_DATE"));
		colonyInfo.setSubjectToMta(rs.getBoolean("SUBJECT_TO_MTA"));
		colonyInfo.setPoolable(rs.getBoolean("IS_POOLABLE"));
		colonyInfo.setAutofillStrain(rs.getBoolean("AUTOFILL_STRAIN"));

		colonyInfo.setCardColour(dictionaryService.fetchEntry(DictionaryEnum.COLONY_CARD_COLOUR, colonyInfo.getCardColourDictId()));

		return colonyInfo;

	}
}
