/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.colony.services;

import java.util.Collection;

import uk.ac.sanger.mig.colony.ColonyBehaviour;
import uk.ac.sanger.mig.colony.dao.ColonyBehaviourDao;
import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.personnel.Person;

public class ColonyBehaviourServiceImpl extends AbstractServiceImpl<ColonyBehaviour> implements ColonyBehaviourService {
	
	private ColonyBehaviourDao colonyBehaviourDao;
	
	public void setColonyBehaviourDao(ColonyBehaviourDao colonyBehaviourDao) {
		this.colonyBehaviourDao = colonyBehaviourDao;
	}

	public int delete(ColonyBehaviour colonyBehaviour, Person user) {
		return colonyBehaviourDao.delete(colonyBehaviour, user);
	}

	public Collection<ColonyBehaviour> fetchByColonyId(Long colonyId, ComponentMap requiredComponents) {
		Collection<ColonyBehaviour> colonyBehaviours = colonyBehaviourDao.fetchByColonyId(colonyId);
		attachComponents(colonyBehaviours, requiredComponents);
		return colonyBehaviours;
	}

	public Long storeAuthenticated(ColonyBehaviour colonyBehaviour, Person user) {
		if(colonyBehaviour == null) {
			throw new RuntimeException("Cannot save a null colonyBehaviour");
		}
		
		return colonyBehaviourDao.store(colonyBehaviour, user);
	}
	
	public ColonyBehaviour fetchById(Long colonyBehaviourId, ComponentMap requiredComponents) {
		ColonyBehaviour colonyBehaviour = colonyBehaviourDao.fetchById(colonyBehaviourId);
		
		if(colonyBehaviour != null)
			attachComponents(colonyBehaviour, requiredComponents);
		
		return colonyBehaviour;
	}

	@Override
	protected void attachComponents(ColonyBehaviour colonyBehaviour, ComponentMap requiredComponents) {
		if(colonyBehaviour == null) {
			throw new RuntimeException("Cannot attach components to null colonyBehaviour");
		}		
	}	
}
								