/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.colony.services;

import java.util.Collection;

import uk.ac.sanger.mig.colony.ColonyCoatColour;
import uk.ac.sanger.mig.colony.dao.ColonyCoatColourDao;
import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.personnel.Person;

public class ColonyCoatColourServiceImpl extends AbstractServiceImpl<ColonyCoatColour> implements ColonyCoatColourService {
	
	private ColonyCoatColourDao colonyCoatColourDao;
	
	public void setColonyCoatColourDao(ColonyCoatColourDao colonyCoatColourDao) {
		this.colonyCoatColourDao = colonyCoatColourDao;
	}

	public int delete(ColonyCoatColour colonyCoatColour, Person user) {
		return colonyCoatColourDao.delete(colonyCoatColour, user);
	}

	public Collection<ColonyCoatColour> fetchByColonyId(Long colonyId, ComponentMap requiredComponents) {
		Collection<ColonyCoatColour> colonyCoatColours = colonyCoatColourDao.fetchByColonyId(colonyId);
		attachComponents(colonyCoatColours, requiredComponents);
		return colonyCoatColours;
	}

	public Long storeAuthenticated(ColonyCoatColour colonyCoatColour, Person user) {
		if(colonyCoatColour == null) {
			throw new RuntimeException("Cannot save a null colonyCoatColour");
		}
		
		return colonyCoatColourDao.store(colonyCoatColour, user);
	}
	
	public ColonyCoatColour fetchById(Long colonyCoatColourId, ComponentMap requiredComponents) {
		ColonyCoatColour colonyCoatColour = colonyCoatColourDao.fetchById(colonyCoatColourId);
		
		if(colonyCoatColour != null)
			attachComponents(colonyCoatColour, requiredComponents);
		
		return colonyCoatColour;
	}

	@Override
	protected void attachComponents(ColonyCoatColour colonyCoatColour, ComponentMap requiredComponents) {
		if(colonyCoatColour == null) {
			throw new RuntimeException("Cannot attach components to null colonyCoatColour");
		}		
	}
}
								