/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.colony.services;

import java.util.Collection;

import uk.ac.sanger.mig.colony.ColonyContact;
import uk.ac.sanger.mig.colony.dao.ColonyContactDao;
import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.personnel.services.PersonService;

public class ColonyContactServiceImpl extends AbstractServiceImpl<ColonyContact> implements ColonyContactService {
	
	private ColonyContactDao colonyContactDao;
	private PersonService personService;
	
	public void setColonyContactDao(ColonyContactDao colonyContactDao) {
		this.colonyContactDao = colonyContactDao;
	}

	public void setPersonService(PersonService personService) {
		this.personService = personService;
	}

	public int delete(ColonyContact colonyContact, Person user) {
		return colonyContactDao.delete(colonyContact, user);
	}

	public Collection<ColonyContact> fetchByColonyId(Long colonyId, ComponentMap requiredComponents) {
		Collection<ColonyContact> colonyContacts = colonyContactDao.fetchByColonyId(colonyId);
		attachComponents(colonyContacts, requiredComponents);
		return colonyContacts;
	}

	public Long storeAuthenticated(ColonyContact colonyContact, Person user) {
		if(colonyContact == null) {
			throw new RuntimeException("Cannot save a null colonyContact");
		}
		
		return colonyContactDao.store(colonyContact, user);
	}
	
	public ColonyContact fetchById(Long colonyContactId, ComponentMap requiredComponents) {
		ColonyContact colonyContact = colonyContactDao.fetchById(colonyContactId);
		
		if(colonyContact != null)
			attachComponents(colonyContact, requiredComponents);
		
		return colonyContact;
	}

	@Override
	protected void attachComponents(ColonyContact colonyContact, ComponentMap requiredComponents) {
		if(colonyContact == null) {
			throw new RuntimeException("Cannot attach components to null colonyContact");
		}		
		
		boolean fetchAll = false;
		
		if(requiredComponents != null) {
			
			if(requiredComponents.containsKey(ColonyContact.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}
			
			if(fetchAll || requiredComponents.containsKey(ColonyContact.Component.PERSON)) {
				colonyContact.setPerson(fetchContact(colonyContact, requiredComponents.get(ColonyContact.Component.PERSON)));				
			}			
		}
	}

	private Person fetchContact(ColonyContact colonyContact, ComponentMap requiredComponents) {
		if(colonyContact.getPersonId() != null) {
			return personService.fetchById(colonyContact.getPersonId(), requiredComponents);
		} 
		else {
			return null;
		}
	}	
	
	public boolean checkContactExists(Long colonyId, Long personId) {
		return colonyContactDao.checkContactExists(colonyId, personId);
	}	

	public boolean checkContactTypeExists(Long colonyId, Long contactTypeDictId) {
		return colonyContactDao.checkContactTypeExists(colonyId, contactTypeDictId);
	}
	
	public boolean allowDuplicateContactType(Long contactTypeDictId) {
		return colonyContactDao.allowDuplicateContactType(contactTypeDictId);
	}
}
								