/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.colony.services;

import java.util.Collection;

import uk.ac.sanger.mig.colony.ColonyCross;
import uk.ac.sanger.mig.colony.dao.ColonyCrossDao;
import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.personnel.Person;

public class ColonyCrossServiceImpl extends AbstractServiceImpl<ColonyCross> implements ColonyCrossService {
	
	private ColonyCrossDao colonyCrossDao;

	public void setColonyCrossDao(ColonyCrossDao colonyCrossDao) {
		this.colonyCrossDao = colonyCrossDao;
	}

	public int delete(ColonyCross colonyCross, Person user) {
		return colonyCrossDao.delete(colonyCross, user);
	}

	public Collection<ColonyCross> fetchByColonyId(Long colonyId, ComponentMap requiredComponents) {
		Collection<ColonyCross> colonyCrosses = colonyCrossDao.fetchByColonyId(colonyId);
		attachComponents(colonyCrosses, requiredComponents);
		return colonyCrosses;
	}

	public Long storeAuthenticated(ColonyCross colonyCross, Person user) {
		if(colonyCross == null) {
			throw new RuntimeException("Cannot save a null colonyCross");
		}
		
		return colonyCrossDao.store(colonyCross, user);
	}
	
	public ColonyCross fetchById(Long colonyCrossId, ComponentMap requiredComponents) {
		ColonyCross colonyCross = colonyCrossDao.fetchById(colonyCrossId);
		
		if(colonyCross != null)
			attachComponents(colonyCross, requiredComponents);
		
		return colonyCross;
	}

	@Override
	protected void attachComponents(ColonyCross colonyCross, ComponentMap requiredComponents) {
		if(colonyCross == null) {
			throw new RuntimeException("Cannot attach components to null colonyCross");
		}	
	}	
}
								