/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.colony.validators;

import org.springframework.validation.Errors;
import org.springframework.validation.ValidationUtils;
import org.springframework.validation.Validator;

import uk.ac.sanger.mig.colony.ColonyContact;
import uk.ac.sanger.mig.colony.forms.ColonyContactForm;
import uk.ac.sanger.mig.colony.services.ColonyContactService;

public class ColonyContactFormValidator implements Validator {

	private ColonyContactService colonyContactService;

	public void setColonyContactService(ColonyContactService colonyContactService) {
		this.colonyContactService = colonyContactService;
	}

	public boolean supports(Class clazz) {
		return ColonyContactForm.class.equals(clazz);
	}

	public void validate(Object commandForm, Errors errors) {	

		ColonyContactForm colonyContactForm = (ColonyContactForm)commandForm;
		ColonyContact colonyContact = colonyContactForm.getColonyContact();

		ValidationUtils.rejectIfEmptyOrWhitespace(errors, "colonyContact.contactTypeDictId", "requiredField", "Contact Reason is a required field.");
		ValidationUtils.rejectIfEmptyOrWhitespace(errors, "personId", "", "Person is a required field.");
		
		if(ColonyContactService.CONTACT_TYPE_OTHER.equals(colonyContact.getContactTypeDictId())) {
			ValidationUtils.rejectIfEmptyOrWhitespace(errors, "colonyContact.reason", "", "Reason Details is a required field.");
		}
		
		// not tested on 4000 but tested on 40 chars
		if (colonyContact.getReason() != null) {
			if (colonyContact.getReason().length() > 4000) {
				errors.rejectValue("colonyContact.reason", "", "Reason Details must be less than 4000 characters.");
			}
		}
		
		// check if duplicate contact types are disallowed and present
		if(colonyContact.getContactTypeDictId() != null) {
			Long contactTypeDictId = colonyContact.getContactTypeDictId();			
			if(!colonyContactService.allowDuplicateContactType(contactTypeDictId) && 
			  colonyContactService.checkContactTypeExists(colonyContact.getColonyId(), contactTypeDictId)) {
				errors.reject(null, "Only one contact of this type is allowed per colony.");
			}
		}

		if (!errors.hasErrors()) {
			//	check for existing:
			Long personId = colonyContact.getPersonId();
			Long colonyId = colonyContact.getColonyId();
			if (colonyContactService.checkContactExists( colonyId, personId )) {
				errors.rejectValue("personId", "", "This person is already a contact for this colony.");	
			}			
		}

	}

}