package uk.ac.sanger.mig.common;

import java.util.Collection;

import org.springframework.transaction.annotation.Transactional;

import uk.ac.sanger.mig.database.TypedDao;
import uk.ac.sanger.mig.personnel.Person;

public abstract class AbstractServiceImpl2<T extends AuthenticatedDataObject, D extends TypedDao<T>> extends AbstractServiceImpl<T> {

	private D primaryDao;

	protected D getPrimaryDao() {
		return primaryDao;
	}

	public void setPrimaryDao(D primaryDao) {
		this.primaryDao = primaryDao;
	}

	@Transactional
	public int storeAll(Collection<T> authenticatedDataObjects, Person user) {

		for(T authenticatedDataObject : authenticatedDataObjects) {

			store( authenticatedDataObject, user );
		}

		return authenticatedDataObjects.size();
	}

	@Transactional
	public Long store(T t, Person user) {
		if(t == null) {
			throw new RuntimeException("Cannot save a null dataObject");
		}
		return primaryDao.store(t, user);
	}

	public T fetchById(Long tId, ComponentMap requiredComponents) {
		T t = primaryDao.fetchById(tId);

		if(t != null)
			attachComponents(t, requiredComponents);

		return t;
	}

	public Collection<T> fetchLastSelection(String sessionId, String queryName, ComponentMap requiredComponents ) {
		Collection<T> ts = primaryDao.fetchLastSelection(sessionId, queryName);
		attachComponents(ts, requiredComponents);
		return ts;
	}

	public Collection<Long> fetchLastSelectionIds(String sessionId, String queryName) {
		Collection<Long> ids = primaryDao.fetchLastSelectionIds(sessionId, queryName);
		return ids;
	}

}
