/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.common;


/**
 * Immutable class to encapsulate allowed form fields, user readable names, and whether required/allowed.
 * NOTE: String objects are immutable in Java (see String class JavaDoc) 
 * so no need for defensive copying
 * @author ae1
 *
 */
public class AllowedFormField {

	private String fieldName;
	private String userReadableName;
	private boolean required = false; //default
		
	/**
	 * Throws IllegalArgumentException if String fieldName or userReadableName is null
	 * boolean required field defaults to false
	 * @param fieldName
	 * @param userReadableName
	 * @param required
	 * @throws IllegalArgumentException
	 */
	public AllowedFormField(String fieldName, String userReadableName,  boolean required) 
					throws IllegalArgumentException {
		
		if( fieldName == null ) 
			throw new IllegalArgumentException("String fieldName is required in FormField constructor.");

		if( userReadableName == null ) 
			throw new IllegalArgumentException("String userReadableName is required in FormField constructor.");
		
		this.fieldName = fieldName;
		this.userReadableName = userReadableName;
		this.required = required;
	}
	
	/**
	 * Returns the field name 
	 * @return
	 */
	public String getFieldName() {
		return fieldName;
	}
	
	/**
	 * Returns true of this field is required 
	 * @return
	 */
	public boolean isRequired() {
		return required;
	}
	
	/**
	 * Returns user readable name/phrase for this field
	 * @return
	 */
	public String getUserReadableName() {
		return userReadableName;
	}	
}
