/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.common;

import uk.ac.sanger.mig.jsptags.SelectOption;



public class DictionaryEntry extends DataObject implements SelectOption, Comparable<DictionaryEntry>{
	
	private String name;
	private String description;
	private boolean active;
	private int order;
	
	public DictionaryEntry() {};
	
	/**
	 * Constructor for use when you wish to specify default values in pull down lists generated from
	 * dictionary backing tables. 
	 * @param id is the Long value associated with the dictionary entry you wish to represent.
	 */
	public DictionaryEntry(Long id){
		this.id = id;
	}

	/**
	 * Constructor for use when you wish to initialize dictionary entry 
	 * manually belonging to given object -- eg, set PrimerPair type when we want
	 * empty PrimerPair set up when creating new ModifiedAllele 
	 * @param id
	 * @param name
	 */
	public DictionaryEntry(Long id, String name){
		this.id = id;
		this.name = name;
	}
	
	public boolean isActive() {
		return active;
	}
	
	public void setActive(boolean active) {
		this.active = active;
	}
	
	public String getDescription() {
		return description;
	}
	
	public void setDescription(String description) {
		this.description = description;
	}

	public String getName() {
		return name;
	}
	public void setName(String name) {
		this.name = name;
	}	
	public int getOrderBy() {
		return order;
	}
	public void setOrderBy(int order) {
		this.order = order;
	}
	
	public String getOptionValue() {
		return this.id.toString();
	}
	
	public String getOptionDescription() {
		// TODO Auto-generated method stub
		return this.name;
	}	
	
	public boolean equals(Object object) {
		if( object == this ) return true;
		if( object == null || !(object instanceof DictionaryEntry) ) return false;
		DictionaryEntry dictionaryEntry = (DictionaryEntry)object;
		return ( this.name.equals(dictionaryEntry.getName()) );
	}
	
	//keep Object contract w/equals()
	public int hashCode() {
		if(name != null)	
			return name.hashCode();
		else 
			return 0;
	}

	public String getDisplayText() {
		return name;
	}
	
	public String getElementData() {
		return 
		LookupListUtil.format("id", getId()) +
		LookupListUtil.format("name", getName());
	}

  public int compareTo(DictionaryEntry de) {
    int sortResult = Integer.valueOf(order).compareTo(de.getOrderBy());
    
    if (sortResult == 0) {
      sortResult = id.compareTo(de.getId());
    }
    
    return sortResult;
  }
	
}
