/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.common; 

/**
 * Interface that represents a record that can be selected from a lookup list.
 * The record consists of:<br>
 * The displayText field which contains the text that will be displayed to the user,
 * and is the basis on which the user will make a selection. <br>
 * The elementData field which contains name/value pairs of data that can be processed by the caller
 * to populate (e.g.) multiple HTML form element fields.
 */
public interface LookupListElement{
	
	/**
	 * Returns a String containing the text to be displayed to the user in the lookup list
	 * @return String containing the text to be displayed to the user in the lookup list
	 */
	public String getDisplayText();
	
	/**
	 * Returns a String containing the element data (name/value pairs) to be parsed by the caller
	 * @return String containing the element data (name/value pairs) to be parsed by the caller
	 */
	public String getElementData();
	
	
	
	/**
	 * Sets the String representing the text to be displayed for this element
	 * @param value the String representing the text to be displayed for this element
	 */  
	public void setDisplayText(String displayText);
	
	
	/**
	 * Sets the String representing the data to be returned to the caller.
	 * @param value the String representing the data to be returned to the caller.
	 */  
	public void setElementData(String elementData);
}