/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.common; 

/**
 * LookupListElement encapsulates the underlying information used when displaying
 * multiple choices in a Popup as a selection tool in a user interface. It describes two main
 * items:
 * 1) the displayText variable describes the text that will be displayed to the user, and is the basis on which the user will make a selection.
 * 2) the elementData variable is a String of name-value pairs, delimited using end tags. 
 * This is used to make one or many fieldNames and fieldValues available once an element has been selected, 
 * though it is up to the calling code to parse the String and extract the name-value pairs correctly.
 *
 */
public class LookupListElementImpl implements LookupListElement, Comparable {
	
	private String displayText = "";
	private String elementData = "";
	
	/**
	 * Returns a String representing the text to be displayed for this element
	 * @return a String representing the text to be displayed for this element
	 */
	public String getDisplayText(){
		return displayText;
	}
	
	/**
	 * Sets the String representing the text to be displayed for this element
	 * @param value the String representing the text to be displayed for this element
	 */
	public void setDisplayText(String value){
		displayText = value;
	}
	
	/**
	 * Returns the String representing the data to be returned to the caller.
	 * @return the String representing the data to be returned to the caller.
	 */
	public String getElementData(){
		return elementData;
	}
	
	/**
	 * Sets the String representing the data to be returned to the caller.
	 * @param value the String representing the data to be returned to the caller.
	 */
	public void setElementData(String value){
		elementData = value;
	}
	
	/**
	 * Implementation of the Comparable interface which can be used to sort lists of LoolupListElements
	 * @param o Object to compare this element to (should be LookupListElement)
	 * @return int value of the result of the compareTo() method
	 * @see Comparable#compareTo(java.lang.Object)
	 */
	public int compareTo(Object o) {
		
		if (o instanceof LookupListElement) {
			LookupListElement b = (LookupListElement) o;
			
			return this.getDisplayText().compareTo(b.getDisplayText());		
		}
		else {
			return 0;
		}  	
	}	
}