/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.common;

import java.net.MalformedURLException;
import java.net.URL;

import uk.ac.sanger.mig.database.Dao;
import uk.ac.sanger.mig.database.TypedDao;

public class MigValidatorUtils {

	
	
	
	private MigValidatorUtils() {}

	/**
	 * Determines whether a DataObject is valid--ie, it maps to record
	 * that exists in data source
	 * @param dataObject 
	 * @param dao Data access object that interfaces with datasource
	 * @return
	 */
	public static boolean isValidDataObject(DataObject dataObject, Dao dao) {
		if(dataObject == null || dataObject.getId() < 1) return false;	
		return (dao.fetchById(dataObject.getId()) != null);
	}

	public static boolean isValidDataObject(DataObject dataObject, TypedDao typedDao) {
		if(dataObject == null || dataObject.getId() < 1) return false;	
		return (typedDao.fetchById(dataObject.getId()) != null);
	}
	
	
	/**
	 * Determines if the supplied String constitutes a valid URL string.
	 * @param url is the String containing the URL.
	 * 
	 * @return true if the String contains a valid 'looking' URL.
	 */
	public static boolean isValidUrl(String url) {
		try {
			new URL(url);
		} catch (MalformedURLException e) {
			return false;
		}
		return true;
	}

	
}
