/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.common;

import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.net.URL;
import java.net.URLConnection;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.xml.sax.helpers.DefaultHandler;

public class OracleReport extends DefaultHandler {
	
	private static final Log logger = LogFactory.getLog(OracleReport.class);

	private OracleReportServer reportServer;
	
	public void setReportServer(OracleReportServer reportServer) {
		this.reportServer = reportServer;
	}

	public String run(String queryString) {

		URL url = null;
		// Construct the URL for the reports server
		try {
			url = new URL(reportServer.getServerUrl() + queryString);
			logger.debug("'"+url+"'");
		}
		catch(Exception e) {
			throw new RuntimeException(e);
		}
		BufferedReader in = null;
		StringBuffer sb = new StringBuffer();
		try {
			// opens a connection to the report server URL
			URLConnection connection = url.openConnection();
			// read the response
			in = new BufferedReader(new InputStreamReader(connection.getInputStream()));
			String inputLine;
			while ((inputLine = in.readLine()) != null)
				sb.append(inputLine);
		}
		catch(Exception e) {
			return(e.getMessage());
		}
		finally {
			//close the inputStream
			if(in != null) {
				try {
					in.close();
				}
				catch(Exception e) {
					
				}
			}
		}

		// try to determine if a success page has been returned - The success page
		// contains the text "Successfully run"

		if(sb.toString().indexOf(reportServer.getSuccessString()) > 0) {
			return null;
		}
		else {

			//if the report wasn't successful try to find the error info and return it
			String errorMessage = findErrorString(sb.toString());

			return errorMessage;
		}
	}

	private String findErrorString(String err){
		String errString = "";

		try{

			int firstTagIndex = err.indexOf("<pre>");
			int secondTagIndex = err.indexOf("</pre>");

			if((firstTagIndex != -1) && (secondTagIndex != -1))
				errString = err.substring(firstTagIndex + 5, secondTagIndex);
			else
				errString = "Couldn't isolate error text";

		}
		catch(Exception e){
			errString = " Exception in error findError";
		}

		return errString;
	}
}