/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.common;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import uk.ac.sanger.mig.personnel.Person;

/**
 * Static Utilities class to assist common activitied relating to the HttpServletRequest
 *
 */
public abstract class RequestUtils {

	private static final Log logger = LogFactory.getLog(RequestUtils.class);

	/**
	 * Private constructor - this class should not need to be instantiated.
	 *
	 */
	private RequestUtils() {

	}

	/**
	 * Returns a clone of the current user's Person object from the session
	 *
	 * @param request HttpServletRequest
	 * @return Person object
	 */
	public static Person getUser(HttpServletRequest request) {
		return (Person)request.getSession(true).getAttribute("user");
	}

	/**
	 * Returns the current user's session ID
	 * @param request HttpServletRequest
	 * @return String session ID
	 */
	public static String getSessionId(HttpServletRequest request){
		return request.getSession(true).getId();
	}

	/**
	 * Copies the referer header attribute to a session attribute called "migLastRefer"
	 * This can be used to handle invalid submits
	 *
	 * @param request
	 */
	public static void setLastReferer(HttpServletRequest request ) {
		request.getSession().setAttribute("migLastRefer",request.getHeader("referer"));
		logger.debug("migLastRefer="  + request.getSession().getAttribute("migLastRefer"));
	}

	public static String getLastReferer(HttpServletRequest request) {
		return (String)request.getSession().getAttribute("migLastRefer");
	}
}
