/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.common;


import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.web.bind.ServletRequestBindingException;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.ParameterizableViewController;

/**
 * Controller for selecting paginated records.
 * Requires the view and query names used to generate the paginated data under consideration
 *
 * Accepts multiple recordNumbers, matching entries in the paginated data.
 * If the recordNumber is positive, it will be selected.
 * If the recordNumber is negative, it will be unselected.
 *
 * The controller will place a count of selected records into the mode, with the key 'selectedCount'
 *
 */
public class ToggleSelectedRecordController extends ParameterizableViewController {
	private PaginatedSearchUtils paginatedSearchUtils;

	public void setPaginatedSearchUtils(PaginatedSearchUtils paginatedSearchUtils) {
		this.paginatedSearchUtils = paginatedSearchUtils;
	}

	@Override
	protected ModelAndView handleRequestInternal(HttpServletRequest request, HttpServletResponse response) throws ServletRequestBindingException {
		String sessionId = RequestUtils.getSessionId(request);
		String viewName = ServletRequestUtils.getRequiredStringParameter(request, "viewName");
		String queryName = ServletRequestUtils.getRequiredStringParameter(request, "queryName");
		long[] recordNumbers = ServletRequestUtils.getRequiredLongParameters(request, "recordNumber");

		PaginatedSearchBean bean = new PaginatedSearchBean();
		bean.setSessionId(sessionId);
		bean.setViewName(viewName);
		bean.setQueryName(queryName);

		for(long recordNumber : recordNumbers) {
			boolean selected = (recordNumber > 0);
			recordNumber = Math.abs(recordNumber);
			paginatedSearchUtils.toggleRecord(bean, recordNumber, selected);
		}

		return new ModelAndView(getViewName(), "selectedCount", paginatedSearchUtils.countSelectedRecords(sessionId, queryName));
	}
}
