package uk.ac.sanger.mig.common.forms;

/**
 * Extend this class if you want to test the validity of a form before processing in a service
 * without having to re-code the validation logic in the service layer also.
 *
 * Use in conjuction with a validator (e.g the Spring Validator interface).
 * Set the validated status to be false at the start of validation
 * then set to true if the form passes all validation steps.
 *
 */
public abstract class ValidatableForm {

	private boolean validated;

	/**
	 * Should return true if and only if the form passed all validation steps and is ready for processing.
	 * @return true if form has been validated, otherwise false.
	 */
	public boolean isValidated() {
		return validated;
	}

	/**
	 * Set the validated status of a form to true if the form has been validated, otherwise false.	 *
	 * @param validated
	 */
	public void setValidated(boolean validated) {
		this.validated = validated;
	}
}
