package uk.ac.sanger.mig.common.services;

import java.util.Collection;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.personnel.Person;

public interface CommonServices<T> {

	/**
	 * Store (insert or update) a single object of type T to the database
	 * @param t object to be stored
	 * @param person user performing the store operation
	 * @return Long primary key value of the database record
	 */
	public Long store(T t, Person person);

	/**
	 * Stores (insert or update) a collection of objects of type T to the database
	 * @param t Collection of objects to be stored
	 * @param person user performing the store operation
	 * @return int number of objects stored.
	 */
	public int storeAll(Collection<T> t, Person person);

	/**
	 * Return a single object based on its primary key
	 * @param id primary key of object to return
	 * @param requiredComponents ComponentMap of sub-objects to attach
	 * @return object of type T
	 */
	public T fetchById(Long id, ComponentMap requiredComponents);

	/**
	 * Returns the collection of objects selected by the user in a previous query
	 * @param sessionId unique user session ID
	 * @param queryName name of the query previously executed
	 * @param requiredComponents ComponentMap of sub-objects to attach
	 * @return Collection of type T
	 */
	public Collection<T> fetchLastSelection(String sessionId, String queryName, ComponentMap requiredComponents);

	/**
	 * Returns the collection of primary keys for objects selected by the user in a previous query
	 * @param sessionId unique user session ID
	 * @param queryName name of the query previously executed
	 * @param requiredComponents ComponentMap of sub-objects to attach
	 * @return Collection of type T
	 */
	public Collection<Long> fetchLastSelectionIds(String sessionId, String queryName);
}
