/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.common.services;

import java.io.IOException;
import java.io.InputStream;
import java.util.Collection;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.Map;
import java.util.Set;

import org.apache.commons.digester.Digester;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.core.io.Resource;
import org.springframework.core.io.support.PathMatchingResourcePatternResolver;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.ComponentMapRuleSet;

public class ComponentMapService {

	private Log logger = LogFactory.getLog(ComponentMapService.class);
	private Collection<String> configFiles;
	private Map<String, ComponentMap> componentMaps = new HashMap<String, ComponentMap>();


	public void setConfigFiles(Collection<String> configFiles) {
		this.configFiles = configFiles;
	}

	public Set<String> componentMapKeys() {
		return componentMaps.keySet();
	}

	private Collection<Resource> getConfigResources() throws IOException {
    Collection<Resource> configResources = new LinkedList<Resource>();
    PathMatchingResourcePatternResolver resolver = new PathMatchingResourcePatternResolver();

    for (String path : configFiles) {
      Resource[] matchingRes = resolver.getResources(path);
      for (Resource r : matchingRes) {
        configResources.add(r);
      }
    }

		return configResources;
	}

	public ComponentMap getComponentMap(String componentMapName) {
		ComponentMap componentMap = componentMaps.get(componentMapName);
		if( componentMap == null )
			throw new RuntimeException("Could not find ComponentMap for map name: " + componentMapName);
		return componentMap;
	}

	private void parseConfigFile(Resource resource, Map<String, ComponentMap> mapContainer) throws Exception {
		Digester digester = getDigester();
		digester.push(mapContainer);

    InputStream is = null;

    logger.debug("Parsing component map config: "+resource);

		try {
      is = resource.getInputStream();
      digester.parse(is);
		}
		catch(Exception e) {
			throw new RuntimeException("An error occurred while parsing component map file '" + resource +"': " + e.getMessage(), e);
		}
    finally {
      if (is != null) is.close();
    }
	}

	/**
	 * Initialise the Digester used to parse the configuration file.
	 * See Apache Commons Digester documentation for more information.
	 * @return
	 */
	private Digester getDigester() {
		// Create a new Digester instance with standard capabilities
		Digester configDigester = new Digester();
    configDigester.setUseContextClassLoader(true);
    configDigester.addRuleSet(new ComponentMapRuleSet());

		// Return the completely configured Digester instance
		return configDigester;
	}

	public void init() throws Exception {
		Map<String, ComponentMap> mapContainer = new HashMap<String, ComponentMap>();

    for(Resource resource : getConfigResources()) {
      parseConfigFile(resource,mapContainer);
    }

    componentMaps = mapContainer;
	}

}
