/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.cryoprocessing;

import java.util.Collection;
import java.util.Date;

import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.ComponentEnum;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.personnel.Person;

public class EmbryoHarvest extends AuthenticatedDataObject  {

	public enum Component implements ComponentEnum {
		ALL_COMPONENTS,  //add additional component enums here as needed for this AuthenticatedDataObject
		FREEZE_DOWN_SAMPLES,
		TECHNICIAN,
		COHORT
		}

    private Long scheduledJobId;
    private Date editedDate;
    private String comments;
    private Integer cellCount16;
    private Integer cellCount8;
    private Integer cellCount4;
    private Integer cellCount2;
    private Integer cellCount1;
    private Integer deadCount;
    private Integer fragmentedCount;
    private Integer otherEmbryoTypeCount;
    private Integer numberSuperovulated;
    private Integer numberPlugged;
    private Date flushDate;
    private Long technicianId;
    private String otherDescription;
    private Person technician;
    private Collection<FreezeDownSample> freezeDownSamples;
    private boolean use16Cell;
    private boolean use8Cell;
    private boolean use4Cell;
    private boolean use2Cell;
    private ScheduledCryoPreservationJob scheduledCryoPreservationJob;
    private Long femaleStrainDictId;
    private DictionaryEntry femaleStrain;
    private String cohortName;
    private Long cohortId;
    private String femaleStrainComments;


	public String getFemaleStrainComments() {
		return femaleStrainComments;
	}

	public void setFemaleStrainComments(String femaleStrainComments) {
		this.femaleStrainComments = femaleStrainComments;
	}

	public Long getCohortId() {
		return cohortId;
	}

	public void setCohortId(Long cohortId) {
		this.cohortId = cohortId;
	}

	public String getCohortName() {
		return cohortName;
	}

	public void setCohortName(String cohortName) {
		this.cohortName = cohortName;
	}

	public boolean isUse16Cell() {
		return use16Cell;
	}

	public void setUse16Cell(boolean use16Cell) {
		this.use16Cell = use16Cell;
	}

	public boolean isUse4Cell() {
		return use4Cell;
	}

	public void setUse4Cell(boolean use4Cell) {
		this.use4Cell = use4Cell;
	}

	public boolean isUse8Cell() {
		return use8Cell;
	}

	public void setUse8Cell(boolean use8Cell) {
		this.use8Cell = use8Cell;
	}

	public boolean isUse2Cell() {
		return use2Cell;
	}

	public void setUse2Cell(boolean use2Cell) {
		this.use2Cell = use2Cell;
	}

	public void setCellCount1(Integer cellCount1) {
		this.cellCount1 = cellCount1;
	}

	public void setCellCount16(Integer cellCount16) {
		this.cellCount16 = cellCount16;
	}

	public void setCellCount2(Integer cellCount2) {
		this.cellCount2 = cellCount2;
	}

	public void setCellCount4(Integer cellCount4) {
		this.cellCount4 = cellCount4;
	}

	public void setCellCount8(Integer cellCount8) {
		this.cellCount8 = cellCount8;
	}

	public void setDeadCount(Integer deadCount) {
		this.deadCount = deadCount;
	}

	public void setFragmentedCount(Integer fragmentedCount) {
		this.fragmentedCount = fragmentedCount;
	}

	public void setNumberPlugged(Integer numberPlugged) {
		this.numberPlugged = numberPlugged;
	}

	public void setNumberSuperovulated(Integer numberSuperovulated) {
		this.numberSuperovulated = numberSuperovulated;
	}

	public void setOtherEmbryoTypeCount(Integer otherEmbryoTypeCount) {
		this.otherEmbryoTypeCount = otherEmbryoTypeCount;
	}

	public Long getScheduledJobId() {
        return scheduledJobId;
    }

    public void setScheduledJobId(Long scheduledJobId) {
        this.scheduledJobId = scheduledJobId;
    }
    public Date getEditedDate() {
        return editedDate;
    }

    public void setEditedDate(Date editedDate) {
        this.editedDate = editedDate;
    }
    public String getComments() {
        return comments;
    }

    public void setComments(String comments) {
        this.comments = comments;
    }
    public Integer getCellCount16() {
        return cellCount16;
    }

    public void setCellCount16(int cellCount16) {
        this.cellCount16 = cellCount16;
    }
    public Integer getCellCount8() {
        return cellCount8;
    }

    public void setCellCount8(int cellCount8) {
        this.cellCount8 = cellCount8;
    }
    public Integer getCellCount4() {
        return cellCount4;
    }

    public void setCellCount4(int cellCount4) {
        this.cellCount4 = cellCount4;
    }
    public Integer getCellCount2() {
        return cellCount2;
    }

    public void setCellCount2(int cellCount2) {
        this.cellCount2 = cellCount2;
    }
    public int getCellCount1() {
        return cellCount1;
    }

    public void setCellCount1(int cellCount1) {
        this.cellCount1 = cellCount1;
    }
    public int getDeadCount() {
        return deadCount;
    }

    public void setDeadCount(int deadCount) {
        this.deadCount = deadCount;
    }
    public Integer getFragmentedCount() {
        return fragmentedCount;
    }

    public void setFragmentedCount(int fragmentedCount) {
        this.fragmentedCount = fragmentedCount;
    }
    public Integer getOtherEmbryoTypeCount() {
        return otherEmbryoTypeCount;
    }

    public void setOtherEmbryoTypeCount(int otherEmbryoTypeCount) {
        this.otherEmbryoTypeCount = otherEmbryoTypeCount;
    }
    public Integer getNumberSuperovulated() {
        return numberSuperovulated;
    }

    public void setNumberSuperovulated(int numberSuperovulated) {
        this.numberSuperovulated = numberSuperovulated;
    }
    public Integer getNumberPlugged() {
        return numberPlugged;
    }

    public void setNumberPlugged(int numberPlugged) {
        this.numberPlugged = numberPlugged;
    }
    public Date getFlushDate() {
        return flushDate;
    }

    public void setFlushDate(Date flushDate) {
        this.flushDate = flushDate;
    }
    public Long getTechnicianId() {
        return technicianId;
    }

    public void setTechnicianId(Long technicianId) {
        this.technicianId = technicianId;
    }
    public String getOtherDescription() {
        return otherDescription;
    }

    public void setOtherDescription(String otherDescription) {
        this.otherDescription = otherDescription;
    }

	public Collection<FreezeDownSample> getFreezeDownSamples() {
		return freezeDownSamples;
	}

	public void setFreezeDownSample(Collection<FreezeDownSample> freezeDownSamples) {
		this.freezeDownSamples = freezeDownSamples;
	}

	public Person getTechnician() {
		return technician;
	}

	public void setTechnician(Person technician) {
		this.technician = technician;
	}

	public void setFreezeDownSamples(Collection<FreezeDownSample> freezeDownSamples) {
		this.freezeDownSamples = freezeDownSamples;
	}

	public int calculateAvailableEmbryos() {
		int availableEmbryos = 0;

		if(this.isUse16Cell() && this.cellCount16 != null) {
			availableEmbryos += this.cellCount16.intValue();
		}
		if(this.isUse8Cell() && this.cellCount8 != null) {
			availableEmbryos += this.cellCount8.intValue();
		}
		if(this.isUse4Cell() && this.cellCount4 != null) {
			availableEmbryos += this.cellCount4.intValue();
		}
		if(this.isUse2Cell() && this.cellCount2 != null) {
			availableEmbryos += this.cellCount2.intValue();
		}

		return availableEmbryos;
	}

	public ScheduledCryoPreservationJob getScheduledCryoPreservationJob() {
		return scheduledCryoPreservationJob;
	}

	public void setScheduledCryoPreservationJob(
			ScheduledCryoPreservationJob scheduledCryoPreservationJob) {
		this.scheduledCryoPreservationJob = scheduledCryoPreservationJob;
	}

	public DictionaryEntry getFemaleStrain() {
		return femaleStrain;
	}

	public void setFemaleStrain(DictionaryEntry wildTypeFemaleStrain) {
		this.femaleStrain = wildTypeFemaleStrain;
	}

	public Long getFemaleStrainDictId() {
		return femaleStrainDictId;
	}

	public void setFemaleStrainDictId(Long wildTypeFemaleStrainDictId) {
		this.femaleStrainDictId = wildTypeFemaleStrainDictId;
	}



}