/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.cryoprocessing;

import java.util.Collection;
import java.util.Date;

import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.ComponentEnum;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.cryoprocessing.views.StrawLocation;
import uk.ac.sanger.mig.cryoprocessing.views.VialLocation;
import uk.ac.sanger.mig.miprocessing.EmbryoTransferProcedure;
import uk.ac.sanger.mig.personnel.Person;

public class FreezeDownSample extends AuthenticatedDataObject {

	public enum Component implements ComponentEnum {
		TECHNICIAN,
		EMBRYO_HARVEST,
		VIAL_LOCATION,
		STRAW_LOCATION,
		THAW_TEST,
		ALL_COMPONENTS
	}

    private Long embryoHarvestId;
    private EmbryoHarvest embryoHarvest;

    private String comments;

    private Long technicianId;
    private Person technician;

    private Long embryoGradeDictId;
    private DictionaryEntry embryoGradeDict;

    private Integer embryoCount;
    private Date freezeDownDate;
    private Long locationId;
    private VialLocation vialLocation;
    private StrawLocation strawLocation;
    private Collection<EmbryoTransferProcedure> embryoTransfers;
    private Date thawDate;

    private Long thawTestId;
    private ThawTest thawTest;

    private Long shippingID;
    private Shipping shipping;

    public Shipping getShipping() {
		return shipping;
	}
	public void setShipping(Shipping shipping) {
		this.shipping = shipping;
	}
	public Long getShippingID() {
		return shippingID;
	}
	public void setShippingID(Long shippingID) {
		this.shippingID = shippingID;
	}
	public ThawTest getThawTest() {
		return thawTest;
	}
	public void setThawTest(ThawTest thawTest) {
		this.thawTest = thawTest;
	}
	public Long getThawTestId() {
		return thawTestId;
	}
	public void setThawTestId(Long thawTestId) {
		this.thawTestId = thawTestId;
	}
	public Date getThawDate() {
		return thawDate;
	}
	public void setThawDate(Date thawDate) {
		this.thawDate = thawDate;
	}
	public VialLocation getVialLocation() {
		return vialLocation;
	}
	public void setVialLocation(VialLocation vialLocation) {
		this.vialLocation = vialLocation;
	}
	public Long getLocationId() {
		return locationId;
	}
	public void setLocationId(Long locationId) {
		this.locationId = locationId;
	}
	public String getComments() {
		return comments;
	}
	public void setComments(String comments) {
		this.comments = comments;
	}
	public Integer getEmbryoCount() {
		return embryoCount;
	}
	public void setEmbryoCount(Integer embryoCount) {
		this.embryoCount = embryoCount;
	}
	public DictionaryEntry getEmbryoGradeDict() {
		return embryoGradeDict;
	}
	public void setEmbryoGradeDict(DictionaryEntry embryoGradeDict) {
		this.embryoGradeDict = embryoGradeDict;
	}
	public Long getEmbryoGradeDictId() {
		return embryoGradeDictId;
	}
	public void setEmbryoGradeDictId(Long embryoGradeDictId) {
		this.embryoGradeDictId = embryoGradeDictId;
	}
	public EmbryoHarvest getEmbryoHarvest() {
		return embryoHarvest;
	}
	public void setEmbryoHarvest(EmbryoHarvest embryoHarvest) {
		this.embryoHarvest = embryoHarvest;
	}
	public Long getEmbryoHarvestId() {
		return embryoHarvestId;
	}
	public void setEmbryoHarvestId(Long embryoHarvestId) {
		this.embryoHarvestId = embryoHarvestId;
	}
	public Date getFreezeDownDate() {
		return freezeDownDate;
	}
	public void setFreezeDownDate(Date freezeDownDate) {
		this.freezeDownDate = freezeDownDate;
	}
	public Person getTechnician() {
		return technician;
	}
	public void setTechnician(Person technician) {
		this.technician = technician;
	}
	public Long getTechnicianId() {
		return technicianId;
	}
	public void setTechnicianId(Long technicianId) {
		this.technicianId = technicianId;
	}
	public StrawLocation getStrawLocation() {
		return strawLocation;
	}
	public void setStrawLocation(StrawLocation strawLocation) {
		this.strawLocation = strawLocation;
	}
	/*
	 * comparator used when sort out the avaiable samples by their ids
	 */
	public int compareTo(FreezeDownSample o1, FreezeDownSample o2) {

		return o1.getId().compareTo(o2.getId());
	}
	public Collection<EmbryoTransferProcedure> getEmbryoTransfers() {
		return embryoTransfers;
	}
	public void setEmbryoTransfers(
			Collection<EmbryoTransferProcedure> embryoTransfers) {
		this.embryoTransfers = embryoTransfers;
	}

}