/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.cryoprocessing;

import java.util.Date;

import uk.ac.sanger.mig.common.PaginatedSearchBean;



/**
 * This class serves as wrapper around domain object POJO for searching on particular fields that are set.
 * It also inherits orderBy and sortOrder methods from SortableSearchBean enabling sort functionlity.
 *
 * If you also need pagination functionality, subclass PaginatedSearchBean which extends SortableSearchBean
 * 
 * NOTE: Using wrapper is just one appraoch to search bean. You could alternatively created a standalone
 * search bean that effectively mimics all of the fields with getters and setters of your domain object POJO.
 */

public class FreezeDownSampleSearchBean extends PaginatedSearchBean  {
	
		private Long id;//the id for the sample list view, the primary key for vial/straw
	    private String colonyName;        
	    private Long colonyId;        
	    private Long requestId;        
	    private Date freezeDownDate;        
	    private Integer embryoCount;        
	    private String embryoGrade;  
	    private Long embryoGradeDictId;
	    private String freezerName;        
	    private Long freezerId;        
	    private String canisterName;        
	    private Long canisterId;        
	    private String gobletName;        
	    private Long gobletId;        
	    private String wedgeColour;        
	    private Long wedgeId;        
	    private String technicianName;        
	    private Long technicianId;
	    private Long towerId;
	    private Long vialPosition;
	    private Long boxId;
	    private String femaleStrainName;
	    
		public String getFemaleStrainName() {
			return femaleStrainName;
		}
		public void setFemaleStrainName(String femaleStrainName) {
			this.femaleStrainName = femaleStrainName;
		}
		public Long getBoxId() {
			return boxId;
		}
		public void setBoxId(Long boxId) {
			this.boxId = boxId;
		}
		public Long getTowerId() {
			return towerId;
		}
		public void setTowerId(Long towerId) {
			this.towerId = towerId;
		}
		public Long getCanisterId() {
			return canisterId;
		}
		public void setCanisterId(Long canisterId) {
			this.canisterId = canisterId;
		}
		public String getCanisterName() {
			return canisterName;
		}
		public void setCanisterName(String canisterName) {
			this.canisterName = canisterName;
		}
		public Long getColonyId() {
			return colonyId;
		}
		public void setColonyId(Long colonyId) {
			this.colonyId = colonyId;
		}
		public String getColonyName() {
			return colonyName;
		}
		public void setColonyName(String colonyName) {
			this.colonyName = colonyName;
		}
		
		public Integer getEmbryoCount() {
			return embryoCount;
		}
		public void setEmbryoCount(Integer embryoCount) {
			this.embryoCount = embryoCount;
		}
		public String getEmbryoGrade() {
			return embryoGrade;
		}
		public void setEmbryoGrade(String embryoGrade) {
			this.embryoGrade = embryoGrade;
		}
		public Date getFreezeDownDate() {
			return freezeDownDate;
		}
		public void setFreezeDownDate(Date freezeDownDate) {
			this.freezeDownDate = freezeDownDate;
		}
		public Long getFreezerId() {
			return freezerId;
		}
		public void setFreezerId(Long freezerId) {
			this.freezerId = freezerId;
		}
		public String getFreezerName() {
			return freezerName;
		}
		public void setFreezerName(String freezerName) {
			this.freezerName = freezerName;
		}
		public Long getGobletId() {
			return gobletId;
		}
		public void setGobletId(Long gobletId) {
			this.gobletId = gobletId;
		}
		public String getGobletName() {
			return gobletName;
		}
		public void setGobletName(String gobletName) {
			this.gobletName = gobletName;
		}
		public Long getRequestId() {
			return requestId;
		}
		public void setRequestId(Long requestId) {
			this.requestId = requestId;
		}
	
		public Long getTechnicianId() {
			return technicianId;
		}
		public void setTechnicianId(Long technicianId) {
			this.technicianId = technicianId;
		}
		public String getTechnicianName() {
			return technicianName;
		}
		public void setTechnicianName(String technicianName) {
			this.technicianName = technicianName;
		}
		public String getWedgeColour() {
			return wedgeColour;
		}
		public void setWedgeColour(String wedgeColour) {
			this.wedgeColour = wedgeColour;
		}
		public Long getWedgeId() {
			return wedgeId;
		}
		public void setWedgeId(Long wedgeId) {
			this.wedgeId = wedgeId;
		}
		public Long getEmbryoGradeDictId() {
			return embryoGradeDictId;
		}
		public void setEmbryoGradeDictId(Long embryoGradeDictId) {
			this.embryoGradeDictId = embryoGradeDictId;
		}
		
		public Long getVialPosition() {
			return vialPosition;
		}
		public void setVialPosition(Long vialPosition) {
			this.vialPosition = vialPosition;
		}
		public Long getId() {
			return id;
		}
		public void setId(Long id) {
			this.id = id;
		}        

}