/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.cryoprocessing;

import java.util.Date;

import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.common.PaginatedSearchBean;

/**
 * This class serves as wrapper around domain object POJO for searching on particular fields that are set.
 * It also inherits orderBy and sortOrder methods from SortableSearchBean enabling sort functionlity.
 *
 * If you also need pagination functionality, subclass PaginatedSearchBean which extends SortableSearchBean
 * 
 * NOTE: Using wrapper is just one appraoch to search bean. You could alternatively created a standalone
 * search bean that effectively mimics all of the fields with getters and setters of your domain object POJO.
 */

public class ScheduledCryoPreservationSearchBean extends PaginatedSearchBean  {
	
	private ScheduledCryoPreservationJob scheduledCryoPreservationJob;
	private Date startTargetDate;
	private Date endTargetDate;
	private String getTodaysJobs;
	private String searchBy;
	private String searchString;
	private Long id;
	private Long cryoRequestId;
	private Long statusDictId;
	private String cancelComments;
	
	public String getCancelComments() {
		return cancelComments;
	}

	public void setCancelComments(String cancelComments) {
		this.cancelComments = cancelComments;
	}

	public String getGetTodaysJobs() {
		return getTodaysJobs;
	}

	public void setGetTodaysJobs(String getTodaysJobs) {
		this.getTodaysJobs = getTodaysJobs;
	}

	public void setCryoSchedulePreservation(ScheduledCryoPreservationJob cryoSchedulePreservation) {
		this.scheduledCryoPreservationJob = cryoSchedulePreservation;
		
	}
	
	public ScheduledCryoPreservationSearchBean(){
		scheduledCryoPreservationJob = new ScheduledCryoPreservationJob();
		this.endTargetDate = null;//new Date();
		this.startTargetDate = null;//new Date();
		scheduledCryoPreservationJob.setJobStatusDict(new DictionaryEntry());
	}


	public ScheduledCryoPreservationJob getScheduledCryoPreservationJob() {
		return scheduledCryoPreservationJob;
	}

	public void setScheduledCryoPreservationJob(
			ScheduledCryoPreservationJob scheduledCryoPreservationJob) {
		this.scheduledCryoPreservationJob = scheduledCryoPreservationJob;
	}

	public Date getEndTargetDate() {
		return endTargetDate;
	}

	public void setEndTargetDate(Date endTargetDate) {
		this.endTargetDate = endTargetDate;
	}

	public Date getStartTargetDate() {
		return startTargetDate;
	}

	public void setStartTargetDate(Date startTargetDate) {
		this.startTargetDate = startTargetDate;
	}

	public String getSearchBy() {
		return searchBy;
	}

	public void setSearchBy(String searchBy) {
		this.searchBy = searchBy;
	}

	public String getSearchString() {
		return searchString;
	}

	public void setSearchString(String searchString) {
		this.searchString = searchString;
	}
	
	public void setId( Long id ) {
		this.id = id;
	}
	
	public Long getId() {
		return id;
	}

	public Long getStatusDictId() {
		return statusDictId;
	}

	public void setStatusDictId(Long statusDictId) {
		this.statusDictId = statusDictId;
	}

	public Long getCryoRequestId() {
		return cryoRequestId;
	}

	public void setCryoRequestId(Long cryoRequestId) {
		this.cryoRequestId = cryoRequestId;
	}
}