package uk.ac.sanger.mig.cryoprocessing;

import java.util.Calendar;
import java.util.Collection;
import java.util.Date;

import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.ComponentEnum;
import uk.ac.sanger.mig.cryorequest.CryoRequest;
import uk.ac.sanger.mig.miprocessing.EmbryoTransferProcedure;


public class ThawTest extends AuthenticatedDataObject {

	public enum Component implements ComponentEnum {
		EMBRYO_TRANSFERS,
		FREEZE_DOWN_SAMPLES,
		CRYO_REQUEST,
		ALL_COMPONENTS
	}

	private final static String DEFAULT_EMBRYO_AGE = "2.5";
	private final static String OVERNIGHT_EMBRYO_AGE = "0.5";
	private Collection<EmbryoTransferProcedure> embryoTransfers;
	private Collection<FreezeDownSample> freezeDownSamples;
	private CryoRequest cryoRequest;
	private Long cryoRequestId;
	private String comments;
	private Date dateCompleted;
	private Integer retrievalNumber;
	private Date dueDate;


	public String getComments() {
		return comments;
	}
	public void setComments(String comments) {
		this.comments = comments;
	}
	public CryoRequest getCryoRequest() {
		return cryoRequest;
	}
	public void setCryoRequest(CryoRequest cryoRequest) {
		this.cryoRequest = cryoRequest;
	}
	public Long getCryoRequestId() {
		return cryoRequestId;
	}
	public void setCryoRequestId(Long cryoRequestId) {
		this.cryoRequestId = cryoRequestId;
	}
	public Collection<EmbryoTransferProcedure> getEmbryoTransfers() {
		return embryoTransfers;
	}
	public void setEmbryoTransfers(
			Collection<EmbryoTransferProcedure> embryoTransfers) {
		this.embryoTransfers = embryoTransfers;
	}
	public Collection<FreezeDownSample> getFreezeDownSamples() {
		return freezeDownSamples;
	}
	public void setFreezeDownSamples(Collection<FreezeDownSample> freezeDownSamples) {
		this.freezeDownSamples = freezeDownSamples;
	}
	public Date getDateCompleted() {
		return dateCompleted;
	}
	public void setDateCompleted(Date dateCompleted) {
		this.dateCompleted = dateCompleted;
	}

	public int getRetrieval(){
		int totalRetrieval = 0;
		for(FreezeDownSample freezeDownSample:this.getFreezeDownSamples()){
			totalRetrieval += freezeDownSample.getEmbryoCount();
		}
		return totalRetrieval;
	}

	public int getNumberTransferred(){
		int numberTransferred = 0;
		for(EmbryoTransferProcedure embryoTransfer: this.getEmbryoTransfers()){
			numberTransferred += embryoTransfer.getTotalEmbryosTransferred();
		}
		return numberTransferred;
	}

	public String getSampleIds(){
		String sampleIds = "";
		for(FreezeDownSample sample:this.freezeDownSamples){
			sampleIds += " "+sample.getId().toString();

		}
		return sampleIds;
	}

	public Integer getRetrievalNumber() {
		return retrievalNumber;
	}

	public void setRetrievalNumber(Integer retrievalNumber) {
		this.retrievalNumber = retrievalNumber;
	}

	 public Date getDueDate() {
	    	if( dateCompleted == null )
	    		throw new RuntimeException("Thaw Date is empty!");

	    	Calendar cal = Calendar.getInstance();
	    	Date transferDate = dateCompleted;
	    	cal.setTime( transferDate );
	    	cal.add(Calendar.DAY_OF_YEAR, 17);
	    	return cal.getTime();
	    }
	public void setDueDate(Date dueDate) {
		this.dueDate = dueDate;
	}
}