/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.cryoprocessing.controllers;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.AbstractCancellableFormController;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.cryoprocessing.forms.CancelSampleForm;
import uk.ac.sanger.mig.cryoprocessing.services.StrawService;
import uk.ac.sanger.mig.cryoprocessing.services.VialService;

public class CancelSampleController extends AbstractCancellableFormController {
	private StrawService strawService;
	private String successViewToListView;
	private VialService vialService; 
	private String successViewToViewOneRequest;
	
	public void setVialService(VialService vialService) {
		this.vialService = vialService;
	}

	public void setSuccessViewToListView(String successViewToListView) {
		this.successViewToListView = successViewToListView;
	}

	public StrawService getStrawService() {
		return strawService;
	}

	public void setStrawService(StrawService strawService) {
		this.strawService = strawService;
	}


	@Override
	protected Object formBackingObject(HttpServletRequest httpServletRequest) throws Exception {
		
		CancelSampleForm form = (CancelSampleForm)createCommand();				    
		//fields in the request URL 
		//get the straw id or vial id
		Long id = ServletRequestUtils.getRequiredLongParameter(httpServletRequest, "id");
		String referrer = ServletRequestUtils.getRequiredStringParameter(httpServletRequest, "referrer");
		String freezeDownPageRefer = ServletRequestUtils.getStringParameter(httpServletRequest, "freezeDownPageRefer");
		boolean strawSystem = ServletRequestUtils.getRequiredBooleanParameter(httpServletRequest, "strawSystem");
		Long scpId = ServletRequestUtils.getRequiredLongParameter(httpServletRequest, "scheduledCryoPreservationJob.id");
		Long cryoRequestId = null;
		if(httpServletRequest.getQueryString().contains("cryoRequestId")){
		cryoRequestId = ServletRequestUtils.getRequiredLongParameter(httpServletRequest, "cryoRequestId"); 			
		form.setCryoRequestId(cryoRequestId);
		}
		form.setId(id);
		form.setReferrer(referrer);
		form.setStrawSystem(strawSystem);
		form.setScheduledCryoPreservationJobId(scpId);
		form.setFreezeDownPageRefer(freezeDownPageRefer);
		
		return form;
	}
		
	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, 
				Object command, BindException errors) throws Exception {
		
		CancelSampleForm cancelForm = (CancelSampleForm) command;	
		
		if(cancelForm.isStrawSystem()){
			//cancel the straw
			strawService.cancelStrawById(cancelForm.getId(), RequestUtils.getUser(request),cancelForm.getCancelReason());
		}else {
			//cancel the vial
			vialService.cancelVialById(cancelForm.getId(), RequestUtils.getUser(request), cancelForm.getCancelReason());
		}
		
		
		
		if(cancelForm.getReferrer().equals("freezeDownSample")){ //if referring page is overDueAndToday job list
			return new ModelAndView(getSuccessView()+"scheduledCryoPreservationJob.id="+cancelForm.getScheduledCryoPreservationJobId()+"&refer="+cancelForm.getFreezeDownPageRefer());
		}else if(cancelForm.getReferrer().equals("sampleList")){ //if referring page is filtered job list
			return new ModelAndView(getSuccessViewToListView());
		}else if(cancelForm.getReferrer().equalsIgnoreCase("viewOneRequest")){
			return new ModelAndView(getSuccessViewToViewOneRequest()+"&id="+cancelForm.getCryoRequestId());
		}
		{
			throw new RuntimeException("The original page is not specified.");
		}
		
	}

	public String getSuccessViewToListView() {
		return successViewToListView;
	}

	public void setSuccessViewToViewOneRequest(String successViewToViewOneRequest) {
		this.successViewToViewOneRequest = successViewToViewOneRequest;
	}

	public String getSuccessViewToViewOneRequest() {
		return successViewToViewOneRequest;
	}
}
