/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.cryoprocessing.controllers;

import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.SimpleFormController;

import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.cryoprocessing.ScheduledCryoPreservationJob;
import uk.ac.sanger.mig.cryoprocessing.forms.CancelScheduledCryoProcessingJobForm;
import uk.ac.sanger.mig.cryoprocessing.services.ScheduleCryoPreservationJobService;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;

public class CancelScheduledJobFormController extends SimpleFormController {
	private ScheduleCryoPreservationJobService scheduleCryoPreservationJobService;
	private DictionaryService dictionaryService;
	private String successViewToSchedulePage;

	public String getSuccessViewToSchedulePage() {
		return successViewToSchedulePage;
	}

	public void setSuccessViewToSchedulePage(String successViewToSchedulePage) {
		this.successViewToSchedulePage = successViewToSchedulePage;
	}

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	public void setScheduleCryoPreservationJobService(
			ScheduleCryoPreservationJobService scheduleCryoPreservationJobService) {
		this.scheduleCryoPreservationJobService = scheduleCryoPreservationJobService;
	}

	@Override
	protected Object formBackingObject(HttpServletRequest httpServletRequest) throws Exception {

		CancelScheduledCryoProcessingJobForm form
			= (CancelScheduledCryoProcessingJobForm)createCommand();
		boolean wtCancel = ServletRequestUtils.getBooleanParameter(httpServletRequest, "wtcancel");

		//fields in the request URL

		Long id = ServletRequestUtils.getRequiredLongParameter(httpServletRequest, "id");
		String referrer = ServletRequestUtils.getRequiredStringParameter(httpServletRequest, "referrer");

		ScheduledCryoPreservationJob scpJob
		= scheduleCryoPreservationJobService.fetchWithAllComponentsById(id);

		//set the form fields (note that these fields may not necessarily be displayed in the jsp
		//referrer is a request field in th URL - identifies which page the cancel page was accessed from
		form.setScheduledCryoPreservationJob(scpJob);
		form.setReferrer(referrer);
		form.setScheduledCryoPreservationJobId( id );

		if(wtCancel){
			form.setNeedReschedule(true);
		}
		return form;
	}


	@Override
	protected Map referenceData(HttpServletRequest request, Object command,
			Errors errors) throws Exception {
		Map<String,Object> model = new HashMap<String, Object>();
		int sampleCount = 0;


		CancelScheduledCryoProcessingJobForm form
		= (CancelScheduledCryoProcessingJobForm)command;
		if(form.getScheduledCryoPreservationJob().getEmbryoHarvest()!=null
				&&form.getScheduledCryoPreservationJob().getEmbryoHarvest().getFreezeDownSamples()!=null){
			sampleCount = form.getScheduledCryoPreservationJob().getEmbryoHarvest().getFreezeDownSamples().size();
		}
		model.put("cancelReasons",dictionaryService.fetch(DictionaryEnum.CRQ_CANCEL_JOB_REASON_DICT));
		model.put("samplesCount", sampleCount);

		return model;
	}

	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response,
				Object command, BindException errors) throws Exception {

		CancelScheduledCryoProcessingJobForm form = (CancelScheduledCryoProcessingJobForm) command;



		//cancel the scheduled job and also update the status of cryo request if necessary
		scheduleCryoPreservationJobService.cancelJob(form,
					RequestUtils.getUser(request));

		//on submit go to specific page i.e. the referring page
		if(form.getReferrer()!=null){
			if(form.getReferrer().equals("overdueAndToday")){ //if referring page is overDueAndToday job list
				return new ModelAndView(getSuccessView()+"&firstAccess=true&retrieveFromSession=true&bypassForm=true&newQuery=false");
			}
			if(form.getReferrer().equals("filteredList")){ //if referring page is filtered job list
				return new ModelAndView(getSuccessView()+"&retrieveFromSession=true&bypassForm=true&newQuery=true");
			}
			if(form.getReferrer().equals("editScheduledPage")){ //if referring page is schedule cryo preservation page
				return new ModelAndView(getSuccessViewToSchedulePage()+"&retrieveFromSession=true&bypassForm=true&newQuery=false&cryoRequestId="+form.getScheduledCryoPreservationJob().getCryoRequestId());
			}
		}
		  return new ModelAndView( getSuccessView()+"&retrieveFromSession=true&bypassForm=true&newQuery=false" );
	}
}
