package uk.ac.sanger.mig.cryoprocessing.controllers;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.propertyeditors.CustomDateEditor;
import org.springframework.beans.propertyeditors.CustomNumberEditor;
import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.bind.ServletRequestDataBinder;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.SimpleFormController;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.cryoprocessing.Box;
import uk.ac.sanger.mig.cryoprocessing.Canister;
import uk.ac.sanger.mig.cryoprocessing.FreezeDownSample;
import uk.ac.sanger.mig.cryoprocessing.FreezeDownSampleComparator;
import uk.ac.sanger.mig.cryoprocessing.Freezer;
import uk.ac.sanger.mig.cryoprocessing.Goblet;
import uk.ac.sanger.mig.cryoprocessing.ScheduledCryoPreservationJob;
import uk.ac.sanger.mig.cryoprocessing.Straw;
import uk.ac.sanger.mig.cryoprocessing.Tower;
import uk.ac.sanger.mig.cryoprocessing.Vial;
import uk.ac.sanger.mig.cryoprocessing.Wedge;
import uk.ac.sanger.mig.cryoprocessing.forms.FreezeDownSampleForm;
import uk.ac.sanger.mig.cryoprocessing.services.BoxService;
import uk.ac.sanger.mig.cryoprocessing.services.CanisterService;
import uk.ac.sanger.mig.cryoprocessing.services.FreezeDownSampleService;
import uk.ac.sanger.mig.cryoprocessing.services.FreezerService;
import uk.ac.sanger.mig.cryoprocessing.services.GobletService;
import uk.ac.sanger.mig.cryoprocessing.services.ScheduleCryoPreservationJobService;
import uk.ac.sanger.mig.cryoprocessing.services.TowerService;
import uk.ac.sanger.mig.cryoprocessing.services.VialService;
import uk.ac.sanger.mig.cryoprocessing.services.WedgeService;
import uk.ac.sanger.mig.cryorequest.services.CryoRequestService;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.mousetracking.LabelPrinter;
import uk.ac.sanger.mig.mousetracking.services.LabelPrinterService;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.personnel.services.PersonService;
import ChartDirector.Chart;
import ChartDirector.PieChart;

public class FreezeDownSampleFormController extends SimpleFormController {
	
	private FreezeDownSampleService freezeDownSampleService;
	private ScheduleCryoPreservationJobService scheduleCryoPreservationJobService;
	private DictionaryService dictionaryService;
	private FreezerService freezerService;
	private TowerService towerService;
	private VialService vialService;
	private BoxService boxService;
	private CanisterService canisterService;
	private GobletService gobletService;
	private WedgeService wedgeService;
	private CryoRequestService cryoRequestService;
	private LabelPrinterService labelPrinterService;
	private PersonService personService;
	
	private String exitView;
	private String exitFilterListView;
	private String exitSampleListView;
	private String exitToViewOneRequestView;
	
	public String getExitFilterListView() {
		return exitFilterListView;
	}

	public void setExitFilterListView(String exitFilterListView) {
		this.exitFilterListView = exitFilterListView;
	}

	public String getExitSampleListView() {
		return exitSampleListView;
	}

	public void setExitSampleListView(String exitSampleListView) {
		this.exitSampleListView = exitSampleListView;
	}

	public void setExitView(String exitView) {
		this.exitView = exitView;
	}
	
	public void setFreezerService(FreezerService freezerService) {
		this.freezerService = freezerService;
	}
	
	public void setTowerService(TowerService towerService) {
		this.towerService = towerService;
	}
	
	public void setVialService(VialService vialService) {
		this.vialService = vialService;
	}
	
	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}
	
	public void setFreezeDownSampleService(FreezeDownSampleService cryoFreezeDownSampleService) {
		this.freezeDownSampleService = cryoFreezeDownSampleService;
	}
	
	@Override
	protected void initBinder(HttpServletRequest request, ServletRequestDataBinder binder) throws Exception {
		binder.registerCustomEditor(Long.class, new CustomNumberEditor(Long.class, true));
		binder.registerCustomEditor(Integer.class, new CustomNumberEditor(Integer.class, true));
		binder.registerCustomEditor(Double.class, new CustomNumberEditor(Double.class, true));
		binder.registerCustomEditor(Date.class, new CustomDateEditor(new SimpleDateFormat("dd-MMM-yyyy"), true));		
	}
	
	@Override
	protected Object formBackingObject(HttpServletRequest httpServletRequest) throws Exception {
		FreezeDownSampleForm freezeDownSampleForm = (FreezeDownSampleForm)createCommand();				    
		Long id = ServletRequestUtils.getLongParameter(httpServletRequest, "freezeDownSample.id");	
		Long scpId = ServletRequestUtils.getLongParameter(httpServletRequest, "scheduledCryoPreservationJob.id");
		String refer = ServletRequestUtils.getStringParameter(httpServletRequest, "refer", "");
		
		freezeDownSampleForm.setReferPage(refer);
		
		ScheduledCryoPreservationJob scpJob = scheduleCryoPreservationJobService.fetchWithAllComponentsById(scpId);
		FreezeDownSample freezeDownSample = null; 	
		Collection<String> sampleLoctions = null;
		
		if(scpJob.getCryoRequest() != null) {
			sampleLoctions =cryoRequestService.fetchAllSampleLocations(scpJob.getCryoRequest().getId());
		}
		
		freezeDownSampleForm.setSampleLocations(sampleLoctions);
		
		if(scpJob.isVialSystem()) {
			freezeDownSampleForm.setStrawSystem(false);
		}else if(scpJob.isStrawSystem()) {
			freezeDownSampleForm.setStrawSystem(true);
		}else{
			freezeDownSampleForm.setStrawSystem(true);
		}
		
		if(id != null) {
			//edit, need fetch the location
			freezeDownSample = freezeDownSampleService.fetchById(id,ComponentMap.of(FreezeDownSample.Component.ALL_COMPONENTS));
			
			if(scpJob.isVialSystem()) {
				freezeDownSampleForm = vialFormPrepopulate(freezeDownSampleForm, freezeDownSample);
			}else if(scpJob.isStrawSystem()){
				freezeDownSampleForm = strawFormPrepopulate(freezeDownSampleForm, freezeDownSample);
			}
			
		} else {
			//new freezeDownSample
			freezeDownSample = new FreezeDownSample();
			freezeDownSampleService.inflateFreezeDownSampleComponents(freezeDownSample);
			
			//new form, default techinicain is the user and the date is the same day as the flush date of embryos.
			freezeDownSample.setTechnician(RequestUtils.getUser(httpServletRequest));
			freezeDownSample.setTechnicianId(RequestUtils.getUser(httpServletRequest).getId());
			Date defaultDate = scpJob.getEmbryoHarvest().getFlushDate();
			freezeDownSample.setFreezeDownDate(defaultDate);
			
			//use the previous straw/vial location as the default location
			if(!scpJob.isNewFreezeDown()){
				List<FreezeDownSample> samples = new ArrayList<FreezeDownSample>(scpJob.getEmbryoHarvest().getFreezeDownSamples());
				Collections.sort(samples,new FreezeDownSampleComparator());
				FreezeDownSample sample = samples.get(samples.size()-1);
				
				if(scpJob.isStrawSystem()) {
					freezeDownSampleForm = strawFormPrepopulate(freezeDownSampleForm, sample);
				}else if(scpJob.isVialSystem()) {
					freezeDownSampleForm = vialFormPrepopulateLocation(freezeDownSampleForm, sample);
				}
			}
		}
		
		freezeDownSampleForm.setFreezeDownSample(freezeDownSample);	
		freezeDownSampleForm.setScheduledCryoPreservationJob(scpJob);
		
		return freezeDownSampleForm;
	}
	
	@Override
	protected Map referenceData(HttpServletRequest httpServletRequest, Object command, Errors errors) throws Exception {
		Map<String,Object> formMetaData = new HashMap<String,Object>();	
		
		//Used by header file to set whether freeze down sample locations list should be shown (not displayed on embryo harvest and cryo schedule page)
		formMetaData.put("showSampleLocations", true);
		
		FreezeDownSampleForm freezeDownForm = (FreezeDownSampleForm)command;
		Person technician = personService.fetchById(freezeDownForm.getFreezeDownSample().getTechnicianId(),null);
		freezeDownForm.getFreezeDownSample().setTechnician(technician);
		ScheduledCryoPreservationJob scpJob = freezeDownForm.getScheduledCryoPreservationJob();
		LabelPrinter cryoPrinter = labelPrinterService.fetchById(FreezeDownSampleService.CRYO_STRAW_LABEL_PRINTER_ID, null);
		//**********Start of chart generator for goblet display**********
		//Sizing for wedges to make 11 equal sectors
		double[] wedgeSector = {10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10};
		String[] wedgeId = new String[11];
		String[] wedgeColour = new String[11];		//actual wedge name being displayed
		int[] wedgeColourCode = new int[11];		//actual wedge colour displayed (Hex value)
		int[] wedgeTextColourCode = new int[11];	//actual wedge text colour (Hex value)
		String[] wedgeCapacity = new String[11];
		String[] wedgeStrain = new String[11];
		String[] wedgeTitleDisplay = new String[11];
		String[] wedgeHoverPointer = new String[11];
		String[] wedgeDisplayStrain = new String[11];
		
		//Hash map to for wedge colour name to hex colour code conversion 
		Map<String, Integer> wedgeColourMap = new HashMap<String, Integer>();
		wedgeColourMap.put("Black", 0x1C1C1C);
		wedgeColourMap.put("Grey", 0xa9a9a9);
		wedgeColourMap.put("Brown", 0x995100);
		wedgeColourMap.put("Red", 0xCC1A26);
		wedgeColourMap.put("Green", 0x9FDD3B);
		wedgeColourMap.put("Purple", 0xba55d3);
		wedgeColourMap.put("Turquoise", 0x00FFD4);
		wedgeColourMap.put("Blue", 0x4169e1);
		wedgeColourMap.put("Yellow", 0xF7EA00);
		wedgeColourMap.put("Orange", 0xff8c00);
		wedgeColourMap.put("Pink", 0xE8A2AC);

		//Get db wedge details
		ArrayList<Wedge> wedges = new ArrayList<Wedge>(freezeDownForm.getWedges());
		ArrayList<Wedge> wedgesDropDown = new ArrayList<Wedge>();
		String embryoStrainName = null;
		
		//when its WT freeze down, there will be no colony associat to it
	    if(scpJob.getCryoRequest() != null && scpJob.getCryoRequest().getColonyInfo() != null 
	    		&& scpJob.getCryoRequest().getColonyInfo().getColonyName() != null) {
	    	embryoStrainName = scpJob.getCryoRequest().getColonyInfo().getColonyName();
	    } 

		//Wedge details for chart (formatting, info, linking etc)
		if(wedges.size() > 0) {
			for(int i=0;i<11;i++) {
				wedgeColour[i]= wedges.get(i).getColour();
				//Get colourcode for colour name
				wedgeColourCode[i]= wedgeColourMap.get(wedges.get(i).getColour());
				wedgeCapacity[i] = Integer.toString(wedges.get(i).getStrawCounts());
				Set<String> strains = new HashSet<String>(wedgeService.fetchWedgeStrainNames(wedges.get(i)));
				String strainsString = strains.toString().replace("'", "\\'");
				strainsString = strainsString.replace("[]", "N/A");
				wedgeDisplayStrain[i] = strainsString;
				
				wedgeStrain[i] = wedgeService.fetchWedgeColonyName(wedges.get(i));
			
				wedgeId[i] = wedges.get(i).getId().toString();
				
				if(wedgeStrain[i] != null &&embryoStrainName != null&& !wedgeStrain[i].equals(embryoStrainName) ) {
					wedgeTitleDisplay[i] = "The " + wedges.get(i).getColour() + " wedge contains a different strain and so may not be used for storage";
					wedgeHoverPointer[i] = "not-allowed";
					//Get colourcode for colour name (disabled 'look')
					wedgeColourCode[i] = 0xE1E1E1;//wedgeColourMapDisabled.get(wedges.get(i).getColour());
					wedgeTextColourCode[i] = 0xB1B1B1; 
				} else {
					wedgeTitleDisplay[i] = "";
					wedgesDropDown.add(wedges.get(i));
					//Get colourcode for colour name
					wedgeColourCode[i]= wedgeColourMap.get(wedges.get(i).getColour());
					wedgeHoverPointer[i] = "pointer";
					wedgeTextColourCode[i] = 0x000000;
				}
			}
		}
		
		//Create chart
		PieChart chart = new PieChart(280, 280);

		chart.setDonutSize(140, 140, 130, 30);
		chart.setColors2(Chart.DataColor, wedgeColourCode);
		chart.setData(wedgeSector, wedgeId);
		chart.addExtraField(wedgeCapacity);
		chart.addExtraField(wedgeDisplayStrain);
		chart.addExtraField(wedgeColour);
		chart.addExtraField(wedgeHoverPointer);
		chart.addExtraField(wedgeTitleDisplay);
		chart.setLabelStyle("Arial", 8, 0x000000);
		//Set wedge text colour ('disabled' in grey)
		for(int i=0;i<11;i++) {
			chart.sector(i).setLabelStyle("Arial", 8, wedgeTextColourCode[i]);
			if (wedgeColourCode[i] == 0x1C1C1C) {
				chart.sector(i).setLabelStyle("Arial", 8, 0xFFFFFF);
			}
		}
		chart.setLineColor(0xffffff);

		//Client side Javascript to show detail information on "onmouseover" in textarea
		//String showPointer = "onmouseover=\"this.style.cursor = '{field3}'; showWedgeInfo('{field2}', '{field1}', '{field0}');\" ";
		String showPointer = "onmouseover=\"changeCursor(this, '{field3}'); showWedgeInfo('{field2}', '{field1}', '{field0}');\" ";
		
		//Client side Javascript to hide detail information on "onmouseout"
		//String hidePointer = "onmouseout=\"this.style.cursor = 'default';\" ";
		String hidePointer = "class=\"wedgeClass\" onmouseout=\"changeCursor(this, 'default');\" ";
		//String hidePointer = "class=\"wedgeClass\" ";
		
		//Set Wedge drop-down
		String onclick = "onclick=\"setWedge({label});\" ";
		//Show message if strain does not match
		String title = "title=\"{field4}\" ";
		chart.setLabelPos(-40);
		chart.setLabelFormat("{field2}\n{field0}");
		
		//Use date/time addition in name to prevent cacheing
		String imageId = "gobletPiechart" + new Date().getTime();
		chart.makeSession(httpServletRequest, imageId);
				formMetaData.put("imageId", imageId);
		formMetaData.put("imageMap", chart.getHTMLImageMap("","", title + onclick + showPointer + hidePointer));
		//**********End of chart generator**********
		
		Collection<DictionaryEntry> cellGrades = dictionaryService.fetch(DictionaryEnum.CRQ_EMBRYO_GRADE_DICT, true);
		Collection<Freezer> freezers = new ArrayList<Freezer>();
		if(freezeDownForm.getStrawSystem() != null) {
			if( !freezeDownForm.getStrawSystem()) {
				freezers = freezerService.fetchVialFreezers(null);
			}
			if(freezeDownForm.getStrawSystem()) {
				freezers = freezerService.fetchStrawFreezers(null);
			}
		}
		
		Map<Boolean, String> strawSystemMap = new HashMap<Boolean, String>();
		strawSystemMap.put(true,"Straw");
		strawSystemMap.put(false,"Vial");	
		formMetaData.put("strawSystemMap", strawSystemMap);
		
		freezeDownForm.setFreezers(freezers);
		Collection<Integer> vialPositions = new ArrayList<Integer>();
		vialPositions.add(25);
		formMetaData.put("cellGrades", cellGrades);
		formMetaData.put("vialPositions", vialPositions);
		formMetaData.put("freezeDownSampleList", scpJob.getEmbryoHarvest().getFreezeDownSamples());
		formMetaData.put("cryoRequest", scpJob.getCryoRequest());
		formMetaData.put("wedgesDropDown", wedgesDropDown);
		formMetaData.put("printer",cryoPrinter.getSysName());
		return formMetaData;
	} 
	
	@Override
	protected boolean isFormChangeRequest(HttpServletRequest request) {
		boolean formChange = ServletRequestUtils.getBooleanParameter(request, "onFormChange", false);	
		if( formChange ) 
			return true;
		else
			return super.isFormChangeRequest( request );		
	}
	
	@Override
	protected void onFormChange(HttpServletRequest request, HttpServletResponse response, 
			Object command, BindException bindEx) throws Exception {
		
		FreezeDownSampleForm freezeDownSampleForm = (FreezeDownSampleForm)command;
		
		if(freezeDownSampleForm.getStrawSystem() != null) {
			if(freezeDownSampleForm.getStrawSystem()) {
				freezeDownSampleForm = strawSystemOnFormChange(freezeDownSampleForm);
			}else if(!freezeDownSampleForm.getStrawSystem()) {
				freezeDownSampleForm = vialSystemOnFormChange(freezeDownSampleForm);
			}
		}
		
		freezeDownSampleForm.setOnFormChange(false);
	}
	
	private FreezeDownSampleForm vialSystemOnFormChange(FreezeDownSampleForm freezeDownSampleForm) {
		if(freezeDownSampleForm.getFreezerId() != null) {
			//the freezer is selected and the towers are not populated
			//then populate the towers
			
			Collection<Tower> towers = towerService.fetchByFreezerId(freezeDownSampleForm.getFreezerId(), null);
			if(towers != null) {
				freezeDownSampleForm.setTowers(towers);
			}
			freezeDownSampleForm.setBoxes(new ArrayList<Box>());
			freezeDownSampleForm.setAvailableVialPosition(new ArrayList<Integer>());
		}else {
			freezeDownSampleForm.setBoxes(new ArrayList<Box>());
			freezeDownSampleForm.setTowers(new ArrayList<Tower>());
			freezeDownSampleForm.setAvailableVialPosition(new ArrayList<Integer>());
		}
		
		if(freezeDownSampleForm.getTowerId() != null && !freezeDownSampleForm.getTowers().isEmpty()) {
			//the freezer and the tower are choosen, the box has not been populated
			//then populate the box
			
			Collection<Box> boxes = boxService.fetchByTowerId(freezeDownSampleForm.getTowerId(), null);
			if(boxes != null) {
				freezeDownSampleForm.setBoxes(boxes);
			}
			
		}else {
			freezeDownSampleForm.setBoxes(new ArrayList<Box>());
			freezeDownSampleForm.setAvailableVialPosition(new ArrayList<Integer>());
		}
		
		if(freezeDownSampleForm.getBoxId() != null && !freezeDownSampleForm.getBoxes().isEmpty()) {
			//after choose the box, need get all the vials in the box
			Collection<Integer> usedPosition = new ArrayList<Integer>();
			Collection<Vial> vials = vialService.fetchActiveByBoxId(freezeDownSampleForm.getBoxId(), null);
			List<Integer> availablePosition = new ArrayList<Integer>(100);
			for(Vial vial:vials) {
				usedPosition.add(vial.getPosition());
			}
			
			for(int i=1;i<101;i++) {
				availablePosition.add(i);
			}
			
			availablePosition.removeAll(usedPosition);
			
			freezeDownSampleForm.setAvailableVialPosition(availablePosition);
			freezeDownSampleForm.setVialPosition(null);
		}else {
			freezeDownSampleForm.setAvailableVialPosition(new ArrayList<Integer>());
			
		}
		return freezeDownSampleForm;
		
	}
	
	private FreezeDownSampleForm strawSystemOnFormChange(FreezeDownSampleForm freezeDownSampleForm) {
		if(freezeDownSampleForm.getFreezerId() != null) {
			//the freezer is selected and the towers are not populated
			//then populate the towers
			
			Collection<Canister> canisters = canisterService.fetchByFreezerId(freezeDownSampleForm.getFreezerId(), null);
			if(canisters != null) {
				freezeDownSampleForm.setCanisters(canisters);
			}
			freezeDownSampleForm.setGoblets(new ArrayList<Goblet>());
			freezeDownSampleForm.setWedges(new ArrayList<Wedge>());
		}else {
			freezeDownSampleForm.setCanisters(new ArrayList<Canister>());
			freezeDownSampleForm.setGoblets(new ArrayList<Goblet>());
			freezeDownSampleForm.setWedges(new ArrayList<Wedge>());
		}
		
		if(freezeDownSampleForm.getCanisterId() != null && !freezeDownSampleForm.getCanisters().isEmpty()) {
			//the freezer and the tower are choosen, the box has not been populated
			//then populate the box
			
			Collection<Goblet> goblets = gobletService.fetchByCanisterId(freezeDownSampleForm.getCanisterId(), null);
			if(goblets != null) {
				freezeDownSampleForm.setGoblets(goblets);
			}
			
		}else {
			freezeDownSampleForm.setGoblets(new ArrayList<Goblet>());
			freezeDownSampleForm.setWedges(new ArrayList<Wedge>());
		}
		
		if(freezeDownSampleForm.getGobletId() != null && !freezeDownSampleForm.getGoblets().isEmpty()) {
			
			ComponentMap wedgeComponent = new ComponentMap();
			wedgeComponent = ComponentMap.putAll(new ComponentMap(Wedge.Component.STRAWS, new ComponentMap(Straw.Component.FREEZE_DOWN_SAMPLE, null)));
			
			Collection<Wedge> wedges = wedgeService.fetchByGobletId(freezeDownSampleForm.getGobletId(), wedgeComponent);
			if(wedges != null) {
				freezeDownSampleForm.setWedges(wedges);
			}
			
		}else {
			freezeDownSampleForm.setWedges(new ArrayList<Wedge>());
			
		}
		return freezeDownSampleForm;
		
	}
	
	@Override
	protected boolean isFormSubmission(HttpServletRequest request) {
		boolean exitOnly = ServletRequestUtils.getBooleanParameter(request, "exitOnly", false);
		boolean completeOneExit = ServletRequestUtils.getBooleanParameter(request, "completeOnExit", false);
		
		if(exitOnly || completeOneExit)
			return true;	
		return super.isFormSubmission(request);
	}
	
	@Override
	protected boolean suppressValidation(HttpServletRequest request, Object command) {
		boolean exitOnly = ServletRequestUtils.getBooleanParameter(request, "exitOnly", false);
		boolean completeOneExit = ServletRequestUtils.getBooleanParameter(request, "completeOnExit", false);
		if(exitOnly || completeOneExit)
			return true;	
		return super.suppressValidation(request, command);
	}
	
	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, 
			Object command, BindException errors) throws Exception {
		FreezeDownSampleForm freezeDownSampleForm = (FreezeDownSampleForm) command;
		FreezeDownSample freezeDownSample = freezeDownSampleForm.getFreezeDownSample();
		
		ScheduledCryoPreservationJob scpJob = freezeDownSampleForm.getScheduledCryoPreservationJob();
		boolean exit = ServletRequestUtils.getBooleanParameter(request, "exitOnly", false);	
		boolean complete = ServletRequestUtils.getBooleanParameter(request, "completeOnExit", false);
		
		if(complete || exit){
			if(complete) {
				scheduleCryoPreservationJobService.completeAttempt(scpJob, RequestUtils.getUser(request));
			}
			if(freezeDownSampleForm.getReferPage().equals("filterList")){
				return new ModelAndView(getExitFilterListView());
			}else if(freezeDownSampleForm.getReferPage().equals("sampleList")){
				return new ModelAndView(getExitSampleListView());
			}else if(freezeDownSampleForm.getReferPage().equals("viewOneRequest")){
				return new ModelAndView(exitToViewOneRequestView+"&id="+scpJob.getCryoRequestId());
			}
			else{
				return new ModelAndView(getExitView());
			}
		}else{
			
			//add new freezeDownSample(Vial or Straw) or edit an existing one
			if(freezeDownSampleForm.getStrawSystem() != null) {
				freezeDownSampleService.editFreezeDownSample(freezeDownSample,freezeDownSampleForm, RequestUtils.getUser(request));
				logger.debug("Object " + freezeDownSample + " successfully stored.");
			}else {
				throw new RuntimeException("no system has been selected. Can not save sample!");
			}
			
		}
		return new ModelAndView(getSuccessView() 
				+ "?scheduledCryoPreservationJob.id="
				+freezeDownSampleForm.getScheduledCryoPreservationJob().getId()
				+"&refer="+freezeDownSampleForm.getReferPage());
	}
	
	public void setScheduleCryoPreservationJobService(
			ScheduleCryoPreservationJobService scheduleCryoPreservationJobService) {
		this.scheduleCryoPreservationJobService = scheduleCryoPreservationJobService;
	}
	
	public void setBoxService(BoxService boxService) {
		this.boxService = boxService;
	}
	
	public String getExitView() {
		return exitView;
	}	
	
	private FreezeDownSampleForm strawFormPrepopulate(FreezeDownSampleForm freezeDownSampleForm, FreezeDownSample freezeDownSample) {
		
		freezeDownSampleForm.setFreezerId(freezeDownSample.getStrawLocation().getFreezerId());
		freezeDownSampleForm.setCanisterId(freezeDownSample.getStrawLocation().getCanisterId());
		freezeDownSampleForm.setGobletId(freezeDownSample.getStrawLocation().getGobletId());
		freezeDownSampleForm.setWedgeId(freezeDownSample.getStrawLocation().getWedgeId());
		Collection<Canister> canisters = canisterService.fetchByFreezerId(freezeDownSampleForm.getFreezerId(), null);
		Collection<Goblet> goblets = gobletService.fetchByCanisterId(freezeDownSampleForm.getCanisterId(), null);
		
		ComponentMap wedgeComponent = new ComponentMap();
		wedgeComponent = ComponentMap.putAll(new ComponentMap(Wedge.Component.STRAWS, new ComponentMap(Straw.Component.FREEZE_DOWN_SAMPLE, null)));
		
		Collection<Wedge> wedges = wedgeService.fetchByGobletId(freezeDownSampleForm.getGobletId(), wedgeComponent);
		
		
		freezeDownSampleForm.setCanisters(canisters);
		freezeDownSampleForm.setGoblets(goblets);
		freezeDownSampleForm.setWedges(wedges);

		return freezeDownSampleForm;
	}
	
	
	private FreezeDownSampleForm vialFormPrepopulate(FreezeDownSampleForm freezeDownSampleForm, FreezeDownSample freezeDownSample) {
		
		freezeDownSampleForm.setFreezerId(freezeDownSample.getVialLocation().getFreezerId());
		freezeDownSampleForm.setTowerId(freezeDownSample.getVialLocation().getTowerId());
		freezeDownSampleForm.setBoxId(freezeDownSample.getVialLocation().getBoxId());
		freezeDownSampleForm.setVialPosition(freezeDownSample.getVialLocation().getVialPosition());
		
		Collection<Tower> towers = towerService.fetchByFreezerId(freezeDownSampleForm.getFreezerId(), null);
		Collection<Box> boxes = boxService.fetchByTowerId(freezeDownSampleForm.getTowerId(), null);
		
		Collection<Integer> usedPosition = new ArrayList<Integer>();
		Collection<Vial> vials = vialService.fetchActiveByBoxId(freezeDownSampleForm.getBoxId(), null);
		List<Integer> availablePosition = new ArrayList<Integer>(100);
		
		for(Vial vial:vials) {
			usedPosition.add(vial.getPosition());
		}
		
		for(int i=1;i<101;i++) {
			availablePosition.add(i);
		}
		
		availablePosition.removeAll(usedPosition);
		availablePosition.add(freezeDownSampleForm.getVialPosition());
		Collections.sort(availablePosition);
		freezeDownSampleForm.setAvailableVialPosition(availablePosition);
		freezeDownSampleForm.setTowers(towers);
		freezeDownSampleForm.setBoxes(boxes);
		
		return freezeDownSampleForm;
	}
	
private FreezeDownSampleForm vialFormPrepopulateLocation(FreezeDownSampleForm freezeDownSampleForm, FreezeDownSample freezeDownSample) {
		
		freezeDownSampleForm.setFreezerId(freezeDownSample.getVialLocation().getFreezerId());
		freezeDownSampleForm.setTowerId(freezeDownSample.getVialLocation().getTowerId());
		freezeDownSampleForm.setBoxId(freezeDownSample.getVialLocation().getBoxId());
	//	freezeDownSampleForm.setVialPosition(freezeDownSample.getVialLocation().getVialPosition());
		
		Collection<Tower> towers = towerService.fetchByFreezerId(freezeDownSampleForm.getFreezerId(), null);
		Collection<Box> boxes = boxService.fetchByTowerId(freezeDownSampleForm.getTowerId(), null);
		freezeDownSampleForm.setTowers(towers);
		freezeDownSampleForm.setBoxes(boxes);
		
		Collection<Integer> usedPosition = new ArrayList<Integer>();
		Collection<Vial> vials = vialService.fetchActiveByBoxId(freezeDownSampleForm.getBoxId(), null);
		List<Integer> availablePosition = new ArrayList<Integer>();
		
		for(Vial vial:vials) {
			usedPosition.add(vial.getPosition());
		}
		
		for(int i=1;i<101;i++) {
			availablePosition.add(i);
		}
		
		availablePosition.removeAll(usedPosition);
		Collections.sort(availablePosition);
		freezeDownSampleForm.setAvailableVialPosition(availablePosition);
		
		return freezeDownSampleForm;
	}


	public void setCanisterService(CanisterService canisterService) {
		this.canisterService = canisterService;
	}

	public void setGobletService(GobletService gobletService) {
		this.gobletService = gobletService;
	}

	public void setWedgeService(WedgeService wedgeService) {
		this.wedgeService = wedgeService;
	}

	public void setCryoRequestService(CryoRequestService cryoRequestService) {
		this.cryoRequestService = cryoRequestService;
	}

	public void setLabelPrinterService(LabelPrinterService labelPrinterService) {
		this.labelPrinterService = labelPrinterService;
	}

	public void setExitToViewOneRequestView(String exitToViewOneRequestView) {
		this.exitToViewOneRequestView = exitToViewOneRequestView;
	}

	public void setPersonService(PersonService personService) {
		this.personService = personService;
	}
	

}