/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.cryoprocessing.controllers;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.AbstractCancellableFormController;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.cryoprocessing.ScheduledCryoPreservationJob;
import uk.ac.sanger.mig.cryoprocessing.forms.ScheduleCryoRequestForm;
import uk.ac.sanger.mig.cryoprocessing.services.ScheduleCryoPreservationJobService;
import uk.ac.sanger.mig.cryoprocessing.views.ScheduledCryoPreservationJobListView;
import uk.ac.sanger.mig.cryorequest.CryoRequest;
import uk.ac.sanger.mig.cryorequest.services.CryoRequestService;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.personnel.Person;

public class ScheduleCryoPreservationJobFormController extends AbstractCancellableFormController {

	private CryoRequestService cryoRequestService;
	private DictionaryService dictionaryService;
	private ScheduleCryoPreservationJobService scheduleCryoPreservationJobService;


	@Override
	protected Object formBackingObject(HttpServletRequest request) throws Exception {

		return createCommand();
	}

	@Override
	protected void onBindOnNewForm(HttpServletRequest request, Object command) throws Exception {

		ScheduleCryoRequestForm form = (ScheduleCryoRequestForm)command;
		Long cryoRequestId = ServletRequestUtils.getRequiredLongParameter(request, "cryoRequestId");
		CryoRequest cryoRequest = cryoRequestService.fetchById(cryoRequestId, null);
		form.setCryoRequest(cryoRequest);
		super.onBindOnNewForm(request, command);
	}


	@Override
	protected boolean isFormChangeRequest(HttpServletRequest request) {

		return !"".equals(ServletRequestUtils.getStringParameter(request, "orderBy", ""));
	}

	@Override
	protected Map referenceData(HttpServletRequest request, Object command, Errors errors) throws Exception {
		Map<String, Object> model = new HashMap<String, Object>();
		ScheduleCryoRequestForm form = (ScheduleCryoRequestForm)command;
		form.setQueryName("listJobsForCryoRequest");

		Long cryoRequestId = ServletRequestUtils.getRequiredLongParameter(request, "cryoRequestId");
		ComponentMap requiredComponent = cryoRequestService.getComponentMapForHeaderFile();
		CryoRequest cryoRequest = cryoRequestService.fetchById(cryoRequestId, requiredComponent);
		model.put("cryoRequest", cryoRequest);

		Collection<ScheduledCryoPreservationJobListView> scheduledCryoPreservationJobs
			=	scheduleCryoPreservationJobService.fetchAllScheduledJobsbyCryoRequestId(cryoRequest.getId(), form);
		model.put("scheduledJobList", scheduledCryoPreservationJobs);

		return model;

	}
	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response,
				Object command, BindException errors) throws Exception {

		ScheduleCryoRequestForm form = (ScheduleCryoRequestForm)command;

		ScheduledCryoPreservationJob scheduledCryoPreservationJob = new ScheduledCryoPreservationJob();
		scheduledCryoPreservationJob.setCryoRequestId(form.getCryoRequest().getId());
		//cryoSchedulePreservationJob.setCryoJobStatusDictId();
		scheduledCryoPreservationJob.setNextScheduledDate(form.getNextScheduleDate());
		scheduledCryoPreservationJob.setJobStatusDict(
				dictionaryService.fetchEntry(DictionaryEnum.CRQ_CRYO_SCHEDULED_JOB_STATUS_DICT,1l));
		Person person = RequestUtils.getUser(request);

		scheduledCryoPreservationJob.setNextScheduledDate(form.getNextScheduleDate());
		scheduledCryoPreservationJob.setCreator(person);
		scheduledCryoPreservationJob.setComments(form.getComments());
		scheduledCryoPreservationJob.setStatusScheduled();
		scheduledCryoPreservationJob.setJobName(
				scheduleCryoPreservationJobService.getNextJobName(form.getCryoRequest().getId()));

		scheduleCryoPreservationJobService.storeAuthenticated(scheduledCryoPreservationJob, person);


		if(scheduleCryoPreservationJobService.fetchWildTypeScheduledJobByDate(scheduledCryoPreservationJob.getNextScheduledDate()).size()==0){
			scheduleCryoPreservationJobService.createWildTypeJob(form.getNextScheduleDate(), person,null);

		}
		scheduleCryoPreservationJobService.updateCryoRequestOnSchedule(form.getCryoRequest(), person);

		return new ModelAndView(getSuccessView()+"?retrieveFromSession=true&newQuery=false&bypassForm=true&currentRecordId=" + form.getCryoRequest().getId());

	}



	public void setCryoRequestService(CryoRequestService cryoRequestService) {
		this.cryoRequestService = cryoRequestService;
	}

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}
	public void setScheduleCryoPreservationJobService(
			ScheduleCryoPreservationJobService scheduleCryoPreservationJobService) {
		this.scheduleCryoPreservationJobService = scheduleCryoPreservationJobService;
	}


}
