/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.cryoprocessing.controllers;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.AbstractSearchFormController;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.cryoprocessing.ScheduledCryoPreservationSearchBean;
import uk.ac.sanger.mig.cryoprocessing.services.ScheduleCryoPreservationJobService;
import uk.ac.sanger.mig.cryoprocessing.views.ScheduledCryoPreservationJobListView;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;

public class SearchScheduledCryoPreservationJobsController extends
		AbstractSearchFormController {

	private ScheduleCryoPreservationJobService scheduleCryoPreservationJobService;

	private DictionaryService dictionaryService;

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	public ScheduleCryoPreservationJobService getScheduleCryoPreservationJobService() {
		return scheduleCryoPreservationJobService;
	}

	public void setScheduleCryoPreservationJobService(
			ScheduleCryoPreservationJobService scheduleCryoPreservationJobService) {
		this.scheduleCryoPreservationJobService = scheduleCryoPreservationJobService;
	}
	
	protected Map<String, Object> referenceData(HttpServletRequest request) throws Exception {
	    Map<String, Object> model = new HashMap<String, Object>();  
	    Collection<DictionaryEntry> statuses = new ArrayList<DictionaryEntry>();
		statuses = dictionaryService.fetch(DictionaryEnum.CRQ_CRYO_SCHEDULED_JOB_STATUS_DICT);
		model.put("statuses", statuses);
		return model;
	 }

	@Override
	protected ModelAndView onSearch(HttpServletRequest request,
			HttpServletResponse response, Object command, BindException errors)
			throws Exception {

		ScheduledCryoPreservationSearchBean searchBean = (ScheduledCryoPreservationSearchBean) command;
		searchBean.setQueryName("listCryoRequestJobs");
		searchBean.setSearchBy(request.getParameter("searchBy"));
	    searchBean.setSearchString(request.getParameter("searchString"));
		
	    Map<String, Object> model = referenceData(request);
	    SimpleDateFormat defaultDateFormat = new SimpleDateFormat("dd-MMM-yyyy");
	    String today = defaultDateFormat.format(new Date());
	   
		
	    /*initialise three lists i)filtered job list (list of jobs as oer filter criteria)
	      	                ii) cryoScheduled jobs (scheduled jobs for today and
	    				   iii) overdue jobs (jobs scheduled for a past date and which 
	                              have status still as scheduled )
	    */
	    //Note: on first access to this page, filtered job should not be fetched
	    
	    Collection<ScheduledCryoPreservationJobListView> filteredJobList = null;
	    Collection<ScheduledCryoPreservationJobListView> cryoScheduledJobsList = null;
	    Collection<ScheduledCryoPreservationJobListView> overdueJobsList = null;
	    
	    //firstAccess request parameter being true implies this page accessed first time. Set in URL
		String firstAccess = ServletRequestUtils.getStringParameter(request, "firstAccess");
		
		if(firstAccess !=null){ 
			//meaning don;t fetch filtered list (send an empty list).
			filteredJobList= new ArrayList<ScheduledCryoPreservationJobListView>();
			model.put("firstTimeAccess", true);
		}else{ 
			//Not a  first time access i.e. while inside this page and navigating through internal buttons 
			String showTodays = ServletRequestUtils.getStringParameter(request, "getTodaysJobs");
			if(showTodays!=null && showTodays.equals("true")){ 
				//Access after user clicks on 'show today's jobs' so set firstTimeAccess to true
				model.put("firstTimeAccess", true);
			}else{ 
				//Access after user clicks on 'Refresh button to fetch filtered list'., so set firstTimeAccess to false 
				model.put("firstTimeAccess", false);	
			}
			filteredJobList= scheduleCryoPreservationJobService.fetch(searchBean);	
		}
		
		model.put("filteredJobList", filteredJobList);
		model.put("today", today);
		cryoScheduledJobsList = scheduleCryoPreservationJobService.fetchByTargetDate(new Date());
		model.put("scheduledJobsList", cryoScheduledJobsList);
		overdueJobsList = scheduleCryoPreservationJobService
				.fetchOverdueJobs(new Date());
		model.put("overdueJobsList", overdueJobsList);
		return showForm(request, response, errors, model);
	}

	@Override
	protected void onBindAndValidate(HttpServletRequest arg0, Object arg1, BindException arg2) throws Exception {
		
		super.onBindAndValidate(arg0, arg1, arg2);
	}
	
	@Override
	protected ModelAndView showForm(HttpServletRequest arg0, HttpServletResponse arg1, BindException arg2, Map arg3) throws Exception {
		// TODO Auto-generated method stub
		return super.showForm(arg0, arg1, arg2, arg3);
	}
}
