/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.cryoprocessing.controllers;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.AbstractCancellableFormController;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.cryoprocessing.Shipping;
import uk.ac.sanger.mig.cryoprocessing.forms.ShippingForm;
import uk.ac.sanger.mig.cryoprocessing.services.FreezeDownSampleService;
import uk.ac.sanger.mig.cryoprocessing.services.ShippingService;
import uk.ac.sanger.mig.cryoprocessing.views.SampleListView;
import uk.ac.sanger.mig.cryorequest.CryoRequest;
import uk.ac.sanger.mig.cryorequest.services.CryoRequestService;

public class ShipFormController extends AbstractCancellableFormController{

	private FreezeDownSampleService freezeDownSampleService;
	private CryoRequestService cryoRequestService;
	private ShippingService shippingService;


	public void setShippingService(ShippingService shippingService) {
		this.shippingService = shippingService;
	}

	public FreezeDownSampleService getFreezeDownSampleService() {
		return freezeDownSampleService;
	}

	public void setFreezeDownSampleService(
			FreezeDownSampleService freezeDownSampleService) {
		this.freezeDownSampleService = freezeDownSampleService;
	}

	public void setCryoRequestService(CryoRequestService cryoRequestService) {
		this.cryoRequestService = cryoRequestService;
	}

	@Override
	protected Map referenceData(HttpServletRequest request, Object command, Errors arg2) throws Exception {


		Long id = ServletRequestUtils.getRequiredLongParameter(request, "cryoRequestId");

		Map<String, Object> model = new HashMap<String, Object>();
		ComponentMap requiredComponents = cryoRequestService.getComponentMapForHeaderFile();
		CryoRequest cryoRequest = cryoRequestService.fetchById(id, requiredComponents);

		model.put("cryoRequest", cryoRequest);
		return model;
	}

	@Override
	protected Object formBackingObject(HttpServletRequest request) throws Exception {
		ShippingForm shipForm = (ShippingForm)createCommand();
		Long id = ServletRequestUtils.getRequiredLongParameter(request, "cryoRequestId");
        shipForm.setCryoRequestId(id);
		Collection<SampleListView> samples = freezeDownSampleService.fetchByCryoRequestId(id);
		shipForm.buildNewCheckBoxes(samples);

		return shipForm;
	}

	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response,
			Object command, BindException errors) throws Exception {

		ShippingForm form = (ShippingForm) command;
		Shipping shipping = new Shipping();
		shipping.setShippingDate(form.getShippingDate());
		shipping.setShipTo(form.getShipTo());
        shippingService.storeShoppingSamples(form.getCheckBoxes(), shipping,RequestUtils.getUser(request));
		return new ModelAndView(getSuccessView()
				+"?retrieveFromSession=true&newQuery=false&bypassForm=true&currentRecordId="
				+ form.getCryoRequestId());
	}

	@Override
	protected void onBindOnNewForm(HttpServletRequest request, Object command) throws Exception {

		super.onBindOnNewForm(request, command);
	}


}