/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.cryoprocessing.controllers;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.SimpleFormController;

import uk.ac.sanger.mig.cryoprocessing.Shipping;
import uk.ac.sanger.mig.cryoprocessing.ShippingSearchBean;
import uk.ac.sanger.mig.cryoprocessing.services.ShippingService;

public class ShippingListController extends SimpleFormController {

	private ShippingService shippingService;
	private String excelView;
	
	public void setShippingService(ShippingService shippingService) {
		this.shippingService = shippingService;
	}

	public String getExcelView() {
		return excelView;
	}

	public void setExcelView(String excelView) {
		this.excelView = excelView;
	}
	
		@Override
	protected boolean isFormSubmission(HttpServletRequest request) {
		return false; //so always treated as new form 
	}
	
	@Override
	protected ModelAndView showForm(HttpServletRequest request, HttpServletResponse arg1, BindException arg2) throws Exception {
		
		Map<String, Object> model = new HashMap<String, Object>();	
		ShippingSearchBean searchBean = (ShippingSearchBean)getCommand(request);
		Collection<Shipping> results = shippingService.search(searchBean);
		model.put("results", results);	
		model.put("form",searchBean);
		Boolean excelExport = ServletRequestUtils.getBooleanParameter(request, "excel",false);

		if(excelExport) {
			return new ModelAndView(getExcelView(), model);
		} else {
			return new ModelAndView(getSuccessView(), model);
		}
	}
		
	protected Object formBackingObject(HttpServletRequest request) throws Exception {			
		ShippingSearchBean searchBean = (ShippingSearchBean)createCommand();		
		Shipping queryShipping = new Shipping(); //create and inject Shipping obj with query fields set
		searchBean.setShipping(queryShipping);
		String orderBy = ServletRequestUtils.getStringParameter(request, "orderBy","id");
		searchBean.setOrderBy( orderBy );
		boolean isDescending = ServletRequestUtils.getBooleanParameter(request, "orderDesc",false);
		searchBean.setOrderDesc( isDescending );	
		return searchBean;
	}
}
	


	