/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.cryoprocessing.controllers;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.AbstractSearchFormController;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.cryoprocessing.FreezeDownSampleSearchBean;
import uk.ac.sanger.mig.cryoprocessing.services.FreezeDownSampleService;
import uk.ac.sanger.mig.cryoprocessing.views.SampleListView;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;

public class SimpleSearchSampleController extends AbstractSearchFormController {

	private FreezeDownSampleService freezeDownSampleService;
	private DictionaryService dictionaryService;

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	public void setFreezeDownSampleService(
			FreezeDownSampleService freezeDownSampleService) {
		this.freezeDownSampleService = freezeDownSampleService;
	}

	@Override
	protected ModelAndView onSearch(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {

		FreezeDownSampleSearchBean searchBean = (FreezeDownSampleSearchBean)command;
		searchBean.setQueryName("sampleSearch");

		Map<String, Object> model = new HashMap<String, Object>();

		Collection<SampleListView> samples = freezeDownSampleService.searchSamples(searchBean);

		model.put("samples", samples);
		return new ModelAndView(getSuccessView(), model);
	}

	@Override
	protected Map referenceData(HttpServletRequest request, Object command, Errors errors) throws Exception {
		Map<String, Object> referenceData = new HashMap<String, Object>();
		Collection<DictionaryEntry> femaleStrainDicts = dictionaryService.fetch(DictionaryEnum.CRQ_CRYO_REQUEST_STRAIN_DICT);
		String[] femaleStrains = new String[femaleStrainDicts.size()];
		int counter = 0;

		for(DictionaryEntry femaleStrainDict : femaleStrainDicts){
			femaleStrains[counter] = femaleStrainDict.getName();
			counter++;
		}
		referenceData.put("femaleStrains", femaleStrains);
		return referenceData;
	}
}
