package uk.ac.sanger.mig.cryoprocessing.controllers;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import uk.ac.sanger.mig.common.AbstractCancellableFormController;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.cryoprocessing.ThawTest;
import uk.ac.sanger.mig.cryoprocessing.forms.ThawTestForm;
import uk.ac.sanger.mig.cryoprocessing.services.FreezeDownSampleService;
import uk.ac.sanger.mig.cryoprocessing.services.ThawTestService;
import uk.ac.sanger.mig.cryoprocessing.views.SampleListView;
import uk.ac.sanger.mig.cryorequest.CryoRequest;
import uk.ac.sanger.mig.cryorequest.services.CryoRequestService;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.database.TableMetadataEnum;
import uk.ac.sanger.mig.licensing.PersonalLicence;
import uk.ac.sanger.mig.licensing.services.PersonalLicenceService;
import uk.ac.sanger.mig.miprocessing.EmbryoTransferProcedure;
import uk.ac.sanger.mig.miprocessing.services.EmbryoTransferProcedureService;
import uk.ac.sanger.mig.miprocessing.services.MirMouseTrackingBridgeService;
import uk.ac.sanger.mig.mousetracking.Cage;
import uk.ac.sanger.mig.mousetracking.services.CageService;
import uk.ac.sanger.mig.personnel.Person;

public class ThawTestFormController extends AbstractCancellableFormController {

	private ThawTestService thawTestService;
	private DictionaryService dictionaryService;
	private MirMouseTrackingBridgeService embryoTransferMouseTrackingBridgeService;
	private FreezeDownSampleService freezeDownSampleService;
	private EmbryoTransferProcedureService embryoTransferProcedureService;
	private CryoRequestService cryoRequestService;
	private PersonalLicenceService personalLicenceService;
	private CageService cageService;

	//private static final SimpleDateFormat simpleDateFormat = new SimpleDateFormat("dd-MMM-yyyy");
	private String requestView;
	private String listView;

	public String getListView() {
		return listView;
	}

	public void setListView(String listView) {
		this.listView = listView;
	}

	@Override
	protected Object formBackingObject(HttpServletRequest request) throws Exception {

		ThawTestForm thawTestForm = (ThawTestForm)createCommand();

		Long thawTestId = ServletRequestUtils.getLongParameter(request, "thawTestId");
		Long embryoTransferId = ServletRequestUtils.getLongParameter(request, "embryoTransferId");
		Long cryoRequestId = ServletRequestUtils.getRequiredLongParameter(request, "cryoRequestId");
		ThawTest thawTest = null;
		EmbryoTransferProcedure embryoTransfer = null;
		CryoRequest cryoRequest = cryoRequestService.fetchById(cryoRequestId, cryoRequestService.getComponentMapForHeaderFile());
		Collection<SampleListView> samples = freezeDownSampleService.fetchByCryoRequestId(cryoRequestId);

		if( thawTestId != null ) {
			//existing thawTest, come here to edit ETs
			thawTest =  thawTestService.fetchWithAllComponents(thawTestId);
			thawTestForm.setDateCompleted(thawTest.getDateCompleted());
		}else{
			//new thaw, need assign the cryo request Id
			thawTest = new ThawTest();
			thawTest.setCryoRequestId(cryoRequestId);
		}

		//edit the embryo transfer which already existed in database
		if(embryoTransferId != null) {
			embryoTransfer = embryoTransferProcedureService.fetchWithAllComponentsById(embryoTransferId);
		}else{
			//set the default value such as pil holder
			embryoTransfer = embryoTransferProcedureService.buildDefaultThawTestEmbryoTransfer(RequestUtils.getUser(request) );
		}

		thawTestForm.setCryoRequest(cryoRequest);//for header file display request information
		thawTestForm.setCryoRequestId(cryoRequestId);//keep track of the request No
		thawTestForm.setThawTest(thawTest);
		thawTestForm.setThawTestId(thawTestId);//keep track of the thawTestId
		thawTestForm.setSamples(samples);//existing samples for the thawTest

		//need revise
		populateForm(thawTestForm, new Date(), embryoTransfer);

		return thawTestForm;
	}

	@Override
	protected Map referenceData(HttpServletRequest httpServletRequest, Object command, Errors errors) throws Exception {

		ThawTestForm thawTestForm = (ThawTestForm)command;
		Collection<DictionaryEntry> stufferStrains = dictionaryService.fetch(DictionaryEnum.MOUSE_STRAIN, true);
		Collection<DictionaryEntry> anaesthetics = dictionaryService.fetch(DictionaryEnum.MIR_ANAESTHETIC_DICT, true);
		Collection<DictionaryEntry> analgesics = dictionaryService.fetch(DictionaryEnum.MIR_ANALGESIA_DICT, true);
		Collection<DictionaryEntry> transferTypes = dictionaryService.fetch(DictionaryEnum.MIR_TRANSFER_TYPE_DICT, true);
		Collection<SampleListView> avaiableSamples = freezeDownSampleService.fetchByCryoRequestId(thawTestForm.getCryoRequestId());

		Map<String,Object> metaData = new HashMap<String,Object>();
		metaData.put("stufferStrains", stufferStrains);
		metaData.put("anaesthetics", anaesthetics);
		metaData.put("analgesics", analgesics);
		metaData.put("transferTypes", transferTypes);
		metaData.put("daysFromPlugChoices", new String[] {"2.5", "0.5"});
		metaData.put("embryoRange", new int[] {1,2,3,4,5,6,7,8,9,10,11,12,13,14,15});
		metaData.put("avaiableSamples",avaiableSamples);
		metaData.put("editThaw",thawTestForm.isEditThaw());
		metaData.put("cryoRequest", thawTestForm.getCryoRequest());
		metaData.put("retrievalRange", new int[] {1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30});
		return metaData;
	}

	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response,
			Object command, BindException errors) throws Exception {

		ThawTestForm form = (ThawTestForm) command;
		boolean storeThawTestOnly = ServletRequestUtils.getBooleanParameter(request, "saveThawTestOnly", false);
		boolean storeAll = ServletRequestUtils.getBooleanParameter(request, "saveAll", false);

		if(storeAll) {
			ThawTest thawTest = form.getThawTest();
			thawTest.setDateCompleted(form.getDateCompleted());
			Long thawTestId = thawTestService.storeThawTest(thawTest, form.getSamples(), form.getEmbryoTransfers(), RequestUtils.getUser(request));
			return new ModelAndView(getSuccessView()+"?cryoRequestId="+form.getCryoRequestId()+"&thawTestId="+thawTestId);
		}else if(storeThawTestOnly){
			ThawTest thawTest = form.getThawTest();
			thawTest.setDateCompleted(form.getDateCompleted());
			thawTestService.editThawTest(thawTest,RequestUtils.getUser(request));

			return new ModelAndView(getRequestView()+"?id="+form.getCryoRequest().getId()+"&showSampleList=true");
		}else {
			throw new RuntimeException("The success view is not specified!");
		}
	}

	@Override
	protected void onBind(HttpServletRequest request, Object command)
			throws Exception {

		//lookup and bind PIL Holder to an actual PIL if there is one
		ThawTestForm embryoTransferProcedureForm = (ThawTestForm)command;

		EmbryoTransferProcedure embryoTransferProcedure = embryoTransferProcedureForm.getEmbryoTransferProcedure();
		Long personId = embryoTransferProcedure.getMouseProcedure().getPersonalLicence().getPersonId();
		PersonalLicence pil = personalLicenceService.fetchByPersonId( personId,
				ComponentMap.of(PersonalLicence.Component.PERSON) );
		if( pil != null) {
			embryoTransferProcedure.getMouseProcedure().setPersonalLicenceId( pil.getId() );
			embryoTransferProcedure.getMouseProcedure().setPersonalLicence( pil );
		}
		super.onBind(request, command);
	}


	@Override
	protected boolean isFormChangeRequest(HttpServletRequest request) {

		boolean formChange = ServletRequestUtils.getBooleanParameter(request, "changeEarmarks", false);
		boolean addEmbryoTransfer = ServletRequestUtils.getBooleanParameter(request, "onFormChangeOnAdd", false);
		boolean editAddedEmbryoTransfer = ServletRequestUtils.getBooleanParameter(request, "editAddedEmbryoTransfer", false);
		boolean editExistEmbryoTransfer = ServletRequestUtils.getBooleanParameter(request, "editExistEmbryoTransfer", false);
		int deleteEmbryoTransferId = ServletRequestUtils.getIntParameter(request, "deleteAddedEmbryoTransferId", -1);
		int editEmbryoTransferId = ServletRequestUtils.getIntParameter(request, "editAddedEmbryoTransferId", -1);

		if( formChange || addEmbryoTransfer||editAddedEmbryoTransfer||editExistEmbryoTransfer||deleteEmbryoTransferId>-1||editEmbryoTransferId>-1)
				return true;
			else
				return super.isFormChangeRequest( request );
	}

	@Override
	protected void onFormChange(HttpServletRequest request, HttpServletResponse response,
			Object command, BindException bindEx) throws Exception {

		ThawTestForm thawTestForm = (ThawTestForm)	command;
		if(thawTestForm.isChangeEarmarks()){
			Collection<DictionaryEntry> existingEarmarks = new ArrayList<DictionaryEntry>();
			Collection<DictionaryEntry> avaiableEarmarks = dictionaryService.fetch(DictionaryEnum.MOUSE_EARMARK_DICT, true);

			if("cage".equalsIgnoreCase(thawTestForm.getEmbryoTransferBarcodeType())) {

				existingEarmarks = embryoTransferMouseTrackingBridgeService.getEarmarksByCageId(
						thawTestForm.getEmbryoTransferCageOrRackId());

				if(existingEarmarks != null) {
					avaiableEarmarks.removeAll( existingEarmarks );
				}
			}
			for(EmbryoTransferProcedure embryoTransferProcedure: thawTestForm.getEmbryoTransfers()){
				if(embryoTransferProcedure.getMouse().getLocation().getCageBarcode().equalsIgnoreCase(thawTestForm.getEmbryoTransferBarcode())){
					avaiableEarmarks.remove(embryoTransferProcedure.getMouse().getEarmark());
				}
			}
			thawTestForm.setEarmarks( avaiableEarmarks );
		}else if(thawTestForm.isOnFormChangeOnAdd()){

			dePopulateForm(thawTestForm, RequestUtils.getUser(request));
			if("rack".equalsIgnoreCase(thawTestForm.getEmbryoTransferBarcodeType())) {
				Long cageId = embryoTransferMouseTrackingBridgeService.creatNewCageInRack(
						thawTestForm.getEmbryoTransferCageOrRackId(), RequestUtils.getUser(request));

				thawTestForm.setEmbryoTransferCageOrRackId(cageId);

				Cage cage = embryoTransferMouseTrackingBridgeService.fetchCage(cageId);
				thawTestForm.setCageBarcode(cage.getBarcode());
			}else{
				thawTestForm.setCageBarcode(thawTestForm.getEmbryoTransferBarcode());
			}

			EmbryoTransferProcedure embryoTransfer = embryoTransferProcedureService.createThawTestEmbryoTransfer(
					thawTestForm.getEmbryoTransferProcedure(),
					thawTestForm);

			//edit the added embryo transfer or add new embryo transfer
			if(thawTestForm.getEditAddedEmbryoTransferId()>-1){
				thawTestForm.getEmbryoTransfers().remove(thawTestForm.getEditAddedEmbryoTransferId());
				thawTestForm.setEditAddedEmbryoTransferId(-1);
			}
			thawTestForm.getEmbryoTransfers().add(embryoTransfer);
			EmbryoTransferProcedure embryoTransferTemp = embryoTransferProcedureService.buildDefaultThawTestEmbryoTransfer(RequestUtils.getUser(request) );
			populateForm(thawTestForm, thawTestForm.getDateCompleted(), embryoTransferTemp);
			thawTestForm.setEmbryoTransferBarcode(null);
			thawTestForm.setEmbryoTransferBarcodeDescription(null);
			thawTestForm.setEmbryoTransferBarcodeType(null);

		}else if(thawTestForm.isEditExistEmbryoTransfer()){
			dePopulateForm(thawTestForm, RequestUtils.getUser(request));
			if("rack".equalsIgnoreCase(thawTestForm.getEmbryoTransferBarcodeType())) {
				Long cageId =  embryoTransferMouseTrackingBridgeService.creatNewCageInRack(
						thawTestForm.getEmbryoTransferCageOrRackId(),
						RequestUtils.getUser(request));
				thawTestForm.setEmbryoTransferCageOrRackId( cageId );
			}
			thawTestForm.getEmbryoTransferProcedure().getMouse().setCageId(thawTestForm.getEmbryoTransferCageOrRackId());
			embryoTransferProcedureService.storeThawTestEmbryoTransfer(thawTestForm.getEmbryoTransferProcedure(), RequestUtils.getUser(request));
			EmbryoTransferProcedure embryoTransferTemp = embryoTransferProcedureService.buildDefaultThawTestEmbryoTransfer(RequestUtils.getUser(request) );
			populateForm(thawTestForm, thawTestForm.getDateCompleted(), embryoTransferTemp);
			thawTestForm.setEmbryoTransferBarcode(null);
			thawTestForm.setEmbryoTransferBarcodeDescription(null);
			thawTestForm.setEmbryoTransferBarcodeType(null);
			thawTestForm.getThawTest().setEmbryoTransfers(
					embryoTransferProcedureService.fetchWithAllComponentsByThawTestId(thawTestForm.getThawTest().getId()));
		}else if(thawTestForm.getDeleteAddedEmbryoTransferId()>-1){
			thawTestForm.getEmbryoTransfers().remove(thawTestForm.getDeleteAddedEmbryoTransferId());

			EmbryoTransferProcedure embryoTransferTemp = embryoTransferProcedureService.buildDefaultThawTestEmbryoTransfer(RequestUtils.getUser(request) );
			populateForm(thawTestForm, thawTestForm.getDateCompleted(), embryoTransferTemp);
			thawTestForm.setEmbryoTransferBarcode(null);
			thawTestForm.setEmbryoTransferBarcodeDescription(null);
			thawTestForm.setEmbryoTransferBarcodeType(null);

		}else if(thawTestForm.getEditAddedEmbryoTransferId()>-1){
			EmbryoTransferProcedure editEmbryoTransfer =
				thawTestForm.getEmbryoTransfers().get(thawTestForm.getEditAddedEmbryoTransferId());
			thawTestForm.setEmbryoTransferProcedure(editEmbryoTransfer);
			thawTestForm.setEmbryoTransferBarcode(editEmbryoTransfer.getMouse().getLocation().getCageBarcode());

			Cage cage = cageService.fetchByBarcode(
					thawTestForm.getEmbryoTransferBarcode(), ComponentMap.of(Cage.Component.RACK));
			thawTestForm.setEmbryoTransferBarcodeDescription(cage.getBarcodeDescription());
		}
		thawTestForm.setChangeEarmarks(false);
		thawTestForm.setOnFormChangeOnAdd(false);
		thawTestForm.setEditExistEmbryoTransfer(false);
		thawTestForm.setDeleteAddedEmbryoTransferId(-1);
	}

	@Override
	protected boolean suppressValidation(HttpServletRequest request,Object object) {
		boolean add = ServletRequestUtils.getBooleanParameter(request, "onFormChangeOnAdd", false);
		boolean saveEditExisting = ServletRequestUtils.getBooleanParameter(request,"editExistEmbryoTransfer", false);
		boolean saveAll = ServletRequestUtils.getBooleanParameter(request, "saveAll", false);
		boolean saveThawTestOnly = ServletRequestUtils.getBooleanParameter(request, "saveThawTestOnly", false);

		if(add || saveAll || saveThawTestOnly || saveEditExisting )
			return false;
		return super.suppressValidation(request, object);
	}


	/////////////////////////////////////////////////////////////////////////////////////////////
	////////////////////////////////// dependencies /////////////////////////////////////////////
	/////////////////////////////////////////////////////////////////////////////////////////////



	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}
	public void setThawTestService(ThawTestService thawTestService) {
		this.thawTestService = thawTestService;
	}

	/////////////////////////////////////////////////////////////////////////////////////////////
	//////////////////////////////////  privates ////////////////////////////////////////////////
	/////////////////////////////////////////////////////////////////////////////////////////////


	private void dePopulateForm(ThawTestForm form, Person person) {

		EmbryoTransferProcedure embryoTransferProcedure = form.getEmbryoTransferProcedure();
		embryoTransferProcedure.getMouseProcedure().setStartDate( form.getDateCompleted() );
		embryoTransferProcedure.getMouseProcedure().setEndDate( form.getDateCompleted() );
		embryoTransferProcedure.getMouseProcedure().setMouseId( embryoTransferProcedure.getMouseId() );
		embryoTransferProcedure.getMouseProcedure().setForeignTableName(TableMetadataEnum.MIR_EMBRYO_TRANSFER_PROCEDURE);
		embryoTransferProcedure.setThawTestId(form.getThawTestId());
		embryoTransferProcedure.setCreator(person);
		embryoTransferProcedure.setCreatorId(person.getId());
	}

	private void populateForm(ThawTestForm form, Date defaultDate,
			EmbryoTransferProcedure embryoTransferProcedure) {


		form.setEmbryoTransferProcedure(embryoTransferProcedure);

		Collection<DictionaryEntry> avaiableEarmarks = dictionaryService.fetch(DictionaryEnum.MOUSE_EARMARK_DICT, true);


		//prepopulate PPL info, derived from MiRequest requester's PPL for the new Thaw Test
		if(form.getThawTestId()== null && embryoTransferProcedure.getId() == null) {
			form.setDateCompleted( defaultDate );
		} else {
			form.setDateCompleted(
					form.getThawTest().getDateCompleted());
			//edit existing ET
			if(embryoTransferProcedure.getId()!=null){

				form.setEarmarkId(embryoTransferProcedure.getMouse().getEarmarkDictId());
				form.setEmbryoTransferBarcode(embryoTransferProcedure.getMouse().getCage().getBarcode());
				form.setEmbryoTransferBarcodeDescription(embryoTransferProcedure.getMouse().getCage().getBarcodeDescription());
				form.setEmbryoTransferCageOrRackId(embryoTransferProcedure.getMouse().getCage().getId());
				form.setEmbryoTransferProcedure(embryoTransferProcedure);

				Collection<DictionaryEntry> existingEarmarks
				= embryoTransferMouseTrackingBridgeService.getEarmarksByCageId(embryoTransferProcedure.getMouse().getCageId());
				existingEarmarks.remove(embryoTransferProcedure.getMouse().getEarmark());
				avaiableEarmarks.removeAll( existingEarmarks );
			}
		}
		form.setEarmarks(avaiableEarmarks);
	}

	public void setFreezeDownSampleService(
			FreezeDownSampleService freezeDownSampleService) {
		this.freezeDownSampleService = freezeDownSampleService;
	}
	public void setEmbryoTransferMouseTrackingBridgeService(
			MirMouseTrackingBridgeService embryoTransferMouseTrackingBridgeService) {
		this.embryoTransferMouseTrackingBridgeService = embryoTransferMouseTrackingBridgeService;
	}
	public void setEmbryoTransferProcedureService(
			EmbryoTransferProcedureService embryoTransferProcedureService) {
		this.embryoTransferProcedureService = embryoTransferProcedureService;
	}
	public void setCryoRequestService(CryoRequestService cryoRequestService) {
		this.cryoRequestService = cryoRequestService;
	}
	public void setPersonalLicenceService(
			PersonalLicenceService personalLicenceService) {
		this.personalLicenceService = personalLicenceService;
	}

	public void setCageService(CageService cageService) {
		this.cageService = cageService;
	}

	public String getRequestView() {
		return requestView;
	}
	public void setRequestView(String requestView) {
		this.requestView = requestView;
	}
}