/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.cryoprocessing.dao;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.cryoprocessing.Canister;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;

public class CanisterDaoSpringImpl extends AbstractDaoSpringImpl<Canister> implements CanisterDao {


	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, Canister canister) {
		sql.addStringParam(canister.getComments(), "COMMENTS");
		sql.addLongParam(canister.getFreezerId(), "FREEZER_ID");
		sql.addStringParam(canister.getName(), "NAME");
		sql.addLongParam(canister.getId(), "ID");
	}
	
	public Collection<Canister> fetchByFreezerId(Long freezerId) {
		String sql = " select * from " + getTableName() + " where freezer_id = ? order by cast(name as Integer)";
		Collection<Canister> canisters = getSimpleJdbcTemplate().query(sql, getRowMapper(), freezerId);
		
		return (canisters == null) ? new ArrayList<Canister>() : canisters;
	}
}