/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.cryoprocessing.dao;

import java.util.Collection;

import org.springframework.dao.IncorrectResultSizeDataAccessException;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.cryoprocessing.EmbryoHarvest;
import uk.ac.sanger.mig.cryoprocessing.EmbryoHarvestSearchBean;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.personnel.Person;

public class EmbryoHarvestDaoSpringImpl extends AbstractDaoSpringImpl<EmbryoHarvest> implements EmbryoHarvestDao {


	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, EmbryoHarvest embryoHarvest) {
		sql.addLongParam(embryoHarvest.getScheduledJobId(), "SCHEDULED_JOB_ID");
		sql.addDateParam(embryoHarvest.getEditedDate(), "EDITED_DATE");
		sql.addStringParam(embryoHarvest.getEditedBy(), "EDITED_BY");
		sql.addDateParam(embryoHarvest.getCreatedDate(), "CREATED_DATE");
		sql.addLongParam(embryoHarvest.getCreatorId(), "CREATOR_ID");
		sql.addLongParam(embryoHarvest.getCheckNumber(), "CHECK_NUMBER");
		sql.addStringParam(embryoHarvest.getComments(), "COMMENTS");
		sql.addStringParam(embryoHarvest.getFemaleStrainComments(),"FEMALE_STRAIN_COMMENTS");
		sql.addIntParam(embryoHarvest.getCellCount16(), "CELL_COUNT_16");
		sql.addIntParam(embryoHarvest.getCellCount8(), "CELL_COUNT_8");
		sql.addIntParam(embryoHarvest.getCellCount4(), "CELL_COUNT_4");
		sql.addIntParam(embryoHarvest.getCellCount2(), "CELL_COUNT_2");
		sql.addIntParam(embryoHarvest.getCellCount1(), "CELL_COUNT_1");
		sql.addIntParam(embryoHarvest.getDeadCount(), "DEAD_COUNT");
		sql.addIntParam(embryoHarvest.getFragmentedCount(), "FRAGMENTED_COUNT");
		sql.addIntParam(embryoHarvest.getOtherEmbryoTypeCount(), "OTHER_EMBRYO_TYPE_COUNT");
		sql.addIntParam(embryoHarvest.getNumberSuperovulated(), "NUMBER_SUPEROVULATED");
		sql.addIntParam(embryoHarvest.getNumberPlugged(), "NUMBER_PLUGGED");
		sql.addDateParam(embryoHarvest.getFlushDate(), "FLUSH_DATE");
		sql.addLongParam(embryoHarvest.getTechnicianId(), "TECHNICIAN_ID");
		sql.addStringParam(embryoHarvest.getOtherDescription(), "OTHER_DESCRIPTION");
		sql.addBooleanParam(embryoHarvest.isUse16Cell(), "USE_16_CELL");
		sql.addBooleanParam(embryoHarvest.isUse8Cell(), "USE_8_CELL");
		sql.addBooleanParam(embryoHarvest.isUse4Cell(), "USE_4_CELL");
		sql.addBooleanParam(embryoHarvest.isUse2Cell(), "USE_2_CELL");
		sql.addLongParam(embryoHarvest.getFemaleStrainDictId(),"FEMALE_STRAIN_ID");

		sql.addLongParam(embryoHarvest.getCohortId(), "COHORT_ID");
		sql.addLongParam(embryoHarvest.getId(), "ID");
	}

	public Collection<EmbryoHarvest> search(EmbryoHarvestSearchBean embryoHarvestSearchBean) {
		// TODO Auto-generated method stub
		return null;
	}

	public EmbryoHarvest fetchByScheduledJobId(Long jobId) {
		String sql = "select * from crq_embryo_harvest where scheduled_job_id=?";
		EmbryoHarvest result = null;
		try{
			result = (EmbryoHarvest)getSimpleJdbcTemplate().queryForObject(sql, getRowMapper(),jobId);
		}catch(IncorrectResultSizeDataAccessException e){
			logger.warn(e);
		}

		return (result == null) ? null :  result;
	}

	/* method to store the cryo scheduled job and update the status of scheduled job and if required the status of
	 * cryo request
	 */

	public Long storeAndUpdateJob(EmbryoHarvest embryoHarvest, Person user) {
		store(embryoHarvest, user);
		return null;
	}


}