package uk.ac.sanger.mig.cryoprocessing.dao;

import java.util.ArrayList;
import java.util.Collection;

import org.springframework.dao.IncorrectResultSizeDataAccessException;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.common.PaginatedSearchUtils;
import uk.ac.sanger.mig.cryoprocessing.FreezeDownSample;
import uk.ac.sanger.mig.cryoprocessing.FreezeDownSampleSearchBean;
import uk.ac.sanger.mig.cryoprocessing.dao.rowmappers.SampleListViewRowMapper;
import uk.ac.sanger.mig.cryoprocessing.dao.rowmappers.StrawListViewRowMapper;
import uk.ac.sanger.mig.cryoprocessing.views.SampleListView;
import uk.ac.sanger.mig.cryoprocessing.views.StrawListView;
import uk.ac.sanger.mig.cryorequest.ManageCryoRequestSearchBean;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.database.StringRowMapper;


/**
 * @author wl1
 *
 */
public class FreezeDownSampleDaoSpringImpl extends AbstractDaoSpringImpl<FreezeDownSample> implements FreezeDownSampleDao {

	private  StrawListViewRowMapper strawListViewRowMapper;
	private SampleListViewRowMapper sampleListViewRowMapper;
	private PaginatedSearchUtils<StrawListView> strawListPaginator;
	private PaginatedSearchUtils<SampleListView> sampleListPaginator;
	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, FreezeDownSample freezeDownSample) {
		sql.addLongParam(freezeDownSample.getEmbryoHarvestId(), "EMBRYO_HARVEST_ID");
		sql.addDateParam(freezeDownSample.getEditDate(), "EDIT_DATE");
		sql.addStringParam(freezeDownSample.getEditedBy(), "EDITED_BY");
		sql.addDateParam(freezeDownSample.getCreatedDate(), "CREATED_DATE");
		sql.addLongParam(freezeDownSample.getCreatorId(), "CREATOR_ID");
		sql.addLongParam(freezeDownSample.getCheckNumber(), "CHECK_NUMBER");
		sql.addStringParam(freezeDownSample.getComments(), "COMMENTS");
		sql.addLongParam(freezeDownSample.getTechnicianId(), "TECHNICIAN_ID");
		sql.addLongParam(freezeDownSample.getLocationId(), "LOCATION_ID");
		sql.addLongParam(freezeDownSample.getEmbryoGradeDictId(), "EMBRYO_GRADE_DICT_ID");
		sql.addIntParam(freezeDownSample.getEmbryoCount(), "EMBRYO_COUNT");
		sql.addDateParam(freezeDownSample.getFreezeDownDate(), "FREEZE_DOWN_DATE");
		sql.addLongParam(freezeDownSample.getThawTestId(), "THAW_TEST_ID");
		sql.addLongParam(freezeDownSample.getShippingID(),"SHIPPING_ID");
		sql.addLongParam(freezeDownSample.getId(), "ID");
	}


	public Collection<FreezeDownSample> search(FreezeDownSampleSearchBean cryoFreezeDownSampleSearchBean) {
		// TODO Auto-generated method stub
		return null;
	}

	public Collection<StrawListView> searchStraws(FreezeDownSampleSearchBean freezeDownSampleSearchBean) {
		Collection<Object> bindVariables = new ArrayList<Object>();

		String sql = constructStrawSearchSql(freezeDownSampleSearchBean, bindVariables, "crq_straw_sample_list_vw");


		//Collection<StrawListView> straws = getSimpleJdbcTemplate().query(sql, strawListViewRowMapper, bindVariables.toArray());
		//return (straws == null) ? new ArrayList<StrawListView>() : straws;
		return strawListPaginator.fetchSearchResults(sql, bindVariables, freezeDownSampleSearchBean, strawListViewRowMapper);
	}

	public Collection<SampleListView> searchSamples(FreezeDownSampleSearchBean freezeDownSampleSearchBean) {
		Collection<Object> bindVariables = new ArrayList<Object>();

		String sql = constructSampleSearchSql(freezeDownSampleSearchBean, bindVariables, "crq_sample_list_vw");


		//Collection<StrawListView> straws = getSimpleJdbcTemplate().query(sql, strawListViewRowMapper, bindVariables.toArray());
		//return (straws == null) ? new ArrayList<StrawListView>() : straws;
		return sampleListPaginator.fetchSearchResults(sql, bindVariables, freezeDownSampleSearchBean, sampleListViewRowMapper);
	}

	public Collection<SampleListView> fetchSamplesByCryoRequestId(Long requestId, ManageCryoRequestSearchBean searchBean){
		String sql = "select v.* from crq_sample_list_vw v where v.request_id = ?";
		if(searchBean != null){
			Collection<Object> bindVariables = new ArrayList<Object>();

			bindVariables.add(requestId);
			if(searchBean.getOrderBy() != null && searchBean.getOrderBy().length() > 0) {
				sql += " order by " + searchBean.getOrderBy();
				if(searchBean.isOrderDesc()) {
					sql += " desc ";
				}
			} else {
				sql += " order by id desc";
			}
			return sampleListPaginator.fetchSearchResults(sql, bindVariables, searchBean, sampleListViewRowMapper);
		}else {
			Collection<SampleListView> results = new ArrayList<SampleListView>();

			if(requestId != null) {
				results = getSimpleJdbcTemplate().query(sql,sampleListViewRowMapper, requestId);
			}

			return results;
		}
	}

private String constructStrawSearchSql(FreezeDownSampleSearchBean bean, Collection<Object> bindVariables, String tableName) {

		String selectSql  = " select s.* ";
		String fromSql = " from " + tableName + " s ";
		String whereSql = " where 1=1 ";

		// Straw ID
		if(bean.getId() != null) {
			whereSql += " and s.id = ? ";
			bindVariables.add(bean.getId());
		}

		// Colony Name
		if(bean.getColonyId() != null) {
			whereSql += " and s.colony_id = ? ";
			bindVariables.add(bean.getColonyId());
		}
			//female strain name
		if(bean.getFemaleStrainName() != null) {
			whereSql += " and s.female_strain_name = ? ";
			bindVariables.add(bean.getFemaleStrainName());
		}

		if(bean.getColonyName() != null) {
			whereSql += " and s.colony_name = ? ";
			bindVariables.add(bean.getColonyName());
		}

		//request
		if(bean.getRequestId() != null) {
			whereSql +=" and s.request_id = ? ";
			bindVariables.add(bean.getRequestId());
		}

		// embryo grade Dict ID
		if(bean.getEmbryoGradeDictId() != null) {
			whereSql += " and s.embryo_grade_id = ? ";
			bindVariables.add(bean.getEmbryoGradeDictId());
		}

		// freeze down Date
		if(bean.getFreezeDownDate() != null) {
			whereSql += " and s.freeze_down_date = ? ";
			bindVariables.add(defaultDateFormat.format(bean.getFreezeDownDate()));
		}

		// freezer_id
		if(bean.getFreezerId() != null) {
			whereSql += " and s.freezer_id = ? ";
			bindVariables.add(bean.getFreezerId());
		}

		// canister_id
		if(bean.getCanisterId() != null) {
			whereSql += " and s.canister_id = ? ";
			bindVariables.add(bean.getCanisterId());
		}

		// goblet_id
		if(bean.getGobletId() != null) {
			whereSql += " and s.goblet_id = ? ";
			bindVariables.add(bean.getGobletId());
		}

		//wedge_id
		if(bean.getWedgeId() != null) {
			whereSql += " and s.wedge_id = ? ";
			bindVariables.add(bean.getWedgeId());
		}

		//technician_id
		if(bean.getTechnicianId() != null) {
			whereSql += " and s.technician_id = ? ";
			bindVariables.add(bean.getTechnicianId());
		}
		String orderBySql = "";

		if(bean.getOrderBy() != null && bean.getOrderBy().length() > 0) {
			orderBySql += " order by " + bean.getOrderBy();
			if(bean.isOrderDesc()) {
				orderBySql += " desc ";
			}
		} else {
			orderBySql += " order by id desc";
			bean.setOrderBy("id");
			bean.setOrderDesc(true);
		}

		String sql = selectSql + fromSql + whereSql + orderBySql;

		logger.debug(sql);

		return sql;
	}

private String constructSampleSearchSql(FreezeDownSampleSearchBean bean, Collection<Object> bindVariables, String tableName) {

	String selectSql  = " select s.* ";
	String fromSql = " from " + tableName + " s ";
	String whereSql = " where 1=1 ";


	// Straw ID
	if(bean.getId() != null) {
		whereSql += " and s.id = ?";
		bindVariables.add(bean.getId());
	}

	// Colony Id
	if(bean.getColonyId() != null) {
		whereSql += " and s.colony_id = ? ";
		bindVariables.add(bean.getColonyId());
	}


	//request
	if(bean.getRequestId() != null) {
		whereSql +=" and s.request_id = ? ";
		bindVariables.add(bean.getRequestId());
	}

	// embryo grade Dict ID
	if(bean.getEmbryoGradeDictId() != null) {
		whereSql += " and s.embryo_grade_id = ? ";
		bindVariables.add(bean.getEmbryoGradeDictId());
	}

	// freeze down Date
	if(bean.getFreezeDownDate() != null) {
		whereSql += " and s.freeze_down_date = ? ";
		bindVariables.add(defaultDateFormat.format(bean.getFreezeDownDate()));
	}

	if(bean.getFemaleStrainName() != null) {
		whereSql += " and s.female_strain_name = ? ";
		bindVariables.add(bean.getFemaleStrainName());
	}

	//technician_id
	if(bean.getTechnicianId() != null) {
		whereSql += " and s.technician_id = ? ";
		bindVariables.add(bean.getTechnicianId());
	}
	String orderBySql = "";

	if(bean.getOrderBy() != null && bean.getOrderBy().length() > 0) {
		orderBySql += " order by " + bean.getOrderBy();
		if(bean.isOrderDesc()) {
			orderBySql += " desc ";
		}
	} else {
		orderBySql += " order by id desc";
		bean.setOrderBy("id");
		bean.setOrderDesc(true);
	}

	String sql = selectSql + fromSql + whereSql + orderBySql;

	logger.debug(sql);

	return sql;
}

	public FreezeDownSample fetchByLocationId(Long locationId) {
		String sql = "select * from "+getTableName() + " where location_id = ? ";
		FreezeDownSample freezeDownSample = null;
		try {
			freezeDownSample = getSimpleJdbcTemplate().queryForObject(sql, getRowMapper(), locationId);
		}
		catch(IncorrectResultSizeDataAccessException e) {
		}

		return freezeDownSample;
	}


	public Long getVialIdById(Long freezeDownSampleId) {
		Long vialId = null;

		String sql = "select v. id from crq_freeze_down_sample s, crq_location l, crq_vial v where "
			+ "s.location_id = l.id and l.vial_id = v.id and s.id = ?";

		if(freezeDownSampleId != null) {

			try{
				vialId = getSimpleJdbcTemplate().queryForLong(sql, freezeDownSampleId);
			}catch(IncorrectResultSizeDataAccessException e) {
			}
		}else {
			throw new IllegalArgumentException("FreezeDownSampleId is null!");
		}

		return vialId;
	}


	public Long getStrawIdById(Long freezeDownSampleId) {
		Long strawId = null;

		String sql = "select st.id from crq_freeze_down_sample s, crq_location l, crq_straw st where " +
		"s.location_id = l.id and l.straw_id = st.id and s.id = ?";

		if(freezeDownSampleId != null) {

			try {
				strawId = getSimpleJdbcTemplate().queryForLong(sql, freezeDownSampleId);
			}
			catch(IncorrectResultSizeDataAccessException e) {

			}
		}else {
			throw new IllegalArgumentException("FreezeDownSampleId is null!");
		}

		return strawId;
	}


	/****************************
	 * fetchActiveByEmbryoHarvestId(java.lang.Long)
	 * return the list of active samples associated with the given EH
	 * they are either all straws or all vials, coz for one flush, no different systems are allowed.
	 ******************************/
	public Collection<FreezeDownSample> fetchActiveByEmbryoHarvestId(Long embryoHarvestId) {
	    String strawSql = "select s.* from crq_freeze_down_sample s, crq_embryo_harvest h , crq_straw_sample_list_vw svw " +
	    		"where s.id = svw.sample_id and s.embryo_harvest_id = h.id and h.id = ?";
	    String vialSql = "select s.* from crq_freeze_down_sample s, crq_embryo_harvest h , crq_vial_sample_list_vw vvw " +
	    		"where s.id = vvw.sample_id and s.embryo_harvest_id = h.id and h.id = ?";

	    Collection<FreezeDownSample> results = new ArrayList<FreezeDownSample>();

	    if(embryoHarvestId != null) {
	    	results = getSimpleJdbcTemplate().query(strawSql,getRowMapper(), embryoHarvestId);
	    }

	    if(results == null || results.size() == 0) {
	    		results = getSimpleJdbcTemplate().query(vialSql,getRowMapper(), embryoHarvestId);
	    }
		return results ;
	}

	public String fetchSampleColonyNameById(Long id) {


		String sql = "select ci.colony_name return_string from crq_freeze_down_sample fds, crq_embryo_harvest eh, " +
				"crq_scheduled_cryo_prv cr, crq_cryo_request re, mts_colony_info ci where re.colony_id = ci.id and fds.embryo_harvest_id = eh.id " +
				"and eh.scheduled_job_id=cr.id and cr.cryo_request_id=re.id and fds.id = ?";

		String colonyName = null;
		if(id != null) {
			try{
				colonyName = getSimpleJdbcTemplate().queryForObject(sql,new StringRowMapper(), id);
			}catch(IncorrectResultSizeDataAccessException e)
			{

			}
		}
		return colonyName;
	}

	public String fetchWildTypeNameById(Long id) {
		String wildTypeSql = "select wd.name return_string from crq_freeze_down_sample fds, " +
		"crq_embryo_harvest eh, crq_scheduled_cryo_prv sj, crq_wildtype_strain_dict_vw wd " +
		"where fds.embryo_harvest_id =  eh.id and sj.id=eh.scheduled_job_id and " +
		"eh.female_strain_id = wd.id and sj.cryo_request_id is null and fds.id = ?";

		String wildTypeName = null;
		if(id != null) {
			try{
				wildTypeName = getSimpleJdbcTemplate().queryForObject(wildTypeSql,new StringRowMapper(), id);
			}catch(IncorrectResultSizeDataAccessException e)
			{

			}
		}
		return wildTypeName;
	}
public Collection<FreezeDownSample> fetchByThawTestId(Long thawTestId) {
		String sql = "select * from "+getTableName()+" where thaw_test_id = ?";
		Collection<FreezeDownSample> freezeDownSamples =  getSimpleJdbcTemplate().query(sql, getRowMapper(), thawTestId);
		return (freezeDownSamples == null)? new ArrayList<FreezeDownSample>() : freezeDownSamples;
	}

	public Long storeSampleToTransfer(Long sampleId, Long embryoTransferProcedureId) {
		String sql = "insert into crq_sample_2_transfer (sample_id, embryo_transfer_procedure_id) values(?,?)";
		getSimpleJdbcTemplate().update(sql, sampleId, embryoTransferProcedureId);
		return sampleId;
	}

	public Collection<SampleListView> fetchByCryoRequestId(Long cryoRequestId) {
		String sql = "select v.* from crq_sample_list_vw v where v.request_id = ? order by v.id";
		Collection<SampleListView> freezeDownSamples =  getSimpleJdbcTemplate().query(sql, sampleListViewRowMapper, cryoRequestId);
		return (freezeDownSamples == null)? new ArrayList<SampleListView>() : freezeDownSamples;
	}

	public SampleListView fetchSampleById(Long sampleId) {
		SampleListView sampleListView = null;
		String sql = "select * from crq_sample_list_vw where sample_id = ?";

		try{
			sampleListView = getSimpleJdbcTemplate().queryForObject(sql, sampleListViewRowMapper, sampleId);
		}catch(IncorrectResultSizeDataAccessException e){
		}

		return sampleListView;
	}

	public void setStrawListViewRowMapper(
			StrawListViewRowMapper strawListViewRowMapper) {
		this.strawListViewRowMapper = strawListViewRowMapper;
	}


	public void setSampleListPaginator(
			PaginatedSearchUtils<SampleListView> sampleListPaginator) {
		this.sampleListPaginator = sampleListPaginator;
	}


	public void setStrawListPaginator(
			PaginatedSearchUtils<StrawListView> strawListPaginator) {
		this.strawListPaginator = strawListPaginator;
	}


	public void setSampleListViewRowMapper(
			SampleListViewRowMapper sampleListViewRowMapper) {
		this.sampleListViewRowMapper = sampleListViewRowMapper;
	}









}