/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.cryoprocessing.dao;

import java.util.ArrayList;
import java.util.Collection;

import org.springframework.dao.IncorrectResultSizeDataAccessException;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.cryoprocessing.Straw;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;

public class StrawDaoSpringImpl extends AbstractDaoSpringImpl<Straw> implements StrawDao {


	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, Straw straw) {
		sql.addDateParam(straw.getEditDate(), "EDIT_DATE");
		sql.addStringParam(straw.getEditedBy(), "EDITED_BY");
		sql.addDateParam(straw.getCreatedDate(), "CREATED_DATE");
		sql.addLongParam(straw.getCreatorId(), "CREATOR_ID");
		sql.addLongParam(straw.getCheckNumber(), "CHECK_NUMBER");
		sql.addStringParam(straw.getComments(), "COMMENTS");
		sql.addLongParam(straw.getWedgeId(), "WEDGE_ID");
		sql.addBooleanParam(straw.getInUse(), "IN_USE");
		sql.addLongParam(straw.getId(), "ID");
	}
	
public Collection<Straw> fetchActiveByWedgeId(Long wedgeId) {
		
		String sql = "select * from " + getTableName() + " where wedge_id = ? and in_use = 1";
		Collection<Straw> straws = getSimpleJdbcTemplate().query(sql, getRowMapper(), wedgeId);
		
		return (straws == null) ? new ArrayList<Straw>() : straws;
	}
	
	public Long fetchLocationIdByStrawId(Long strawId) {
		
		String sql = "select l.id from crq_location l, crq_straw s where l.straw_id = s.id and s.id = ? ";
		Long locationId = null;
		
		try {
			locationId = getSimpleJdbcTemplate().queryForLong(sql, strawId);
		}
		catch(IncorrectResultSizeDataAccessException e) {
			
		}
		
		return locationId;
	}
	
	public Long fetchIdBySampleId(Long sampleId) {
		String sql = "select id from crq_straw_sample_list_vw where sample_id = ?";
		Long strawId = null;
		
		try{
			strawId = getSimpleJdbcTemplate().queryForLong(sql, sampleId);
		}
		catch(IncorrectResultSizeDataAccessException e){
			
		}
		return strawId;
	}

	public Long storeLocation(Long strawId) {
		
		Long id = getLocationPk();
		String sql = "insert into crq_location (ID, STRAW_ID) values(?,?)";
		getSimpleJdbcTemplate().update(sql, id,strawId);
		return id;
		
	}
	
	protected Long getLocationPk() {
		return getSimpleJdbcTemplate().queryForLong("select crq_cryo_location_seq.nextval from dual");	
	}
}