/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.cryoprocessing.dao;

import java.util.ArrayList;
import java.util.Collection;

import org.springframework.dao.IncorrectResultSizeDataAccessException;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.cryoprocessing.Vial;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;

public class VialDaoSpringImpl extends AbstractDaoSpringImpl<Vial> implements VialDao {


	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, Vial vial) {
		sql.addDateParam(vial.getEditDate(), "EDIT_DATE");
		sql.addStringParam(vial.getEditedBy(), "EDITED_BY");
		sql.addDateParam(vial.getCreatedDate(), "CREATED_DATE");
		sql.addLongParam(vial.getCreatorId(), "CREATOR_ID");
		sql.addLongParam(vial.getCheckNumber(), "CHECK_NUMBER");
		sql.addStringParam(vial.getComments(), "COMMENTS");
		sql.addLongParam(vial.getBoxId(), "BOX_ID");
		sql.addIntParam(vial.getPosition(), "POSITION");
		sql.addStringParam(vial.getName(), "NAME");
		sql.addBooleanParam(vial.isInUse(), "IN_USE");
		sql.addStringParam(vial.getLabel(), "LABEL");
		sql.addLongParam(vial.getId(), "ID");
	}



	public Collection<Vial> fetchActiveByBoxId(Long boxId) {
		
		String sql = "select * from " + getTableName() + " where box_id = ? and in_use = 1";
		Collection<Vial> vials = getSimpleJdbcTemplate().query(sql, getRowMapper(), boxId);
		
		return (vials == null) ? new ArrayList<Vial>() : vials;
	}
	
	public Long fetchLocationIdByVialId(Long vialId) {
		
		String sql = "select l.id from crq_location l, crq_vial v where l.vial_id = v.id and v.id = ? ";
		Long locationId = null;
		
		try {
			locationId = getSimpleJdbcTemplate().queryForLong(sql, vialId);
		}
		catch(IncorrectResultSizeDataAccessException e) {
			
		}
		
		return locationId;
	}
	

	public Long storeLocation(Long vialId) {
		
		Long id = getLocationPk();
		String sql = "insert into crq_location (ID, VIAL_ID) values(?,?)";
		getSimpleJdbcTemplate().update(sql, id,vialId);
		return id;
		
	}
	
	protected Long getLocationPk() {
		return getSimpleJdbcTemplate().queryForLong("select crq_cryo_location_seq.nextval from dual");	
	}
}