/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.cryoprocessing.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.cryoprocessing.EmbryoHarvest;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;

public class EmbryoHarvestRowMapper implements ParameterizedRowMapper<EmbryoHarvest> {

	DictionaryService dictionaryService;

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	public EmbryoHarvest mapRow(ResultSet rs, int rowNum) throws SQLException {

		EmbryoHarvest embryoHarvest = new EmbryoHarvest();


		embryoHarvest.setId(rs.getLong("ID"));

		embryoHarvest.setScheduledJobId(rs.getLong("SCHEDULED_JOB_ID"));
		if(rs.wasNull()) embryoHarvest.setScheduledJobId(null);

		embryoHarvest.setEditedDate(rs.getTimestamp("EDITED_DATE"));

		embryoHarvest.setEditedBy(rs.getString("EDITED_BY"));

		embryoHarvest.setCreatedDate(rs.getTimestamp("CREATED_DATE"));

		embryoHarvest.setCreatorId(rs.getLong("CREATOR_ID"));

		embryoHarvest.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) embryoHarvest.setCheckNumber(null);

		embryoHarvest.setComments(rs.getString("COMMENTS"));
		embryoHarvest.setFemaleStrainComments(rs.getString("FEMALE_STRAIN_COMMENTS"));

		embryoHarvest.setCellCount16(rs.getInt("CELL_COUNT_16"));

		embryoHarvest.setCellCount8(rs.getInt("CELL_COUNT_8"));

		embryoHarvest.setCellCount4(rs.getInt("CELL_COUNT_4"));

		embryoHarvest.setCellCount2(rs.getInt("CELL_COUNT_2"));

		embryoHarvest.setCellCount1(rs.getInt("CELL_COUNT_1"));

		embryoHarvest.setDeadCount(rs.getInt("DEAD_COUNT"));

		embryoHarvest.setFragmentedCount(rs.getInt("FRAGMENTED_COUNT"));

		embryoHarvest.setOtherEmbryoTypeCount(rs.getInt("OTHER_EMBRYO_TYPE_COUNT"));

		embryoHarvest.setNumberSuperovulated(rs.getInt("NUMBER_SUPEROVULATED"));

		embryoHarvest.setNumberPlugged(rs.getInt("NUMBER_PLUGGED"));

		embryoHarvest.setFlushDate(rs.getTimestamp("FLUSH_DATE"));

		embryoHarvest.setTechnicianId(rs.getLong("TECHNICIAN_ID"));

		embryoHarvest.setOtherDescription(rs.getString("OTHER_DESCRIPTION"));

		embryoHarvest.setUse16Cell(rs.getBoolean("USE_16_CELL"));

		embryoHarvest.setUse8Cell(rs.getBoolean("USE_8_CELL"));

		embryoHarvest.setUse4Cell(rs.getBoolean("USE_4_CELL"));

		embryoHarvest.setUse2Cell(rs.getBoolean("USE_2_CELL"));



		embryoHarvest.setFemaleStrainDictId(rs.getLong("FEMALE_STRAIN_ID"));
		if(rs.wasNull()) embryoHarvest.setFemaleStrainDictId(null);

		embryoHarvest.setCohortId(rs.getLong("COHORT_ID"));
		if(rs.wasNull()) embryoHarvest.setCohortId(null);

		embryoHarvest.setFemaleStrain(dictionaryService.fetchEntry(DictionaryEnum.MOUSE_STRAIN, embryoHarvest.getFemaleStrainDictId()));

		return embryoHarvest;

	}
}