/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.cryoprocessing.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.cryoprocessing.ScheduledCryoPreservationJob;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;

public class ScheduleCryoPreservationJobRowMapper implements ParameterizedRowMapper<ScheduledCryoPreservationJob> {

	private DictionaryService dictionaryService;
	
	
	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	public ScheduledCryoPreservationJob mapRow(ResultSet rs, int rowNum) throws SQLException {
		
		ScheduledCryoPreservationJob schedulePreservationJob = new ScheduledCryoPreservationJob();
		schedulePreservationJob.setId(rs.getLong("ID"));
		if(rs.wasNull()) schedulePreservationJob.setId(null);	
		schedulePreservationJob.setCryoRequestId(rs.getLong("CRYO_REQUEST_ID"));
		if(rs.wasNull()) schedulePreservationJob.setCryoRequestId(null);		

		schedulePreservationJob.setNextScheduledDate(rs.getDate("TARGET_SCHEDULED_DATE"));
		schedulePreservationJob.setCancelComments(rs.getString("CANCEL_COMMENTS"));
		schedulePreservationJob.setEditDate(rs.getTimestamp("EDIT_DATE"));
		schedulePreservationJob.setEditedBy(rs.getString("EDITED_BY"));
		schedulePreservationJob.setCreatedDate(rs.getTimestamp("CREATED_DATE"));
		schedulePreservationJob.setCreatorId(rs.getLong("CREATOR_ID"));
		schedulePreservationJob.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) schedulePreservationJob.setCheckNumber(null);	
		
		schedulePreservationJob.setJobName(rs.getString("JOB_NAME"));
		schedulePreservationJob.setCancelReasonDictId(rs.getLong("CANCEL_REASON_DICT_ID"));
		if(rs.wasNull()) schedulePreservationJob.setCancelReasonDictId(null);	
		schedulePreservationJob.setComments(rs.getString("COMMENTS"));
		schedulePreservationJob.setStatusDictId(rs.getLong("CRYO_JOB_STATUS_DICT_ID"));
		if(rs.wasNull()) schedulePreservationJob.setStatusDictId(null);
		
		if(schedulePreservationJob.getStatusDictId() != null)
		schedulePreservationJob.setJobStatusDict(
				dictionaryService.fetchEntry(DictionaryEnum.CRQ_CRYO_SCHEDULED_JOB_STATUS_DICT,schedulePreservationJob.getStatusDictId()));
		
		if(schedulePreservationJob.getCancelReasonDictId() != null){
			schedulePreservationJob.setCancelReasonDict(
				dictionaryService.fetchEntry(DictionaryEnum.CRQ_CANCEL_JOB_REASON_DICT, schedulePreservationJob.getCancelReasonDictId()));
			
		}
		return schedulePreservationJob;
	}
}