/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.cryoprocessing.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.text.NumberFormat;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.cryoprocessing.views.ScheduledCryoPreservationJobListView;

public class ScheduledCryoPreservationListViewRowMapper implements ParameterizedRowMapper<ScheduledCryoPreservationJobListView> {

	public static NumberFormat average_yield_number_format = NumberFormat.getInstance();
	
	
	public ScheduledCryoPreservationJobListView mapRow(ResultSet rs, int rowNum) throws SQLException {
		
		ScheduledCryoPreservationJobListView scheduledCryoPreservationJobListView
		= new ScheduledCryoPreservationJobListView();
		// TODO Auto-generated method stub
		
		scheduledCryoPreservationJobListView.setId(rs.getLong("ID"));
		scheduledCryoPreservationJobListView.setCryoRequestId(rs.getLong("CRYO_REQUEST_ID"));
		if(rs.wasNull()) scheduledCryoPreservationJobListView.setCryoRequestId(null);
		scheduledCryoPreservationJobListView.setTargetDate(rs.getDate("TARGET_SCHEDULED_DATE"));
		scheduledCryoPreservationJobListView.setTotalFrozenCount(rs.getInt("TOTAL_FROZEN_COUNT"));
		if(rs.wasNull())
			scheduledCryoPreservationJobListView.setTotalFrozenCount(0);
		
		scheduledCryoPreservationJobListView.setStatus(rs.getString("JOB_STATUS"));
		scheduledCryoPreservationJobListView.setStatusId(rs.getLong("STATUS_ID"));
		scheduledCryoPreservationJobListView.setCancelReason(rs.getString("CANCEL_COMMENTS"));
		scheduledCryoPreservationJobListView.setEmbryoHarvestId(rs.getLong("EMBRYO_HARVEST_ID"));
		scheduledCryoPreservationJobListView.setColonyName(rs.getString("COLONY_NAME"));
		scheduledCryoPreservationJobListView.setComments(rs.getString("COMMENTS"));
		scheduledCryoPreservationJobListView.setFemaleStrain(rs.getString("female_strain_name"));
		scheduledCryoPreservationJobListView.setWhetherFlushComplete(rs.getLong("STATUS_ID"));
		scheduledCryoPreservationJobListView.setWhetherAttemptComplete(rs.getLong("STATUS_ID"));
		scheduledCryoPreservationJobListView.setWhetherCancelled(rs.getLong("STATUS_ID"));
		scheduledCryoPreservationJobListView.setWhetherScheduled(rs.getLong("STATUS_ID"));
		average_yield_number_format.setMaximumFractionDigits(2);
		average_yield_number_format.setMinimumFractionDigits(2);
		scheduledCryoPreservationJobListView.setAverageFrozenCount(average_yield_number_format.format(rs.getDouble("AVERAGE_FROZEN_COUNT")));
		if(rs.wasNull())
			scheduledCryoPreservationJobListView.setAverageFrozenCount("0");
		scheduledCryoPreservationJobListView.setWhetherWildType(rs.getLong("CRYO_REQUEST_ID"));
		
		scheduledCryoPreservationJobListView.setJobName(rs.getString("JOB_NAME"));
		scheduledCryoPreservationJobListView.setCancelComments(rs.getString("CANCEL_COMMENTS"));
		return scheduledCryoPreservationJobListView;
	}

}
