/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.cryoprocessing.forms;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import uk.ac.sanger.mig.cryoprocessing.Box;
import uk.ac.sanger.mig.cryoprocessing.Canister;
import uk.ac.sanger.mig.cryoprocessing.FreezeDownSample;
import uk.ac.sanger.mig.cryoprocessing.Freezer;
import uk.ac.sanger.mig.cryoprocessing.Goblet;
import uk.ac.sanger.mig.cryoprocessing.ScheduledCryoPreservationJob;
import uk.ac.sanger.mig.cryoprocessing.Tower;
import uk.ac.sanger.mig.cryoprocessing.Wedge;

public class FreezeDownSampleForm {

	private String vialName;
	private Integer vialPosition;
	private Long freezerId;
	private String freezerName;
	private Long towerId;
	private String towerName;
	private Long boxId;
	private String boxName;
	private Long canisterId;
	private Long gobletId;
	private Long wedgeId;
	private boolean onFormChange;
	private Collection<Tower> towers = new ArrayList<Tower>();
	private Collection<Freezer> freezers = new ArrayList<Freezer>();
	private Collection<Box> boxes = new ArrayList<Box>();
	private Collection<Canister> canisters = new ArrayList<Canister>();
	private Collection<Goblet> goblets = new ArrayList<Goblet>();
	private Collection<Wedge> wedges = new ArrayList<Wedge>();
	private List<Integer> availableVialPosition = new ArrayList<Integer>();
	private ScheduledCryoPreservationJob scheduledCryoPreservationJob;
	private String referPage;
	private FreezeDownSample freezeDownSample; 
	private Boolean strawSystem = null;
	private Collection<String> sampleLocations;
	
	public Collection<String> getSampleLocations() {
		return sampleLocations;
	}
	public void setSampleLocations(Collection<String> strawLocations) {
		this.sampleLocations = strawLocations;
	}
	public Long getFreezerId() {
		return freezerId;
	}
	public void setFreezerId(Long freezerId) {
		this.freezerId = freezerId;
	}
	public Long getTowerId() {
		return towerId;
	}
	public void setTowerId(Long towerId) {
		this.towerId = towerId;
	}
	public FreezeDownSample getFreezeDownSample() {
		return freezeDownSample;
	}
	public void setFreezeDownSample(FreezeDownSample freezeDownSample) {
		this.freezeDownSample = freezeDownSample;
	}
	public String getFreezerName() {
		return freezerName;
	}
	public void setFreezerName(String freezerName) {
		this.freezerName = freezerName;
	}
	public String getTowerName() {
		return towerName;
	}
	public void setTowerName(String towerName) {
		this.towerName = towerName;
	}
	public String getVialName() {
		return vialName;
	}
	public void setVialName(String vialName) {
		this.vialName = vialName;
	}
	public Long getBoxId() {
		return boxId;
	}
	public void setBoxId(Long boxId) {
		this.boxId = boxId;
	}
	public String getBoxName() {
		return boxName;
	}
	public void setBoxName(String boxName) {
		this.boxName = boxName;
	}
	public Integer getVialPosition() {
		return vialPosition;
	}
	public void setVialPosition(Integer vialPosition) {
		this.vialPosition = vialPosition;
	}
	public ScheduledCryoPreservationJob getScheduledCryoPreservationJob() {
		return scheduledCryoPreservationJob;
	}
	public void setScheduledCryoPreservationJob(
			ScheduledCryoPreservationJob scheduledCryoPreservationJob) {
		this.scheduledCryoPreservationJob = scheduledCryoPreservationJob;
	}
	public boolean getOnFormChange() {
		return onFormChange;
	}
	public void setOnFormChange(boolean onFormChange) {
		this.onFormChange = onFormChange;
	}
	public Collection<Tower> getTowers() {
		return towers;
	}
	public void setTowers(Collection<Tower> towers) {
		this.towers = towers;
	}
	public Collection<Box> getBoxes() {
		return boxes;
	}
	public void setBoxes(Collection<Box> boxes) {
		this.boxes = boxes;
	}
	public Collection<Integer> getAvailableVialPosition() {
		return availableVialPosition;
	}
	public void setAvailableVialPosition(List<Integer> availableVialPosition) {
		this.availableVialPosition = availableVialPosition;
	}
	public Long getCanisterId() {
		return canisterId;
	}
	public void setCanisterId(Long canisterId) {
		this.canisterId = canisterId;
	}
	public Long getGobletId() {
		return gobletId;
	}
	public void setGobletId(Long gobletId) {
		this.gobletId = gobletId;
	}
	public Long getWedgeId() {
		return wedgeId;
	}
	public void setWedgeId(Long wedgeId) {
		this.wedgeId = wedgeId;
	}
	public Collection<Canister> getCanisters() {
		return canisters;
	}
	public void setCanisters(Collection<Canister> canisters) {
		this.canisters = canisters;
	}
	public Collection<Goblet> getGoblets() {
		return goblets;
	}
	public void setGoblets(Collection<Goblet> goblets) {
		this.goblets = goblets;
	}
	public Collection<Wedge> getWedges() {
		return wedges;
	}
	public void setWedges(Collection<Wedge> wedges) {
		this.wedges = wedges;
	}
	public Collection<Freezer> getFreezers() {
		return freezers;
	}
	public void setFreezers(Collection<Freezer> freezers) {
		this.freezers = freezers;
	}
	public Boolean getStrawSystem() {
		return strawSystem;
	}
	public void setStrawSystem(Boolean strawSystem) {
		this.strawSystem = strawSystem;
	}
	public String getReferPage() {
		return referPage;
	}
	public void setReferPage(String referPage) {
		this.referPage = referPage;
	}
	
	
}