/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.cryoprocessing.services;

import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.cryoprocessing.Box;
import uk.ac.sanger.mig.cryoprocessing.Tower;
import uk.ac.sanger.mig.cryoprocessing.Vial;
import uk.ac.sanger.mig.cryoprocessing.dao.BoxDao;

public class BoxServiceImpl extends AbstractServiceImpl<Box> implements BoxService {
	
	private BoxDao boxDao;
	
	private TowerService towerService;
	private VialService vialService; 
	
	public void setVialService(VialService vialService) {
		this.vialService = vialService;
	}

	public void setTowerService(TowerService towerService) {
		this.towerService = towerService;
	}

	
	public void setBoxDao(BoxDao boxDao) {
		this.boxDao = boxDao;
	}
	
	
	
	public Box fetchById(Long boxId, ComponentMap requiredComponents) {
		Box box = boxDao.fetchById(boxId);
		
		if(box != null)
			attachComponents(box, requiredComponents);
		
		return box;
	}
	
	@Override
	protected void attachComponents(Box box, ComponentMap requiredComponents) {
		if(box == null) {
			throw new RuntimeException("Cannot attach components to null box");
		}		
		
		boolean fetchAll = false;
		
		if(requiredComponents != null) {
			
			if(requiredComponents.containsKey(Box.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}
			
			if(fetchAll || requiredComponents.containsKey(Box.Component.VAILS)) {
				box.setCurrentVails(fetchCurrentVails(box, requiredComponents.get(Box.Component.VAILS)));
			}
			
			if(fetchAll || requiredComponents.containsKey(Box.Component.TOWER)) {
				box.setTower(fetchTower(box, requiredComponents.get(Box.Component.TOWER)));
			}
		}
	}
	
	
	public Collection<Box> fetchByFreezerId(Long freezerId, ComponentMap requiredComponents) {
		
		Collection<Tower> towers = towerService.fetchByFreezerId(freezerId, null);
		Collection<Box> boxes = null;
		
		for(Tower tower : towers) {
			boxes.addAll(boxDao.fetchByTowerId(tower.getId()));
		}
		
		attachComponents(boxes, requiredComponents);
		return boxes;
	}
	
	
	public Collection<Box> fetchByTowerId(Long towerId, ComponentMap requiredComponents) {
		Collection<Box> boxes = boxDao.fetchByTowerId(towerId);
		attachComponents(boxes, requiredComponents);
		return boxes;
	}
	
	// Helper methods
	private Tower fetchTower(Box box, ComponentMap requiredComponents) {
		if(box.getTowerId() != null) {
			return towerService.fetchById(box.getTowerId(), requiredComponents);
		}else {
			return null;
		}
	}

	private Collection<Vial> fetchCurrentVails(Box box, ComponentMap requiredComponents) {
		return vialService.fetchActiveByBoxId(box.getId(), requiredComponents);
	}
	
}
