/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.cryoprocessing.services;

import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.cryoprocessing.Canister;
import uk.ac.sanger.mig.cryoprocessing.dao.CanisterDao;

public class CanisterServiceImpl extends AbstractServiceImpl<Canister> implements CanisterService {
	
	private CanisterDao canisterDao;
	public void setCanisterDao(CanisterDao canisterDao) {
		this.canisterDao = canisterDao;
	}



	
	public Canister fetchById(Long canisterId, ComponentMap requiredComponents) {
		Canister canister = canisterDao.fetchById(canisterId);
		
		if(canister != null)
			attachComponents(canister, requiredComponents);
		
		return canister;
	}

	@Override
	protected void attachComponents(Canister canister, ComponentMap requiredComponents) {
		if(canister == null) {
			throw new RuntimeException("Cannot attach components to null canister");
		}		
		
		boolean fetchAll = false;
		
		if(requiredComponents != null) {
			
			if(requiredComponents.containsKey(Canister.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}
			
			if(fetchAll) {
			//later
			}
			
		}
	}
	
	public Collection<Canister> fetchByFreezerId(Long freezerId, ComponentMap requiredComponents) {
		Collection<Canister> canisters = canisterDao.fetchByFreezerId(freezerId);
		attachComponents(canisters, requiredComponents);
		return canisters;
	}
	
}
								