package uk.ac.sanger.mig.cryoprocessing.services;

import java.util.Collection;

import org.springframework.transaction.annotation.Transactional;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.cryoprocessing.EmbryoHarvest;
import uk.ac.sanger.mig.cryoprocessing.FreezeDownSample;
import uk.ac.sanger.mig.cryoprocessing.FreezeDownSampleSearchBean;
import uk.ac.sanger.mig.cryoprocessing.Straw;
import uk.ac.sanger.mig.cryoprocessing.Vial;
import uk.ac.sanger.mig.cryoprocessing.dao.FreezeDownSampleDao;
import uk.ac.sanger.mig.cryoprocessing.forms.FreezeDownSampleForm;
import uk.ac.sanger.mig.cryoprocessing.views.SampleListView;
import uk.ac.sanger.mig.cryoprocessing.views.StrawListView;
import uk.ac.sanger.mig.cryoprocessing.views.StrawLocation;
import uk.ac.sanger.mig.cryoprocessing.views.VialLocation;
import uk.ac.sanger.mig.cryorequest.ManageCryoRequestSearchBean;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.personnel.services.PersonService;

public class FreezeDownSampleServiceImpl extends AbstractServiceImpl<FreezeDownSample> implements FreezeDownSampleService {

	private FreezeDownSampleDao freezeDownSampleDao;
	private PersonService personService;
	private EmbryoHarvestService embryoHarvestService;
	private VialLocationService vialLocationService;
	private VialService vialService;
	private StrawService strawService;
	private StrawLocationService strawLocationService;



	public void setStrawLocationService(StrawLocationService strawLocationService) {
		this.strawLocationService = strawLocationService;
	}

	public void setStrawService(StrawService strawService) {
		this.strawService = strawService;
	}

	public void setVialService(VialService vialService) {
		this.vialService = vialService;
	}

	public void setVialLocationService(VialLocationService vialLocationService) {
		this.vialLocationService = vialLocationService;
	}

	public void setEmbryoHarvestService(EmbryoHarvestService embryoHarvestService) {
		this.embryoHarvestService = embryoHarvestService;
	}


	public void setPersonService(PersonService personService) {
		this.personService = personService;
	}

	public void setFreezeDownSampleDao(FreezeDownSampleDao freezeDownSampleDao) {
		this.freezeDownSampleDao = freezeDownSampleDao;
	}

	public Long storeAuthenticated(FreezeDownSample cryoFreezeDownSample, Person user) {
		if(cryoFreezeDownSample == null) {
			throw new RuntimeException("Cannot save a null cryoFreezeDownSample");
		}

		return freezeDownSampleDao.store(cryoFreezeDownSample, user);
	}

	public FreezeDownSample fetchById(Long cryoFreezeDownSampleId, ComponentMap requiredComponents) {
		FreezeDownSample cryoFreezeDownSample = freezeDownSampleDao.fetchById(cryoFreezeDownSampleId);

		if(cryoFreezeDownSample != null)
			attachComponents(cryoFreezeDownSample, requiredComponents);

		return cryoFreezeDownSample;
	}

	@Override
	protected void attachComponents(FreezeDownSample freezeDownSample, ComponentMap requiredComponents) {
		if(freezeDownSample == null) {
			throw new RuntimeException("Cannot attach components to null cryoFreezeDownSample");
		}

		boolean fetchAll = false;

		if(requiredComponents != null) {

			if(requiredComponents.containsKey(FreezeDownSample.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}
			if(fetchAll || requiredComponents.containsKey(FreezeDownSample.Component.EMBRYO_HARVEST)) {
				freezeDownSample.setEmbryoHarvest(fetchEmbryoHarvest(freezeDownSample, requiredComponents.get(FreezeDownSample.Component.EMBRYO_HARVEST)));
			}
			if(fetchAll || requiredComponents.containsKey(FreezeDownSample.Component.TECHNICIAN)) {
				freezeDownSample.setTechnician(fetchTechnician(freezeDownSample,requiredComponents.get(FreezeDownSample.Component.TECHNICIAN)));
			}
			if(fetchAll || requiredComponents.containsKey(FreezeDownSample.Component.VIAL_LOCATION)) {
				freezeDownSample.setVialLocation(fetchVialLocation(freezeDownSample,requiredComponents.get(FreezeDownSample.Component.VIAL_LOCATION)));
			}
			if(fetchAll || requiredComponents.containsKey(FreezeDownSample.Component.STRAW_LOCATION)) {
				freezeDownSample.setStrawLocation(fetchStrawLocation(freezeDownSample,requiredComponents.get(FreezeDownSample.Component.STRAW_LOCATION)));
			}

		}
	}

	public FreezeDownSample fetchByLocationId(Long locationId, ComponentMap requiredComponents) {

		FreezeDownSample freezeDownSample = freezeDownSampleDao.fetchByLocationId(locationId);

		if(freezeDownSample != null)
			attachComponents(freezeDownSample, requiredComponents);

		return freezeDownSample;

	}

	public Collection<StrawListView> searchStraws(FreezeDownSampleSearchBean freezeDownSampleSearchBean) {
		return freezeDownSampleDao.searchStraws(freezeDownSampleSearchBean);
	}

	public Collection<SampleListView> searchSamples(FreezeDownSampleSearchBean freezeDownSampleSearchBean) {
		return freezeDownSampleDao.searchSamples(freezeDownSampleSearchBean);
	}

	//private helper methods
	private Person fetchTechnician(FreezeDownSample freezeDownSample, ComponentMap requiredComponents) {
		if(freezeDownSample.getTechnicianId() != null) {
			return personService.fetchById(freezeDownSample.getTechnicianId(), requiredComponents) ;
		}
		else {
			return null;
		}
	}

	private EmbryoHarvest fetchEmbryoHarvest(FreezeDownSample freezeDownSample, ComponentMap requiredComponents) {
		if(freezeDownSample.getEmbryoHarvestId() != null) {
			return embryoHarvestService.fetchById(freezeDownSample.getEmbryoHarvestId(), requiredComponents);
		}
		else {
			return null;
		}
	}

	private VialLocation fetchVialLocation(FreezeDownSample freezeDownSample, ComponentMap requiredComponents) {
		Long vialId = freezeDownSampleDao.getVialIdById(freezeDownSample.getId());

		if(vialId != null) {
			return vialLocationService.fetchById(vialId, requiredComponents);
		}
		else {
			return null;
		}
	}

	private StrawLocation fetchStrawLocation(FreezeDownSample freezeDownSample, ComponentMap requiredComponents) {
		Long strawId = freezeDownSampleDao.getStrawIdById(freezeDownSample.getId());

		if(strawId != null) {
			return strawLocationService.fetchById(strawId, requiredComponents);
		}
		else {
			return null;
		}
	}

	public void inflateFreezeDownSampleComponents(FreezeDownSample freezeDownSample) {
		if (freezeDownSample ==  null) {
			throw new RuntimeException("FreezeDownSample cannot be null when inflating components.");
		}

		if(freezeDownSample.getEmbryoHarvest() == null) {
			freezeDownSample.setEmbryoHarvest(new EmbryoHarvest());
		}
		if(freezeDownSample.getEmbryoGradeDict() == null) {
			freezeDownSample.setEmbryoGradeDict(new DictionaryEntry());
		}
		if(freezeDownSample.getTechnician() == null) {
			freezeDownSample.setTechnician(new Person());
		}
		if(freezeDownSample.getVialLocation() == null) {
			freezeDownSample.setVialLocation(new VialLocation());
		}
		if(freezeDownSample.getStrawLocation() == null) {
			freezeDownSample.setStrawLocation(new StrawLocation());
		}
	}

	@Transactional
	public Long editFreezeDownSample(FreezeDownSample freezeDownSample, FreezeDownSampleForm freezeDownSampleForm, Person user) {
		Long id = freezeDownSample.getId();
		Vial vial = null;
		Straw straw = null;

		if(id == null) {


			if(!freezeDownSampleForm.getStrawSystem()){//new vial
				//1) store new vial
				Long locationId;
				vial = new Vial();
				vial.setBoxId(freezeDownSampleForm.getBoxId());
				vial.setPosition(freezeDownSampleForm.getVialPosition());
				vial.setInUse(true);
				locationId = vialService.storeVialAndLocation(vial, user);

				// 2) store freeze down sample
				freezeDownSample.setLocationId(locationId);
				freezeDownSample.setEmbryoHarvestId(freezeDownSampleForm.getScheduledCryoPreservationJob().getEmbryoHarvest().getId());
				id = freezeDownSampleDao.store(freezeDownSample, user);
			}else{//new straw

				//1) Store new straw
				Long locationId;
				straw = new Straw();
				straw.setWedgeId(freezeDownSampleForm.getWedgeId());
				straw.setInUse(true);
				locationId = strawService.storeStrawAndLocation(straw, user);

				// 2) store freeze down sample
				freezeDownSample.setLocationId(locationId);
				freezeDownSample.setEmbryoHarvestId(freezeDownSampleForm.getScheduledCryoPreservationJob().getEmbryoHarvest().getId());
				id = freezeDownSampleDao.store(freezeDownSample, user);
			}

		}else{
			if(!freezeDownSampleForm.getStrawSystem()){//edit vial
				Long vialId = freezeDownSample.getVialLocation().getVialId();
				vial = vialService.fetchById(vialId, null);
				vial.setBoxId(freezeDownSampleForm.getBoxId());
				vial.setPosition(freezeDownSampleForm.getVialPosition());
				vialService.storeVial(vial, user);
				id = freezeDownSampleDao.store(freezeDownSample, user);
			}else{
				//edit straw
				Long strawId = freezeDownSample.getStrawLocation().getStrawId();
				straw = strawService.fetchById(strawId, null);
				straw.setWedgeId(freezeDownSampleForm.getWedgeId());
				strawService.storeStraw(straw, user);
				id = freezeDownSampleDao.store(freezeDownSample, user);
			}

		}

		return id;

	}

	public Collection<FreezeDownSample> fetchActiveByEmbryoHarvestId(Long embryoHarvestId, ComponentMap requiredComponents) {

		Collection<FreezeDownSample> freezeDownSamples = freezeDownSampleDao.fetchActiveByEmbryoHarvestId(embryoHarvestId);
		attachComponents(freezeDownSamples, requiredComponents);
		return freezeDownSamples;
	}
	public Collection<FreezeDownSample> fetchByThawTestId(Long thawTestId, ComponentMap componentMap) {
		Collection<FreezeDownSample> freezeDownSamples = freezeDownSampleDao.fetchByThawTestId(thawTestId);
		attachComponents(freezeDownSamples, componentMap);
		return freezeDownSamples;
	}

	public String fetchSampleColonyNameById(Long id) {
		String colonyName = freezeDownSampleDao.fetchSampleColonyNameById(id);
		return colonyName;
	}

	public String fetchWildTypeNameById(Long id) {
		String wildTypeName = freezeDownSampleDao.fetchWildTypeNameById(id);
		return wildTypeName;
	}

	public Collection<SampleListView> fetchSamplesByCryoRequestId(Long id, ManageCryoRequestSearchBean searchBean) {

		return freezeDownSampleDao.fetchSamplesByCryoRequestId(id, searchBean);
	}

	public Collection<SampleListView> fetchByCryoRequestId(Long cryoRequestId) {

		return freezeDownSampleDao.fetchByCryoRequestId(cryoRequestId);
	}

	public SampleListView cancelSampleBySampleId(Long sampleId, Person user) {
		SampleListView sampleListView = freezeDownSampleDao.fetchSampleById(sampleId);
		if(sampleListView != null){
			if(sampleListView.getStorageType().equalsIgnoreCase("straw")){
				strawService.cancelStrawById(sampleListView.getSampleId(), user, "thaw test");
			}else{
                vialService.cancelVialById(sampleListView.getSampleId(), user, "thaw test");
			}
		}else{
			throw new RuntimeException("can't delete the sample"+sampleId);
		}
		return sampleListView;
	}
}
