/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.cryoprocessing.services;

import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.cryoprocessing.Box;
import uk.ac.sanger.mig.cryoprocessing.Freezer;
import uk.ac.sanger.mig.cryoprocessing.dao.FreezerDao;
import uk.ac.sanger.mig.personnel.Person;

public class FreezerServiceImpl extends AbstractServiceImpl<Freezer> implements FreezerService {
	
	private FreezerDao freezerDao;
	private BoxService boxService;
	
	public void setBoxService(BoxService boxService) {
		this.boxService = boxService;
	}


	public void setFreezerDao(FreezerDao freezerDao) {
		this.freezerDao = freezerDao;
	}


	public Long storeAuthenticated(Freezer freezer, Person user) {
		if(freezer == null) {
			throw new RuntimeException("Cannot save a null freezer");
		}
		
		return freezerDao.store(freezer, user);
	}
	
	public Freezer fetchById(Long freezerId, ComponentMap requiredComponents) {
		Freezer freezer = freezerDao.fetchById(freezerId);
		
		if(freezer != null)
			attachComponents(freezer, requiredComponents);
		
		return freezer;
	}

	@Override
	protected void attachComponents(Freezer freezer, ComponentMap requiredComponents) {
		if(freezer == null) {
			throw new RuntimeException("Cannot attach components to null freezer");
		}		
		
		boolean fetchAll = false;
		
		if(requiredComponents != null) {
			
			if(requiredComponents.containsKey(Freezer.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}
			
			if(fetchAll || requiredComponents.containsKey(Freezer.Component.BOXES)) {
				freezer.setBoxes(fetchBoxes(freezer, requiredComponents.get(Freezer.Component.BOXES)));
			}
			
			
		}
	}

	public Collection<Freezer> fetch(ComponentMap requiredComponents) {
		
		Collection<Freezer> freezers = freezerDao.fetch();
		attachComponents(freezers, requiredComponents);
		return freezers;
	}
	
	public Collection<Freezer> fetchStrawFreezers(ComponentMap requiredComponents) {
		
		Collection<Freezer> freezers = freezerDao.fetchStrawFreezers();
		attachComponents(freezers, requiredComponents);
		return freezers;
	}
	
	public Collection<Freezer> fetchVialFreezers(ComponentMap requiredComponents) {
		
		Collection<Freezer> freezers = freezerDao.fetchVialFreezers();
		attachComponents(freezers, requiredComponents);
		return freezers;
	}
	
	//private helper methods
	private Collection<Box> fetchBoxes(Freezer freezer, ComponentMap requiredComponents) {
		
		return boxService.fetchByFreezerId(freezer.getId(),requiredComponents);
	}

	
}
								