/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.cryoprocessing.services;

import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.cryoprocessing.Goblet;
import uk.ac.sanger.mig.cryoprocessing.dao.GobletDao;

public class GobletServiceImpl extends AbstractServiceImpl<Goblet> implements GobletService {
	
	private GobletDao gobletDao;
	
	
	
	public void setGobletDao(GobletDao gobletDao) {
		this.gobletDao = gobletDao;
	}


	
	public Goblet fetchById(Long gobletId, ComponentMap requiredComponents) {
		Goblet goblet = gobletDao.fetchById(gobletId);
		
		if(goblet != null)
			attachComponents(goblet, requiredComponents);
		
		return goblet;
	}

	public Collection<Goblet> fetchByCanisterId(Long canisterId, ComponentMap requiredComponents) {
		Collection<Goblet> goblets = gobletDao.fetchByCanisterId(canisterId);
		attachComponents(goblets, requiredComponents);
		return goblets;
	}
	
	@Override
	protected void attachComponents(Goblet goblet, ComponentMap requiredComponents) {
		if(goblet == null) {
			throw new RuntimeException("Cannot attach components to null goblet");
		}		
		
		
		if(requiredComponents != null) {
			
			if(requiredComponents.containsKey(Goblet.Component.ALL_COMPONENTS)) {
				//fetchAll = true;
			}
			
			//later
		}
	}
	
	//private helper methods--eg, fetchSomeSubComponent (REM: use service injection, not Dao!)
	
}
								