/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.cryoprocessing.services;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.personnel.Person;

import java.util.Collection;

import org.springframework.transaction.annotation.Transactional;

import uk.ac.sanger.mig.common.AbstractServiceImpl;

import uk.ac.sanger.mig.cryoprocessing.FreezeDownSample;
import uk.ac.sanger.mig.cryoprocessing.Shipping;
import uk.ac.sanger.mig.cryoprocessing.ShippingSearchBean;
import uk.ac.sanger.mig.cryoprocessing.dao.ShippingDao;
import uk.ac.sanger.mig.cryoprocessing.forms.FreezeDownSampleCheckBox;

public class ShippingServiceImpl extends AbstractServiceImpl<Shipping> implements ShippingService {

	private ShippingDao shippingDao;
	private FreezeDownSampleService freezeDownSampleService;

	public void setFreezeDownSampleService(
			FreezeDownSampleService freezeDownSampleService) {
		this.freezeDownSampleService = freezeDownSampleService;
	}

	public void setShippingDao(ShippingDao shippingDao) {
		this.shippingDao = shippingDao;
	}


	public Long store(Shipping shipping, Person user) {
		if(shipping == null) {
			throw new RuntimeException("Cannot save a null shipping");
		}

		return shippingDao.store(shipping, user);
	}

	public Shipping fetchById(Long shippingId, ComponentMap requiredComponents) {
		Shipping shipping = shippingDao.fetchById(shippingId);

		if(shipping != null)
			attachComponents(shipping, requiredComponents);

		return shipping;
	}

	@Override
	protected void attachComponents(Shipping shipping, ComponentMap requiredComponents) {
		if(shipping == null) {
			throw new RuntimeException("Cannot attach components to null shipping");
		}
		boolean fetchAll = false;

		if(requiredComponents != null) {

			if(requiredComponents.containsKey(Shipping.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}
		}
	}


	public Collection<Shipping> search(ShippingSearchBean shippingSearchBean) {
		// TODO Auto-generated method stub
		return null;
	}

	@Transactional
	public void storeShoppingSamples(Collection<FreezeDownSampleCheckBox> samples, Shipping shipping, Person person) {
		if(shipping != null){
			Long shippingId = store(shipping,person);
			for(FreezeDownSampleCheckBox sample: samples){
				if(sample.isChecked()){
					FreezeDownSample freezeDownSample = freezeDownSampleService.fetchById(sample.getSampleListView().getId(),null);
					freezeDownSample.setShippingID(shippingId);
					freezeDownSampleService.storeAuthenticated(freezeDownSample, person);
					freezeDownSampleService.cancelSampleBySampleId(sample.getSampleListView().getId(), person);
				}
			}
		}else{
			throw new RuntimeException("No Samples avaiable for shipping");
		}
	}

}
