/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.cryoprocessing.services;

import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.cryoprocessing.FreezeDownSample;
import uk.ac.sanger.mig.cryoprocessing.Straw;
import uk.ac.sanger.mig.cryoprocessing.dao.StrawDao;
import uk.ac.sanger.mig.personnel.Person;

public class StrawServiceImpl extends AbstractServiceImpl<Straw> implements StrawService {

	private StrawDao strawDao;
	private FreezeDownSampleService freezeDownSampleService;


	public void setFreezeDownSampleService(
			FreezeDownSampleService freezeDownSampleService) {
		this.freezeDownSampleService = freezeDownSampleService;
	}

	public void setStrawDao(StrawDao strawDao) {
		this.strawDao = strawDao;
	}

	/*
	 * store into straw and location(linker table)
	 */
	public Long storeStrawAndLocation(Straw straw, Person person){
		if(straw == null) {
			throw new RuntimeException("Cannot save a null straw!");
		}

		Long strawId = strawDao.store(straw, person);
		return strawDao.storeLocation(strawId);
	}

	/*
	 * store just straw alone
	 */
	public Long storeStraw(Straw straw, Person person){
		return strawDao.store(straw, person);
	}

	public Straw fetchById(Long strawId, ComponentMap requiredComponents){
		Straw straw = strawDao.fetchById(strawId);

		if(straw != null)
			attachComponents(straw, requiredComponents);

		return straw;
	}

	public Collection<Straw> fetchActiveByWedgeId(Long wedgeId, ComponentMap requiredComponents) {
		Collection<Straw> straws = strawDao.fetchActiveByWedgeId(wedgeId);
		attachComponents(straws, requiredComponents);
		return straws;
	}


	@Override
	protected void attachComponents(Straw straw, ComponentMap requiredComponents) {
		if(straw == null) {
			throw new RuntimeException("Cannot attach components to null vial");
		}

		boolean fetchAll = false;

		if(requiredComponents != null) {

			if(requiredComponents.containsKey(Straw.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}

			if(fetchAll || requiredComponents.containsKey(Straw.Component.FREEZE_DOWN_SAMPLE)) {
				straw.setFreezeDownSample(fetchFreezeDownSample(straw, requiredComponents.get(Straw.Component.FREEZE_DOWN_SAMPLE)));
			}

		}

	}

	//helper methods
	private FreezeDownSample fetchFreezeDownSample(Straw straw, ComponentMap requiredComponents) {
		FreezeDownSample freezeDownSample = null;
		Long locationId = strawDao.fetchLocationIdByStrawId(straw.getId());
		if(locationId != null) {
			freezeDownSample = freezeDownSampleService.fetchByLocationId(locationId, requiredComponents);
		}
		return freezeDownSample;

	}

	public Long cancelStrawById(Long id, Person user, String cancelReason) {

		Straw straw = new Straw();
		straw = strawDao.fetchById(id);
		if(straw == null){
			throw new RuntimeException("straw "+id+" does not exist");
		}else{
			straw.setInUse(false);
			straw.setComments(cancelReason);
			return storeStraw(straw, user);
		}
	}

	public Long cancelStrawBySampleId(Long sampleId, Person user) {
		Long strawId = strawDao.fetchIdBySampleId(sampleId);
		return cancelStrawById(strawId, user, "thaw test");
	}
}
