package uk.ac.sanger.mig.cryoprocessing.services;

import java.util.Collection;
import org.springframework.transaction.annotation.Transactional;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.cryoprocessing.FreezeDownSample;
import uk.ac.sanger.mig.cryoprocessing.ThawTest;
import uk.ac.sanger.mig.cryoprocessing.dao.ThawTestDao;
import uk.ac.sanger.mig.cryoprocessing.views.SampleListView;
import uk.ac.sanger.mig.cryorequest.CryoRequest;
import uk.ac.sanger.mig.cryorequest.services.CryoRequestService;
import uk.ac.sanger.mig.miprocessing.EmbryoTransferProcedure;
import uk.ac.sanger.mig.miprocessing.services.EmbryoTransferProcedureService;
import uk.ac.sanger.mig.mousetracking.Litter;
import uk.ac.sanger.mig.mousetracking.services.LitterService;
import uk.ac.sanger.mig.personnel.Person;

/**
 * @author wl1
 *
 **/
public class ThawTestServiceImpl  extends AbstractServiceImpl<ThawTest> implements ThawTestService {
	private ThawTestDao thawTestDao;
	private FreezeDownSampleService freezeDownSampleService;
	private CryoRequestService cryoRequestService;
	private EmbryoTransferProcedureService embryoTransferProcedureService;
	private LitterService litterService;



	public void setLitterService(LitterService litterService) {
		this.litterService = litterService;
	}

	@Override
	protected void attachComponents(ThawTest thawTest, ComponentMap requiredComponents) {

		if(thawTest == null) {
			throw new RuntimeException("Cannot attach components to null thawTest!");
		}

		boolean fetchAll = false;

		if(requiredComponents != null) {

			if(requiredComponents.containsKey(ThawTest.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}
			if(fetchAll || requiredComponents.containsKey(ThawTest.Component.CRYO_REQUEST)) {
				thawTest.setCryoRequest(fetchRequestById(thawTest.getCryoRequestId(),
						requiredComponents.get(ThawTest.Component.CRYO_REQUEST)));
			}
			if(fetchAll || requiredComponents.containsKey(ThawTest.Component.EMBRYO_TRANSFERS)) {
				thawTest.setEmbryoTransfers(fetchEmbryoTransfersByThawTestId(
						thawTest.getId(),
						requiredComponents.get(ThawTest.Component.EMBRYO_TRANSFERS)));
			}
			if(fetchAll || requiredComponents.containsKey(ThawTest.Component.FREEZE_DOWN_SAMPLES)) {
				thawTest.setFreezeDownSamples(fetchFreezeDownSampleByThawTestId(
						thawTest.getId(),
						requiredComponents.get(ThawTest.Component.FREEZE_DOWN_SAMPLES)));
			}
		}
	}

	/////////////////////////////////////////////////////////////////////////////////////////////
	////////////////////////////////// dependencies /////////////////////////////////////////////
	/////////////////////////////////////////////////////////////////////////////////////////////

	public void setThawTestDao(ThawTestDao thawTestDao) {
		this.thawTestDao = thawTestDao;
	}

	public void setCryoRequestService(CryoRequestService cryoRequestService) {
		this.cryoRequestService = cryoRequestService;
	}

	public void setEmbryoTransferProcedureService(
			EmbryoTransferProcedureService embryoTransferProcedureService) {
		this.embryoTransferProcedureService = embryoTransferProcedureService;
	}

	public void setFreezeDownSampleService(
			FreezeDownSampleService freezeDownSampleService) {
		this.freezeDownSampleService = freezeDownSampleService;
	}


	/////////////////////////////////////////////////////////////////////////////////////////////
	////////////////////////////////////  privates //////////////////////////////////////////////
	/////////////////////////////////////////////////////////////////////////////////////////////

	private CryoRequest	fetchRequestById(Long requestId, ComponentMap requiredComponents){
		return (requestId != null) ? cryoRequestService.fetchById(requestId, requiredComponents) : null;
	}

	private Collection<EmbryoTransferProcedure> fetchEmbryoTransfersByThawTestId(Long thawTestId, ComponentMap requiredComponents){
		return (thawTestId != null)? embryoTransferProcedureService.fetchByThawTestId(thawTestId, requiredComponents) : null;
	}

	private Collection<FreezeDownSample>fetchFreezeDownSampleByThawTestId(Long thawTestId, ComponentMap componentMap){
		return freezeDownSampleService.fetchByThawTestId(thawTestId, componentMap);

	}

	public ThawTest fetchById(Long id, ComponentMap componentMap) {

		ThawTest thawTest = thawTestDao.fetchById(id);

		if(thawTest != null)
			attachComponents(thawTest, componentMap);
		return thawTest;
	}

	public Collection<ThawTest> fetchAllByRequestId(Long requestId, ComponentMap componentMap) {

		Collection<ThawTest> thawTests =  thawTestDao.fetchAllByRequestId(requestId);
		if(thawTests != null)
			attachComponents(thawTests, componentMap);
		return thawTests;
	}

	@Transactional
	public Long editThawTest(ThawTest thawTest, Person user) {
		//update the thaw test
	    Long id = thawTestDao.store(thawTest, user);
	    //update the cage card of each embryo transfer
	     for(EmbryoTransferProcedure et:thawTest.getEmbryoTransfers()){
	    	 Litter litter = litterService.fetchByEmbryoTransferId(et.getId(),null);
	    	 litter.setDueDate(thawTest.getDueDate());
	    	 litterService.store(litter, user);
	     }
	     return id;
	}

	public Long store(ThawTest thawTest, Person user){
		return thawTestDao.store(thawTest, user);
	}

	@Transactional
	public Long storeThawTest(ThawTest thawTest,Collection<SampleListView> samples,Collection<EmbryoTransferProcedure> embryoTransfers,Person user) {

		if(thawTest!=null && samples != null && embryoTransfers != null ) {
			//if its new get the id, if edit the thawDate could change
			Long thawTestId = store(thawTest, user);

			for(SampleListView sample: samples) {
				if(sample.isSelected()){
					FreezeDownSample freezeDownSample = freezeDownSampleService.fetchById(sample.getId(), null);
					freezeDownSample.setThawTestId(thawTestId);
					freezeDownSampleService.storeAuthenticated(freezeDownSample, user);
					freezeDownSampleService.cancelSampleBySampleId(freezeDownSample.getId(), user);
				}
			}
			for(EmbryoTransferProcedure em: embryoTransfers){
				em.setThawTestId(thawTestId);
				//when store embryo transfer, need store the mouse and together mark the cage to be used
				embryoTransferProcedureService.storeThawTestEmbryoTransfer(em, user);
			}
		}
		else {
			throw new RuntimeException("Thaw Test does not contain freeze down samples or embryo transfers!");
		}
		return thawTest.getId();
	}

	public ThawTest fetchWithAllComponents(Long thawTestId) {
		ThawTest thawTest = null;
		ComponentMap requiredComponents = new ComponentMap();
		requiredComponents.put(ThawTest.Component.CRYO_REQUEST, cryoRequestService.getComponentMapForHeaderFile());
		requiredComponents.put(ThawTest.Component.FREEZE_DOWN_SAMPLES,ComponentMap.of(FreezeDownSample.Component.TECHNICIAN, null));

		Collection<EmbryoTransferProcedure> embryoTransfers
		= embryoTransferProcedureService.fetchWithAllComponentsByThawTestId(thawTestId);

		thawTest = fetchById(thawTestId, requiredComponents);
		thawTest.setEmbryoTransfers(embryoTransfers);

		return thawTest;
	}
}
