/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.cryoprocessing.services;

import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.cryoprocessing.Box;
import uk.ac.sanger.mig.cryoprocessing.FreezeDownSample;
import uk.ac.sanger.mig.cryoprocessing.Vial;
import uk.ac.sanger.mig.cryoprocessing.dao.VialDao;
import uk.ac.sanger.mig.personnel.Person;

public class VialServiceImpl extends AbstractServiceImpl<Vial> implements VialService {
	
	private VialDao vialDao;
	private FreezeDownSampleService freezeDownSampleService;
	private BoxService boxService;
	
	public void setBoxService(BoxService boxService) {
		this.boxService = boxService;
	}

	public void setFreezeDownSampleService(
			FreezeDownSampleService freezeDownSampleService) {
		this.freezeDownSampleService = freezeDownSampleService;
	}


	public void setVialDao(VialDao cryoVialDao) {
		this.vialDao = cryoVialDao;
	}


	
	public Vial fetchById(Long vialId, ComponentMap requiredComponents) {
		Vial vial = vialDao.fetchById(vialId);
		
		if(vial != null)
			attachComponents(vial, requiredComponents);
		
		return vial;
	}

	

	
	public Collection<Vial> fetchActiveByBoxId(Long boxId, ComponentMap requiredComponents) {
		
		Collection<Vial> vials = vialDao.fetchActiveByBoxId(boxId);
		attachComponents(vials, requiredComponents);
		return vials;
	}
	
	public Long storeVialAndLocation(Vial vial, Person person) {
		
		if(vial == null) {
			throw new RuntimeException("Cannot save a null vial");
		}
		
		Long vialId = vialDao.store(vial, person);
		return vialDao.storeLocation(vialId);
		
	}
	
	
	public Long storeVial(Vial vial, Person person) {
		return vialDao.store(vial, person);
	}
	
	@Override
	protected void attachComponents(Vial vial, ComponentMap requiredComponents) {
		if(vial == null) {
			throw new RuntimeException("Cannot attach components to null vial");
		}		
		
		boolean fetchAll = false;
		
		if(requiredComponents != null) {
			
			if(requiredComponents.containsKey(Vial.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}
			if(fetchAll || requiredComponents.containsKey(Vial.Component.BOX)) {
				vial.setBox(fetchBox(vial,requiredComponents.get(Vial.Component.BOX)));
			}
			if(fetchAll || requiredComponents.containsKey(Vial.Component.FREEZE_DOWN_SAMPLE)) {
				vial.setFreezeDownSample(fetchFreezeDownSample(vial, requiredComponents.get(Vial.Component.FREEZE_DOWN_SAMPLE)));
			}
			
		}
	}
	
	// helper methods
	private FreezeDownSample fetchFreezeDownSample(Vial vial, ComponentMap requiredComponents) {
		FreezeDownSample freezeDownSample = null;
		Long locationId = vialDao.fetchLocationIdByVialId(vial.getId());
		if(locationId != null) {
			freezeDownSample = freezeDownSampleService.fetchByLocationId(locationId, requiredComponents); 
		}
		return freezeDownSample;
	}

	private Box fetchBox(Vial vial, ComponentMap requiredComponents) {
		
		if(vial.getBoxId() != null) {
			return boxService.fetchById(vial.getBoxId(), requiredComponents);
		}else {
			return null;
		}
	}

	public Long cancelVialById(Long id, Person user, String cancelReason) {
		Vial vial = new Vial();
		vial = vialDao.fetchById(id);
		if(vial == null){
			throw new RuntimeException("vial "+id+" does not exist");
		}else{
			vial.setInUse(false);
			vial.setComments(cancelReason);
			return storeVial(vial, user);
		}
	}
}
								