/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.cryoprocessing.validators;

import org.springframework.validation.Errors;
import org.springframework.validation.Validator;

import uk.ac.sanger.mig.cryoprocessing.FreezeDownSample;
import uk.ac.sanger.mig.cryoprocessing.forms.FreezeDownSampleForm;

public class FreezeDownSampleFormValidator implements Validator {
		
public boolean supports(Class clazz) {
		return FreezeDownSampleForm.class.equals(clazz);
	}

	public void validate(Object commandForm, Errors errors) {	

		FreezeDownSampleForm freezeDownSampleForm = (FreezeDownSampleForm)commandForm;
		FreezeDownSample freezeDownSample = freezeDownSampleForm.getFreezeDownSample();
		
		if(freezeDownSampleForm.getStrawSystem() == null) {
			errors.reject(null, "The type system is required!");
			
		}else if(!freezeDownSampleForm.getStrawSystem()) {
			if(freezeDownSample.getTechnicianId() == null)
				errors.reject(null, "Technician is required.");
			
			if(freezeDownSample.getEmbryoCount() == null)
				errors.reject(null, "Embryos Count is required.");
			
			if(freezeDownSample.getEmbryoGradeDictId() == null)
				errors.reject(null, "Embryo Grade is required.");
			
			if(freezeDownSample.getFreezeDownDate() == null)
				errors.reject(null, "Freeze Down Date is required.");
			if(!((freezeDownSampleForm.getFreezerId() != null)
					&& (freezeDownSampleForm.getTowerId() != null)
					&& (freezeDownSampleForm.getBoxId() != null)
					&& (freezeDownSampleForm.getVialPosition() != null))) {
				errors.reject(null, "The vial location (Freezer/Tower/Box/Vial position) is required.");
			}
			
			
		} else {
			if(freezeDownSample.getTechnicianId() == null)
				errors.reject(null, "Technician is required.");
			
			if(freezeDownSample.getEmbryoCount() == null)
				errors.reject(null, "Embryos Count is required.");
			
			if(freezeDownSample.getEmbryoGradeDictId() == null)
				errors.reject(null, "Embryo Grade is required.");
			
			if(freezeDownSample.getFreezeDownDate() == null)
				errors.reject(null, "Freeze Down Date is required.");
			if(!((freezeDownSampleForm.getFreezerId() != null)
					&& (freezeDownSampleForm.getCanisterId() != null)
					&& (freezeDownSampleForm.getGobletId() != null)
					&& (freezeDownSampleForm.getWedgeId() != null))) {
				errors.reject(null, "The straw location (Freezer/Canister/Goblet/Wedge position) is required.");
			}
			
			
		}	
	}
}