/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.cryoprocessing.views;

import java.util.Date;

import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.cryoprocessing.ScheduledCryoPreservationJob;

public class ScheduledCryoPreservationJobListView extends AuthenticatedDataObject implements Comparable {

	public int compareTo(Object arg0) {
		// TODO Auto-generated method stub
		return 0;
	}
	
	private String status;
	private Date targetDate;
	private Long cryoRequestId;
	private int totalFrozenCount;
	private String averageFrozenCount;
	private Long statusId;
	private String cancelReason;
	private Long embryoHarvestId;
	private String colonyName;
	private String comments;
	private String femaleStrain;
	private boolean cancelled;
	private boolean flushComplete;
	private boolean attemptComplete;
	private boolean scheduled;
	private boolean wildType;
	private String jobName;
	private String cancelComments;
	
	
	private ScheduledCryoPreservationJob scheduledCryoPreservationJob;
	
	
	public int getTotalFrozenCount() {
		return totalFrozenCount;
	}
	
	
	public void setWhetherAttemptComplete(Long statusId){
		if(statusId.equals(ScheduledCryoPreservationJob.InternalStatus.ATTEMPT_COMPLETE.getId()))
	 		this.setAttemptComplete(true);
	 	else
	 		this.setAttemptComplete(false);	
	}
	
	public void setWhetherCancelled(Long statusId){
		if(statusId.equals(ScheduledCryoPreservationJob.InternalStatus.CANCELLED.getId()))
	 		this.setCancelled(true);
	 	else
	 		this.setCancelled(false);
	}
	
	public void setWhetherScheduled(Long statusId){
		if(statusId.equals(ScheduledCryoPreservationJob.InternalStatus.SCHEDULED.getId()))
	 		this.setScheduled(true);
	 	else
	 		this.setScheduled(false);
	}
	
	public void setWhetherFlushComplete(Long statusId){
	 	if(statusId.equals(ScheduledCryoPreservationJob.InternalStatus.FLUSH_COMPLETED.getId()))
	 		this.setFlushComplete(true);
	 	else
	 		this.setFlushComplete(false);
	}
	
	public void setTotalFrozenCount(int totalFrozenCount) {
		this.totalFrozenCount = totalFrozenCount;
	}
	public Long getCryoRequestId() {
		return cryoRequestId;
	}
	public void setCryoRequestId(Long cryoRequestId) {
		this.cryoRequestId = cryoRequestId;
	}
	public String getStatus() {
		return status;
	}
	public void setStatus(String status) {
		this.status = status;
	}
	public Date getTargetDate() {
		return targetDate;
	}
	public void setTargetDate(Date targetDate) {
		this.targetDate = targetDate;
	}
	public ScheduledCryoPreservationJob getScheduledCryoPreservationJob() {
		return scheduledCryoPreservationJob;
	}
	public void setScheduledCryoPreservationJob(
			ScheduledCryoPreservationJob scheduledCryoPreservationJob) {
		this.scheduledCryoPreservationJob = scheduledCryoPreservationJob;
	}

	public Long getStatusId() {
		return statusId;
	}

	public void setStatusId(Long statusId) {
		this.statusId = statusId;
	}

	public String getCancelReason() {
		return cancelReason;
	}

	public void setCancelReason(String cancelReason) {
		this.cancelReason = cancelReason;
	}

	public Long getEmbryoHarvestId() {
		return embryoHarvestId;
	}

	public void setEmbryoHarvestId(Long embryoHarvestId) {
		this.embryoHarvestId = embryoHarvestId;
	}

	public String getColonyName() {
		return colonyName;
	}

	public void setColonyName(String colonyName) {
		this.colonyName = colonyName;
	}

	public String getComments() {
		return comments;
	}

	public void setComments(String comments) {
		this.comments = comments;
	}

	public String getFemaleStrain() {
		return femaleStrain;
	}

	public void setFemaleStrain(String femaleStrain) {
		this.femaleStrain = femaleStrain;
	}


	public boolean isAttemptComplete() {
		return attemptComplete;
	}


	public boolean isCancelled() {
		return cancelled;
	}


	public boolean isFlushComplete() {
		return flushComplete;
	}


	public boolean isScheduled() {
		return scheduled;
	}


	public String getAverageFrozenCount() {
		return averageFrozenCount;
	}


	public void setAverageFrozenCount(String averageFrozenCount) {
		this.averageFrozenCount = averageFrozenCount;
	}


	public void setAttemptComplete(boolean attemptComplete) {
		this.attemptComplete = attemptComplete;
	}


	public void setCancelled(boolean cancelled) {
		this.cancelled = cancelled;
	}


	public void setFlushComplete(boolean flushComplete) {
		this.flushComplete = flushComplete;
	}


	public void setScheduled(boolean scheduled) {
		this.scheduled = scheduled;
	}


	public void setWhetherWildType(Long cryoRequestId) {
		if(cryoRequestId>0){
			this.setWildType(false);
		}else{
			this.setWildType(true);
		}
		
	}


	public boolean isWildType() {
		return wildType;
	}


	public void setWildType(boolean wildType) {
		this.wildType = wildType;
	}


	public String getJobName() {
		return jobName;
	}


	public void setJobName(String jobId) {
		this.jobName = jobId;
	}


	public String getCancelComments() {
		return cancelComments;
	}


	public void setCancelComments(String cancelComments) {
		this.cancelComments = cancelComments;
	}


	

}
