/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.cryorequest.controllers;

import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.AbstractCancellableFormController;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.cryorequest.CryoRequest;
import uk.ac.sanger.mig.cryorequest.forms.CancelCryoRequestForm;
import uk.ac.sanger.mig.cryorequest.services.CryoRequestService;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;

public class CancelCryoRequestFormController extends AbstractCancellableFormController {
	
	private String successViewToSchedulePage;
	private CryoRequestService cryoRequestService;
	private DictionaryService dictionaryService;
	
	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	public void setCryoRequestService(CryoRequestService cryoRequestService) {
		this.cryoRequestService = cryoRequestService;
	}

	public String getSuccessViewToSchedulePage() {
		return successViewToSchedulePage;
	}

	public void setSuccessViewToSchedulePage(String successViewToSchedulePage) {
		this.successViewToSchedulePage = successViewToSchedulePage;
	}


	@Override
	protected Object formBackingObject(HttpServletRequest httpServletRequest) throws Exception {
		
		CancelCryoRequestForm form 
			= (CancelCryoRequestForm)createCommand();				    
		Long id = ServletRequestUtils.getRequiredLongParameter(httpServletRequest, "id");	
		
		ComponentMap map = cryoRequestService.getComponentMapForHeaderFile();
		form.setCryoRequest(cryoRequestService.fetchById(id, map));
		form.setCryoRequestId(id);
		return form;
	}
		
	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, 
				Object command, BindException errors) throws Exception {
		
		
		CancelCryoRequestForm form 
			= (CancelCryoRequestForm) command;	
		CryoRequest cryoRequest = form.getCryoRequest();
		String viewName = getSuccessView()+"bypassForm=true&newQuery=true&retrieveFromSession=true&paginated=true&currentRecordId=" + cryoRequest.getId();
		
		cryoRequest.changeStatus( 
				dictionaryService.fetchEntry(DictionaryEnum.CRQ_CRYO_REQUEST_STATUS_DICT,
						CryoRequest.RequestStatusEnum.CANCELLED.getId()));
		
		cryoRequest.setCancelReason(form.getCancelOrFailReason());
		cryoRequestService.cancelChildrenAndStore(cryoRequest, RequestUtils.getUser(request));
		Map<String, CryoRequest> model = new HashMap<String, CryoRequest> ();
		model.put("cryoRequest", cryoRequest);
		return new ModelAndView( viewName);
		
	}
}
