/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.cryorequest.controllers;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.AbstractSearchFormController;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.cryoprocessing.ThawTest;
import uk.ac.sanger.mig.cryoprocessing.services.FreezeDownSampleService;
import uk.ac.sanger.mig.cryoprocessing.services.ThawTestService;
import uk.ac.sanger.mig.cryoprocessing.views.SampleListView;
import uk.ac.sanger.mig.cryorequest.CryoRequest;
import uk.ac.sanger.mig.cryorequest.ManageCryoRequestSearchBean;
import uk.ac.sanger.mig.cryorequest.services.CryoRequestService;

public class ViewOneCryoRequestController extends AbstractSearchFormController {
	
	private FreezeDownSampleService freezeDownSampleService;
	private CryoRequestService cryoRequestService;
	private ThawTestService thawTestService;
	

	public void setThawTestService(ThawTestService thawTestService) {
		this.thawTestService = thawTestService;
	}

	public FreezeDownSampleService getFreezeDownSampleService() {
		return freezeDownSampleService;
	}

	public void setFreezeDownSampleService(
			FreezeDownSampleService freezeDownSampleService) {
		this.freezeDownSampleService = freezeDownSampleService;
	}
	

	@Override
	protected ModelAndView onSearch(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		Map<String, Object> model = (HashMap<String, Object>) referenceData(request);
		return showForm(request, response, errors, model);
	}
	@Override
	protected Map referenceData(HttpServletRequest request, Object command, Errors arg2) throws Exception {
		 
		ManageCryoRequestSearchBean searchBean = (ManageCryoRequestSearchBean)command;
		searchBean.setQueryName("listSamplesForCryoRequest");
		//searchBean.setNewQuery(true);
		searchBean.setSessionId(request.getSession().getId());
		searchBean.setRecordSetLength(5);
		Long id = null;
		if(request.getQueryString().contains("showSampleList")){
			id = ServletRequestUtils.getRequiredLongParameter(request, "id");
		}else{
			id = searchBean.getCryoRequestId();
		}
		Map<String, Object> model = new HashMap<String, Object>();
		ComponentMap requiredComponents = cryoRequestService.getComponentMapForHeaderFile();
		CryoRequest cryoRequest = cryoRequestService.fetchById(id, requiredComponents);
		
		Collection<SampleListView> samples = freezeDownSampleService.fetchSamplesByCryoRequestId(id, searchBean);
		Collection<ThawTest> thawTests = thawTestService.fetchAllByRequestId(id, ComponentMap.of(ThawTest.Component.ALL_COMPONENTS));
		boolean complete = cryoRequestService.isCompleteOK(id);
		boolean awaiting = cryoRequestService.isAwaitingOK(id);
		
		model.put("samples", samples);
		model.put("cryoRequest", cryoRequest);
		model.put("thawTests", thawTests);
		model.put("complete", complete);
		model.put("awaiting", awaiting);
		
		return model;
	}

	public void setCryoRequestService(CryoRequestService cryoRequestService) {
		this.cryoRequestService = cryoRequestService;
	}
	
}