/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.cryorequest.dao;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.util.Map;

import uk.ac.sanger.mig.charting.ChartData;
import uk.ac.sanger.mig.charting.DatabaseChartData;
import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.common.PaginatedSearchUtils;
import uk.ac.sanger.mig.cryoprocessing.ScheduledCryoPreservationJob;
import uk.ac.sanger.mig.cryorequest.CryoRequest;
import uk.ac.sanger.mig.cryorequest.CryoRequestSearchBean;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;

public class CryoRequestDaoSpringImpl extends AbstractDaoSpringImpl<CryoRequest> implements CryoRequestDao {

	private PaginatedSearchUtils<CryoRequest> paginator;


	public void setPaginator(PaginatedSearchUtils<CryoRequest> paginator) {
		this.paginator = paginator;
	}

	public ChartData fetchStatusChartData() {

		String sql = "select STATUS label, STATUS_DICT_ID extra_field, count(*) data0 " +
		"from crq_cryo_request_list_vw group by STATUS, STATUS_DICT_ID order by data0";

		DatabaseChartData data = new DatabaseChartData(1);
		getSimpleJdbcTemplate().query(sql, data);
		return data;
	}


	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, CryoRequest cryoRequest) {
		sql.addLongParam(cryoRequest.getRequesterId(), "REQUESTER_ID");
		sql.addLongParam(cryoRequest.getProjectLicenceId(), "PROJECT_LICENCE_ID");
		sql.addLongParam(cryoRequest.getColonyInfoId(), "COLONY_ID");
		sql.addLongParam(cryoRequest.getFemaleStrainDictId(), "FEMALE_STRAIN_DICT_ID");
		sql.addLongParam(cryoRequest.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(cryoRequest.getCreatedDate(), "CREATED_DATE");
		sql.addStringParam(cryoRequest.getEditedBy(), "EDITED_BY");
		sql.addDateParam(cryoRequest.getEditDate(), "EDIT_DATE");
		sql.addLongParam(cryoRequest.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(cryoRequest.getStatusDictId(), "STATUS_DICT_ID");
		sql.addLongParam(cryoRequest.getFundingSourceDictId(),"FUNDING_SOURCE_DICT_ID");
		sql.addIntParam(cryoRequest.getTargetNumber(), "target_count");
		sql.addStringParam(cryoRequest.getNumberThawed(), "number_thawed");
		sql.addStringParam(cryoRequest.getCancelReason(), "CANCEL_REASON");

		sql.addLongParam(cryoRequest.getId(), "ID");
	}

	public Collection<CryoRequest> fetch(CryoRequestSearchBean searchBean) {
		Collection<Object> bindVariables = new ArrayList<Object>();
		CryoRequest cryoRequest =  searchBean.getCryoRequest();
		StringBuffer sql = new StringBuffer();
		sql.append(" select * from crq_cryo_request c where 1=1 ");

		// search by status id
		if(cryoRequest.getStatusDictId() != null ) {
			sql.append(" and c.status_dict_id = ? ");
			bindVariables.add(cryoRequest.getStatusDictId());
		}

		if(searchBean.getOrderBy() != null && searchBean.getOrderBy().length() > 0) {
			sql.append(" order by " + searchBean.getOrderBy());
			if(searchBean.isOrderDesc()) {
				sql.append(" desc ");
			}
		}
		else {
			sql.append(" order by id ");
		}

		return paginator.fetchSearchResults(sql.toString(), bindVariables, searchBean, getRowMapper());
	}

	public CryoRequest fetchRequestByScheduledJobId(Long scheduledJobId) {

		return null;
	}

	public Long getMaxActiveStatusinJobs(Long cryoRequestId) {
		String sql ="select max(cryo_job_status_dict_id) from crq_scheduled_cryo_prv where " +
				"cryo_request_id = ? and cryo_job_status_dict_id !=?";
		Object[] bindVariables = new Object[2];
		bindVariables[0] = cryoRequestId;
		bindVariables[1] = ScheduledCryoPreservationJob.InternalStatus.CANCELLED.getId();
		Long result = getSimpleJdbcTemplate().queryForLong(sql, bindVariables);
		return result;
	}


	public Integer getTotalFrozen(Long cryoRequestId) {
		String sql = "select TOTAL_FROZEN from crq_cryo_request_list_vw where" +
				" id = ?";
		Integer result = getSimpleJdbcTemplate().queryForInt(sql, cryoRequestId);
		return (result == null) ? 0 : result;
	}



	public Collection<String> fetchAllSampleLocations(Long cryoRequestId) {

		String sql = "select distinct "+
						"freezer_name || ', Canister ' || " +
						"canister_name || ', Goblet ' || " +
						"goblet_name || ', Wedge ' || " +
						"wedge_colour as location_name " +
						"from crq_straw_sample_list_vw where request_id = ? " +
						"union " +
						"select distinct " +
						"freezer_name || ', Tower ' || "+
						"tower_name || ', Box ' || " +
						"box_name as location_name " +
						"from crq_vial_sample_list_vw where request_id = ? " +
						"order by location_name";
		Collection<String> uniqueLocations = new ArrayList<String>();

		Object[] args = new Object[2];
		args[0] = cryoRequestId;
		args[1] = cryoRequestId;

		if(cryoRequestId != null){
			List<Map<String, Object>> sampleLocations = new ArrayList<Map<String, Object>>(getSimpleJdbcTemplate().queryForList(sql, args));

			if(sampleLocations != null && sampleLocations.size() >0) {
				for(int i=0; i<sampleLocations.size();i++) {
					String temp = String.valueOf(sampleLocations.get(i).get("LOCATION_NAME"));
					uniqueLocations.add(temp);
				}
			}
		}

		return uniqueLocations;
	}

}

