/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.cryorequest.dao;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.common.PaginatedSearchUtils;
import uk.ac.sanger.mig.cryorequest.CryoRequest;
import uk.ac.sanger.mig.cryorequest.CryoRequestSearchBean;
import uk.ac.sanger.mig.cryorequest.views.CryoRequestListView;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;

public class CryoRequestListDaoSpringImpl extends AbstractDaoSpringImpl<CryoRequestListView> implements CryoRequestListDao {

	private PaginatedSearchUtils<CryoRequestListView> paginator;


	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, CryoRequestListView t) {

	}

	public void setPaginator(PaginatedSearchUtils<CryoRequestListView> paginator) {
		this.paginator = paginator;
	}

	public Collection<CryoRequestListView> fetch(CryoRequestSearchBean searchBean) {
		StringBuffer sql= new StringBuffer();
		sql.append(" select * from crq_cryo_request_list_vw c where 1=1 ");
		CryoRequest cryoRequest =  searchBean.getCryoRequest();
		Collection<Object> bindVariables = new ArrayList<Object>();

		if(cryoRequest.getStatusDictId() != null ) {
			sql.append(" and c.status_dict_id = ? ");
			bindVariables.add(cryoRequest.getStatusDictId());
		}
		if(searchBean.getColonyId()!=null){
			sql.append(" and c.colony_info_id=? ");
			bindVariables.add(searchBean.getColonyId());
		}
		if(searchBean.getStartRequestDate() != null){
			sql.append("and trunc(c.CREATED_DATE, 'DD') >= ? ");
			bindVariables.add(defaultDateFormat.format(searchBean.getStartRequestDate()));
		}

		if(searchBean.getEndRequestDate() != null ){
			sql.append("and trunc(c.CREATED_DATE, 'DD') <= ?  ");
			bindVariables.add(defaultDateFormat.format(searchBean.getEndRequestDate()));
		}

		if(searchBean.getFundingSource() != null) {
			sql.append(" and c.funding_source = ?");
			bindVariables.add(searchBean.getFundingSource());
		}

		if(searchBean.getOrderBy() != null && searchBean.getOrderBy().length() > 0) {
			sql.append(" order by " + searchBean.getOrderBy());

			if(searchBean.isOrderDesc()) {
				sql.append(" desc ");
			}
			sql.append(", id ");
		}
		else {
			sql.append(" order by id desc ");
		}

		return paginator.fetchSearchResults(sql.toString(), bindVariables, searchBean, getRowMapper());
	}

}

