/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.cryorequest.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.cryorequest.views.CryoRequestListView;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;

public class CryoRequestListViewRowMapper implements ParameterizedRowMapper<CryoRequestListView>{

	private DictionaryService dictionaryService;
	public CryoRequestListView mapRow(ResultSet rs, int rowNum) throws SQLException {

		CryoRequestListView cryoRequestListView = new CryoRequestListView();


		cryoRequestListView.setId(rs.getLong("ID"));
		cryoRequestListView.setStatus(rs.getString("STATUS"));
		cryoRequestListView.setColonyName(rs.getString("COLONY_NAME"));
		cryoRequestListView.setTeamNumber(rs.getInt("TEAM_NUMBER"));
		cryoRequestListView.setColonyPrefix(rs.getString("COLONY_PREFIX"));
		cryoRequestListView.setAppendedStrains(rs.getString("APPENDED_STRAINS"));
		cryoRequestListView.setAppendedAlleles(rs.getString("APPENDED_ALLELES"));
		cryoRequestListView.setAppendedHomozygousLethal(rs.getString("APPEND_HOMOZYGOUS_LETHAL"));
		cryoRequestListView.setFemaleStrain(rs.getString("FEMALE_STRAIN"));
		cryoRequestListView.setTotalPlugged(rs.getInt("TOTAL_PLUGGED"));
		cryoRequestListView.setTotalAttempts(rs.getInt("TOTAL_ATTEMPTS"));
		cryoRequestListView.setTotalSuperOvulated(rs.getInt("TOTAL_SUPEROVULATED"));
		cryoRequestListView.setTotalFrozen(rs.getInt("TOTAL_FROZEN"));
		cryoRequestListView.setFundingSource(rs.getString("FUNDING_SOURCE"));
		if(rs.getInt("TARGET_COUNT")!=0){
			cryoRequestListView.setTargetCount(Integer.toString(rs.getInt("TARGET_COUNT")));
		}else{
			cryoRequestListView.setTargetCount("Not Assigned");
		}
		cryoRequestListView.setRequestDate(rs.getDate("CREATED_DATE"));
		cryoRequestListView.setPersonId(rs.getLong("PERSON_ID"));
		cryoRequestListView.setRequesterName(rs.getString("REQUESTER_NAME"));
		cryoRequestListView.setColonyInfoId(rs.getLong("COLONY_INFO_ID"));
		cryoRequestListView.setCancelReason(rs.getString("CANCEL_REASON"));
		if(rs.wasNull()){
			cryoRequestListView.setCancelReason("");
		}
		cryoRequestListView.setStatusDict(dictionaryService.fetchEntry(DictionaryEnum.CRQ_CRYO_REQUEST_STATUS_DICT, rs.getLong("STATUS_DICT_ID")));
		//cryoRequestListView.setTotalSamplesThawed(rs.getInt("TOTAL_SAMPLES_THAWED"));
		return cryoRequestListView;
	}
	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}
}
