/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.cryorequest.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.cryorequest.CryoRequest;
import uk.ac.sanger.mig.cryorequest.services.CryoRequestService;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;

public class CryoRequestRowMapper implements ParameterizedRowMapper<CryoRequest> {

	private DictionaryService dictionaryService;
	private CryoRequestService cryoRequestService;

	public void setCryoRequestService(CryoRequestService cryoRequestService) {
		this.cryoRequestService = cryoRequestService;
	}

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	public CryoRequest mapRow(ResultSet rs, int rowNum) throws SQLException {

		CryoRequest cryoRequest = new CryoRequest();


		cryoRequest.setId(rs.getLong("ID"));

		cryoRequest.setRequesterId(rs.getLong("REQUESTER_ID"));

		if(rs.wasNull()) cryoRequest.setRequesterId(null);

		cryoRequest.setProjectLicenceId(rs.getLong("PROJECT_LICENCE_ID"));
		if(rs.wasNull()) cryoRequest.setProjectLicenceId(null);

		cryoRequest.setColonyInfoId(rs.getLong("COLONY_ID"));
		if(rs.wasNull()) cryoRequest.setColonyInfoId(null);

		cryoRequest.setFemaleStrainDictId(rs.getLong("FEMALE_STRAIN_DICT_ID"));
		if(rs.wasNull()) cryoRequest.setFemaleStrainDictId(null);
		cryoRequest.setFemaleStrain(dictionaryService.fetchEntry(DictionaryEnum.CRQ_CRYO_REQUEST_STRAIN_DICT, cryoRequest.getFemaleStrainDictId()));

		cryoRequest.setFundingSourceDictId(rs.getLong("FUNDING_SOURCE_DICT_ID"));
		if(rs.wasNull()) cryoRequest.setFundingSourceDictId(null);
		cryoRequest.setFundingSourceDict(dictionaryService.fetchEntry(DictionaryEnum.APP_FUNDING_SOURCE, cryoRequest.getFundingSourceDictId()));


		cryoRequest.setCreatorId(rs.getLong("CREATOR_ID"));
		if(rs.wasNull()) cryoRequest.setCreatorId(null);

		cryoRequest.setCreatedDate(rs.getTimestamp("CREATED_DATE"));

		cryoRequest.setEditedBy(rs.getString("EDITED_BY"));

		cryoRequest.setEditDate(rs.getTimestamp("EDIT_DATE"));

		cryoRequest.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) cryoRequest.setCheckNumber(null);

		cryoRequest.setStatusDictId(rs.getLong("STATUS_DICT_ID"));
		if(rs.wasNull()) cryoRequest.setStatusDictId(null);
		cryoRequest.setStatusDict(dictionaryService.fetchEntry(DictionaryEnum.CRQ_CRYO_REQUEST_STATUS_DICT, cryoRequest.getStatusDictId()));

		cryoRequest.setTargetNumber(rs.getInt("target_count"));
		if(rs.getInt("TARGET_COUNT")!=0){
			cryoRequest.setTargetNumber(rs.getInt("TARGET_COUNT"));
		}else{
			cryoRequest.setTargetNumber(null);
		}

		cryoRequest.setNumberThawed(rs.getString("number_thawed"));
		cryoRequest.setTotalFrozen(cryoRequestService.getTotalFrozen(cryoRequest.getId()));

		return cryoRequest;

	}
}