/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.cryorequest.validators;

import org.springframework.validation.Errors;
import org.springframework.validation.ValidationUtils;
import org.springframework.validation.Validator;

import uk.ac.sanger.mig.colony.ColonyInfo;
import uk.ac.sanger.mig.colony.services.ColonyInfoService;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.cryorequest.forms.CryoRequestForm;

public class CryoRequestFormValidator implements Validator {

	ColonyInfoService colonyInfoService;

	public void setColonyInfoService(ColonyInfoService colonyInfoService) {
		this.colonyInfoService = colonyInfoService;
	}

	public boolean supports(Class clazz) {
		return CryoRequestForm.class.equals(clazz);
	}

	public void validate(Object commandForm, Errors errors) {
		ValidationUtils.rejectIfEmptyOrWhitespace(errors,"cryoRequest.requesterId", null, "Requester is a required field");
		ValidationUtils.rejectIfEmptyOrWhitespace(errors,"cryoRequest.projectLicenceId",null, "Project Licence is a required field.");
		ValidationUtils.rejectIfEmptyOrWhitespace(errors,"cryoRequest.colonyInfoId", null, "Colony Name is a required field.");
		ValidationUtils.rejectIfEmptyOrWhitespace(errors,"cryoRequest.femaleStrainDictId", null, "Female Strain is a required field.");
		ValidationUtils.rejectIfEmptyOrWhitespace(errors,"cryoRequest.fundingSourceDictId", null, "Funding Source is a required field.");

		CryoRequestForm form = (CryoRequestForm)commandForm;
		Long colonyInfoId = form.getCryoRequest().getColonyInfoId();

		if(form.getCryoRequest().getTargetNumber()!=null && form.getCryoRequest().getTargetNumber()<0){
			errors.reject(null, "Target number cannot be negative");
		}
        //new request, allele information is required
		if(form.getCryoRequest().getId()==null && form.getCryoRequest().getColonyInfoId()!=null){
			ColonyInfo colonyInfo = colonyInfoService.fetchById(colonyInfoId, ComponentMap.of(ColonyInfo.Component.ALLELES));
			if(colonyInfo.getAlleles()==null||colonyInfo.getAlleles().size()==0){
				if(form.getModifiedAlleleId()==null){
					errors.reject(null,"The selected modified allele doesnt have allele associated. Please add allele to it.");
				}
			}

		}
	}

}