/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.cryorequest.views;

import java.util.Date;

import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.common.DictionaryEntryEnum;

public class CryoRequestListView extends AuthenticatedDataObject implements Comparable {


	private String requesterName;
	private String status;
	private Integer teamNumber;
	private String colonyName;
	private String colonyPrefix;
	private String appendedStrains;
	private String appendedAlleles;
	private String appendedHomozygousLethal;
	private String femaleStrain;
	private Integer totalPlugged;
	private Integer totalSuperOvulated;
	private Integer totalAttempts;
	private Integer totalFrozen;
	private String targetCount;
	private Date requestDate;
	private Long personId;
	private Long colonyInfoId;
	private DictionaryEntry statusDict;
	private Integer totalSamplesThawed;
	private String cancelReason;
	private String fundingSource;

	public enum RequestStatusEnum implements DictionaryEntryEnum {
		REQUESTED(11L ),  //system driven
		RESCHEULE_NEEDED(14L ), //system driven
		FREEZING_IN_PROCESS(13L ),  //system driven
		COMPLETED(15L ), //user driven
		CANCELLED(16L ), //user driven
		SCHEDULED(12L), //system driven
		AWAITING_TEST_THRAW(17L), //system driven
		THAW_TEST_COMPLETED_AWAITING_BIRTH(18L); //system driven

		private Long dictionaryId;

		RequestStatusEnum(Long dictId) {
			this.dictionaryId = dictId;
		}

		public Long getId() {
			return dictionaryId;
		}
	}

	public Long getColonyInfoId() {
		return colonyInfoId;
	}

	public void setColonyInfoId(Long colonyInfoId) {
		this.colonyInfoId = colonyInfoId;
	}

	public Date getRequestDate() {
		return requestDate;
	}

	public void setRequestDate(Date requestDate) {
		this.requestDate = requestDate;
	}

	public int compareTo(Object arg0) {
		// TODO Auto-generated method stub
		return 0;
	}

	public String getAppendedAlleles() {
		return appendedAlleles;
	}

	public void setAppendedAlleles(String appendedAlleles) {
		this.appendedAlleles = appendedAlleles;
	}

	public String getAppendedHomozygousLethal() {
		return appendedHomozygousLethal;
	}

	public void setAppendedHomozygousLethal(String appendedHomozygousLethal) {
		this.appendedHomozygousLethal = appendedHomozygousLethal;
	}

	public String getAppendedStrains() {
		return appendedStrains;
	}

	public void setAppendedStrains(String appendedStrains) {
		this.appendedStrains = appendedStrains;
	}

	public String getColonyName() {
		return colonyName;
	}

	public void setColonyName(String colonyName) {
		this.colonyName = colonyName;
	}

	public String getColonyPrefix() {
		return colonyPrefix;
	}

	public void setColonyPrefix(String colonyPrefix) {
		this.colonyPrefix = colonyPrefix;
	}

	public String getFemaleStrain() {
		return femaleStrain;
	}

	public void setFemaleStrain(String femaleStrain) {
		this.femaleStrain = femaleStrain;
	}

	public String getRequesterName() {
		return requesterName;
	}

	public void setRequesterName(String requesterName) {
		this.requesterName = requesterName;
	}

	public String getTargetCount() {
		return targetCount;
	}

	public void setTargetCount(String targetCount) {
		this.targetCount = targetCount;
	}

	public Integer getTeamNumber() {
		return teamNumber;
	}

	public void setTeamNumber(Integer teamNumber) {
		this.teamNumber = teamNumber;
	}

	public Integer getTotalAttempts() {
		return totalAttempts;
	}

	public void setTotalAttempts(Integer totalAttempts) {
		this.totalAttempts = totalAttempts;
	}

	public Integer getTotalFrozen() {
		return totalFrozen;
	}

	public void setTotalFrozen(Integer totalFrozen) {
		this.totalFrozen = totalFrozen;
	}

	public Integer getTotalPlugged() {
		return totalPlugged;
	}

	public void setTotalPlugged(Integer totalPlugged) {
		this.totalPlugged = totalPlugged;
	}

	public Integer getTotalSuperOvulated() {
		return totalSuperOvulated;
	}

	public void setTotalSuperOvulated(Integer totalSuperOvulated) {
		this.totalSuperOvulated = totalSuperOvulated;
	}

	public String getStatus() {
		return status;
	}

	public void setStatus(String status) {
		this.status = status;
	}

	public Long getPersonId() {
		return personId;
	}

	public void setPersonId(Long personId) {
		this.personId = personId;
	}


	public boolean isRequest() {
		return  (statusDict.getId() == RequestStatusEnum.REQUESTED.getId());
	}

	public boolean isInProcess() {
		return  (statusDict.getId() == RequestStatusEnum.FREEZING_IN_PROCESS.getId());
	}

	public boolean isAwaitingThawTest() {
		return (statusDict.getId() == RequestStatusEnum.AWAITING_TEST_THRAW.getId());
	}

	public boolean isThawTestCompleted() {
		return (statusDict.getId() == RequestStatusEnum.THAW_TEST_COMPLETED_AWAITING_BIRTH.getId());
	}

	public boolean isScheduled() {
		return  (statusDict.getId() == RequestStatusEnum.SCHEDULED.getId());
	}

	public boolean isRescheduleNeeded() {
		return  (statusDict.getId() == RequestStatusEnum.RESCHEULE_NEEDED.getId());
	}

	public boolean isCompleted(){
		return  (statusDict.getId() == RequestStatusEnum.COMPLETED.getId());
	}

	public boolean isCancelled(){
		return  (statusDict.getId() == RequestStatusEnum.CANCELLED.getId());
	}

	public DictionaryEntry getStatusDict() {
		return statusDict;
	}

	public void setStatusDict(DictionaryEntry statusDict) {
		this.statusDict = statusDict;
	}


	public Integer getTotalSamplesThawed() {
		return totalSamplesThawed;
	}

	public void setTotalSamplesThawed(Integer totalSamplesThawed) {
		this.totalSamplesThawed = totalSamplesThawed;
	}

	public String getCancelReason() {
		return cancelReason;
	}

	public void setCancelReason(String cancelReason) {
		this.cancelReason = cancelReason;
	}

	public String getFundingSource() {
		return fundingSource;
	}

	public void setFundingSource(String fundingSource) {
		this.fundingSource = fundingSource;
	}

}
