/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.customquery.controllers;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang.StringUtils;
import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.SimpleFormController;

import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.customquery.CustomQuery;
import uk.ac.sanger.mig.customquery.CustomQueryColumn;
import uk.ac.sanger.mig.customquery.forms.CustomQueryColumnPrefsForm;
import uk.ac.sanger.mig.customquery.services.CustomQueryColumnService;
import uk.ac.sanger.mig.customquery.services.CustomQueryService;
import uk.ac.sanger.mig.personnel.Person;

public class EditCustomQueryColumnPrefsFormController extends SimpleFormController {

	CustomQueryColumnService customQueryColumnService;
	CustomQueryService customQueryService;

	public void setCustomQueryService(CustomQueryService customQueryService) {
		this.customQueryService = customQueryService;
	}

	public void setCustomQueryColumnService(
			CustomQueryColumnService customQueryColumnService) {
		this.customQueryColumnService = customQueryColumnService;
	}



	@Override
	protected Object formBackingObject(HttpServletRequest request) throws Exception {
		CustomQueryColumnPrefsForm form = (CustomQueryColumnPrefsForm)createCommand();

		RequestUtils.setLastReferer(request);

		Long customQueryId = ServletRequestUtils.getLongParameter(request, "customQueryId");
		String uniqueName = ServletRequestUtils.getStringParameter(request, "uniqueName");

		Person user = RequestUtils.getUser(request);
		form.setPersonId(user.getId());

		if(StringUtils.isNotEmpty(uniqueName)) {
			CustomQuery cqTemp = customQueryService.fetchByUniqueName(uniqueName, user.getId(), null);
			customQueryId = cqTemp.getId();
		}

		form.setCustomQueryId(customQueryId);

		return form;
	}

	@Override
	protected ModelAndView processFormSubmission(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		CustomQueryColumnPrefsForm form = (CustomQueryColumnPrefsForm)command;

		customQueryColumnService.storePersonPreferences(form);

		String x = RequestUtils.getLastReferer(request);

		return new ModelAndView("redirect:" + x);
	}

	@Override
	protected Map referenceData(HttpServletRequest request, Object command, Errors errors) throws Exception {
		CustomQueryColumnPrefsForm form = (CustomQueryColumnPrefsForm)command;
		Map<String, Object> referenceData = new HashMap<String, Object>();

		Collection<CustomQueryColumn> currentColumns =
			customQueryColumnService.fetchCurrent(form.getCustomQueryId(), form.getPersonId());

		Collection<CustomQueryColumn> availableColumns =
			customQueryColumnService.fetchAvailable(form.getCustomQueryId(), form.getPersonId());

		if(currentColumns.isEmpty()) {
			referenceData.put("currentColumns", availableColumns);
			referenceData.put("availableColumns", currentColumns);
		}
		else {
			referenceData.put("currentColumns", currentColumns);
			referenceData.put("availableColumns", availableColumns);
		}

		referenceData.put("person", RequestUtils.getUser(request));

		return referenceData;
	}
}
