/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.customquery.dao;

import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.customquery.CustomQueryAction;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;


public class CustomQueryActionDaoSpringImpl extends AbstractDaoSpringImpl<CustomQueryAction> implements CustomQueryActionDao {

	public Collection<CustomQueryAction> fetchByCustomQueryId(Long customQueryId) {
		String sql = " select * from APP_CUSTOM_QUERY_ACTION where custom_query_id = ? order by order_by ";
		return fetchCollection(sql, customQueryId);
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, CustomQueryAction customQueryAction) {
		sql.addStringParam(customQueryAction.getPermittedRoles(),"PERMITTED_ROLES");
		sql.addLongParam(customQueryAction.getCustomQueryId(), "CUSTOM_QUERY_ID");
		sql.addStringParam(customQueryAction.getActionTitle(), "ACTION_TITLE");
		sql.addStringParam(customQueryAction.getActionUrl(), "ACTION_URL");
		sql.addStringParam(customQueryAction.getActionParam(), "ACTION_PARAM");
		sql.addIntParam(customQueryAction.getOrderBy(), "ORDER_BY");
		sql.addStringParam(customQueryAction.getHrefTarget(), "HREF_TARGET");
		sql.addStringParam(customQueryAction.getConditionalTest(), "CONDITIONAL");
		sql.addStringParam(customQueryAction.getConditionalValue(), "CONDITIONAL_VALUE");
		sql.addStringParam(customQueryAction.getQueryParam(), "QUERY_PARAM");
		sql.addLongParam(customQueryAction.getId(), "ID");

	}

}