package uk.ac.sanger.mig.customquery.dao;

import java.util.ArrayList;
import java.util.Collection;

import org.springframework.dao.IncorrectResultSizeDataAccessException;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.customquery.CustomQueryColumn;
import uk.ac.sanger.mig.customquery.CustomQueryColumnValidValue;
import uk.ac.sanger.mig.customquery.dao.rowmappers.CustomQueryColumnValidValueRowMapper;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;

public class CustomQueryColumnDaoSpringImpl extends AbstractDaoSpringImpl<CustomQueryColumn> implements CustomQueryColumnDao {

	private CustomQueryColumnValidValueRowMapper validValueRowMapper;

	public void setValidValueRowMapper(
			CustomQueryColumnValidValueRowMapper validValueRowMapper) {
		this.validValueRowMapper = validValueRowMapper;
	}

	public CustomQueryColumn fetchByName(Long queryId, String columnName) {
		String sql = " select * from app_custom_query_column where custom_query_id = ? and lower(column_name) = lower(?) ";

		CustomQueryColumn column = null;

		try {
			column = getSimpleJdbcTemplate().queryForObject(sql, getRowMapper(), queryId, columnName);
		}
		catch(IncorrectResultSizeDataAccessException e) {

		}

		return column;
	}

	public Collection<CustomQueryColumn> fetchColumnPrefsByQueryId(Long queryId, Long personId) {
		String sql = " select * from app_custom_query_col_pref_vw where custom_query_id = ? and person_id = ? and is_display_column = 1 order by order_by ";

		Collection<CustomQueryColumn> columns = getSimpleJdbcTemplate().query(sql, getRowMapper(), queryId, personId);

		return (columns == null) ? new ArrayList<CustomQueryColumn>() : columns;
	}

	public Collection<CustomQueryColumn> fetchCurrent(Long queryId, Long personId) {
		String sql = " select c.* from app_custom_query_column c, app_custom_query_person_pref p where c.id = p.query_column_id and c.custom_query_id = ? and p.person_id = ? order by p.order_by ";

		Collection<CustomQueryColumn> columns = getSimpleJdbcTemplate().query(sql, getRowMapper(), queryId, personId);

		return (columns == null) ? new ArrayList<CustomQueryColumn>() : columns;
	}

	public Collection<CustomQueryColumn> fetchAvailable(Long queryId, Long personId) {
		String sql = " select c.* from app_custom_query_column c where c.custom_query_id = ? and is_display_column = 1 and not exists (select null from app_custom_query_person_pref p where c.id = p.query_column_id and p.person_id = ?) order by c.order_by ";

		Collection<CustomQueryColumn> columns = getSimpleJdbcTemplate().query(sql, getRowMapper(), queryId, personId);

		return (columns == null) ? new ArrayList<CustomQueryColumn>() : columns;
	}

	public Collection<CustomQueryColumn> fetchFilterable(Long queryId) {
		String sql = " select c.* from app_custom_query_column c, app_custom_query q where q.id = c.custom_query_id and q.id = ? and is_filter_column = 1 order by lower(column_title) ";

		Collection<CustomQueryColumn> columns = getSimpleJdbcTemplate().query(sql, getRowMapper(), queryId);

		return (columns == null) ? new ArrayList<CustomQueryColumn>() : columns;
	}

	public int deleteCurrent(Long queryId, Long personId) {
		String sql = " delete app_custom_query_person_pref where person_id = ? and query_column_id in (select id from app_custom_query_column where custom_query_id = ? )";

		return getSimpleJdbcTemplate().update(sql, personId, queryId);
	}

	public int insertNew(Long queryId, Long personId, int orderBy) {
		String sql = " insert into app_custom_query_person_pref(person_id, query_column_id, order_by) values (?,?,?)";

		return getSimpleJdbcTemplate().update(sql, personId, queryId, orderBy);
	}

	public Collection<CustomQueryColumnValidValue> fetchValidValues(CustomQueryColumn column) {
		Collection<CustomQueryColumnValidValue> validValues = null;

		if(column.getListQuery() != null) {
			String sql = column.getListQuery();

			validValues = getSimpleJdbcTemplate().query(sql, validValueRowMapper);
		}

		return (validValues == null) ? new ArrayList<CustomQueryColumnValidValue>() : validValues;
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, CustomQueryColumn t) {
		//not implemented. currently read-only
	}
}