package uk.ac.sanger.mig.customquery.dao;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Map;

import org.apache.commons.lang.StringUtils;
import org.apache.commons.lang.math.NumberUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.common.PaginatedSearchBean;
import uk.ac.sanger.mig.common.PaginatedSearchUtils;
import uk.ac.sanger.mig.common.Pair;
import uk.ac.sanger.mig.customquery.CustomQuery;
import uk.ac.sanger.mig.customquery.CustomQueryColumn;
import uk.ac.sanger.mig.customquery.CustomQueryColumnDatatype;
import uk.ac.sanger.mig.customquery.forms.CustomQueryFieldCondition;
import uk.ac.sanger.mig.customquery.forms.CustomQueryForm;
import uk.ac.sanger.mig.customquery.forms.CustomQueryFormFilter;
import uk.ac.sanger.mig.customquery.forms.CustomQueryFormSort;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;

public class CustomQueryDaoSpringImpl extends AbstractDaoSpringImpl<CustomQuery> implements CustomQueryDao {

	private PaginatedSearchUtils<Map<String, Object>> paginator;
	private static SimpleDateFormat sdf = new SimpleDateFormat("dd-MMM-yyyy");

	private Log logger = LogFactory.getLog(CustomQueryDaoSpringImpl.class);

	public void setPaginator(PaginatedSearchUtils<Map<String, Object>> paginator) {
		this.paginator = paginator;
	}

	public Collection<Map<String, Object>> executeCustomQuery(String sql, Collection<Object> bindVariables, PaginatedSearchBean searchBean) {
		Collection<Map<String, Object>> results = paginator.fetchSearchResults(sql, bindVariables, searchBean);

		return results;
	}

	public Collection<CustomQuery> fetchCustomQueries() {
		String sql = " select * from app_custom_query_vw where system_query != 1 order by category, query_title ";
		return fetchCollection(sql);
	}

	public CustomQuery fetchByUniqueName(String uniqueName) {
		String sql = " select * from app_custom_query_vw where unique_name = ? ";
		return fetchOne(sql, uniqueName);
	}

	public Pair<String, Collection<Object>> generateSQL(CustomQueryForm form) {

		if(form == null || form.getCustomQueryId() == null) {
			throw new IllegalArgumentException("CustomQueryForm cannot be null and must contain non-null customQueryId");
		}

		CustomQuery customQuery = fetchById(form.getCustomQueryId());

		String sql = " select cq.* from " + customQuery.getQueryViewName() + " cq ";
		String sqlOrderBy = " order by ";
		Collection<Object> bindVariables = new ArrayList<Object>();

		String andOrMode = (form.isOrMode()) ? " or " : " and ";

		boolean firstWhereCondition = true;
		if(form.getFilters() != null) {
			for(CustomQueryFormFilter filter : form.getFilters()) {
				if(filter.getFieldName() != null) {
					CustomQueryColumn queryColumn = filter.getColumn();
					String fieldName = "";

					String prefix = "cq.";

					if(StringUtils.isNotEmpty(queryColumn.getActualQueryColumn())) {
						fieldName = queryColumn.getActualQueryColumn();
					}
					else {
						fieldName = queryColumn.getColumnName();
					}

					if(fieldName.indexOf(".") == -1) {
						fieldName = prefix + fieldName;
					}

					// truncate fieldname to remove time element
					if(CustomQueryColumnDatatype.DATE.equals(queryColumn.getDatatype())) {
						fieldName = "trunc(" + fieldName + ")";
					}

					String whereSql = "";
					if(firstWhereCondition) {
						whereSql += " where ";
					}
					else {
						whereSql += andOrMode;
					}
					whereSql += "(";

					if(queryColumn.getDatatype().equals(CustomQueryColumnDatatype.EXISTS)) {
						whereSql += " exists (" + queryColumn.getDatatypeFormat() + "(";
					}

					int loopIndex = 0;
					boolean validCondition = false;
					String conditionString = "";
					for(CustomQueryFieldCondition fieldFilter : filter.getConditions()) {

						if(loopIndex > 0) {
							conditionString += " or ";
						}
						loopIndex++;

						String testValue = (fieldFilter.getTestValue() == null) ? null : fieldFilter.getTestValue().toString();
						String testValue2 = (fieldFilter.getTestValue2() == null) ? null : fieldFilter.getTestValue2().toString();
						boolean negativeQualifier = fieldFilter.isNegativeQualifier();

						switch (fieldFilter.getComparator()) {
						case EQUALS:
							if(StringUtils.isNotEmpty(testValue)) {

								validCondition = true;

								if(NumberUtils.isNumber(testValue)) {
									conditionString += fieldName + " " + ((negativeQualifier) ? "!" : "") + "= ? ";
								}
								else if(isDate(testValue)) {
									conditionString += fieldName + " " + ((negativeQualifier) ? "!" : "") + "= ? ";
								}
								else {
									conditionString += " lower(" + fieldName + ") " + ((negativeQualifier) ? "!" : "") + "= lower(?) ";
								}
								bindVariables.add(testValue);
							}
							break;

						case CONTAINS:
							if(StringUtils.isNotEmpty(testValue)) {

								validCondition = true;

								conditionString += " lower(" + fieldName + ") " + ((negativeQualifier) ? "not" : "") + " like lower('%'||?||'%') ";
								bindVariables.add(testValue);
							}
							break;

						case STARTS_WITH:
							if(StringUtils.isNotEmpty(testValue)) {

								validCondition = true;

								conditionString += " lower(" + fieldName + ") " + ((negativeQualifier) ? "not" : "") + " like lower(?||'%') ";
								bindVariables.add(testValue);
							}
							break;

						case GREATER:
							if(StringUtils.isNotEmpty(testValue)) {

								validCondition = true;

								conditionString += fieldName + ((negativeQualifier) ? " <= " : " > ") + "?";
								bindVariables.add(testValue);
							}
							break;

						case LESS:
							if(StringUtils.isNotEmpty(testValue)) {

								validCondition = true;

								conditionString += fieldName + ((negativeQualifier) ? " >= " : " < ") + "?";
								bindVariables.add(testValue);
							}
							break;

						case NULL:

							validCondition = true;

							conditionString += fieldName + " is " + ((negativeQualifier) ? "not" : "") + " null ";
							break;


						case BETWEEN:
							if(StringUtils.isNotEmpty(testValue) && StringUtils.isNotEmpty(testValue2)) {

								validCondition = true;

								conditionString += fieldName + ((negativeQualifier) ? "not" : "") + " between ? and ? ";
								bindVariables.add(testValue);
								bindVariables.add(testValue2);
							}
							break;

						case IN:
							if(StringUtils.isNotEmpty(testValue)) {

								String[] testValues = testValue.split("[\\s,;]+");
								if(testValues.length > 0) {
									validCondition = true;

									conditionString += " lower(" + fieldName + ") " + ((negativeQualifier) ? "not" : "") + " in (";
									int tempIndex = 0;
									for(String value : testValues) {
										conditionString += (tempIndex++ == 0) ? "lower(?)" : ",lower(?)";
										value = value.trim();
										bindVariables.add(value);
										if(tempIndex == 1000) break; //limit in values to 1000 (max SQL limit for IN statement)
									}
									conditionString += ")";
								}
							}
							break;

						}
					}

					if(validCondition) {
						firstWhereCondition = false;
						sql += whereSql + conditionString;

						if(queryColumn.getDatatype().equals(CustomQueryColumnDatatype.EXISTS)) {
							sql += ") ) ";
						}

						sql += ") ";
					}
				}
			}
		}

		if(form.getSorts() != null) {
			boolean hasSortColumn = false;
			for(CustomQueryFormSort sort : form.getSorts()) {
				if(sort.getFieldName() != null) {
					hasSortColumn = true;
					sqlOrderBy += sort.getFieldName();

					if(sort.isDescending()) {
						sqlOrderBy += " desc ";
					}

					if(sort.isNullsFirst()) {
						sqlOrderBy += " nulls first ";
					}
					else {
						sqlOrderBy += " nulls last ";
					}

					sqlOrderBy += ",";
				}
			}

			if(hasSortColumn) {
				sqlOrderBy = sqlOrderBy.substring(0, sqlOrderBy.length()-1);
				sql += sqlOrderBy;
			}
		}

		Pair<String, Collection<Object>> generatedSql = new Pair<String, Collection<Object>>(sql, bindVariables);

		logger.debug(sql);
		logger.debug(bindVariables);

		return generatedSql;
	}

	private boolean isDate(String testValue) {
		try {
			sdf.parse(testValue);
		}
		catch (ParseException e) {
			return false;
		}
		return true;
	}

	public Collection<Long> fetchLastSelectionIds(String sessionId, String queryName) {
		return paginator.fetchSelectedIds(sessionId, queryName);
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, CustomQuery t) {
		//not implemented. currently read-only
	}
}
