package uk.ac.sanger.mig.customquery.forms;

import java.util.ArrayList;
import java.util.List;

import org.apache.commons.collections15.FactoryUtils;
import org.apache.commons.collections15.ListUtils;
import org.apache.commons.lang.StringUtils;

import uk.ac.sanger.mig.common.PaginatedSearchBean;

public class CustomQueryForm extends PaginatedSearchBean {

	private List<CustomQueryFormFilter> filters;
	private List<CustomQueryFormSort> sorts;
	private Long customQueryId;
	private String uniqueName;
	private boolean excel;
	private String changeForm;
	private String changeFormValue;
	private Long personId;
	private String modelKey;
	private boolean orMode;

	public CustomQueryForm(Long customQueryId, Long personId, String modelKey) {
		this();
		this.personId = personId;
		this.setPaginated(false);
		this.customQueryId = customQueryId;
		this.modelKey = modelKey;
	}

	public CustomQueryForm() {
		//make the filters and sorts a lazy list so they can be dynamically extended
		setFilters(ListUtils.lazyList(new ArrayList<CustomQueryFormFilter>(), FactoryUtils.instantiateFactory(CustomQueryFormFilter.class)));

		setSorts(ListUtils.lazyList(new ArrayList<CustomQueryFormSort>(), FactoryUtils.instantiateFactory(CustomQueryFormSort.class)));

	}

	public void addSort(CustomQueryFormSort sort) {
		sorts.add(sort);
	}

	public void addFilter(CustomQueryFormFilter filter) {
		boolean alreadyExists = false;
		for(CustomQueryFormFilter existingFilter : filters) {
			if(StringUtils.equals(filter.getFieldName(),existingFilter.getFieldName())) {
				existingFilter.getConditions().add(new CustomQueryFieldCondition());
				alreadyExists = true;
				break;
			}
		}

		// have to do this outside the loop as collection can't be modified while iterating over it.
		if(!alreadyExists) {
			filters.add(filter);
		}
	}

	public void removeFilter(int fieldIndex, int conditionIndex) {
		CustomQueryFormFilter filter = filters.get(fieldIndex);

		//remove condition, then if filter has no remaining conditions, remove filter
		filter.getConditions().remove(conditionIndex);
		if(filter.getConditions().size() == 0) {
			filters.remove(fieldIndex);
		}
	}

	public void removeSort(int sortIndex) {
		sorts.remove(sortIndex);
	}

	public List<CustomQueryFormFilter> getFilters() {
		return filters;
	}

	private void setFilters(List<CustomQueryFormFilter> filters) {
		this.filters = filters;
	}

	public List<CustomQueryFormSort> getSorts() {
		return sorts;
	}

	private void setSorts(List<CustomQueryFormSort> sorts) {
		this.sorts = sorts;
	}

	public Long getCustomQueryId() {
		return customQueryId;
	}

	public void setCustomQueryId(Long customQueryId) {
		this.customQueryId = customQueryId;
	}

	public boolean isExcel() {
		return excel;
	}

	public void setExcel(boolean excelView) {
		this.excel = excelView;
	}

	public String getChangeForm() {
		return changeForm;
	}

	public void setChangeForm(String changeForm) {
		this.changeForm = changeForm;
	}

	public Long getPersonId() {
		return personId;
	}

	public void setPersonId(Long personId) {
		this.personId = personId;
	}

	public String getModelKey() {
		return modelKey;
	}

	public void setModelKey(String instanceName) {
		this.modelKey = instanceName;
	}

	public String getChangeFormValue() {
		return changeFormValue;
	}

	public void setChangeFormValue(String changeFormValue) {
		this.changeFormValue = changeFormValue;
	}

	public boolean isOrMode() {
		return orMode;
	}

	public void setOrMode(boolean orMode) {
		this.orMode = orMode;
	}

	public String getUniqueName() {
		return uniqueName;
	}

	public void setUniqueName(String uniqueName) {
		this.uniqueName = uniqueName;
	}

}
