package uk.ac.sanger.mig.customquery.services;

import java.util.Collection;

import org.springframework.transaction.annotation.Transactional;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.customquery.CustomQueryColumn;
import uk.ac.sanger.mig.customquery.CustomQueryColumnValidValue;
import uk.ac.sanger.mig.customquery.dao.CustomQueryColumnDao;
import uk.ac.sanger.mig.customquery.forms.CustomQueryColumnPrefsForm;

public class CustomQueryColumnServiceImpl extends AbstractServiceImpl<CustomQueryColumn> implements CustomQueryColumnService {

	private CustomQueryColumnDao customQueryColumnDao;

	public void setCustomQueryColumnDao(CustomQueryColumnDao customQueryColumnDao) {
		this.customQueryColumnDao = customQueryColumnDao;
	}

	public Collection<CustomQueryColumn> fetchColumnPrefsByQueryId(Long queryId, Long personId, ComponentMap requiredComponents) {
		Collection<CustomQueryColumn> columns = customQueryColumnDao.fetchColumnPrefsByQueryId(queryId, personId);
		attachComponents(columns, requiredComponents);
		return columns;
	}

	public CustomQueryColumn fetchById(Long columnId, ComponentMap requiredComponents) {
		CustomQueryColumn column = customQueryColumnDao.fetchById(columnId);
		if(column != null) {
			attachComponents(column, requiredComponents);
		}
		return column;
	}

	public CustomQueryColumn fetchByName(Long queryId, String columnName, ComponentMap requiredComponents) {
		CustomQueryColumn column = customQueryColumnDao.fetchByName(queryId, columnName);
		if(column != null) {
			attachComponents(column, requiredComponents);
		}
		return column;
	}

	public Collection<CustomQueryColumn> fetchCurrent(Long queryId, Long personId) {
		return customQueryColumnDao.fetchCurrent(queryId, personId);
	}

	public Collection<CustomQueryColumn> fetchAvailable(Long queryId, Long personId) {
		return customQueryColumnDao.fetchAvailable(queryId, personId);
	}

	public Collection<CustomQueryColumn> fetchFilterable(Long queryId, ComponentMap requiredComponents) {
		Collection<CustomQueryColumn> columns =  customQueryColumnDao.fetchFilterable(queryId);
		attachComponents(columns, requiredComponents);
		return columns;
	}

	@Transactional
	public void storePersonPreferences(CustomQueryColumnPrefsForm form) {
		customQueryColumnDao.deleteCurrent(form.getCustomQueryId(), form.getPersonId());
		if(form.getCurrentColumns() != null) {
			int orderBy = 1;
			for(Long columnId : form.getCurrentColumns()) {
				customQueryColumnDao.insertNew(columnId, form.getPersonId(), orderBy++);
			}
		}
	}

	@Override
	protected void attachComponents(CustomQueryColumn customQueryColumn, ComponentMap requiredComponents) {
		if(customQueryColumn == null) {
			throw new RuntimeException("Cannot attach components to null customQueryColumn");
		}

		boolean fetchAll = false;

		if(requiredComponents != null) {

			if(requiredComponents.containsKey(CustomQueryColumn.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}

			if(fetchAll || requiredComponents.containsKey(CustomQueryColumn.Component.VALID_VALUES)) {
				customQueryColumn.setValidValues(fetchValidValues(customQueryColumn));
			}
		}

	}

	private Collection<CustomQueryColumnValidValue> fetchValidValues(CustomQueryColumn customQueryColumn) {
		if(customQueryColumn.getListQuery() == null) {
			return null;
		}
		else {
			return customQueryColumnDao.fetchValidValues(customQueryColumn);
		}
	}

}
