package uk.ac.sanger.mig.customquery.services;

import java.util.Collection;
import java.util.Map;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.customquery.CustomQuery;
import uk.ac.sanger.mig.customquery.forms.CustomQueryFilterEnum;
import uk.ac.sanger.mig.customquery.forms.CustomQueryForm;
import uk.ac.sanger.mig.customquery.forms.CustomQueryFormFilter;

public interface CustomQueryService {

	public CustomQuery fetchById(Long queryId);

	public CustomQuery fetchById(Long queryId, Long personId, ComponentMap requiredComponents);

	/**
	 * Return a Map containing a single CustomQuery object with populated Results map.
	 *
	 * If the form.modelKey is not specified, then the key will be "customQuery" otherwise the key will be the value of modelKey.
	 *
	 * @param form must contain non-null customQueryId and personId values.
	 * @return Map containing a single CustomQuery object with populated Results map.
	 */
	public Map<String, Object> fetchCustomQueryModel(CustomQueryForm form);

	public Collection<CustomQuery> fetchCustomQueries(ComponentMap requiredComponents);

	/**
	 * Contruct and return a CustomQueryFormFilter object having retrieved the CustomQueryColumn from the database
	 * based on the input columnName
	 *
	 * @param queryId
	 * @param columnName name of the CustomQueryColumn to be used with the form filter.
	 * @param negativeQualifier
	 * @param comparator
	 * @param testValue
	 * @return new CustomQueryFormFilter object.
	 */
	public CustomQueryFormFilter constructFormFilter(Long queryId, String columnName, boolean negativeQualifier, CustomQueryFilterEnum comparator, Object testValue);

	/**
	 * Return the last selected records (Primary Keys) for a custom query
	 * @param sessionId
	 * @return
	 */
	public Collection<Long> fetchLastSelection(Long customQueryId, String sessionId);

	/**
	 * Return the queryName for a paginated search
	 * @param customQueryId
	 * @return
	 */
	public String fetchQueryName(Long customQueryId);

	public CustomQuery fetchByUniqueName(String uniqueName, Long personId, ComponentMap requiredComponents);
}