/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.database;

import java.sql.Connection;
import java.sql.SQLException;

import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.sql.DataSource;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * MigDatabaseImpl implements the MigDatabase interface using JNDI to connect to a pooled datasource
 * 
 */
public class MigDatabaseImpl implements MigDatabase {
	
	private static final Log logger = LogFactory.getLog(MigDatabaseImpl.class);
	
	private DataSource dataSource;	
	
	public void setDataSource(DataSource dataSource) {
		this.dataSource = dataSource;
	}
	
	/**
	 * 
	 * @param lookupName - the JDNI lookup reference e.g. java:comp/env/jdbc/mig
	 * @throws MigDatabaseException
	 */
	public MigDatabaseImpl(String lookupName) throws MigDatabaseException {		
		
		try {
			Context initialContext = (Context)new InitialContext();		
			dataSource = (DataSource)initialContext.lookup(lookupName);
		}
		catch(NamingException e) {
			logger.error(e);
			throw new MigDatabaseException(e);
		}
	}
	
	
	/**
	 * @see MigDatabase#getConnection()
	 */
	public Connection getConnection() throws MigDatabaseException {
		try {
			return dataSource.getConnection();
		}
		catch(SQLException e) {
			throw new MigDatabaseException(e);
		}
	}	
	
	public Connection getTransactionConnection() throws MigDatabaseException {
		try {
			Connection connection = dataSource.getConnection();
			connection.setAutoCommit(false);
			return connection;
		}
		catch(SQLException e) {
			throw new MigDatabaseException(e);
		}
	}
	
	public void closeTransactionConnection(Connection connection) throws MigDatabaseException {
		try {
			connection.setAutoCommit(true);
			connection.close();
			
		} catch (SQLException e) {
			throw new MigDatabaseException(e);
		}
	}
}
