/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.database;

import java.sql.Blob;
import java.sql.Types;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Date;
import java.util.List;


public class ParameterizedSqlQuery {
	
	private List<Integer>parametersType = new ArrayList<Integer>();
	private Collection<Object> parameters = new ArrayList<Object>();

	public void addByteArrayParam(byte[] param) {
		parametersType.add(Types.ARRAY);
		parameters.add(param);
	}	
	
	public void addBlobParam(Blob param) {
		parametersType.add(Types.BLOB);
		parameters.add(param);
	}
	
	public void addClobParam(String param) {
		parametersType.add(Types.CLOB);
		parameters.add(param);
	}

	public void addStringParam(String param) {
		parametersType.add(Types.VARCHAR);
		parameters.add(param);
	}

	public void addIntParam(Integer param) {
		parametersType.add(Types.NUMERIC);
		parameters.add(param);
	}	

	public void addIntegerParam(Integer param) {
		parametersType.add(Types.NUMERIC);
		parameters.add(param);
	}	
	
	public void addFloatParam(Float param) {
		parametersType.add(Types.NUMERIC);
		parameters.add(param);
	}		

	public void addDoubleParam(Double param) {
		parametersType.add(Types.NUMERIC);
		parameters.add(param);
	}
	
	public void addBooleanParam(Boolean param) {
		parametersType.add(Types.NUMERIC);
		parameters.add(param);
	}	
	
	public void addLongParam(Long param) {
		parametersType.add(Types.NUMERIC);
		parameters.add(param);
	}	
	
	public void addDateParam(Date param) {
		parametersType.add(Types.TIMESTAMP);
		parameters.add(param);		
	}

	public Object[] getParameters() {
		return parameters.toArray();
	}

	public int[] getParametersType() {
		int[] returnArray = new int[parametersType.size()];
		for(int i=0;i<parametersType.size();i++){
			returnArray[i] = parametersType.get(i);
		}
		return returnArray;
	}

}
