/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.designrequest;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.ComponentEnum;
import uk.ac.sanger.mig.eucomm.designinstance.DesignInstance;


public class Design extends AuthenticatedDataObject implements Comparable<Design> {
 
  private String designName;
  private Long designId;
  private String wellLoc;
  private String exonName;
  private String plate;
  private String geneBuildName;
  private String geneBuildVersion;
  private String eucommStatus;
  private Collection<Long> featureStarts;
  private Collection<Long> featureEnds;
  private Collection<String> featureTypes;
  private Collection<String> featureSequences;
  private Collection<String> designNotesTypes;
  private Collection<String> designNotes;
  private Collection<Long> featureLengths;
  private Collection<DesignInstance> designInstances;
  
  
  public enum Component implements ComponentEnum {
    ALL_COMPONENTS,
    DESIGN_INSTANCES
    //add additional component enums here as needed for this AuthenticatedDataObject
}

  public Collection<Long> getFeatureLengths() {
    return featureLengths;
  }

  public void setFeatureLengths(Collection<Long> featureLengths) {
    this.featureLengths = featureLengths;
  }

  public Design(){
    featureStarts = new ArrayList<Long>();
    featureTypes = new ArrayList<String>();
    featureEnds = new ArrayList<Long>();
    featureSequences= new ArrayList<String>();
    featureLengths = new ArrayList<Long>();
    designNotes = new ArrayList<String>();
    designNotesTypes = new ArrayList<String>();
  }
  
  public String getDesignName() {
    return designName;
  }
  public void setDesignName(String designName) {
    this.designName = designName;
  }
  public String getExonName() {
    return exonName;
  }
  public void setExonName(String exonName) {
    this.exonName = exonName;
  }
  public Collection<Long> getFeatureEnds() {
    return featureEnds;
  }
  public void setFeatureEnds(Collection<Long> featureEnd) {
    this.featureEnds = featureEnd;
  }
  public Collection<String> getFeatureSequences() {
    return featureSequences;
  }
  public void setFeatureSequences(Collection<String> featureSequences) {
    this.featureSequences = featureSequences;
  }
  public Collection<Long> getFeatureStarts() {
    return featureStarts;
  }
  public void setFeatureStarts(Collection<Long> featureStarts) {
    this.featureStarts = featureStarts;
  }
  public Collection<String> getFeatureTypes() {
    return featureTypes;
  }
  public void setFeatureTypes(Collection<String> featureTypes) {
    this.featureTypes = featureTypes;
  }
  public String getWellLoc() {
    return wellLoc;
  }
  public void setWellLoc(String wellLoc) {
    this.wellLoc = wellLoc;
  }

  public String getPlate() {
    return plate;
  }

  public void setPlate(String plate) {
    this.plate = plate;
  }

  public int compareTo(Design o) {
    
    return 0;
  }

  public Long getDesignId() {
    return designId;
  }

  public void setDesignId(Long designId) {
    this.designId = designId;
  }

  public Collection<String> getDesignNotes() {
    return designNotes;
  }

  public void setDesignNotes(Collection<String> designNotes) {
    this.designNotes = designNotes;
  }

  public Collection<String> getDesignNotesTypes() {
    return designNotesTypes;
  }

  public void setDesignNotesTypes(Collection<String> designNotesTypes) {
    this.designNotesTypes = designNotesTypes;
  }


  public String getEucommStatus() {
    return eucommStatus;
  }

  public void setEucommStatus(String eucommStatus) {
    this.eucommStatus = eucommStatus;
  }


  public String getGeneBuildName() {
    return geneBuildName;
  }

  public void setGeneBuildName(String geneBuildName) {
    this.geneBuildName = geneBuildName;
  }

  public String getGeneBuildVersion() {
    return geneBuildVersion;
  }

  public void setGeneBuildVersion(String geneBuildVersion) {
    this.geneBuildVersion = geneBuildVersion;
  }

  public void setDesignInstances(Collection<DesignInstance> designInstances) {
    this.designInstances = designInstances;
  }

  public Collection<DesignInstance> getDesignInstances() {
    return designInstances;
  }

}
