/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.designrequest;


import java.util.List;

import uk.ac.sanger.mig.allelerequest.AlleleRequest;
import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.ComponentEnum;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.gene.Build;
import uk.ac.sanger.mig.gene.BuildGene;
import uk.ac.sanger.mig.gene.Exon;


public class DesignRequest extends AuthenticatedDataObject implements Comparable<DesignRequest> {
       
  private Long alleleRequestId;
  private AlleleRequest alleleRequest;
  private String comments;        
  private String editedBy;
  private String vegaId;
  private String ensemblId;
  private String buildName;
  private Build build; 
  private BuildGene buildGene;
  private Exon startExon;
  private Exon endExon;
  private Integer targetStart;
  private Integer targetEnd;
  private Integer min5pExonFlanks;
  private Integer min3pExonFlanks;
  private Integer splitTargetSeqLength;
  private Integer multiRegionOffsetShim;
  private Integer primerLength;
  private Integer retrievalPrimerOffset5p;
  private Integer retrievalPrimerOffset3p;
  private Integer retrievalPrimerLength5p;
  private Integer retrievalPrimerLength3p;
  private Integer score;
  
  private Long statusDictId;
  private DictionaryEntry status;
  private List<Design> designs;
  
  public enum Component implements ComponentEnum {
    ALL_COMPONENTS,
    ALLELE_REQUEST
    //add additional component enums here as needed for this AuthenticatedDataObject
  }

  
  public Long getAlleleRequestId() {
    return alleleRequestId;
  }

  public void setAlleleRequestId(Long alleleRequestId) {
    this.alleleRequestId = alleleRequestId;
  }

  public Long getStatusDictId() {
    return statusDictId;
  }

  public void setStatusDictId(Long statusDictId) {
    this.statusDictId = statusDictId;
  }

  public DictionaryEntry getStatus() {
    return status;
  }

  public void setStatus(DictionaryEntry status) {
    this.status = status;
  }

  public AlleleRequest getAlleleRequest() {
    return alleleRequest;
  }
    
  public void setAlleleRequest(AlleleRequest alleleRequest) {
    this.alleleRequest = alleleRequest;
  }             
    
  public String getComments() {
    return comments;
  }
    
  public void setComments(String comments) {
    this.comments = comments;
  }                                                                                                                                            

  public String getEditedBy() {
    return editedBy;
  }
    
  public void setEditedBy(String editedBy) {
    this.editedBy = editedBy;
  }

  public int compareTo(DesignRequest a) {
    DesignRequest b = this;

    if (a.getId() < b.getId()) {
      return 1;
    }
    if (a.getId() > b.getId()) {
      return -1;
    }
    return 0;
  }

  public String getVegaId() {
    return vegaId;
  }

  public void setVegaId(String vegaId) {
    this.vegaId = vegaId;
  }

  public String getEnsemblId() {
    return ensemblId;
  }

  public void setEnsemblId(String ensemblId) {
    this.ensemblId = ensemblId;
  }

  public String getBuildName() {
    return buildName;
  }

  public void setBuildName(String buildName) {
    this.buildName = buildName;
  }

  public void setDesigns(List<Design> designs) {
    this.designs = designs;
  }

  public List<Design> getDesigns() {
    return designs;
  }

  public Exon getEndExon() {
    return endExon;
  }

  public void setEndExon(Exon endExon) {
    this.endExon = endExon;
  }

  public Build getBuild() {
    return build;
  }

  public void setBuild(Build build) {
    this.build = build;
  }

  public BuildGene getBuildGene() {
    return buildGene;
  }

  public void setBuildGene(BuildGene buildGene) {
    this.buildGene = buildGene;
  }

  public Integer getMin3pExonFlanks() {
    return min3pExonFlanks;
  }

  public void setMin3pExonFlanks(Integer min3pExonFlanks) {
    this.min3pExonFlanks = min3pExonFlanks;
  }

  public Integer getMin5pExonFlanks() {
    return min5pExonFlanks;
  }

  public void setMin5pExonFlanks(Integer min5pExonFlanks) {
    this.min5pExonFlanks = min5pExonFlanks;
  }

  public Integer getMultiRegionOffsetShim() {
    return multiRegionOffsetShim;
  }

  public void setMultiRegionOffsetShim(Integer multiRegionOffsetShim) {
    this.multiRegionOffsetShim = multiRegionOffsetShim;
  }

  public Integer getPrimerLength() {
    return primerLength;
  }

  public void setPrimerLength(Integer primerLength) {
    this.primerLength = primerLength;
  }

  public Integer getRetrievalPrimerLength5p() {
    return retrievalPrimerLength5p;
  }

  public void setRetrievalPrimerLength5p(Integer retrievalPrimerLength5p) {
    this.retrievalPrimerLength5p = retrievalPrimerLength5p;
  }

  public Integer getRetrievalPrimerLength3p() {
    return retrievalPrimerLength3p;
  }

  public void setRetrievalPrimerLength3p(Integer retrievalPrimerLength3p) {
    this.retrievalPrimerLength3p = retrievalPrimerLength3p;
  }

  public Integer getRetrievalPrimerOffset5p() {
    return retrievalPrimerOffset5p;
  }

  public void setRetrievalPrimerOffset5p(Integer retrievalPrimerOffset5p) {
    this.retrievalPrimerOffset5p = retrievalPrimerOffset5p;
  }

  public Integer getRetrievalPrimerOffset3p() {
    return retrievalPrimerOffset3p;
  }

  public void setRetrievalPrimerOffset3p(Integer retrievalPrimerOffset3p) {
    this.retrievalPrimerOffset3p = retrievalPrimerOffset3p;
  }

  public Integer getSplitTargetSeqLength() {
    return splitTargetSeqLength;
  }

  public void setSplitTargetSeqLength(Integer splitTargetSeqLength) {
    this.splitTargetSeqLength = splitTargetSeqLength;
  }

  public Exon getStartExon() {
    return startExon;
  }

  public void setStartExon(Exon startExon) {
    this.startExon = startExon;
  }

  public Integer getTargetEnd() {
    return targetEnd;
  }

  public void setTargetEnd(Integer targetEnd) {
    this.targetEnd = targetEnd;
  }

  public Integer getTargetStart() {
    return targetStart;
  }

  public void setTargetStart(Integer targetStart) {
    this.targetStart = targetStart;
  }

  public Integer getScore() {
    return score;
  }

  public void setScore(Integer score) {
    this.score = score;
  }

}
