/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.designrequest.controllers;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.bind.ServletRequestBindingException;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.CancellableFormController;

import uk.ac.sanger.mig.allelerequest.AlleleRequest;
import uk.ac.sanger.mig.allelerequest.dao.AlleleRequestDao;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.database.DictionaryDao;
import uk.ac.sanger.mig.designrequest.DesignRequest;
import uk.ac.sanger.mig.designrequest.DesignSearchBean;
import uk.ac.sanger.mig.designrequest.dao.DesignDesignRequestListDao;
import uk.ac.sanger.mig.designrequest.forms.DesignRequestForm;
import uk.ac.sanger.mig.designrequest.services.DesignRequestFormService;
import uk.ac.sanger.mig.designrequest.services.DesignRequestService;
import uk.ac.sanger.mig.designrequest.views.DesignDesignRequestListView;
import uk.ac.sanger.mig.gene.BuildGene;
import uk.ac.sanger.mig.havanarequest.HavanaRequest;
import uk.ac.sanger.mig.personnel.Person;

public class DesignRequestFormController extends CancellableFormController{

  private DictionaryDao dictionaryDao;
  private DesignRequestService designRequestService;
  private DesignDesignRequestListDao designDesignRequestListDao;
  private AlleleRequestDao<AlleleRequest> alleleRequestDao;
  private DesignRequestFormService designRequestFormService;
  private String successViewToHavana;
  private String successViewToDesignList;
  
  public String getSuccessViewToDesignList() {
    return successViewToDesignList;
  }

  public void setSuccessViewToDesignList(String successViewToDesignList) {
    this.successViewToDesignList = successViewToDesignList;
  }

  public String getSuccessViewToHavana() {
    return successViewToHavana;
  }

  public void setSuccessViewToHavana(String successViewToHavana) {
    this.successViewToHavana = successViewToHavana;
  }

  public void setDictionaryDao(DictionaryDao dictionaryDao) {
    this.dictionaryDao = dictionaryDao;
  }
  
  public void setDesignRequestService(DesignRequestService designRequestService) {
    this.designRequestService = designRequestService;
  }
  
  

  @Override
  protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, Object command, BindException arg3) throws Exception {  
    
    DesignRequestForm form = (DesignRequestForm) command;
    DesignRequest designRequest = form.getDesignRequest();    
    DesignDesignRequestListView[] designListViews = form.getDesignListViews();
    Person person = RequestUtils.getUser(request);
    designDesignRequestListDao.storeAuthenticated(designRequest,designListViews, person);
    
    if(designRequest.getStatus().getId().longValue() != form.getInitialStatusId()) {
      // Set the allele request status to match the design request and store
      AlleleRequest alleleRequest = designRequest.getAlleleRequest();
      alleleRequest.setStatus(designRequest.getStatus());  
      alleleRequestDao.storeAuthenticated(alleleRequest, person);
    }
    
    
    if(form.getReferrer()!=null && form.getReferrer().equalsIgnoreCase("editHavanaRequest")){
      return new ModelAndView(getSuccessViewToHavana()+"?retrieveFromSession=true&newQuery=false&bypassForm=true&currentRecordId=" + form.getHavanaIdOfReferrerPage()+"&id="+form.getHavanaIdOfReferrerPage());
     }else if(form.getReferrer()!=null && form.getReferrer().equalsIgnoreCase("listDesignRequest")){
            return new ModelAndView(getSuccessViewToDesignList()+"?retrieveFromSession=true&newQuery=false&bypassForm=true&currentRecordId=" + designRequest.getId());
     }
    //return to default success view if none of the above condition is true
    return new ModelAndView(getSuccessView()+"?retrieveFromSession=true&newQuery=false&bypassForm=true&currentRecordId=" + designRequest.getId());
  }
  
  /**
   * Populate drop-down select-lists with dictionary values
   */
  
  @Override
  protected Map referenceData(HttpServletRequest request, Object command, Errors errors) throws Exception {
    Map<String, Object> referenceData = new HashMap<String,Object>();
    
    //Request Status
    Collection statuses = dictionaryDao.fetchDictionaryByTableName("ARQ_DESIGN_REQ_STATUS_DICT_VW", false);
    referenceData.put("statuses", statuses);  
    
    DesignRequestForm form = (DesignRequestForm)command;
    
      if(form.getDesignListViews().length>1)
        referenceData.put("hasDesigns",1);
      else { 
        if(form.getDesignListViews()[0].getDesignId()==null || form.getDesignListViews()[0].getDesignId()==0 )
            referenceData.put("hasDesigns",0);
        else
          referenceData.put("hasDesigns",1);
      }
    return referenceData;
    
  }
  
  @Override
  
  protected boolean isFormChangeRequest(HttpServletRequest request) {
    String geneBuildSelected=null;
    try {
      geneBuildSelected = ServletRequestUtils.getRequiredStringParameter(request, "changeForm");
    } catch (ServletRequestBindingException e) {
      e.printStackTrace();
    }
    
    if(geneBuildSelected!=null && geneBuildSelected.length()>0){
      return true;      
    }else{
      return false;
    }
      
  }
  
  @Override
  protected void onFormChange(HttpServletRequest request, HttpServletResponse response, Object command) throws Exception {
    
    String geneBuildSelected = ServletRequestUtils.getRequiredStringParameter(request, "changeForm");
    if(geneBuildSelected.equals("yes")){
      DesignRequestForm form = (DesignRequestForm)command;
      Long designRequestId = ServletRequestUtils.getRequiredLongParameter(request, "id");
      logger.debug("des req id = "+designRequestId);
      Long geneBuildId = ServletRequestUtils.getRequiredLongParameter(request, "IdGeneBuild");
      logger.debug("Gene build Id = "+ geneBuildId);
      Collection<BuildGene> elements = designRequestFormService.fetchByBuild(geneBuildId, designRequestId, ComponentMap.of(BuildGene.Component.ALL_COMPONENTS));
      if(elements.size()==1){
        if(form.getDesignRequest()!=null){
          form.getDesignRequest().setBuildGene((BuildGene)elements.toArray()[0]);
        }
      }
        
    }
    
  }
  
  
  @Override
  protected Object formBackingObject(HttpServletRequest httpServletRequest) throws Exception {
    //
    
    String referrer =ServletRequestUtils.getStringParameter(httpServletRequest, "referrer");
    String havanaId = ServletRequestUtils.getStringParameter(httpServletRequest, "havanaId");

    DesignRequestForm form = (DesignRequestForm)createCommand();
    form.setReferrer(referrer);
    if(havanaId!=null){
      form.setHavanaIdOfReferrerPage(havanaId);
    }

    Long id = ServletRequestUtils.getLongParameter(httpServletRequest, "id");
    ComponentMap designRequestComponentMap = new ComponentMap();
    ComponentMap alleleRequestComponentMap = new ComponentMap();
    ComponentMap havanaRequestComponentMap = new ComponentMap();
    
    havanaRequestComponentMap.put(HavanaRequest.Component.ALL_COMPONENTS, null);
    alleleRequestComponentMap.put(AlleleRequest.Component.ALL_COMPONENTS, null);
    alleleRequestComponentMap.put(AlleleRequest.Component.HAVANA_REQUEST, havanaRequestComponentMap);
    designRequestComponentMap.put(DesignRequest.Component.ALL_COMPONENTS, null);
    designRequestComponentMap.put(DesignRequest.Component.ALLELE_REQUEST, alleleRequestComponentMap);
    
    
    DesignRequest designRequest = designRequestService.fetchById(id, designRequestComponentMap);
    
    if(designRequest == null) {
      designRequest = buildNewDesignRequest();
    }
    
    form.setDesignRequest(designRequest);
    DesignSearchBean searchBean = new DesignSearchBean(form.getDesignRequest());
    Collection<DesignDesignRequestListView> results = designDesignRequestListDao.search(searchBean);
    DesignDesignRequestListView[] views = new DesignDesignRequestListView[results.size()];
    int i=0;
    
    for(DesignDesignRequestListView view: results){
       views[i]=view;     
       i++;
    }
    form.setDesignListViews(views);
    // this is used to compare if the status changes during editing of form.
    form.setInitialStatusId(designRequest.getStatus().getId().longValue());
    
    return form;
  }
  
  /**
   * If it's a new form, return to the main menu, otherwise return to the list of allele requests
   */
  @Override
  protected ModelAndView onCancel(HttpServletRequest request, HttpServletResponse response, Object command) throws Exception {
    DesignRequestForm form = (DesignRequestForm) command;
    DesignRequest designRequest = form.getDesignRequest();    
    if(form.getReferrer()!=null && form.getReferrer().equalsIgnoreCase("editHavanaRequest")){
      return new ModelAndView(getSuccessViewToHavana()+"?retrieveFromSession=true&newQuery=false&bypassForm=true&currentRecordId=" + form.getHavanaIdOfReferrerPage()+"&id="+form.getHavanaIdOfReferrerPage());
     }else if(form.getReferrer()!=null && form.getReferrer().equalsIgnoreCase("listDesignRequest")){
            return new ModelAndView(getSuccessViewToDesignList()+"?retrieveFromSession=true&newQuery=false&bypassForm=true&currentRecordId=" + designRequest.getId());
     }
    // return to default cancel view if none of the above condition is true
    return new ModelAndView(getCancelView()+"?retrieveFromSession=true&newQuery=false&bypassForm=true&currentRecordId=" + designRequest.getId());
  }
  
  private DesignRequest buildNewDesignRequest() {
    DesignRequest designRequest = new DesignRequest();
    designRequest.setStatus(new DictionaryEntry(0L));
    designRequest.setAlleleRequest(new AlleleRequest());
    
    return designRequest;
  }

  public DesignDesignRequestListDao getDesignDesignRequestListDao() {
    return designDesignRequestListDao;
  }


  public void setDesignDesignRequestListDao(DesignDesignRequestListDao designListDao) {
    this.designDesignRequestListDao = designListDao;
  }

  public AlleleRequestDao<AlleleRequest> getAlleleRequestDao() {
    return alleleRequestDao;
  }

  public void setAlleleRequestDao(AlleleRequestDao<AlleleRequest> alleleRequestDao) {
    this.alleleRequestDao = alleleRequestDao;
  }
  @Override
  protected void onBind(HttpServletRequest request, Object command, BindException errors) throws Exception {
    super.onBind(request, command, errors);
    DesignRequestForm form = (DesignRequestForm)command;
    Integer i=1;
    for(DesignDesignRequestListView view: form.getDesignListViews()){
      if(request.getParameter(i.toString())!=null){
        view.setFulfillsRequest(true);
      }else{
        view.setFulfillsRequest(false);
      }
      i++;
    }
  }

  public DesignRequestFormService getDesignRequestFormService() {
    return designRequestFormService;
  }

  public void setDesignRequestFormService(
      DesignRequestFormService designRequestFormService) {
    this.designRequestFormService = designRequestFormService;
  }

  public DesignRequestService getDesignRequestService() {
    return designRequestService;
  }

}
