/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.designrequest.controllers;


import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.ParameterizableViewController;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.designrequest.Design;
import uk.ac.sanger.mig.designrequest.services.DesignService;
import uk.ac.sanger.mig.eucomm.designinstance.DesignInstance;
import uk.ac.sanger.mig.eucomm.designinstancebac.DesignInstanceBac;

public class ViewOneDesignController extends ParameterizableViewController {


  private DesignService designService;
  
  public void setDesignService(DesignService designService) {
    this.designService = designService;
  }
  
  protected ModelAndView handleRequestInternal(HttpServletRequest request, HttpServletResponse response) throws Exception {

    Map<String,Object> model = new HashMap<String,Object>();
    Long id = ServletRequestUtils.getRequiredLongParameter(request,"id");
    
    Design design = null;//designDao.fetchById(id);

    ComponentMap designInstanceBacComponents = new ComponentMap(DesignInstanceBac.Component.ALL_COMPONENTS, null);
    ComponentMap designInstanceComponents = new ComponentMap(DesignInstance.Component.ALL_COMPONENTS, null);
    ComponentMap designComponents = new ComponentMap(Design.Component.ALL_COMPONENTS, null);
    designInstanceComponents.put(DesignInstance.Component.DESIGN_INSTANCE_BACS, designInstanceBacComponents);
    
    designComponents.put(Design.Component.DESIGN_INSTANCES,  designInstanceComponents);
    design = (Design) designService.fetchById(id, designComponents);     
    
    model.put("plate",design.getPlate());
    model.put("designInstances", design.getDesignInstances());
    model.put("countDesignInstances", design.getDesignInstances().size());
    model.put("wellLoc", design.getWellLoc());
    model.put("exonName", design.getExonName());
    model.put("designName", design.getDesignName());
    model.put("geneBuildName", design.getGeneBuildName());
    model.put("geneBuildVersion", design.getGeneBuildVersion());
    model.put("eucommStatus", design.getEucommStatus());   
    model.put("featureStarts", design.getFeatureStarts());
    model.put("featureEnds", design.getFeatureEnds());
    model.put("featureTypes", design.getFeatureTypes());
    model.put("featureSequences", design.getFeatureSequences());
    model.put("designNoteTypes",design.getDesignNotesTypes());
    model.put("designNotes",design.getDesignNotes());
    model.put("countDesignNotes",design.getDesignNotes().size());
    model.put("countValidatedFeatures", design.getFeatureStarts().size());
    model.put("featureLengths",design.getFeatureLengths());
    
    return new ModelAndView(getViewName(),"model",model);   
  }
}
