/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.designrequest.dao;


import java.math.BigDecimal;
import java.sql.Clob;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.util.Map;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.LongRowMapper;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.designrequest.Design;
import uk.ac.sanger.mig.designrequest.views.DesignDataListView;


public class DesignDaoSpringImpl extends AbstractDaoSpringImpl<Design> implements DesignDao {

  private DesignDataListViewRowMapper designDataListViewRowMapper;

  public Design fetchById(Long id) {

    Collection<Object> bindVariables = new ArrayList<Object>();

    bindVariables.add(id);
    Design design = new Design();
    List<Map<String,Object>>designdatalist = new ArrayList<Map<String,Object>>();

    String sql = "select * from arq_design_data_view where design_id = ?";

    Collection<DesignDataListView> designDataList = getSimpleJdbcTemplate().query(
        sql.toString(), designDataListViewRowMapper, bindVariables.toArray());

    if (designDataList != null && designDataList.size() != 0) {
      Clob c;

      for (DesignDataListView designData: designDataList) {
        design.setDesignId(designData.getDesignId());
        design.setPlate(
            designData.getPlate() == null ? "" : designData.getPlate());
        design.setGeneBuildName(
            designData.getGeneBuildName() == null
                ? ""
                : designData.getGeneBuildName());
        design.setGeneBuildVersion(
            designData.getGeneBuildVersion() == null
                ? ""
                : designData.getGeneBuildVersion());
        design.setExonName(
            designData.getExonName() == null ? "" : designData.getExonName());
        design.setDesignName(
            designData.getDesignName() == null
                ? ""
                : designData.getDesignName().toString());
        design.setWellLoc(
            designData.getWellLoc() == null
                ? ""
                : designData.getWellLoc().toString());
        design.setEucommStatus(
            designData.getEucommStatus() == null
                ? ""
                : designData.getEucommStatus());
        c = (Clob) designData.getFeatureSequence();
        String seq = "";

        try {
          seq = c.getSubString(1, (int) c.length());
        } catch (SQLException e) {
          logger.warn(e);
        }
        design.getFeatureEnds().add(
            designData.getFeatureEnd() == null ? 0 : designData.getFeatureEnd());
        design.getFeatureSequences().add(seq == null ? "" : seq);
        design.getFeatureStarts().add(
            designData.getFeatureStart() == null
                ? 0
                : designData.getFeatureStart());
        design.getFeatureTypes().add(
            designData.getFeatureType() == null
                ? ""
                : designData.getFeatureType());
        long length = seq != null ? seq.length() : 0;

        design.getFeatureLengths().add(length);
      }
    } else {
      //if the data is not in the view (cases when it does not have validated features), user might still
     // be interested in viewing basic minimum information
     //	get the basic minimum fields about the design from the query below

      Long[] args = new Long[1];

      args[0] = id;
      sql = "select d.design_id as design_id, d.design_name as design_name, d.final_plate as plate, d.well_loc as well_loc, dsd.description as eucomm_status, ge.primary_name as exon_name, "
          + "gb.name as gene_build_name, gb.version as version from eucomm_vector.design d, gnm_exon ge, gnm_gene_build gb, eucomm_vector.design_status ds, eucomm_vector.design_status_dict dsd "
          + " where d.gene_build_id = gb.id(+) and d.design_id = ds.design_id(+) and (ds.is_current=1 or ds.is_current is null) and "
          + " ds.design_status_id = dsd.design_status_id(+) and  (d.locus_id = ge.locus_id or d.start_exon_id = ge.id) and d.design_id = ?";
      try {
        designdatalist = (List<Map<String,Object>>) getSimpleJdbcTemplate().queryForList(sql,(Object[])args);
      } catch (Exception e) {
        logger.warn(e);
      }
      for (Map designdata: designdatalist) {
        design.setDesignId(
            ((BigDecimal) designdata.get("design_id")).longValue());
        design.setDesignName(
            designdata.get("design_name") != null
                ? designdata.get("design_name").toString()
                : "");
        design.setWellLoc(
            designdata.get("well_loc") != null
                ? designdata.get("well_loc").toString()
                : "");
        design.setPlate(
            designdata.get("plate") != null
                ? designdata.get("plate").toString()
                : "");
        design.setExonName(
            designdata.get("exon_name") != null
                ? designdata.get("exon_name").toString()
                : "");
        design.setGeneBuildName(
            designdata.get("gene_build_name") != null
                ? designdata.get("gene_build_name").toString()
                : "");
        design.setGeneBuildVersion(
            designdata.get("gene_build_version") != null
                ? designdata.get("gene_build_version").toString()
                : "");
        design.setEucommStatus(
            designdata.get("eucomm_status") != null
                ? designdata.get("eucomm_status").toString()
                : "");
      }
    }
    // Finally - Populate design pojo with design notes
    // get the design notes information from desig_note table
    //this table gets information during design creation process when
    //data about design run is periodically stored at various stages during run of a design
    // from havana edit interface

    sql = "select description, note from eucomm_vector.design_note, eucomm_vector.design_note_type_dict where "
        + " eucomm_vector.design_note.design_note_type_id = eucomm_vector.design_note_type_dict.design_note_type_id "
        + " and design_id = ? order by design_note_id";
    try {
      designdatalist = (List<Map<String,Object>>) getSimpleJdbcTemplate().queryForList(sql, id);
    } catch (Exception e) {
      logger.warn(e);
    }

    for (Map designNoteData: designdatalist) {
      design.getDesignNotesTypes().add(
          designNoteData.get("description") != null
              ? designNoteData.get("description").toString()
              : "");
      design.getDesignNotes().add(
          designNoteData.get("note") != null
              ? designNoteData.get("note").toString()
              : "");
    }

    return design;
  }

  public Collection fetchAll() {
    return null;
  }

  public DesignDataListViewRowMapper getDesignDataListViewRowMapper() {
    return designDataListViewRowMapper;
  }

  public void setDesignDataListViewRowMapper(
      DesignDataListViewRowMapper designListViewRowMapper) {
    this.designDataListViewRowMapper = designListViewRowMapper;
  }

  public Collection<Long> fetchDesignInstanceIds(Long designId) {

    Collection<Long> designInstanceIds = new ArrayList<Long>();
    String sql = "select design_instance.design_instance_id return_long from eucomm_vector.design_instance where"
        + " design_id = ?";

    designInstanceIds = getSimpleJdbcTemplate().query(sql, new LongRowMapper(),
        designId);
    return (designInstanceIds == null)
        ? new ArrayList<Long>()
        : designInstanceIds;
  }

  public Long fetchStatusId(Long designId) {

    String sql = "select design_status.design_status_id from eucomm_vector.design, eucomm_vector.design_status where "
        + " design.design_id = design_status.design_id and design_status.is_current=1 and "
        + "design_status_dict.design_status_id = design_status.design_status_id and design.design_id = ?";
    Long statusId = getSimpleJdbcTemplate().queryForLong(sql, designId);

    return statusId;
  }

  @Override
  protected void bindVariables(ParameterizedSqlUpdate sql, Design t) {// TODO Auto-generated method stub
  }

}
