/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.designrequest.dao;

/**
 * The dao to pull data which will be shown in the edit havana request page
 * The columns shown are: Design table fields (design, Design Status), Allele Request,
 * and design request table fields (Score, Comments, Fulfills Request,
 * Promoter inclusion, Conserved Element, Critical exon contains ATG, possible reinitiation, no NMD)
 *
 */

import java.util.ArrayList;
import java.util.Collection;
import java.util.Date;

import org.springframework.jdbc.object.SqlUpdate;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.designrequest.DesignRequest;
import uk.ac.sanger.mig.designrequest.DesignSearchBean;
import uk.ac.sanger.mig.designrequest.views.DesignDesignRequestListView;
import uk.ac.sanger.mig.personnel.Person;

public class DesignDesignRequestListDaoSpringImpl extends AbstractDaoSpringImpl<DesignDesignRequestListView> implements DesignDesignRequestListDao {

  private DesignDesignRequestListViewRowMapper designDesignRequestDataListViewRowMapper;

  /*
   * Called from DesignRequstFormController, while accessing a design request
   * @see uk.ac.sanger.mig.designrequest.dao.DesignDesignRequestListDao#search(uk.ac.sanger.mig.designrequest.DesignSearchBean)
   */
  public Collection<DesignDesignRequestListView> search(DesignSearchBean searchBean) {

    Collection<Object> bindVariables = new ArrayList<Object>();

    StringBuffer sql = new StringBuffer();

    sql.append(
        "SELECT d.*, aaq.ID AS allele_request_id, adr.ID AS designrequestid, " +
        "adr.promoter_inclusion, adr.conserved_elements, " +
        "adr.possible_reinitiation, adr.no_nmd_induced, "
            + "d2d.fulfills_request, adr.comments AS designrequestcomments, adr.critical_exon_contains_atg, "
            + "adr.score, dsd.description, dp.parameter_name, ge.primary_name "
            + "FROM arq_allele_request aaq, " + "arq_design_request adr, "
            + "arq_design_2_design_request d2d, " + "eucomm_vector.design d, "
            + "eucomm_vector.design_status ds, "
            + "eucomm_vector.design_status_dict dsd, "
            + "eucomm_vector.design_parameter dp, " + "gnm_exon ge "
            + "WHERE aaq.id = adr.ALLELE_REQUEST_ID "
            + "and adr.id = d2d.DESIGN_REQUEST_ID(+) "
            + "and d2d.DESIGN_ID = d.design_id(+) "
            + "AND d.design_id = ds.design_id(+) "
            + "AND ds.design_status_id = dsd.design_status_id(+) "
            + "AND (ds.is_current = 1 OR ds.is_current IS NULL) "
            + "and d.start_exon_id = ge.id(+) "
            + "AND d.design_parameter_id = dp.design_parameter_id(+) ");

    // search by alleleRequest id

    if (searchBean.getDesignRequestId() != null
        && searchBean.getDesignRequestId() != 0) {
      sql.append(" and adr.id = ? ");
      bindVariables.add(searchBean.getDesignRequest().getId());
    }
    sql.append("order by adr.id");



    Collection<DesignDesignRequestListView> designLists = getSimpleJdbcTemplate().query(
        sql.toString(), designDesignRequestDataListViewRowMapper, bindVariables.toArray());


    return (designLists == null) ? new ArrayList<DesignDesignRequestListView>() : designLists;

  }
  /*
   * returns the same collection as the previous method, but is called from edit havana interface (HavanaRequestController)
   *
   * (non-Javadoc)
   * @see uk.ac.sanger.mig.designrequest.dao.DesignDesignRequestListDao#search(java.lang.Long)
   */
  public Collection<DesignDesignRequestListView> search(Long alleleRequestId) {

    Collection<Object> bindVariables = new ArrayList<Object>();

    StringBuffer sql = new StringBuffer();

    sql.append(
        "SELECT d.*, aaq.ID AS allele_request_id, adr.ID AS designrequestid, " +
        	"adr.promoter_inclusion, adr.conserved_elements, " +
        	"adr.possible_reinitiation, adr.no_nmd_induced, "
            + "d2d.fulfills_request, adr.comments AS designrequestcomments, adr.critical_exon_contains_atg, "
            + "adr.score, dsd.description, dp.parameter_name, ge.primary_name "
            + "FROM arq_allele_request aaq, " + "arq_design_request adr, "
            + "arq_design_2_design_request d2d, " + "eucomm_vector.design d, "
            + "eucomm_vector.design_status ds, "
            + "eucomm_vector.design_status_dict dsd, "
            + "eucomm_vector.design_parameter dp, " + "gnm_exon ge "
            + "WHERE aaq.id = adr.ALLELE_REQUEST_ID "
            + "and adr.id = d2d.DESIGN_REQUEST_ID(+) "
            + "and d2d.DESIGN_ID = d.design_id(+) "
            + "AND d.design_id = ds.design_id(+) "
            + "AND ds.design_status_id = dsd.design_status_id(+) "
            + "AND (ds.is_current = 1 OR ds.is_current IS NULL) "
            + "and d.start_exon_id = ge.id(+) "
            + "AND d.design_parameter_id = dp.design_parameter_id(+) ");

    // search by alleleRequest id

    if (alleleRequestId != null && alleleRequestId != 0) {
      sql.append(" and aaq.id = ? ");
      bindVariables.add(alleleRequestId);
    }
    sql.append("order by adr.id desc");

    logger.debug(sql);

    Collection<DesignDesignRequestListView> designLists = getSimpleJdbcTemplate().query(
        sql.toString(), designDesignRequestDataListViewRowMapper, bindVariables.toArray());

    return (designLists == null) ? new ArrayList<DesignDesignRequestListView>() : designLists;

  }

  public DesignDesignRequestListViewRowMapper getDesignDesignRequestDataListViewRowMapper() {
    return designDesignRequestDataListViewRowMapper;
  }

  public void setDesignDesignRequestDataListViewRowMapper(
      DesignDesignRequestListViewRowMapper designListViewRowMapper) {
    this.designDesignRequestDataListViewRowMapper = designListViewRowMapper;
  }

  public Long storeAuthenticated(DesignRequest designRequest, DesignDesignRequestListView[] designListViews, Person person) {

   // DesignRequestDao<DesignRequest> designRequestDao;

    designRequest.setEditedBy(person.getUserName());
    designRequest.setEditDate(new Date());

    if (designRequest.getId() == null || designRequest.getId() == 0) {
      insert(designRequest, person);
    } else {
      update(designRequest, designListViews, person);
    }

    for (DesignDesignRequestListView designListView: designListViews) {

      updateDesigns(designRequest, designListView);

    }

    return designRequest.getId();
  }

  public Long updateDesigns(DesignRequest designRequest, DesignDesignRequestListView designListView) {

    String sqlString = "update ARQ_DESIGN_2_DESIGN_REQUEST " +
    		"set FULFILLS_REQUEST=? " +
    		"where design_id = ? " +
    		"and design_request_id =?";
    ParameterizedSqlUpdate sql = new ParameterizedSqlUpdate(getJdbcTemplate());

    bindVariables(sql, designRequest, designListView);
    sql.execute(sqlString);
    return designRequest.getId();

  }

  public void updateDesignRequests(DesignDesignRequestListView designListView) {
    String sqlString = "update arq_design_request set " +
    		"promoter_inclusion = ?, " +
    		"conserved_elements=?, " +
    		"critical_exon_contains_atg=?, " +
    		"possible_reinitiation=?, " +
    		"no_nmd_induced=? " +
    		"where id = ?";
    ParameterizedSqlUpdate sql = new ParameterizedSqlUpdate(getJdbcTemplate());

    if (designListView.isPromoterInclusion()) {
      sql.addBooleanParam(true);
    } else {
      sql.addBooleanParam(false);
    }
    if (designListView.isConservedElements()) {
      sql.addBooleanParam(true);
    } else {
      sql.addBooleanParam(false);
    }
    if (designListView.isCriticalExonContainsATG()) {
      sql.addBooleanParam(true);
    } else {
      sql.addBooleanParam(false);
    }
    if (designListView.isPossibleReinitiation()) {
        sql.addBooleanParam(true);
      } else {
        sql.addBooleanParam(false);
      }
      if (designListView.isNoNMDInduced()) {
        sql.addBooleanParam(true);
      } else {
        sql.addBooleanParam(false);
      }

    sql.addLongParam(designListView.getDesignRequestId());
    sql.execute(sqlString);

  }

  private void bindVariables(ParameterizedSqlUpdate sql, DesignRequest designRequest, DesignDesignRequestListView designListView) {

    if (designListView.isFulfillsRequest()) {
      sql.addBooleanParam(true);
    } else {
      sql.addBooleanParam(false);
    }
    sql.addLongParam(designListView.getDesignId());
    sql.addLongParam(designRequest.getId());
  }

  public Long store(DesignDesignRequestListView dataObject) {
    return null;
  }

  public DesignDesignRequestListView fetchById(Long id) {
    // TODO Auto-generated method stub
    return null;
  }

  private Long insert(DesignRequest designRequest, Person person) {
    designRequest.setId(getPk());
    // TO DO
    // insert into relevant design reuest table not ARQ_HAVANA_REQUEST
    String sqlString = "insert into " +
    		"ARQ_DESIGN_REQUEST(" +
    		"STATUS_DICT_ID, " +
    		"ALLELE_REQUEST_ID, " +
    		"COMMENTS," +
    		" CREATED_BY, " +
	        "CREATED_DATE, " +
	        "EDITED_DATE, " +
	        "EDITED_BY, " +
	        "GENE_BUILD_ID, " +
	        "GENE_BUILD_GENE_ID, " +
	        "START_EXON_ID, " +
	        "END_EXON_ID, " +
	        "TARGET_START, " +
	        "TARGET_END, " +
	        "MIN_5P_EXON_FLANKS, " +
	        "MIN_3P_EXON_FLANKS, " +
	        "SPLIT_TARGET_SEQ_LENGTH, " +
	        "MULTI_REGION_OFFSET_SHIM, " +
	        "PRIMER_LENGTH, " +
	        "RETRIEVAL_PRIMER_OFFSET_5P, " +
	        "RETRIEVAL_PRIMER_OFFSET_3P, " +
	        "RETRIEVAL_PRIMER_LENGTH_5P, " +
	        "RETRIEVAL_PRIMER_LENGTH_3P, " +
	        "SCORE, " +
	        "ID) values " +
	        "(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";
    ParameterizedSqlUpdate sql = new ParameterizedSqlUpdate(getJdbcTemplate());

    bindVariables(sql, designRequest, person);
    sql.execute(sqlString);
    return designRequest.getId();
  }

  private Long update(DesignRequest designRequest, DesignDesignRequestListView[] designListViews, Person person) {

    // TO DO
    // insert into relevant design request table not ARQ_HAVANA_REQUEST
    String sqlString = "update " +
    		"ARQ_DESIGN_REQUEST set " +
    		"STATUS_DICT_ID=?, " +
    		"ALLELE_REQUEST_ID=?, " +
	        "COMMENTS=?,  " +
	        "CREATED_BY=?,  " +
	        "CREATED_DATE=?, " +
	        "EDITED_DATE=?, " +
	        "EDITED_BY=?, " +
	        "GENE_BUILD_ID = ?, " +
	        "GENE_BUILD_GENE_ID = ?, " +
	        "START_EXON_ID = ?, " +
	        "END_EXON_ID = ?, " +
	        "TARGET_START = ?, " +
	        "TARGET_END=?, " +
	        "MIN_5P_EXON_FLANKS=?, " +
	        "MIN_3P_EXON_FLANKS=?, " +
	        "SPLIT_TARGET_SEQ_LENGTH=?, " +
	        "MULTI_REGION_OFFSET_SHIM=?, " +
	        "PRIMER_LENGTH=?, " +
	        "RETRIEVAL_PRIMER_OFFSET_5P=?, " +
	        "RETRIEVAL_PRIMER_OFFSET_3P=?," +
	        "RETRIEVAL_PRIMER_LENGTH_5P=?, " +
	        "RETRIEVAL_PRIMER_LENGTH_3P=?, " +
	        "SCORE=? " +
	        "where ID=?";
    ParameterizedSqlUpdate sql = new ParameterizedSqlUpdate(getJdbcTemplate());

    bindVariables(sql, designRequest, person);
    sql.execute(sqlString);
    return designRequest.getId();
  }

  private void bindVariables(ParameterizedSqlUpdate sql, DesignRequest designRequest, Person person) {

    sql.addLongParam(designRequest.getStatus().getId());
    sql.addLongParam(designRequest.getAlleleRequest().getId());
    sql.addStringParam(designRequest.getComments());
    sql.addLongParam(designRequest.getCreatorId());
    sql.addDateParam(designRequest.getCreatedDate());
    sql.addDateParam(designRequest.getEditDate());
    sql.addStringParam(person.getUserName());
    sql.addLongParam(designRequest.getBuild()!=null?designRequest.getBuild().getId():null);
    sql.addLongParam(designRequest.getBuildGene()!=null?designRequest.getBuildGene().getId():null);
    sql.addLongParam(designRequest.getStartExon()!=null?designRequest.getStartExon().getId():null);
    sql.addLongParam(designRequest.getEndExon()!=null?designRequest.getEndExon().getId():null);
    sql.addLongParam(designRequest.getTargetStart()!=null?new Long(designRequest.getTargetStart()):null);
    sql.addLongParam(designRequest.getTargetEnd()!=null?new Long(designRequest.getTargetEnd()):null);
    sql.addLongParam(designRequest.getMin5pExonFlanks()!=null?new Long(designRequest.getMin5pExonFlanks()):null);
    sql.addLongParam(designRequest.getMin3pExonFlanks()!=null?new Long(designRequest.getMin3pExonFlanks()):null);
    sql.addLongParam(designRequest.getSplitTargetSeqLength()!=null?new Long(designRequest.getSplitTargetSeqLength()):null);
    sql.addLongParam(designRequest.getMultiRegionOffsetShim()!=null?new Long(designRequest.getMultiRegionOffsetShim()):null);
    sql.addLongParam(designRequest.getPrimerLength()!=null?new Long(designRequest.getPrimerLength()):null);
    sql.addLongParam(designRequest.getRetrievalPrimerOffset5p()!=null?new Long(designRequest.getRetrievalPrimerOffset5p()):null);
    sql.addLongParam(designRequest.getRetrievalPrimerOffset3p()!=null?new Long(designRequest.getRetrievalPrimerOffset3p()):null);
    sql.addLongParam(designRequest.getRetrievalPrimerLength5p()!=null?new Long(designRequest.getRetrievalPrimerLength5p()):null);
    sql.addLongParam(designRequest.getRetrievalPrimerLength3p()!=null?new Long(designRequest.getRetrievalPrimerLength3p()):null);
    sql.addLongParam(designRequest.getScore()!=null?new Long(designRequest.getScore()):null);
    sql.addLongParam(designRequest.getId());

  }


  public Long store(DesignDesignRequestListView dataObject, Person currentUser) {
    // TODO Auto-generated method stub
    return null;
  }

  public boolean alreadyExists(Long eucommId, Long designRequestId) {
    Object[] ids = new Long[2];

    ids[0] = eucommId;
    ids[1] = designRequestId;
    System.out.println("design req Id = " + designRequestId);
    int recordCount = getSimpleJdbcTemplate().queryForInt(
        "select count(*) from arq_design_2_design_request where design_id = ? and design_request_id = ?",
        ids);

    if (recordCount > 0) {
      return true;
    } else {
      return false;
    }
  }

  @Override
  protected void bindVariables(ParameterizedSqlUpdate sql, DesignDesignRequestListView t) {
    // TODO Auto-generated method stub

  }
}

