/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.designrequest.dao;

import java.util.ArrayList;
import java.util.Collection;

import org.springframework.dao.IncorrectResultSizeDataAccessException;

import uk.ac.sanger.mig.allelerequest.AlleleRequest;
import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.common.PaginatedSearchUtils;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.designrequest.DesignRequest;
import uk.ac.sanger.mig.designrequest.DesignRequestSearchBean;
import uk.ac.sanger.mig.designrequest.views.DesignRequestListView;

public class DesignRequestDaoSpringImpl extends AbstractDaoSpringImpl<DesignRequest> implements DesignRequestDao{

  private DesignRequestRowMapper designRequestRowMapper;
  private DesignRequestListViewRowMapper designRequestListViewRowMapper;
  private PaginatedSearchUtils<DesignRequestListView> paginator; 
  
  public Collection<DesignRequestListView> search(DesignRequestSearchBean searchBean) {
    DesignRequest designRequest = searchBean.getDesignRequest();
    
    Collection<Object> bindVariables = new ArrayList<Object>();
    
    StringBuffer sql = new StringBuffer();    
    sql.append(" select * from arq_design_request_list_vw v where 1=1 ");
    
    if(searchBean.getSearchString()!=null && 
        !searchBean.getSearchString().equals("") && !searchBean.getSearchBy().equals("") && !searchBean.getSearchString().contains("Please enter")
    ){
      if(searchBean.getSearchBy().equals("ID")){
        sql.append(" and v.id = ? ");
        bindVariables.add(new Long(searchBean.getSearchString()));
      }
      if(searchBean.getSearchBy().equals("VEGA_ID")){
        sql.append(" and upper(v.vega_id) = ? ");
        bindVariables.add(searchBean.getSearchString().toUpperCase());
      }
      if(searchBean.getSearchBy().equals("PRIMARY_NAME")){
        sql.append(" and upper(v.primary_name) =? ");
        bindVariables.add(searchBean.getSearchString().toUpperCase());
      }
      if(searchBean.getSearchBy().equals("ENSEMBL_ID")){
        sql.append(" and upper(v.ENSEMBL_ID) = ? ");
        bindVariables.add(searchBean.getSearchString().toUpperCase());
      }

    }else{
    
    // search by status id
    if(designRequest.getStatusDictId() != null && designRequest.getStatusDictId() > 0 ) {
      sql.append(" and v.status_dict_id = ? ");
      bindVariables.add(designRequest.getStatusDictId());
      //bindVariables.add(21);
    }
    }

    // Order by column and direction as supplied in the search bean
    if(searchBean.getOrderBy() != null && !searchBean.getOrderBy().equals("")) {
      sql.append(" order by " + searchBean.getOrderBy());
      if(searchBean.isOrderDesc()) {
        sql.append(" desc ");
      }
    }
    
    
    logger.debug(sql.toString());
    
    Collection<DesignRequestListView> designRequests = paginator.fetchSearchResults(sql.toString(), bindVariables, searchBean, designRequestListViewRowMapper);
    
//    Collection<DesignRequestListView> designRequests = 
//      getSimpleJdbcTemplate().query(
//          sql.toString(), 
//          designRequestListViewRowMapper,
//          bindVariables.toArray());
    

    return (designRequests == null) ? new ArrayList<DesignRequestListView>() : designRequests;
    
  }

  public void setDesignRequestRowMapper(DesignRequestRowMapper designRequestRowMapper) {
    this.designRequestRowMapper = designRequestRowMapper;
  }

  public void setDesignRequestListViewRowMapper(
      DesignRequestListViewRowMapper designRequestListViewRowMapper) {
    this.designRequestListViewRowMapper = designRequestListViewRowMapper;
  }
  
  public DesignRequest fetchById(Long id) {
    DesignRequest designRequest = null;
    String sql = "select * from arq_design_request where id = ?";   
    try {
      designRequest = getSimpleJdbcTemplate().queryForObject(sql, designRequestRowMapper, id);
    } catch(IncorrectResultSizeDataAccessException e) {
      logger.warn(e);
    } 
    return designRequest;
  }  
  
  @Override
  protected void bindVariables(ParameterizedSqlUpdate sql, DesignRequest designRequest) {

    sql.addLongParam(designRequest.getStatusDictId(), "STATUS_DICT_ID");
    sql.addLongParam(designRequest.getAlleleRequest().getId(), "ALLELE_REQUEST_ID");
    sql.addLongParam(designRequest.getCreatorId(), "CREATOR_ID");
    sql.addDateParam(designRequest.getCreatedDate(), "CREATED_DATE");
    sql.addLongParam(designRequest.getId(), "ID");
    
  }

  
  public boolean alreadyExists(AlleleRequest alleleRequest) {
    int recordCount = 
      getSimpleJdbcTemplate()
      .queryForInt("select count(*) from arq_design_request where allele_request_id = ?", 
          alleleRequest.getId());
    if (recordCount > 0) { return true; } 
    else         {return false;}
  }

  
  
  public Collection<DesignRequest> fetchbyAlleleRequestId(Long id) {
    
    String sql = "select * from arq_design_request adr " +
        "where allele_request_id = ? order by id"; 
    Collection<DesignRequest> results = getSimpleJdbcTemplate().query(sql, designRequestRowMapper,id);    
    
    return (results == null) ? new ArrayList<DesignRequest>() :  results;
    
  }

  public void setPaginator(PaginatedSearchUtils<DesignRequestListView> paginator) {
    this.paginator = paginator;
  }
  
}
