/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.designrequest.dao;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.allelerequest.AlleleRequest;
import uk.ac.sanger.mig.allelerequest.services.AlleleRequestService;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.database.DictionaryDao;
import uk.ac.sanger.mig.designrequest.DesignRequest;
import uk.ac.sanger.mig.gene.Build;
import uk.ac.sanger.mig.gene.BuildGene;
import uk.ac.sanger.mig.gene.Exon;
import uk.ac.sanger.mig.gene.MigGene;
import uk.ac.sanger.mig.gene.services.BuildGeneService;
import uk.ac.sanger.mig.gene.services.BuildService;
import uk.ac.sanger.mig.gene.services.ExonService;

public class DesignRequestRowMapper implements ParameterizedRowMapper<DesignRequest>{

  private DictionaryDao dictionaryDao;
  private AlleleRequestService alleleRequestService;
  private BuildService buildService;
  private BuildGeneService buildGeneService;
  private ExonService exonService;
  
  
  public void setDictionaryDao(DictionaryDao dictionaryDao) {
    this.dictionaryDao = dictionaryDao;
  }

  public DesignRequest mapRow(ResultSet rs, int rowNum) throws SQLException {
	  
	  ComponentMap alleleRequestComponentMap =
			ComponentMap.putAll(
					new ComponentMap(AlleleRequest.Component.GENE, new ComponentMap(MigGene.Component.PRIMARY_ENSEMBL_BUILD_GENE, null)));
    
    AlleleRequest alleleRequest = alleleRequestService.fetchById(rs.getLong("ALLELE_REQUEST_ID"), alleleRequestComponentMap);
    
    DesignRequest designRequest = new DesignRequest();
    if(rs.getObject("GENE_BUILD_ID") != null){
      Build build = buildService.fetchById(rs.getLong("GENE_BUILD_ID"), new ComponentMap());
      designRequest.setBuild(build);
    }else{
      designRequest.setBuild(new Build());
    }
      
    
    if(rs.getObject("GENE_BUILD_GENE_ID") != null){
      BuildGene buildGene = buildGeneService.fetchById(rs.getLong("GENE_BUILD_GENE_ID"), new ComponentMap());
      designRequest.setBuildGene(buildGene);
    }else{
      designRequest.setBuildGene(new BuildGene());
    }
    
    if(rs.getObject("END_EXON_ID") != null){
      designRequest.setEndExon(exonService.fetchById(rs.getLong("END_EXON_ID"), new ComponentMap()));
    }else{
      designRequest.setEndExon(new Exon());
    }
    
    if(rs.getObject("START_EXON_ID")!=null){
      designRequest.setStartExon(exonService.fetchById(rs.getLong("START_EXON_ID"), new ComponentMap()));
    }else{
      designRequest.setStartExon(new Exon());
    }
    
    if(rs.getObject("TARGET_START")!=null){
      designRequest.setTargetStart(rs.getInt("TARGET_START"));
    }else{
      designRequest.setTargetStart(null);
    }
    
    if(rs.getObject("TARGET_END")!=null){
      designRequest.setTargetEnd(rs.getInt("TARGET_END"));
    }else{
      designRequest.setTargetEnd(null);
    }
    
    if(rs.getObject("MIN_5P_EXON_FLANKS")!=null){
      designRequest.setMin5pExonFlanks(rs.getInt("MIN_5P_EXON_FLANKS"));
    }else{
      designRequest.setMin5pExonFlanks(null);
    }
    
    if(rs.getObject("MIN_3P_EXON_FLANKS")!=null){
      designRequest.setMin3pExonFlanks(rs.getInt("MIN_3P_EXON_FLANKS"));
    }else{
      designRequest.setMin3pExonFlanks(null);
    }
    
    if(rs.getObject("SPLIT_TARGET_SEQ_LENGTH")!=null){
      designRequest.setSplitTargetSeqLength(rs.getInt("SPLIT_TARGET_SEQ_LENGTH"));
    }else{
      designRequest.setSplitTargetSeqLength(null);
    }
    
    if(rs.getObject("MULTI_REGION_OFFSET_SHIM")!=null){
      designRequest.setMultiRegionOffsetShim(rs.getInt("MULTI_REGION_OFFSET_SHIM"));
    }else{
      designRequest.setMultiRegionOffsetShim(null);
    }
    
    if(rs.getObject("PRIMER_LENGTH")!=null){
      designRequest.setPrimerLength(rs.getInt("PRIMER_LENGTH"));
    }else{
      designRequest.setPrimerLength(null);
    }
    
    if(rs.getObject("RETRIEVAL_PRIMER_OFFSET_3P")!=null){
      designRequest.setRetrievalPrimerOffset3p(rs.getInt("RETRIEVAL_PRIMER_OFFSET_3P"));
    }else{
      designRequest.setRetrievalPrimerOffset3p(null);
    }
    
    if(rs.getObject("RETRIEVAL_PRIMER_OFFSET_5P")!=null){
      designRequest.setRetrievalPrimerOffset5p(rs.getInt("RETRIEVAL_PRIMER_OFFSET_5P"));
    }else{
      designRequest.setRetrievalPrimerOffset5p(null);
    }

    if(rs.getObject("RETRIEVAL_PRIMER_LENGTH_3P")!=null){
      designRequest.setRetrievalPrimerLength3p(rs.getInt("RETRIEVAL_PRIMER_LENGTH_3P"));
    }else{
      designRequest.setRetrievalPrimerLength3p(null);
    }
    
    if(rs.getObject("RETRIEVAL_PRIMER_LENGTH_5P")!=null){
      designRequest.setRetrievalPrimerLength5p(rs.getInt("RETRIEVAL_PRIMER_LENGTH_5P"));
    }else{
      designRequest.setRetrievalPrimerLength5p(null);
    }
    
    if(rs.getObject("SCORE")!=null){
      designRequest.setScore(rs.getInt("SCORE"));
    }else{
      designRequest.setScore(null);
    }
    
    designRequest.setAlleleRequestId(rs.getLong("ALLELE_REQUEST_ID"));
    designRequest.setComments(rs.getString("COMMENTS"));
    designRequest.setId(rs.getLong("ID"));
    designRequest.setCreatorId(rs.getLong("CREATOR_ID")); if(rs.wasNull()) designRequest.setCreatorId(null);
    designRequest.setEditedBy(rs.getString("EDITED_BY"));
    designRequest.setCreatedDate(rs.getDate("CREATED_DATE"));
    designRequest.setEditDate(rs.getDate("EDITED_DATE")); 
    designRequest.setStatus(dictionaryDao.fetchDictionaryEntryByTableNameAndId("ARQ_DESIGN_REQ_STATUS_DICT_VW", rs.getLong("STATUS_DICT_ID")));
    designRequest.setAlleleRequest(alleleRequest);
    designRequest.setVegaId(rs.getString("VEGA_ID"));
    if(alleleRequest.getMigGene().getPrimaryEnsemblBuildGeneId() != null){
    	designRequest.setEnsemblId(alleleRequest.getMigGene().getPrimaryEnsemblBuildGene().getPrimaryName());
    }
    return designRequest;
    
  }

public void setBuildGeneService(BuildGeneService buildGeneService) {
	this.buildGeneService = buildGeneService;
}

public void setBuildService(BuildService buildService) {
	this.buildService = buildService;
}

public void setExonService(ExonService exonService) {
	this.exonService = exonService;
}

public void setAlleleRequestService(AlleleRequestService alleleRequestService) {
	this.alleleRequestService = alleleRequestService;
}

}
