/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.designrequest.services;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.URL;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import uk.ac.sanger.mig.allelerequest.AlleleRequest;
import uk.ac.sanger.mig.allelerequest.services.AlleleRequestService;
import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.designrequest.DesignRequest;
import uk.ac.sanger.mig.designrequest.DesignRequestSearchBean;
import uk.ac.sanger.mig.designrequest.dao.DesignRequestDao;
import uk.ac.sanger.mig.designrequest.views.DesignRequestListView;
import uk.ac.sanger.mig.personnel.Person;

public class DesignRequestServiceImpl extends AbstractServiceImpl<DesignRequest> implements DesignRequestService{
  private String hostName;
  private String port;
  private DesignRequestDao designRequestDao;
  private AlleleRequestService alleleRequestService;
  
  public AlleleRequestService getAlleleRequestService() {
    return alleleRequestService;
  }

  public void setAlleleRequestService(AlleleRequestService alleleRequestService) {
    this.alleleRequestService = alleleRequestService;
  }

  public void setDesignRequestDao(DesignRequestDao designRequestDao) {
    this.designRequestDao = designRequestDao;
  }

  public String getHostName() {
    return hostName;
  }

  public void setHostName(String hostName) {
    this.hostName = hostName;
  }

  public String getPort() {
    return port;
  }

  public void setPort(String port) {
    this.port = port;
  }

  public String[] purgeDesign(String designID) {
    List<String> messages = new ArrayList<String>();
    try {
      URL designServer =
        new URL("http://"+getHostName()+":"+getPort()+"/?command=purge_design&design_id="+
            designID
        );
      BufferedReader response;
      response = new BufferedReader(new InputStreamReader(designServer.openStream()));
      String line;
      while ((line = response.readLine()) != null){
        messages.add(line);
      }
      response.close();
    } catch (IOException exception) {
      messages.add(exception.getMessage());
    }
 
    String[] returnMsgs = new String[messages.size()];
    for(int i=0; i<messages.size(); i++){
      returnMsgs[i] = messages.get(i);
    }
    return returnMsgs;
  }
  //calls vivek's perl process behind the scenes that does the inserts and updated in the MIG database
  //Syncs the gene with the otterId (populates gnm_gene_build_gene and gnm_gene_2_gene_build_gene tables)
  //creates brand new design requests (as many as the number of critical exons identified by manual annotatation
  //returns a string array (log)which is displayed on the browser for user to read if something goes wrong (no design request get created)
  // this method is called when user hits "import from otterlace" button from edit_havana_request page
  public String[] synchDesignRequest(String build, String otterId, String migGeneID, String alleleRequestId) {
    List<String> messages = new ArrayList<String>();
    
    try {
      URL designServer = 
        new URL(
            "http://"+getHostName()+":"+getPort()+"/?command=synch_only&build_name="+
            build+
            "&otter_id="+otterId+
            "&mig_gene_id="+migGeneID+
            "&allele_request_id="+alleleRequestId
        );
      BufferedReader response;
      response = new BufferedReader(new InputStreamReader(designServer.openStream()));
      String line;
      while ((line = response.readLine()) != null) {
        messages.add(line);
      }
      response.close();
    } catch (IOException exception) {
      messages.add(exception.getMessage());
    }
  
    System.out.println("Ran url thing "+messages.size());
    String[] returnMsgs = new String[messages.size()];
    for(int i=0; i<messages.size(); i++){
      returnMsgs[i] = messages.get(i);
    }
    return returnMsgs;
  }
  //cut down version of syncDesignRequest method above
  //only update the gnm_gene_build_gene and gnm_gene_2_gene_build_gene
  //it does not creates new design requests.
  //this method gets called when user clicks "import from otterlace" button on view one gene page
  //and also from processSubmit method in HavanaRequestFormController
  //if the otter id is same as previous one then teh process does no inserts 
  
  public String[] syncGene(String build, String otterId, String migGeneID) {
    List<String> messages = new ArrayList<String>();
    
    try {
      URL designServer = 
      new URL(
    		  "http://"+getHostName()+":"+getPort()+"/?command=sync_gene&build_name=" +
    		  build+
    		  "&otter_id="+otterId+
    		  "&mig_gene_id="+migGeneID
      	);
      BufferedReader response;
      response = new BufferedReader(new InputStreamReader(designServer.openStream()));
      String line;
      while ((line = response.readLine()) != null) {
        messages.add(line);
      }
      response.close();
    } catch (IOException exception) {
      messages.add(exception.getMessage());
    }
  
    String[] returnMsgs = new String[messages.size()];
    for(int i=0; i<messages.size(); i++){
      returnMsgs[i] = messages.get(i);
    }
    return returnMsgs;
  }
  
  //called when user clicks the "run for designs" button from edit havana interface
  //it gets in a design request id (which has all the parameters required to run design)
  //the perl process then submits the request for design on a farm where it gets queued
  //only parameter thereofore sent is a design request id
  //the process inserts data into the eucomm_vector schema (design, and design_status tables)
  
  
  public String[] submitDesignCreation(String designRequestID) {
    List<String> messages = new ArrayList<String>();

    try {
      URL designServer =
        new URL(
"http://"+getHostName()+":"+getPort()+"/?command=design_only&design_request_id="+
          designRequestID
        );
      BufferedReader response;
      response = new BufferedReader(new InputStreamReader(designServer.openStream()));
      String line;
      while ((line = response.readLine()) != null) {
        messages.add(line);
      }
      response.close();
    } catch (IOException exception) {
      messages.add(exception.getMessage());
    }
 
    String[] returnMsgs = new String[messages.size()];
    for(int i=0; i<messages.size(); i++){
      returnMsgs[i] = messages.get(i);
    }
    return returnMsgs;
  }


  public Collection<DesignRequestListView> search(DesignRequestSearchBean searchBean){
    return designRequestDao.search(searchBean);
  }
  
  public boolean alreadyExists(AlleleRequest alleleRequest){
    return designRequestDao.alreadyExists(alleleRequest);
  }
  

  public Collection<DesignRequest> fetchbyAlleleRequestId(Long id){
    return designRequestDao.fetchbyAlleleRequestId(id);
  }

  public DesignRequest fetchById(Long id) {
    return designRequestDao.fetchById(id);
  }
  
  public DesignRequest fetchById(Long id,  ComponentMap requiredComponents){
    DesignRequest designRequest = designRequestDao.fetchById(id);
    if(designRequest != null){
      attachComponents(designRequest, requiredComponents);
    }
    return designRequest;
    
  }
  @Override
  protected void attachComponents(DesignRequest designRequest, ComponentMap requiredComponents) {
    if(designRequest == null) {
      throw new RuntimeException("Cannot attach components to null designRequest");
    }   
    boolean fetchAll = false;
    
    if(requiredComponents != null) {
      
      if(requiredComponents.containsKey(DesignRequest.Component.ALL_COMPONENTS)) {
        fetchAll = true;
      }
      
      if(fetchAll || requiredComponents.containsKey(DesignRequest.Component.ALLELE_REQUEST)) {
        designRequest.setAlleleRequest(fetchAlleleRequest(designRequest, requiredComponents.get(DesignRequest.Component.ALLELE_REQUEST)));
      }

    }
  }
  
  private AlleleRequest fetchAlleleRequest(DesignRequest designRequest, ComponentMap map) {
      
    return alleleRequestService.fetchById(designRequest.getAlleleRequestId(), map);
  }

  public void store(DesignRequest designRequest, Person user) {
   designRequestDao.store(designRequest, user);
    
  }


  
}
