/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.designrequest.services;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.designrequest.Design;
import uk.ac.sanger.mig.designrequest.dao.DesignDao;
import uk.ac.sanger.mig.eucomm.designinstance.DesignInstance;
import uk.ac.sanger.mig.eucomm.designinstance.services.DesignInstanceService;

public class DesignServiceSpringImpl implements DesignService{
  
  private DesignDao designDao;
  private DesignInstanceService designInstanceService;
  
  public Design fetchById(Long id, ComponentMap requiredComponents){
    Design design = (Design) designDao.fetchById(id);
    if(design != null){
      attachComponents(design, requiredComponents);
    }
    return design;
  }

  private void attachComponents(Design design, ComponentMap requiredComponents) {
    if(design == null) {
      throw new RuntimeException("Cannot attach components to null design");
    }   
    boolean fetchAll = false;
    
    if(requiredComponents != null) {
      
      if(requiredComponents.containsKey(Design.Component.ALL_COMPONENTS)) {
        fetchAll = true;
      }
      
      if(fetchAll || requiredComponents.containsKey(Design.Component.DESIGN_INSTANCES)) {
        design.setDesignInstances(fetchDesignInstances(design, requiredComponents.get(Design.Component.DESIGN_INSTANCES)));
      }

    }
    
  }

  private Collection<DesignInstance> fetchDesignInstances(Design design, ComponentMap map) {
    
    Collection<Long> designInstanceIds = designDao.fetchDesignInstanceIds(design.getDesignId());
    Collection<DesignInstance> designInstances = new ArrayList<DesignInstance>();
    for(Long designInstanceId: designInstanceIds){
      designInstances.add(designInstanceService.fetchById(designInstanceId, map));
    }
    return designInstances;
  }

  public void setDesignDao(DesignDao designDao) {
    this.designDao = designDao;
  }

  public DesignInstanceService getDesignInstanceService() {
    return designInstanceService;
  }

  public void setDesignInstanceService(DesignInstanceService designInstanceService) {
    this.designInstanceService = designInstanceService;
  }

  public DesignDao getDesignDao() {
    return designDao;
  }
  

}
