/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.designrequest.validators;

import org.springframework.validation.Errors;
import org.springframework.validation.ValidationUtils;
import org.springframework.validation.Validator;

import uk.ac.sanger.mig.designrequest.DesignRequest;
import uk.ac.sanger.mig.designrequest.forms.DesignRequestForm;

public class DesignRequestFormValidator implements Validator{
  
  /* RULES:
   --* 1. All teh fields are required
   */
  
  public boolean supports(Class clazz) {
    return DesignRequestForm.class.equals(clazz);
  }
  
  
  public void validate(Object commandForm, Errors errors) {
    
    
    ValidationUtils.rejectIfEmptyOrWhitespace(errors,"designRequest.build.name",null,"Gene Build is a required field.");  
    ValidationUtils.rejectIfEmptyOrWhitespace(errors,"designRequest.buildGene.primaryName",null, "Gene Build Gene is a required field.");
    
    ValidationUtils.rejectIfEmptyOrWhitespace(errors,"designRequest.startExon.primaryName",null,"Start exon is a required field.");  
    ValidationUtils.rejectIfEmptyOrWhitespace(errors,"designRequest.endExon.primaryName",null, "End Exon is a required field.");
    
    ValidationUtils.rejectIfEmptyOrWhitespace(errors,"designRequest.targetStart",null,"Target start is a required field.");  
    ValidationUtils.rejectIfEmptyOrWhitespace(errors,"designRequest.targetEnd",null, "Target end is a required field.");
    
    ValidationUtils.rejectIfEmptyOrWhitespace(errors,"designRequest.min5pExonFlanks",null,"Min 5p exon flanks is a required field");
    ValidationUtils.rejectIfEmptyOrWhitespace(errors,"designRequest.min3pExonFlanks",null,"Min 3p exon flanks is a required field");
    ValidationUtils.rejectIfEmptyOrWhitespace(errors,"designRequest.splitTargetSeqLength",null,"Split target sequence length is a required field");
    ValidationUtils.rejectIfEmptyOrWhitespace(errors,"designRequest.multiRegionOffsetShim",null,"Multi region offset shim is a required field");
    
    ValidationUtils.rejectIfEmptyOrWhitespace(errors,"designRequest.retrievalPrimerOffset5p",null,"5' Retrieval Primer Offset shim is a required field");
    ValidationUtils.rejectIfEmptyOrWhitespace(errors,"designRequest.retrievalPrimerOffset3p",null,"3' Retrieval Primer Offset shim is a required field");
    ValidationUtils.rejectIfEmptyOrWhitespace(errors,"designRequest.retrievalPrimerLength5p",null,"5' Retrieval Primer Length is a required field");
    ValidationUtils.rejectIfEmptyOrWhitespace(errors,"designRequest.retrievalPrimerLength3p",null,"3' Retrieval Primer Length is a required field");
    
    ValidationUtils.rejectIfEmptyOrWhitespace(errors,"designRequest.primerLength",null,"Primer Length is a required field");
    
    DesignRequestForm form = (DesignRequestForm)commandForm;
    DesignRequest designRequest = form.getDesignRequest();
    if(designRequest.getRetrievalPrimerLength3p()!=null &&
        designRequest.getRetrievalPrimerOffset3p()!=null){
      if(designRequest.getRetrievalPrimerLength3p() > designRequest.getRetrievalPrimerOffset3p()){
        errors.rejectValue("designRequest.retrievalPrimerLength3p",
            "3' Retrieval primer length greater than 3' retrieval offset. Not allowed.", "3' Retrieval primer length greater than 3' retrieval offset. Not allowed.");
      }
    }
    
    
    if(designRequest.getRetrievalPrimerLength5p()!=null &&
        designRequest.getRetrievalPrimerOffset5p()!=null){
      
      if(designRequest.getRetrievalPrimerLength5p() > designRequest.getRetrievalPrimerOffset5p()){
        errors.rejectValue("designRequest.retrievalPrimerLength5p",
            "5' Retrieval primer length greater than 5' retrieval offset. Not allowed.", "5' Retrieval primer length greater than 5' retrieval offset. Not allowed.");
      }
    }
    
  }
  
  
  
  
}