/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.eucomm.bac.controllers;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.propertyeditors.CustomDateEditor;
import org.springframework.beans.propertyeditors.CustomNumberEditor;
import org.springframework.validation.BindException;
import org.springframework.web.bind.ServletRequestDataBinder;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.SimpleFormController;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.eucomm.bac.Bac;
import uk.ac.sanger.mig.eucomm.bac.forms.BacForm;
import uk.ac.sanger.mig.eucomm.bac.services.BacService;

public class BacFormController extends SimpleFormController {
	
	private BacService bacService;

	public void setBacService(BacService bacService) {
		this.bacService = bacService;
	}

	@Override
	protected void initBinder(HttpServletRequest request, ServletRequestDataBinder binder) throws Exception {
		binder.registerCustomEditor(Long.class, new CustomNumberEditor(Long.class, true));
		binder.registerCustomEditor(Double.class, new CustomNumberEditor(Integer.class, true));
		binder.registerCustomEditor(Integer.class, new CustomNumberEditor(Double.class, true));
		binder.registerCustomEditor(Date.class, new CustomDateEditor(new SimpleDateFormat("dd-MMM-yyyy"), true));		
	}

	@Override
	protected Object formBackingObject(HttpServletRequest httpServletRequest) throws Exception {
		BacForm bacForm = (BacForm)createCommand();				    
		Long id = ServletRequestUtils.getLongParameter(httpServletRequest, "id");		
		
		Bac bac = null; 
		        
		//REM always ensure our *full* object graph (all sub-objects) available for binding!
					        
		if(id != null) {
			//ok, existing bac id provided, so fetch for edit. NOTE: ALL_COMPONENTS not obligatory
			//fetch component map that you need... 
		bac = bacService.fetchById(id,ComponentMap.of(		Bac.Component.ALL_COMPONENTS));
	
		} else {//else make new bac	
			bac = buildNewBac();
		}
   
		bacForm.setBac(bac);	
		return bacForm;
	}
		
	//called after databinding, before showForm(), merges Map into ModelAndView
	//to populate our form with form "metadata" -- eg, drop-down select lists, etc.
		@Override
	protected Map referenceData(HttpServletRequest httpServletRequest) throws Exception {
		Map<String,Object> formMetaData = new HashMap<String,Object>();				
			
		//..fetch and put any  dropdown list Collections, etc into Map
			
		return formMetaData;
	} 
	
	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, 
				Object command, BindException errors) throws Exception {
		BacForm bacForm = (BacForm) command;
		Bac bac = bacForm.getBac();
		bacService.storeAuthenticated(bac, RequestUtils.getUser(request));
		logger.debug("Object " + bac + " successfully stored.");
		return new ModelAndView(getSuccessView()); // show list view
	}
	
	private Bac buildNewBac() {		
		Bac bac = new Bac();
		    
		//...build skeleton here object graph for binding, 
		//REMing to instantiate & set whole complex object tree!	
		    
		return bac;
	}	
}