/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.eucomm.designinstance.services;

import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.eucomm.designinstance.DesignInstance;
import uk.ac.sanger.mig.eucomm.designinstance.dao.DesignInstanceDao;
import uk.ac.sanger.mig.eucomm.designinstancebac.DesignInstanceBac;
import uk.ac.sanger.mig.eucomm.designinstancebac.services.DesignInstanceBacService;
import uk.ac.sanger.mig.eucomm.designinstancestatus.DesignInstanceStatus;
import uk.ac.sanger.mig.eucomm.designinstancestatus.services.DesignInstanceStatusService;
import uk.ac.sanger.mig.personnel.Person;

public class DesignInstanceServiceImpl extends AbstractServiceImpl<DesignInstance> implements DesignInstanceService {
	
	private DesignInstanceDao designinstanceDao;
  private DesignInstanceStatusService designinstancestatusservice;
  private DesignInstanceBacService designInstanceBacService;

	
	public void setDesigninstanceDao(DesignInstanceDao designinstanceDao) {
		this.designinstanceDao = designinstanceDao;
	}


	public Long storeAuthenticated(DesignInstance designinstance, Person user) {
		if(designinstance == null) {
			throw new RuntimeException("Cannot save a null designinstance");
		}
		
		return designinstanceDao.store(designinstance, user);
	}
	
	public DesignInstance fetchById(Long designinstanceId, ComponentMap requiredComponents) {
		DesignInstance designinstance = designinstanceDao.fetchById(designinstanceId);
		
		if(designinstance != null){
      attachComponents(designinstance, requiredComponents);
    }
		
		return designinstance;
	}

	@Override
	protected void attachComponents(DesignInstance designinstance, ComponentMap requiredComponents) {
		if(designinstance == null) {
			throw new RuntimeException("Cannot attach components to null designinstance");
		}		
		
		boolean fetchAll = false;
		
		if(requiredComponents != null) {
			
			if(requiredComponents.containsKey(DesignInstance.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}
			
      if(fetchAll || requiredComponents.containsKey(DesignInstance.Component.DESIGN_INSTANCE_STATUSES)) {
        designinstance.setStatuses(fetchStatuses(designinstance, requiredComponents.get(DesignInstance.Component.DESIGN_INSTANCE_STATUSES)));
        for(DesignInstanceStatus designInstanceStatus: designinstance.getStatuses()){
          if(designInstanceStatus.getIsCurrent()==1){
            designinstance.setCurrentDesignInstanceStatus(designInstanceStatus);
          }
        }
      }
      if(fetchAll || requiredComponents.containsKey(DesignInstance.Component.DESIGN_INSTANCE_BACS)){
        designinstance.setDesignInstanceBacs(fetchDesignInstanceBacs(designinstance, requiredComponents.get(DesignInstance.Component.DESIGN_INSTANCE_BACS)));
      }
      
		}
	}


  private Collection<DesignInstanceBac> fetchDesignInstanceBacs(DesignInstance designinstance, ComponentMap requiredComponents) {
   if(designinstance.getDesignInstanceId()!=null){
     return designInstanceBacService.fetchBydesignInstanceId(designinstance.getDesignInstanceId(), requiredComponents);
   }else{
     return null;     
   }
  }


  public Collection<DesignInstanceStatus> fetchStatuses(DesignInstance designinstance, ComponentMap requiredComponents) {
    if(designinstance.getDesignInstanceId() != null) {
      return designinstancestatusservice.fetchByDesignInstanceId(designinstance.getDesignInstanceId(), requiredComponents);
    }
    else {
      return null;  
    }
  }


  public DesignInstanceStatusService getDesigninstancestatusservice() {
    return designinstancestatusservice;
  }


  public void setDesigninstancestatusservice(
      DesignInstanceStatusService designinstancestatusservice) {
    this.designinstancestatusservice = designinstancestatusservice;
  }


  public void setDesignInstanceBacService(
      DesignInstanceBacService designInstanceBacService) {
    this.designInstanceBacService = designInstanceBacService;
  }
	
	//private helper methods--eg, fetchSomeSubComponent (REM: use service injection, not Dao!)
	
}
								