/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.eucomm.designinstancestatus.dao;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.eucomm.designinstancestatus.DesignInstanceStatus;
import uk.ac.sanger.mig.eucomm.designinstancestatus.dao.rowmappers.DesignInstanceStatusRowMapper;

public class DesignInstanceStatusDaoSpringImpl extends AbstractDaoSpringImpl<DesignInstanceStatus> implements DesignInstanceStatusDao {

  private DesignInstanceStatusRowMapper designinstancestatusRowMapper;

	@Override
	protected Long insert(DesignInstanceStatus designinstancestatus) {
		designinstancestatus.setId(getPk());
		ParameterizedSqlUpdate sql = new ParameterizedSqlUpdate(getJdbcTemplate());
		bindVariables(sql,designinstancestatus);
		sql.executeInsert(getTableName());
		return designinstancestatus.getId();
	}


	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, DesignInstanceStatus designinstancestatus) {
		sql.addLongParam(designinstancestatus.getDesignInstanceStatusId(), "DESIGN_INSTANCE_STATUS_ID");
		sql.addIntParam(designinstancestatus.getDesignInstanceId(), "DESIGN_INSTANCE_ID");
		sql.addDateParam(designinstancestatus.getStatusDate(), "STATUS_DATE");
		sql.addIntParam(designinstancestatus.getIsCurrent(), "IS_CURRENT");
		sql.addIntParam(designinstancestatus.getIdRole(), "ID_ROLE");
		sql.addLongParam(designinstancestatus.getPostCreStatusId(), "POST_CRE_STATUS_ID");
		sql.addLongParam(designinstancestatus.getPostGatewayStatusId(), "POST_GATEWAY_STATUS_ID");
	}

	protected void attachComponents(DesignInstanceStatus designinstancestatus, ComponentMap requiredComponents) {
		// THIS IS DEPRECATED! USE SERVICE LAYER FROM NOW ON TO ATTACH OBJECT COMPONENTS

	}


    @Override
    protected Long update(DesignInstanceStatus t) {
      // TODO Auto-generated method stub
      return null;
    }



    public Collection<DesignInstanceStatus> fetchByDesignInstanceId(Long designInstanceId){

      String sql = "select * from eucomm_vector.design_instance_status where design_instance_id" +
          " = ?";

      Collection<DesignInstanceStatus> statuses = getSimpleJdbcTemplate().query(sql, getRowMapper(), designInstanceId);

      return (statuses != null) ? statuses : new ArrayList<DesignInstanceStatus>();
    }


    public DesignInstanceStatusRowMapper getDesigninstancestatusRowMapper() {
      return designinstancestatusRowMapper;
    }


    public void setDesigninstancestatusRowMapper(
        DesignInstanceStatusRowMapper designinstancestatusRowMapper) {
      this.designinstancestatusRowMapper = designinstancestatusRowMapper;
    }

}