/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.europhenome;

import org.europhenome.InvalidRecord;
import org.europhenome.ResultState;

public class InvalidResultStateException extends RuntimeException {

  private static final long serialVersionUID = 7605947321250562785L;
  private ResultState resultState;
  
  public InvalidResultStateException(String message, ResultState resultState) {
    super(message);
    this.resultState = resultState;
  }

  @Override
  public String getMessage() {
    StringBuilder msg = new  StringBuilder(super.getMessage());
    String newLine = System.getProperty("line.separator");
    msg.append(newLine);
    
    if (resultState != null) {
      for(InvalidRecord badRecord : resultState.getInvalidRecords()) {
        msg.append("Record: ").append(badRecord.getRecord()).append(newLine);
        msg.append(" Failure reason: ").append(badRecord.getFailureReasons()).append(newLine);
      }
    }
    
    return msg.toString();
  }
  
  

}
