package uk.ac.sanger.mig.europhenome;


import java.util.Collection;

import org.europhenome.Parameter;

import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.ComponentEnum;
import uk.ac.sanger.mig.common.DictionaryEntryEnum;

public class ParameterDefinition extends AuthenticatedDataObject  {

	public enum Component implements ComponentEnum {
		ALL_COMPONENTS,
		PROCEDURE_DEFINITION,
		PARAMETER_MAPPINGS
	}

    private String name;
    private String empressId;
    private Long procedureDefinitionId;
    private String units;
    private Long parameterTypeId;
    private Double minBound;
    private Double maxBound;
    private boolean dataSeries;
    private boolean required;
    private String seriesUnit;

    private ProcedureDefinition procedureDefinition;
    private Collection<ParameterMapping> parameterMappings;

    public ParameterType getParameterType() {
      ParameterType type = null;
      for (ParameterType pt : ParameterType.values()) {
        if (pt.getId().equals(parameterTypeId)) {
          type = pt;
          break;
        }
      }
      return type;
    }

    public ProcedureDefinition getProcedureDefinition() {
      return procedureDefinition;
    }

    public void setProcedureDefinition(ProcedureDefinition procedureDefinition) {
      this.procedureDefinition = procedureDefinition;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getEmpressId() {
        return empressId;
    }

    public void setEmpressId(String empressId) {
        this.empressId = empressId;
    }
    public Long getProcedureDefinitionId() {
        return procedureDefinitionId;
    }

    public void setProcedureDefinitionId(Long procedureDefinitionId) {
        this.procedureDefinitionId = procedureDefinitionId;
    }
    public String getUnits() {
        return units;
    }

    public void setUnits(String units) {
        this.units = units;
    }

    public Long getParameterTypeId() {
      return parameterTypeId;
    }

    public void setParameterTypeId(Long parameterTypeId) {
      this.parameterTypeId = parameterTypeId;
    }

    public Double getMinBound() {
        return minBound;
    }

    public void setMinBound(Double minBound) {
        this.minBound = minBound;
    }
    public Double getMaxBound() {
        return maxBound;
    }

    public void setMaxBound(Double maxBound) {
        this.maxBound = maxBound;
    }
    public boolean isDataSeries() {
        return dataSeries;
    }

    public void setDataSeries(boolean isDataSeries) {
        this.dataSeries = isDataSeries;
    }
    public boolean isRequired() {
        return required;
    }

    public void setRequired(boolean isRequired) {
        this.required = isRequired;
    }

    public Collection<ParameterMapping> getParameterMappings() {
      return parameterMappings;
    }

    public void setParameterMappings(Collection<ParameterMapping> parameterMappings) {
      this.parameterMappings = parameterMappings;
    }

    /**
     * Europhenome define a list of parameter types
     * Their numbering starts from 0.
     * In our system an id should always be greater than 0,
     * so this enum maps between the two.
     *
     */
    public enum ParameterType implements DictionaryEntryEnum {
      SIMPLE_PARAMETER(1L,Parameter.SIMPLE_PARAMETER),
      SERIES_PARAMETER(2L,Parameter.SERIES_PARAMETER),
      MEDIA_PARAMETER(3L,Parameter.MEDIA_PARAMETER),
      PROCEDURE_METADATA(4L,Parameter.PROCEDURE_METADATA),
      MEDIA_SERIES_PARAMETER(5L,Parameter.MEDIA_SERIES);

      private Long id;
      private int europhenomeId;
      public Long getId() {
        return id;
      }
      public int getEurophenomeId() {
        return europhenomeId;
      }
      private ParameterType (Long id, int europhenomeId) {
        this.id = id;
        this.europhenomeId = europhenomeId;
      }
    }

    public String getSeriesUnit() {
      return seriesUnit;
    }

    public void setSeriesUnit(String seriesUnit) {
      this.seriesUnit = seriesUnit;
    }

}