package uk.ac.sanger.mig.europhenome;


import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Collection;
import java.util.Date;
import java.util.Vector;

import org.europhenome.Increment;
import org.europhenome.Parameter;

import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.ComponentEnum;
import uk.ac.sanger.mig.phenotyping.datacapture.Observation;
import uk.ac.sanger.mig.phenotyping.datacapture.RequiredObservation;

public class ParameterMapping extends AuthenticatedDataObject  {

	public enum Component implements ComponentEnum {
		ALL_COMPONENTS,
		PARAMETER_DEFINITION,
		REQUIRED_OBSERVATION,
		OPTION_TRANSLATIONS
	}

    private Long requiredObservationId;
    private Long parameterDefinitionId;
    private Double multiplicationFactor;
    private String seriesMapping;

    private ParameterDefinition parameterDefinition;
    private RequiredObservation requiredObservation;

    private Collection<OptionTranslation> optionTranslations;

    public Long getRequiredObservationId() {
      return requiredObservationId;
    }

    public void setRequiredObservationId(Long requiredObservationId) {
      this.requiredObservationId = requiredObservationId;
    }

    public Long getParameterDefinitionId() {
      return parameterDefinitionId;
    }

    public void setParameterDefinitionId(Long parameterDefinitionId) {
      this.parameterDefinitionId = parameterDefinitionId;
    }

    public Double getMultiplicationFactor() {
      return multiplicationFactor;
    }

    public void setMultiplicationFactor(Double multiplicationFactor) {
      this.multiplicationFactor = multiplicationFactor;
    }

    public String getSeriesMapping() {
      return seriesMapping;
    }

    public void setSeriesMapping(String seriesMapping) {
      this.seriesMapping = seriesMapping;
    }

    public ParameterDefinition getParameterDefinition() {
      return parameterDefinition;
    }

    public void setParameterDefinition(ParameterDefinition parameterDefinition) {
      this.parameterDefinition = parameterDefinition;
    }

    public RequiredObservation getRequiredObservation() {
      return requiredObservation;
    }

    public void setRequiredObservation(RequiredObservation requiredObservation) {
      this.requiredObservation = requiredObservation;
    }

    public Collection<OptionTranslation> getOptionTranslations() {
      return optionTranslations;
    }

    public void setOptionTranslations(Collection<OptionTranslation> optionTranslations) {
      this.optionTranslations = optionTranslations;
    }

    public String convertObservationForExport(Observation o) {
      // enforce a contract
      if (o == null) {
        throw new IllegalArgumentException("Observation should not be null");
      }
      if(!o.getRequiredObservationId().equals(requiredObservationId)) {
        throw new IllegalArgumentException("Mapping is not applicable to argument");
      }
      if (requiredObservation == null || requiredObservation.getObservationType() == null) {
        throw new IllegalStateException("Mapping not ready, require requiredObservation and it's observationType to be attached");
      }
      if (requiredObservation.getObservationType().isRestrictedOption() &&
          optionTranslations == null) {
        throw new IllegalStateException("Translations must be attached to handle options");
      }

      // do the work
      String value = null;

      if (requiredObservation.getObservationType().isRestrictedOption()) {
        Long optionId = Long.valueOf(o.getValue());

        for (OptionTranslation translation : optionTranslations) {
          boolean match = translation.getOptionId().equals(optionId);

          if (match && value != null ) {
            throw new RuntimeException("Several translations available for option "+optionId);
          }

          if (match) value = translation.getEuValue();
        }
      }
      // expand here if other types need special handling
      else {
        value = o.getValue();
      }

      return value;
    }


    @SuppressWarnings("unchecked")
    public void addIncrementValue(Parameter parameter, String value, Date timeRecorded) {
      if (parameter == null) {
        throw new IllegalArgumentException("The argument called parameter must not be null");
      }

      if (parameter.getIncrements() == null) {
        parameter.setIncrements(new Vector<Increment>());
      }
      Vector<Increment> increments = parameter.getIncrements();

      Increment increment = new Increment();
      increment.setValue(value);
      if (seriesMapping == null) {
        DateFormat df= new SimpleDateFormat("dd/MM/yyyy HH:mm:ss zzz");
        increment.setIncreamentValue(df.format(timeRecorded));
      }
      else {
        increment.setIncreamentValue(seriesMapping);
      }


      increments.add(increment);
    }

}