/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.europhenome.dao;

import java.util.Collection;

import org.europhenome.Procedure;
import org.springframework.jdbc.core.simple.SimpleJdbcDaoSupport;

import uk.ac.sanger.mig.europhenome.dao.rowmappers.ClinicalChemistryP1ExportRowMapper;
import uk.ac.sanger.mig.europhenome.dao.rowmappers.ClinicalChemistryP2ExportRowMapper;
import uk.ac.sanger.mig.europhenome.dao.rowmappers.HaematologyExportRowMapper;

public class BloodsExportDaoSpringImpl extends SimpleJdbcDaoSupport implements BloodsExportDao {

	private ClinicalChemistryP1ExportRowMapper ccP1RowMapper = new ClinicalChemistryP1ExportRowMapper();
	private ClinicalChemistryP2ExportRowMapper ccP2RowMapper = new ClinicalChemistryP2ExportRowMapper();
	private HaematologyExportRowMapper haematologyRowMapper = new HaematologyExportRowMapper();

	public Collection<Procedure> fetchClinicalChemP1Data() {
		String sql = makeSql("eur_clinical_chem_p1_exp_vw",1);
		return getSimpleJdbcTemplate().query(sql, ccP1RowMapper);
	}

	public Collection<Procedure> fetchClinicalChemP2Data() {
		String sql = makeSql("eur_clinical_chem_p2_exp_vw",2);
		return getSimpleJdbcTemplate().query(sql, ccP2RowMapper);
	}


	public Collection<Procedure> fetchHaematologyData() {
		String sql = makeSql("EUR_HAEMATOLGY_EXP_VW",2);
		return getSimpleJdbcTemplate().query(sql, haematologyRowMapper);
	}

	private String makeSql(String viewName, int pipeline) {
		String sql = "with mouse_pipeline as (" +
		" select cm.mouse_id," +
		" max(decode(c.PIPELINE_DICT_ID,1,1,0)) p1," +
		" max(decode(c.PIPELINE_DICT_ID,2,1,0)) p2," +
		" max(decode(c.PIPELINE_DICT_ID,1,0,2,0,1)) other_pipeline" +
		" from mts_cohort_mouse cm" +
		" join mts_cohort c on cm.cohort_id = c.id" +
		" where c.COHORT_TYPE_ID = 1" +
		" group by cm.mouse_id" +
		" )" +
		" select e.* from "+ viewName + " e" +
		" join mouse_pipeline p on e.mouse_id = p.mouse_id" +
		" join EUR_MICE_EXPORTED m on m.mouse_id = e.mouse_id" +
		" where e.failed = 0" +
		" and not exists (select null from eur_data_exported where e.run_id = foreign_key_id and foreign_table_name = 'PHN_BLOODS_RUN')";

		if (pipeline == 1)
			sql += " and p.p1 = 1 and p.p2 = 0 and p.other_pipeline = 0";
		else if (pipeline == 2)
			sql += " and p.p1 = 0 and p.p2 = 1 and p.other_pipeline = 0";

		return sql;
	}




}
