/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.europhenome.dao;

import java.util.Collection;

import uk.ac.sanger.mig.phenotyping.datacapture.Experiment;
import uk.ac.sanger.mig.phenotyping.datacapture.dao.ExperimentDaoSpringImpl;

public class ExperimentExportDaoSpringImpl extends ExperimentDaoSpringImpl implements ExperimentExportDao {

  public Collection<Experiment> fetchExperimentsForExport() {
    String sql =
      "SELECT distinct e.* " +
      "FROM phn_experiment e " +
      "JOIN mts_mouse_procedure mp ON mp.foreign_table_name = 'PHN_EXPERIMENT' AND mp.foreign_key_id = e.id " +
      "JOIN eur_mice_exported me ON e.mouse_id = me.mouse_id " +
      "JOIN eur_sop_2_procedure sp on e.sop_id = sp.sop_id " +
      "WHERE e.is_complete = 1 " +
       "AND not exists (select * from eur_data_exported where e.id = foreign_key_id and foreign_table_name = 'PHN_EXPERIMENT') " +
       "AND( " +
       	"sp.min_date is null or trunc(mp.start_date) >= trunc(sp.min_date) " +
       ") " +
       //" and sop_id not in (121) " + // The Europhenome validator has problems with these sops
       "order by e.id";

    return getSimpleJdbcTemplate().query(sql, getRowMapper());
  }

}
