/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.europhenome.dao;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.common.PaginatedSearchUtils;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.europhenome.MouseExported;
import uk.ac.sanger.mig.europhenome.MouseExportedSearchBean;

public class MouseExportedDaoSpringImpl extends AbstractDaoSpringImpl<MouseExported> implements MouseExportedDao {
  private PaginatedSearchUtils<MouseExported> paginator;

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, MouseExported mouseExported) {
		sql.addLongParam(mouseExported.getMouseId(), "MOUSE_ID");
		sql.addLongParam(mouseExported.getCohortId(), "COHORT_ID");
		sql.addBooleanParam(mouseExported.isDeathReported(), "DEATH_REPORTED");
		sql.addLongParam(mouseExported.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(mouseExported.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(mouseExported.getCreatedDate(), "CREATED_DATE");
		sql.addStringParam(mouseExported.getEditedBy(), "EDITED_BY");
		sql.addDateParam(mouseExported.getEditDate(), "EDIT_DATE");
		sql.addLongParam(mouseExported.getId(), "ID");
	}

	public Collection<MouseExported> search(MouseExportedSearchBean searchBean) {
	  Collection<Object> bindVariables = new ArrayList<Object>();
	  String sql = "select * from "+getTableName()+" where 1=1";

	  return paginator.fetchSearchResults(sql, bindVariables, searchBean, getRowMapper());
	}

  public void setPaginator(PaginatedSearchUtils<MouseExported> paginator) {
    this.paginator = paginator;
  }
  
  public MouseExported fetchByMouseId(Long mouseId) {
    String sql = "select * from "+getTableName()+" where mouse_id = ?";
    return getSimpleJdbcTemplate().queryForObject(sql, getRowMapper(), mouseId);
  }
	
}