/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.europhenome.dao;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.common.PaginatedSearchUtils;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.europhenome.ProcedureDefinition;
import uk.ac.sanger.mig.europhenome.ProcedureDefinitionSearchBean;

public class ProcedureDefinitionDaoSpringImpl extends AbstractDaoSpringImpl<ProcedureDefinition> implements ProcedureDefinitionDao {

  private PaginatedSearchUtils<ProcedureDefinition> paginator;

  public void setPaginator(PaginatedSearchUtils<ProcedureDefinition> paginator) {
    this.paginator = paginator;
  }
  
  public Collection<ProcedureDefinition> search(ProcedureDefinitionSearchBean searchBean) {
    Collection<Object> bindVariables = new ArrayList<Object>();
    String sql = "select * from "+getTableName()+" where 1=1";
    
    return paginator.fetchSearchResults(sql, bindVariables, searchBean, getRowMapper());
  }

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, ProcedureDefinition procedureDefinition) {
		sql.addStringParam(procedureDefinition.getName(), "NAME");
		sql.addStringParam(procedureDefinition.getEmpressId(), "EMPRESS_ID");
		sql.addLongParam(procedureDefinition.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(procedureDefinition.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(procedureDefinition.getCreatedDate(), "CREATED_DATE");
		sql.addStringParam(procedureDefinition.getEditedBy(), "EDITED_BY");
		sql.addDateParam(procedureDefinition.getEditDate(), "EDIT_DATE");
		sql.addLongParam(procedureDefinition.getId(), "ID");
	}

  public Collection<ProcedureDefinition> fetchBySopId(Long sopId) {
    String sql = "select * from " + getTableName() + " p join EUR_SOP_2_PROCEDURE s on s.PROCEDURE_DEF_ID = p.ID where s.SOP_ID = ?";
    
    return getSimpleJdbcTemplate().query(sql, getRowMapper(), sopId);
  }

}