/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.europhenome.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Collection;

import org.europhenome.Parameter;

public abstract class AbstractClinicalChemistryRowMapper extends AbstractBloodsExportRowMapper {


	@Override
	Collection<Parameter> getParameters(ResultSet rs) throws SQLException{
		Collection<Parameter> parameters = new ArrayList<Parameter>();

		parameters.addAll(this.getPipelineParameters(rs));

		Parameter plasmaDilution = this.buildParam(this.getPlasmaDilutionEmpressId());
		plasmaDilution.setValue("Neat plasma");
		plasmaDilution.setMeasurementType(Parameter.PROCEDURE_METADATA);
		parameters.add(plasmaDilution);

		Parameter sampleStatus = this.buildParam(this.getSampleStatusEmpressId());
		sampleStatus.setValue("Fresh");
		sampleStatus.setMeasurementType(Parameter.PROCEDURE_METADATA);
		parameters.add(sampleStatus);

		// Clinical Chemistry equipment
		Parameter equipName =
			buildStringParam(this.getEquipNameEmpressId(), "Olympus AU400");
		equipName.setMeasurementType(Parameter.PROCEDURE_METADATA);
		parameters.add(equipName);

		Parameter equipManufacturer =
			buildStringParam(this.getEquipManufacturerEmpressId(), "Olympus");
		equipManufacturer.setMeasurementType(Parameter.PROCEDURE_METADATA);
		parameters.add(equipManufacturer);

		Parameter equipModel =
			buildStringParam(this.getEquipModelEmpressId(), "AU400");
		equipModel.setMeasurementType(Parameter.PROCEDURE_METADATA);
		parameters.add(equipModel);

		return parameters;
	}

	abstract Collection<Parameter> getPipelineParameters(ResultSet rs) throws SQLException;
	abstract String getPlasmaDilutionEmpressId();
	abstract String getSampleStatusEmpressId();
	abstract String getFastingPeriodEmpressId();
	abstract String getWasFastingEmpressId();
	abstract String getEquipNameEmpressId();
	abstract String getEquipManufacturerEmpressId();
	abstract String getEquipModelEmpressId();
	abstract String getWasMovedEmpressId();

}
