/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.europhenome.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Collection;

import org.europhenome.Parameter;


public class ClinicalChemistryP1ExportRowMapper extends AbstractClinicalChemistryRowMapper {

	@Override
	public Collection<Parameter> getPipelineParameters(ResultSet rs) throws SQLException {
		Collection<Parameter> parameters = new ArrayList<Parameter>();

		// results
		Parameter glucose =
			this.buildFloatParam(rs, "GLUCOSE", "ESLIM_021_001_001");
		parameters.add(glucose);

		Parameter totalCholesterol =
			this.buildFloatParam(rs, "TOTAL_CHOLESTEROL", "ESLIM_021_001_002");
		parameters.add(totalCholesterol);

		Parameter triglycerides =
			this.buildFloatParam(rs, "TRIGLYCERIDES", "ESLIM_021_001_003");
		parameters.add(triglycerides);

		Parameter freeFattyAcid =
			this.buildFloatParam(rs, "FREE_FATTY_ACID", "ESLIM_021_001_004");
		parameters.add(freeFattyAcid);

		// hdl & ldl cholesterol are optional values, only add them if we have the data
		Parameter hdlCholesterol =
			this.buildFloatParam(rs, "HDL_CHOLESTEROL", "ESLIM_021_001_005");
		if (hdlCholesterol.getParameterStatus() == null)
			parameters.add(hdlCholesterol);

		Parameter ldlCholesterol =
			this.buildFloatParam(rs, "LDL_CHOLESTEROL", "ESLIM_021_001_006");
		if (ldlCholesterol.getParameterStatus() == null)
			parameters.add(ldlCholesterol);


		//metadata
		Parameter wasFasting = this.buildParam(this.getWasFastingEmpressId());
		wasFasting.setValue("yes");
		wasFasting.setMeasurementType(Parameter.PROCEDURE_METADATA);
		parameters.add(wasFasting);

		Parameter fastingPeriod = this.buildParam(this.getFastingPeriodEmpressId());
		fastingPeriod.setValue("16");
		fastingPeriod.setMeasurementType(Parameter.PROCEDURE_METADATA);
		parameters.add(fastingPeriod);

		Parameter wasMovedForFasting = this.buildParam(this.getWasMovedEmpressId());
		wasMovedForFasting.setValue("yes");
		wasMovedForFasting.setMeasurementType(Parameter.PROCEDURE_METADATA);
		parameters.add(wasMovedForFasting);


		return parameters;
	}

	@Override
	public String getAnaesthesiaEmpressId() {
		return "ESLIM_021_001_812";
	}

	@Override
	public String getBleedTypeEmpressId() {
		return "ESLIM_021_001_804";
	}

	@Override
	public String getCollectionDateEmpressId() {
		return "ESLIM_021_001_806";
	}

	@Override
	public String getProcedureEmpressId() {
		return "ESLIM_021_001";
	}

	@Override
	String getFastingPeriodEmpressId() {
		return "ESLIM_021_001_808";
	}

	@Override
	String getPlasmaDilutionEmpressId() {
		return "ESLIM_021_001_810";
	}

	@Override
	String getSampleStatusEmpressId() {
		return "ESLIM_021_001_811";
	}

	@Override
	String getWasFastingEmpressId() {
		return "ESLIM_021_001_807";
	}

	@Override
	String getEquipManufacturerEmpressId() {
		return "ESLIM_021_001_802";
	}

	@Override
	String getEquipModelEmpressId() {
		return "ESLIM_021_001_803";
	}

	@Override
	String getEquipNameEmpressId() {
		return "ESLIM_021_001_801";
	}

	@Override
	String getWasMovedEmpressId() {
		return "ESLIM_021_001_809";
	}
}
