/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.europhenome.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Collection;

import org.europhenome.Parameter;

public class ClinicalChemistryP2ExportRowMapper extends AbstractClinicalChemistryRowMapper {

	@Override
	Collection<Parameter> getPipelineParameters(ResultSet rs) throws SQLException {
		Collection<Parameter> parameters = new ArrayList<Parameter>();

		// required parameters
		Parameter glucose = this.buildFloatParam(rs, "GLUCOSE", "ESLIM_015_001_001");
		parameters.add(glucose);

		Parameter urea = this.buildFloatParam(rs, "UREA", "ESLIM_015_001_002");
		parameters.add(urea);

		Parameter creatinine = this.buildFloatParam(rs, "CREATININE", "ESLIM_015_001_003");
		parameters.add(creatinine);

		Parameter sodium = this.buildFloatParam(rs, "SODIUM", "ESLIM_015_001_004");
		parameters.add(sodium);

		Parameter potassium = this.buildFloatParam(rs, "POTASSIUM", "ESLIM_015_001_005");
		parameters.add(potassium);

		Parameter chloride = this.buildFloatParam(rs, "CHLORIDE", "ESLIM_015_001_006");
		parameters.add(chloride);

		Parameter totalProtein = this.buildFloatParam(rs, "TOTAL_PROTEIN", "ESLIM_015_001_007");
		parameters.add(totalProtein);

		Parameter albumin = this.buildFloatParam(rs, "ALBUMIN", "ESLIM_015_001_008");
		parameters.add(albumin);

		Parameter calcium = this.buildFloatParam(rs, "CALCIUM", "ESLIM_015_001_009");
		parameters.add(calcium);

		Parameter phosphorus = this.buildFloatParam(rs, "PHOSPHORUS", "ESLIM_015_001_010");
		parameters.add(phosphorus);

		Parameter aspartateAminotransferase = this.buildFloatParam(rs, "ASPARTATE_AMINOTRANSFERASE", "ESLIM_015_001_013");
		parameters.add(aspartateAminotransferase);

		Parameter alanineAminotransferase = this.buildFloatParam(rs, "ALANINE_AMINOTRANSFERASE", "ESLIM_015_001_014");
		parameters.add(alanineAminotransferase);

		Parameter alkalinePhosphatase = this.buildFloatParam(rs, "ALKALINE_PHOSPHATASE", "ESLIM_015_001_015");
		parameters.add(alkalinePhosphatase);

		Parameter alphaAmylase = this.buildFloatParam(rs, "ALPHA_AMYLASE", "ESLIM_015_001_016");
		parameters.add(alphaAmylase);

		Parameter totalCholesterol = this.buildFloatParam(rs, "TOTAL_CHOLESTEROL", "ESLIM_015_001_017");
		parameters.add(totalCholesterol);

		Parameter triglyceride = this.buildFloatParam(rs, "TRIGLYCERIDE", "ESLIM_015_001_018");
		parameters.add(triglyceride);

		Parameter freeFattyAcid = this.buildFloatParam(rs, "FREE_FATTY_ACID", "ESLIM_015_001_019");
		parameters.add(freeFattyAcid);

		// optional paramateters
		Parameter iron = this.buildFloatParam(rs, "IRON", "ESLIM_015_001_011");
		if (iron.getParameterStatus() == null)
			parameters.add(iron);

		Parameter lactateDehydrogenase = this.buildFloatParam(rs, "LACTATE_DEHYDROGENASE", "ESLIM_015_001_012");
		if (lactateDehydrogenase.getParameterStatus() == null)
			parameters.add(lactateDehydrogenase);

		Parameter creatineKinase = this.buildFloatParam(rs, "CREATINE_KINASE", "ESLIM_015_001_020");
		if (creatineKinase.getParameterStatus() == null)
			parameters.add(creatineKinase);


		Parameter uricAcid = this.buildFloatParam(rs, "URIC_ACID", "ESLIM_015_001_021");
		if (uricAcid.getParameterStatus() == null)
			parameters.add(uricAcid);

		Parameter totalBilirubin = this.buildFloatParam(rs, "TOTAL_BILIRUBIN", "ESLIM_015_001_022");
		if (totalBilirubin.getParameterStatus() == null)
			parameters.add(totalBilirubin);

		Parameter hdlCholesterol = this.buildFloatParam(rs, "HDL_CHOLESTEROL", "ESLIM_015_001_023");
		if (hdlCholesterol.getParameterStatus() == null)
			parameters.add(hdlCholesterol);

		Parameter ldlCholesterol = this.buildFloatParam(rs, "LDL_CHOLESTEROL", "ESLIM_015_001_024");
		if (ldlCholesterol.getParameterStatus() == null)
			parameters.add(ldlCholesterol);

		Parameter ferretin = this.buildFloatParam(rs, "FERRETIN", "ESLIM_015_001_025");
		if (ferretin.getParameterStatus() == null)
			parameters.add(ferretin);

		Parameter transferrin = this.buildFloatParam(rs, "TRANSFERRIN", "ESLIM_015_001_026");
		if (transferrin.getParameterStatus() == null)
			parameters.add(transferrin);

		Parameter cReactiveProtein = this.buildFloatParam(rs, "C_REACTIVE_PROTEIN", "ESLIM_015_001_027");
		if (cReactiveProtein.getParameterStatus() == null)
			parameters.add(cReactiveProtein);

		// metadata
		Parameter wasFasting = this.buildParam(this.getWasFastingEmpressId());
		wasFasting.setValue("no");
		wasFasting.setMeasurementType(Parameter.PROCEDURE_METADATA);
		parameters.add(wasFasting);

		Parameter fastingPeriod = this.buildParam(this.getFastingPeriodEmpressId());
		fastingPeriod.setValue("0");
		fastingPeriod.setMeasurementType(Parameter.PROCEDURE_METADATA);
		parameters.add(fastingPeriod);

		Parameter wasMovedForFasting = this.buildParam(this.getWasMovedEmpressId());
		wasMovedForFasting.setValue("no");
		wasMovedForFasting.setMeasurementType(Parameter.PROCEDURE_METADATA);
		parameters.add(wasMovedForFasting);

		return parameters;
	}

	@Override
	String getEquipManufacturerEmpressId() {
		return "ESLIM_015_001_802";
	}

	@Override
	String getEquipModelEmpressId() {
		return "ESLIM_015_001_803";
	}

	@Override
	String getEquipNameEmpressId() {
		return "ESLIM_015_001_801";
	}

	@Override
	String getFastingPeriodEmpressId() {
		return "ESLIM_015_001_808";
	}

	@Override
	String getPlasmaDilutionEmpressId() {
		return "ESLIM_015_001_810";
	}

	@Override
	String getSampleStatusEmpressId() {
		return "ESLIM_015_001_811";
	}

	@Override
	String getWasFastingEmpressId() {
		return "ESLIM_015_001_807";
	}

	@Override
	String getAnaesthesiaEmpressId() {
		return "ESLIM_015_001_812";
	}

	@Override
	String getBleedTypeEmpressId() {
		return "ESLIM_015_001_804";
	}

	@Override
	String getCollectionDateEmpressId() {
		return "ESLIM_015_001_806";
	}

	@Override
	String getProcedureEmpressId() {
		return "ESLIM_015_001";
	}

	@Override
	String getWasMovedEmpressId() {
		return "ESLIM_015_001_809";
	}

}
