/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.europhenome.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Collection;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.europhenome.Parameter;

public class HaematologyExportRowMapper extends AbstractBloodsExportRowMapper {
	protected Log logger = LogFactory.getLog(this.getClass());

	@Override
	public Collection<Parameter> getParameters(ResultSet rs) throws SQLException {
		Collection<Parameter> parameters = new ArrayList<Parameter>();

		Parameter wbcParam = this.buildFloatParam(rs, "WBC_COUNT", "ESLIM_016_001_001");
		parameters.add(wbcParam);

		Parameter rbcParam = this.buildFloatParam(rs, "RBC_COUNT", "ESLIM_016_001_002");
		parameters.add(rbcParam);

		Parameter hgbParam = this.buildFloatParam(rs, "HGB", "ESLIM_016_001_003");
		parameters.add(hgbParam);

		Parameter hctParam = this.buildFloatParam(rs, "HCT", "ESLIM_016_001_004");
		parameters.add(hctParam);

		Parameter mcvParam = this.buildFloatParam(rs, "MCV", "ESLIM_016_001_005");
		parameters.add(mcvParam);

		Parameter mchParam = this.buildFloatParam(rs, "MCH", "ESLIM_016_001_006");
		parameters.add(mchParam);

		Parameter mchcParam = this.buildFloatParam(rs, "MCHC", "ESLIM_016_001_007");
		parameters.add(mchcParam);

		Parameter pltParam = this.buildFloatParam(rs, "PLT", "ESLIM_016_001_008");
		parameters.add(pltParam);

		Parameter equipName = this.buildStringParam("ESLIM_016_001_801", "scil Vet abc hematology analyzer");
		equipName.setMeasurementType(Parameter.PROCEDURE_METADATA);
		parameters.add(equipName);
		
		Parameter equipManufacturer = this.buildStringParam("ESLIM_016_001_802", "scil Vet");
		equipManufacturer.setMeasurementType(Parameter.PROCEDURE_METADATA);
		parameters.add(equipManufacturer);
		
		Parameter equipModel = this.buildStringParam("ESLIM_016_001_803", "abc hematology analyzer");
		equipModel.setMeasurementType(Parameter.PROCEDURE_METADATA);
		parameters.add(equipModel);
		
		Parameter chipCard = this.buildStringParam("ESLIM_016_001_813", "abc hematology analyzer");
		chipCard.setMeasurementType(Parameter.PROCEDURE_METADATA);
		parameters.add(chipCard);

		return parameters;
	}

	@Override
	public String getAnaesthesiaEmpressId() {
		return "ESLIM_016_001_812";
	}

	@Override
	public String getBleedTypeEmpressId() {
		return "ESLIM_016_001_804";
	}

	@Override
	public String getCollectionDateEmpressId() {
		return "ESLIM_016_001_806";
	}

	@Override
	public String getProcedureEmpressId() {
		return "ESLIM_016_001";
	}


}
