/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.europhenome.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.europhenome.ParameterDefinition;

public class ParameterDefinitionRowMapper implements ParameterizedRowMapper<ParameterDefinition> {

	public ParameterDefinition mapRow(ResultSet rs, int rowNum) throws SQLException {
		
		ParameterDefinition parameterDefinition = new ParameterDefinition();
		

		parameterDefinition.setId(rs.getLong("ID"));

		parameterDefinition.setName(rs.getString("NAME"));

		parameterDefinition.setEmpressId(rs.getString("EMPRESS_ID"));

		parameterDefinition.setProcedureDefinitionId(rs.getLong("PROCEDURE_DEFINITION_ID"));
		if(rs.wasNull()) parameterDefinition.setProcedureDefinitionId(null);		

		parameterDefinition.setUnits(rs.getString("UNITS"));

		parameterDefinition.setParameterTypeId(rs.getLong("PARAMETER_TYPE_DICT_ID"));

		parameterDefinition.setMinBound(rs.getDouble("MIN_BOUND"));
		if (rs.wasNull()) parameterDefinition.setMinBound(null);
		
		parameterDefinition.setMaxBound(rs.getDouble("MAX_BOUND"));
		if (rs.wasNull()) parameterDefinition.setMaxBound(null);
		
		parameterDefinition.setDataSeries(rs.getBoolean("IS_DATA_SERIES"));

		parameterDefinition.setRequired(rs.getBoolean("IS_REQUIRED"));

		parameterDefinition.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) parameterDefinition.setCheckNumber(null);		

		parameterDefinition.setCreatorId(rs.getLong("CREATOR_ID"));

		parameterDefinition.setCreatedDate(rs.getTimestamp("CREATED_DATE"));

		parameterDefinition.setEditedBy(rs.getString("EDITED_BY"));

		parameterDefinition.setEditDate(rs.getTimestamp("EDIT_DATE"));
		
		parameterDefinition.setSeriesUnit(rs.getString("SERIES_UNIT"));
		
		return parameterDefinition;
		
	}
}