/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.europhenome.services;

import java.util.Collection;
import java.util.LinkedList;

import org.europhenome.Procedure;
import org.springframework.transaction.annotation.Transactional;

import uk.ac.sanger.mig.database.TableMetadataEnum;
import uk.ac.sanger.mig.europhenome.DataExported;
import uk.ac.sanger.mig.europhenome.dao.BloodsExportDao;
import uk.ac.sanger.mig.personnel.Person;


public class BloodsDataExportServiceImpl implements BloodsDataExportService {

	private BloodsExportDao bloodsExportDao;
	private DataExportedService dataExportedService;

	public void setBloodsExportDao(BloodsExportDao bloodsExportDao) {
		this.bloodsExportDao = bloodsExportDao;
	}

	public void setDataExportedService(DataExportedService dataExportedService) {
		this.dataExportedService = dataExportedService;
	}

	public Collection<Procedure> fetchBloodsData() {
		Collection<Procedure> data = new LinkedList<Procedure>();
		data.addAll(this.fetchClinicalChemistryPipelineOneData());
		data.addAll(this.fetchClinicalChemistryPipelineTwoData());
		data.addAll(this.fetchHaemtologyData());
		return data;
	}

	public Collection<Procedure> fetchClinicalChemistryPipelineOneData() {
		return bloodsExportDao.fetchClinicalChemP1Data();
	}

	public Collection<Procedure> fetchClinicalChemistryPipelineTwoData() {
		return bloodsExportDao.fetchClinicalChemP2Data();
	}

	public Collection<Procedure> fetchHaemtologyData() {
		return bloodsExportDao.fetchHaematologyData();
	}

	@Transactional
	public Collection<Procedure> exportBloodsData(Person user) {
		Collection<Procedure> procedures = this.fetchBloodsData();

		for (Procedure p : procedures) {
			String extId = p.getExternalProcedureId();
			if (! extId.startsWith("BR")) {
				throw new RuntimeException("Exported procedure ID is not in the expected format: "+extId);
			}
			Long bloodsRunId  = Long.valueOf(extId.substring(2));

			DataExported exportNote = new DataExported(bloodsRunId, TableMetadataEnum.PHN_BLOODS_RUN);
			dataExportedService.store(exportNote, user);
		}

		return procedures;
	}

}
