/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.europhenome.services;

import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.database.TableMetadataEnum;
import uk.ac.sanger.mig.europhenome.DataExported;
import uk.ac.sanger.mig.europhenome.DataExportedSearchBean;
import uk.ac.sanger.mig.europhenome.dao.DataExportedDao;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.phenotyping.datacapture.Experiment;

public class DataExportedServiceImpl extends AbstractServiceImpl<DataExported> implements DataExportedService {

	private DataExportedDao dataExportedDao;

	//IMPORTANT: add other dependencies here: Should be other services *not* dao typically
	/**
	 * eg 	private DataExportedDao dataExportedDao;
	 *    private MouseService mouseService
	 *    private PersonService personService;
	 */

	public void setDataExportedDao(DataExportedDao dataExportedDao) {
		this.dataExportedDao = dataExportedDao;
	}


	public Long store(DataExported dataExported, Person user) {
		if(dataExported == null) {
			throw new RuntimeException("Cannot save a null dataExported");
		}

		return dataExportedDao.store(dataExported, user);
	}

	public DataExported fetchById(Long dataExportedId, ComponentMap requiredComponents) {
		DataExported dataExported = dataExportedDao.fetchById(dataExportedId);

		if(dataExported != null)
			attachComponents(dataExported, requiredComponents);

		return dataExported;
	}

	@Override
	protected void attachComponents(DataExported dataExported, ComponentMap requiredComponents) {
		if(dataExported == null) {
			throw new RuntimeException("Cannot attach components to null dataExported");
		}
		// there are no components
	}


  public Collection<DataExported> search(DataExportedSearchBean dataExportedSearchBean) {
    return dataExportedDao.search(dataExportedSearchBean);
  }


  public void recordDataExported(Experiment experiment, Person user) {
    if (experiment == null) throw new IllegalArgumentException("No experiment provided");
    if (user == null) throw new IllegalArgumentException("No person provided");

    DataExported exportNote = new DataExported(experiment.getId(),TableMetadataEnum.PHN_EXPERIMENT);
    store(exportNote,user);

  }

}
