/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.europhenome.services;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.mousetracking.Cohort;
import uk.ac.sanger.mig.mousetracking.Mouse;
import uk.ac.sanger.mig.personnel.Person;
								
import java.util.Collection;

import org.springframework.transaction.annotation.Transactional;

import uk.ac.sanger.mig.common.AbstractServiceImpl;

import uk.ac.sanger.mig.europhenome.MouseExported;
import uk.ac.sanger.mig.europhenome.MouseExportedSearchBean;
import uk.ac.sanger.mig.europhenome.dao.MouseExportedDao;

public class MouseExportedServiceImpl extends AbstractServiceImpl<MouseExported> implements MouseExportedService {
	
	private MouseExportedDao mouseExportedDao;
	
	//IMPORTANT: add other dependencies here: Should be other services *not* dao typically
	/**
	 * eg 	private MouseExportedDao mouseExportedDao;
	 *    private MouseService mouseService
	 *    private PersonService personService; 
	 */
	
	public void setMouseExportedDao(MouseExportedDao mouseExportedDao) {
		this.mouseExportedDao = mouseExportedDao;
	}


	public Long store(MouseExported mouseExported, Person user) {
		if(mouseExported == null) {
			throw new RuntimeException("Cannot save a null mouseExported");
		}
		
		return mouseExportedDao.store(mouseExported, user);
	}
	
	public MouseExported fetchById(Long mouseExportedId, ComponentMap requiredComponents) {
		MouseExported mouseExported = mouseExportedDao.fetchById(mouseExportedId);
		
		if(mouseExported != null)
			attachComponents(mouseExported, requiredComponents);
		
		return mouseExported;
	}

	@Override
	protected void attachComponents(MouseExported mouseExported, ComponentMap requiredComponents) {
		if(mouseExported == null) {
			throw new RuntimeException("Cannot attach components to null mouseExported");
		}		
		
		// yes we have no components, no components today...
		//boolean fetchAll = false;
		
		//if(requiredComponents != null) {
			
			//if(requiredComponents.containsKey(MouseExported.Component.ALL_COMPONENTS)) {
				//fetchAll = true;
			//}
			
			// query required components map and fetch/attach sub-components as needed
			// ...........
			
		//}
	}


  public Collection<MouseExported> search(MouseExportedSearchBean mouseExportedSearchBean) {
    return mouseExportedDao.search(mouseExportedSearchBean);
  }

  @Transactional
  public void recordCohortExport(Cohort cohort, Person person) {
    if (cohort == null || cohort.getMice() == null || cohort.getMice().size() < 1) throw new IllegalArgumentException("Cannot record mouse export, no mice provided");
    if (person == null) throw new IllegalArgumentException("Person must be provided");
    
    for(Mouse m : cohort.getMice()) {
      MouseExported exportNote = new MouseExported(); 
      
      exportNote.setCohortId(cohort.getId());
      exportNote.setMouseId(m.getId());
      exportNote.setDeathReported(false);
      
      store(exportNote,person);
    }
  }
  
  public MouseExported fetchByMouseId(Long mouseId, ComponentMap componentMap) {
    MouseExported mouseExported = mouseExportedDao.fetchByMouseId(mouseId);
    attachComponents(mouseExported, componentMap);
    return mouseExported;
  }
	
}
								