/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.europhenome.services;

import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.europhenome.OptionTranslation;
import uk.ac.sanger.mig.europhenome.OptionTranslationSearchBean;
import uk.ac.sanger.mig.europhenome.dao.OptionTranslationDao;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.phenotyping.datacapture.services.RestrictedOptionService;

public class OptionTranslationServiceImpl extends AbstractServiceImpl<OptionTranslation> implements OptionTranslationService {
	
	private OptionTranslationDao optionTranslationDao;
	private RestrictedOptionService restrictedOptionService;
	
	//IMPORTANT: add other dependencies here: Should be other services *not* dao typically
	/**
	 * eg 	private OptionTranslationDao optionTranslationDao;
	 *    private MouseService mouseService
	 *    private PersonService personService; 
	 */
	
	public void setOptionTranslationDao(OptionTranslationDao optionTranslationDao) {
		this.optionTranslationDao = optionTranslationDao;
	}
	
	public void setRestrictedOptionService(RestrictedOptionService restrictedOptionService) {
    this.restrictedOptionService = restrictedOptionService;
  }

  public Long store(OptionTranslation optionTranslation, Person user) {
		if(optionTranslation == null) {
			throw new RuntimeException("Cannot save a null optionTranslation");
		}
		
		return optionTranslationDao.store(optionTranslation, user);
	}
	
	public OptionTranslation fetchById(Long optionTranslationId, ComponentMap requiredComponents) {
		OptionTranslation optionTranslation = optionTranslationDao.fetchById(optionTranslationId);
		
		if(optionTranslation != null)
			attachComponents(optionTranslation, requiredComponents);
		
		return optionTranslation;
	}

	@Override
	protected void attachComponents(OptionTranslation optionTranslation, ComponentMap requiredComponents) {
		if(optionTranslation == null) {
			throw new RuntimeException("Cannot attach components to null optionTranslation");
		}		
		
		boolean fetchAll = false;
		
		if(requiredComponents != null) {
			
			if(requiredComponents.containsKey(OptionTranslation.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}
			
			if (fetchAll || requiredComponents.containsKey(OptionTranslation.Component.RESTRICTED_OPTION)) {
			  optionTranslation.setOption(
			      restrictedOptionService.fetchById(
			          optionTranslation.getOptionId(),
			          requiredComponents.get(OptionTranslation.Component.RESTRICTED_OPTION)
			      )
			  );
			}
			
		}
	}


  public Collection<OptionTranslation> search(OptionTranslationSearchBean optionTranslationSearchBean) {
    return optionTranslationDao.search(optionTranslationSearchBean);
  }

  public Collection<OptionTranslation> fetchByMappingId(Long mappingId, ComponentMap requiredComponents) {
    Collection<OptionTranslation> translations = optionTranslationDao.fetchByMappingId(mappingId);
    attachComponents(translations, requiredComponents);
    return translations;
  }
	
}
								