/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.europhenome.services;

import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.europhenome.ParameterDefinition;
import uk.ac.sanger.mig.europhenome.ParameterDefinitionSearchBean;
import uk.ac.sanger.mig.europhenome.dao.ParameterDefinitionDao;
import uk.ac.sanger.mig.personnel.Person;

public class ParameterDefinitionServiceImpl extends AbstractServiceImpl<ParameterDefinition> implements ParameterDefinitionService {
	
	private ParameterDefinitionDao parameterDefinitionDao;
	private ParameterMappingService parameterMappingService;
	private ProcedureDefinitionService procedureDefinitionService;
	
	public void setParameterDefinitionDao(ParameterDefinitionDao parameterDefinitionDao) {
		this.parameterDefinitionDao = parameterDefinitionDao;
	}
	
	public void setParameterMappingService(ParameterMappingService parameterMappingService) {
    this.parameterMappingService = parameterMappingService;
  }

  public void setProcedureDefinitionService(ProcedureDefinitionService procedureDefinitionService) {
    this.procedureDefinitionService = procedureDefinitionService;
  }

  

  public Long store(ParameterDefinition parameterDefinition, Person user) {
		if(parameterDefinition == null) {
			throw new RuntimeException("Cannot save a null parameterDefinition");
		}
		
		return parameterDefinitionDao.store(parameterDefinition, user);
	}
	
	public ParameterDefinition fetchById(Long parameterDefinitionId, ComponentMap requiredComponents) {
		ParameterDefinition parameterDefinition = parameterDefinitionDao.fetchById(parameterDefinitionId);
		
		if(parameterDefinition != null)
			attachComponents(parameterDefinition, requiredComponents);
		
		return parameterDefinition;
	}

	@Override
	protected void attachComponents(ParameterDefinition parameterDefinition, ComponentMap requiredComponents) {
		if(parameterDefinition == null) {
			throw new RuntimeException("Cannot attach components to null parameterDefinition");
		}		
		
		boolean fetchAll = false;
		
		if(requiredComponents != null) {
			
			if(requiredComponents.containsKey(ParameterDefinition.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}
			
			if(fetchAll || requiredComponents.containsKey(ParameterDefinition.Component.PARAMETER_MAPPINGS)) {
			  parameterDefinition.setParameterMappings(
			      parameterMappingService.fetchByDefinitionId(
			          parameterDefinition.getId(),
			          requiredComponents.get(ParameterDefinition.Component.PARAMETER_MAPPINGS)
			      )
			  );
      }
			
			if(fetchAll || requiredComponents.containsKey(ParameterDefinition.Component.PROCEDURE_DEFINITION)) {
        parameterDefinition.setProcedureDefinition(
            procedureDefinitionService.fetchById(
                parameterDefinition.getProcedureDefinitionId(),
                requiredComponents.get(ParameterDefinition.Component.PROCEDURE_DEFINITION)
            )
        );
      }
		}
	}


  public Collection<ParameterDefinition> search(ParameterDefinitionSearchBean parameterDefinitionSearchBean) {
    return parameterDefinitionDao.search(parameterDefinitionSearchBean);
  }

  public Collection<ParameterDefinition> fetchByProcedureDefinitionId(Long procedureDefinitionId, ComponentMap requiredComponents) {
    Collection<ParameterDefinition> paramDefs = parameterDefinitionDao.fetchByProcedureDefinitionId(procedureDefinitionId);
    attachComponents(paramDefs, requiredComponents);
    return paramDefs;
  }
	
}
								