/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.europhenome.services;

import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.europhenome.ParameterMapping;
import uk.ac.sanger.mig.europhenome.ParameterMappingSearchBean;
import uk.ac.sanger.mig.europhenome.dao.ParameterMappingDao;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.phenotyping.datacapture.services.RequiredObservationService;

public class ParameterMappingServiceImpl extends AbstractServiceImpl<ParameterMapping> implements ParameterMappingService {
	
	private ParameterMappingDao parameterMappingDao;
	private OptionTranslationService optionTranslationService;
	private ParameterDefinitionService parameterDefinitionService;
	private RequiredObservationService requiredObservationService;

	public Long store(ParameterMapping parameterMapping, Person user) {
		if(parameterMapping == null) {
			throw new RuntimeException("Cannot save a null parameterMapping");
		}
		
		return parameterMappingDao.store(parameterMapping, user);
	}
	
	public ParameterMapping fetchById(Long parameterMappingId, ComponentMap requiredComponents) {
		ParameterMapping parameterMapping = parameterMappingDao.fetchById(parameterMappingId);
		
		if(parameterMapping != null)
			attachComponents(parameterMapping, requiredComponents);
		
		return parameterMapping;
	}

	@Override
	protected void attachComponents(ParameterMapping parameterMapping, ComponentMap requiredComponents) {
		if(parameterMapping == null) {
			throw new RuntimeException("Cannot attach components to null parameterMapping");
		}		
		
		boolean fetchAll = false;
		
		
		if(requiredComponents != null) {
			
			if(requiredComponents.containsKey(ParameterMapping.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}
			
			if (fetchAll || requiredComponents.containsKey(ParameterMapping.Component.OPTION_TRANSLATIONS)) {
			  parameterMapping.setOptionTranslations(
			      optionTranslationService.fetchByMappingId(
			          parameterMapping.getId(),
			          requiredComponents.get(ParameterMapping.Component.OPTION_TRANSLATIONS)
			      )
			  );
			}
			
			if (fetchAll || requiredComponents.containsKey(ParameterMapping.Component.PARAMETER_DEFINITION)) {
        parameterMapping.setParameterDefinition(
            parameterDefinitionService.fetchById(
                parameterMapping.getParameterDefinitionId(),
                requiredComponents.get(ParameterMapping.Component.PARAMETER_DEFINITION)
            )
        );
      }
			
			if (fetchAll || requiredComponents.containsKey(ParameterMapping.Component.REQUIRED_OBSERVATION)) {
        parameterMapping.setRequiredObservation(
            requiredObservationService.fetchById(
                parameterMapping.getRequiredObservationId(),
                requiredComponents.get(ParameterMapping.Component.REQUIRED_OBSERVATION)
            )        
        );
      }
			
			
		}
	}

	public Collection<ParameterMapping> fetchByDefinitionId(Long parameterDefinitionId, ComponentMap requiredComponents) {
	  Collection<ParameterMapping> mappings = parameterMappingDao.fetchByDefinitionId(parameterDefinitionId);
	  attachComponents(mappings, requiredComponents);
	  return mappings;
	}

  public Collection<ParameterMapping> search(ParameterMappingSearchBean parameterMappingSearchBean) {
    return parameterMappingDao.search(parameterMappingSearchBean);
  }

  public void setParameterMappingDao(ParameterMappingDao parameterMappingDao) {
    this.parameterMappingDao = parameterMappingDao;
  }

  public void setOptionTranslationService(OptionTranslationService optionTranslationService) {
    this.optionTranslationService = optionTranslationService;
  }

  public void setParameterDefinitionService(ParameterDefinitionService parameterDefinitionService) {
    this.parameterDefinitionService = parameterDefinitionService;
  }

  public void setRequiredObservationService(RequiredObservationService requiredObservationService) {
    this.requiredObservationService = requiredObservationService;
  }
	
}
								