/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.europhenome.services;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.personnel.Person;
								
import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractServiceImpl;

import uk.ac.sanger.mig.europhenome.ProcedureDefinition;
import uk.ac.sanger.mig.europhenome.ProcedureDefinitionSearchBean;
import uk.ac.sanger.mig.europhenome.dao.ProcedureDefinitionDao;

public class ProcedureDefinitionServiceImpl extends AbstractServiceImpl<ProcedureDefinition> implements ProcedureDefinitionService {
	
	private ProcedureDefinitionDao procedureDefinitionDao;
	private ParameterDefinitionService parameterDefinitionService;

	public Long store(ProcedureDefinition procedureDefinition, Person user) {
		if(procedureDefinition == null) {
			throw new RuntimeException("Cannot save a null procedureDefinition");
		}
		
		return procedureDefinitionDao.store(procedureDefinition, user);
	}
	
	public ProcedureDefinition fetchById(Long procedureDefinitionId, ComponentMap requiredComponents) {
		ProcedureDefinition procedureDefinition = procedureDefinitionDao.fetchById(procedureDefinitionId);
		
		if(procedureDefinition != null)
			attachComponents(procedureDefinition, requiredComponents);
		
		return procedureDefinition;
	}

	@Override
	protected void attachComponents(ProcedureDefinition procedureDefinition, ComponentMap requiredComponents) {
		if(procedureDefinition == null) {
			throw new RuntimeException("Cannot attach components to null procedureDefinition");
		}		
		
		boolean fetchAll = false;
		
		if(requiredComponents != null) {
			
			if(requiredComponents.containsKey(ProcedureDefinition.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}
		
			if (fetchAll || requiredComponents.containsKey(ProcedureDefinition.Component.PARAMETER_DEFINITIONS)) {
			  procedureDefinition.setParameterDefinitions(
			      parameterDefinitionService.fetchByProcedureDefinitionId(
			          procedureDefinition.getId(),
			          requiredComponents.get(ProcedureDefinition.Component.PARAMETER_DEFINITIONS)
			      )
			  );
			}
		}
	}
	
  public Collection<ProcedureDefinition> fetchBySopId(Long sopId, ComponentMap componentMap) {
    Collection<ProcedureDefinition> procDefs = procedureDefinitionDao.fetchBySopId(sopId);
    
    attachComponents(procDefs, componentMap);
    
    return procDefs;
  }


  public Collection<ProcedureDefinition> search(ProcedureDefinitionSearchBean procedureDefinitionSearchBean) {
    return procedureDefinitionDao.search(procedureDefinitionSearchBean);
  }

  public void setProcedureDefinitionDao(ProcedureDefinitionDao procedureDefinitionDao) {
    this.procedureDefinitionDao = procedureDefinitionDao;
  }

  public void setParameterDefinitionService(ParameterDefinitionService parameterDefinitionService) {
    this.parameterDefinitionService = parameterDefinitionService;
  }
	
}
								