/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.filesupport;

import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.database.TableMetadataEnum;

public class BinaryFile extends AuthenticatedDataObject {

	static final long serialVersionUID = 101010103L;

	private byte[] bytes;
	private String fileName;
	private String contentType;
	private String fileDescription;
	private TableMetadataEnum foreignTableName;
	private Long foreignKeyId;
	private Long contentTypeDictId;
	private DictionaryEntry contentTypeDict;

	public DictionaryEntry getContentTypeDict() {
		return contentTypeDict;
	}

	public void setContentTypeDict(DictionaryEntry contentTypeDict) {
		this.contentTypeDict = contentTypeDict;
	}

	public Long getContentTypeDictId() {
		return contentTypeDictId;
	}

	public void setContentTypeDictId(Long contentTypeDictId) {
		this.contentTypeDictId = contentTypeDictId;
	}

	public BinaryFile() {}

	/**
	 * Returns number of bytes used by the actual BinFile file.
	 * Returns 0 if file is empty or null.
	 * @return
	 */
	public int getSize() {
		return (bytes == null) ? 0 : bytes.length;
	}


	/**
	 * Returns raw file data as byte array for this BinFile object
	 * @return
	 */
	public byte[] getBytes() {
		return bytes;
	}

	/**
	 * Sets raw file data as byte array for this BinFile object
	 * @param fileAsByteArray
	 */
	public void setBytes(byte[] bytes) {
		this.bytes = bytes;
	}

	public String getFileDescription() {
		return fileDescription;
	}

	public void setFileDescription(String fileDescription) {
		this.fileDescription = fileDescription;
	}

	public String getFileName() {
		return fileName;
	}

	public void setFileName(String fileName) {
		this.fileName = fileName;
	}

	public String getContentType() {
		return contentType;
	}

	public void setContentType(String contentType) {
		this.contentType = contentType;
	}


	public Long getForeignKeyId() {
		return foreignKeyId;
	}


	public void setForeignKeyId(Long foreignKeyId) {
		this.foreignKeyId = foreignKeyId;
	}


	public TableMetadataEnum getForeignTableName() {
		return foreignTableName;
	}


	public void setForeignTableName(TableMetadataEnum foreignTableName) {
		this.foreignTableName = foreignTableName;
	}

	public boolean isImageFile() {
		return (contentType != null && contentType.toLowerCase().startsWith("image"));
	}

}
