/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.filesupport.controllers;

import java.util.Map;

import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.web.servlet.View;

import uk.ac.sanger.mig.filesupport.BinaryFile;


public class BinaryFileView implements View {

	private String modelName;

	public String getModelName() {
		return this.modelName;
	}

	public void setModelName(String modelName) {
		this.modelName = modelName;
	}

	public String getContentType() {
		return null;
	}

	/**
	 * Renders view as byte[] array written to HTTP response outpustream with mome content header set
	 * appropriately for media type of BinFile data--ie, it "renders" a view of BinFile model as
	 * an HTTP response.  Per MVC, this is really where we should be sending bytes back to browser, anyway, ie. conteroller should
	 * be agnostic (as much as possible ideally) with regard to view rendering and should simply
	 * return model and view, nothing more
	 */
	public void render(Map model, HttpServletRequest request, HttpServletResponse response) throws Exception {
		BinaryFile binaryFile = (BinaryFile)model.get(getModelName());

		if( binaryFile != null && binaryFile.getBytes() != null) {

			ServletOutputStream ouputStream = response.getOutputStream();
			//set http header fields
			response.setBufferSize( binaryFile.getSize() );
			response.setContentType( binaryFile.getContentType() );
			response.setHeader("Content-Disposition:", "attachment; filename=\""+binaryFile.getFileName()+"\"");
			response.setContentLength( binaryFile.getSize() );
			ouputStream.write(binaryFile.getBytes(), 0, binaryFile.getSize() );
			ouputStream.flush();
			ouputStream.close();

		} else {

			response.sendError(204,"No Content.");
		}
	}

}
