/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.filesupport.dao;

import java.util.Collection;

import uk.ac.sanger.mig.database.TableMetadataEnum;
import uk.ac.sanger.mig.filesupport.BinaryFile;
import uk.ac.sanger.mig.personnel.Person;

public interface BinaryFileDao {

	/**
	 * Returns a BinaryFile object with bytes, fileName, file description and content
	 * type fields set.
	 *
	 * @param path
	 * @return
	 */
	public BinaryFile fetchByPath(String path, String contentType);

	public Long store(BinaryFile binaryFile, Person user);

	public BinaryFile fetchById(Long id, boolean includeBinaryData);

	public Collection<BinaryFile> fetchByTableRef(TableMetadataEnum tableName, Long fkRef, boolean includeBinaryData);

	public Collection<BinaryFile> fetchByTableRef(TableMetadataEnum tableName, Long fkRef, Long contentTypeDictId, boolean includeBinaryData);

	/**
	 * Searches for files called filename and of the specified content type. Returns a collection of
	 * matching binary files.
	 *
	 * @param filename -
	 *            the filename to search for.
	 * @param contentTypeDictId -
	 *            the content type of the files to search for.
	 * @param includeBinaryData -
	 *            include the binary data.
	 * @return files - collection of matching binary files or an empty collection if nothing found.
	 */
	public Collection<BinaryFile> fetchByFilenameAndContentTypeDictId(String filename, Long contentTypeDictId, boolean includeBinaryData);

	public int delete(BinaryFile binaryFile, Person user);

	public BinaryFile fetchByName(String fileName, TableMetadataEnum tableName, Long fkRef);
}