/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.filesupport.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.database.TableMetadataEnum;
import uk.ac.sanger.mig.filesupport.BinaryFile;

public class BinaryFileLazyRowMapper implements ParameterizedRowMapper<BinaryFile> {

	private DictionaryService dictionaryService;

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	public BinaryFile mapRow(ResultSet rs, int rowNum) throws SQLException {
		BinaryFile binaryFile = new BinaryFile();
		binaryFile.setId(rs.getLong("ID"));
		binaryFile.setFileName(rs.getString("FILE_NAME"));
		binaryFile.setContentType(rs.getString("CONTENT_TYPE"));
		binaryFile.setFileDescription(rs.getString("FILE_DESCRIPTION"));
		binaryFile.setCreatorId(rs.getLong("CREATOR_ID"));
		if(rs.wasNull()) binaryFile.setCreatorId(null);
		binaryFile.setCreatedDate(rs.getDate("CREATED_DATE"));
		binaryFile.setEditedBy(rs.getString("EDITED_BY"));
		binaryFile.setEditDate(rs.getDate("EDIT_DATE"));
		binaryFile.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) binaryFile.setCheckNumber(null);
		String foreignTableName = rs.getString("FOREIGN_TABLE_NAME");
		if(!rs.wasNull()) {
			binaryFile.setForeignTableName(Enum.valueOf(TableMetadataEnum.class, foreignTableName));
		}
		binaryFile.setForeignKeyId(rs.getLong("FOREIGN_KEY_ID"));
		if(rs.wasNull()) binaryFile.setForeignKeyId(null);

		binaryFile.setContentTypeDictId(rs.getLong("CONTENT_TYPE_DICT_ID"));
		if(rs.wasNull()) binaryFile.setContentTypeDictId(null);

		binaryFile.setContentTypeDict(dictionaryService.fetchEntry(DictionaryEnum.APP_BINARY_FILE_TYPE_DICT, binaryFile.getContentTypeDictId()));

		return binaryFile;
	}

}