/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.filesupport.forms;

import org.springframework.web.multipart.MultipartFile;

import uk.ac.sanger.mig.filesupport.BinaryFile;
import uk.ac.sanger.mig.filesupport.BinaryFileUtil;

public class FileUploadForm {

	private MultipartFile	uploadFile;
	private BinaryFile		binaryFile;


	/**
	 * Returns the binary file that was created from the multipart file that was uploaded.
	 *
	 * @return binaryFile - the binary file object.
	 */
	public BinaryFile getBinaryFile() {
		return binaryFile;
	}


	/**
	 * Sets the BinaryFile.
	 *
	 * @param binaryFile -
	 *            the binary file to set.
	 */
	public void setBinaryFile(BinaryFile binaryFile) {
		this.binaryFile = binaryFile;
	}


	/**
	 * Returns the multipart upload form that is used to create the BinaryFile instance wthin the
	 * setUploadForm() method.
	 *
	 * @return uploadForm - the multipart file that was uploaded.
	 */
	public MultipartFile getUploadFile() {
		return uploadFile;
	}


	/**
	 * Sets the multipart file and creates the BinaryFile object.
	 *
	 * @param file -
	 *            the multipart file that is being uploaded.
	 */
	public void setUploadFile(MultipartFile file) {
		this.uploadFile = file;
		if (file != null) {
			if(this.binaryFile == null) {
				this.binaryFile = new BinaryFile();
			}
			BinaryFileUtil.createBinaryFileFromMultipart(file, this.binaryFile);
		}
	}
}
