/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.filesupport.services;

import java.util.Collection;

import org.springframework.transaction.annotation.Transactional;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.database.TableMetadataEnum;
import uk.ac.sanger.mig.filesupport.BinaryFile;
import uk.ac.sanger.mig.filesupport.dao.BinaryFileDao;
import uk.ac.sanger.mig.personnel.Person;

public class BinaryFileServiceSpringImpl extends AbstractServiceImpl<BinaryFile> implements BinaryFileService {

	private BinaryFileDao binaryFileDao;

	public void setBinaryFileDao(BinaryFileDao binaryFileDao) {
		this.binaryFileDao = binaryFileDao;
	}

	public int delete(BinaryFile binaryFile, Person user) {
		return binaryFileDao.delete(binaryFile, user);
	}

	public Collection<BinaryFile> fetchByTableRef(TableMetadataEnum tableName, Long fkRef, boolean includeBinaryData, ComponentMap requiredComponents) {
		Collection<BinaryFile> binaryFiles = null;

		binaryFiles = binaryFileDao.fetchByTableRef(tableName, fkRef, includeBinaryData);

		attachComponents(binaryFiles, requiredComponents);

		return binaryFiles;
	}


	public Collection<BinaryFile> fetchByTableRef(TableMetadataEnum tableName, Long fkRef, Long contentTypeDictId,
			boolean includeBinaryData, ComponentMap requiredComponents) {
		Collection<BinaryFile> binaryFiles = binaryFileDao.fetchByTableRef(tableName, fkRef, contentTypeDictId,
				includeBinaryData);
		attachComponents(binaryFiles, requiredComponents);
		return binaryFiles;
	}


	/**
	 * Searches for files called filename with a content type of contentTypeDictId. Results are
	 * ordered by creation date.
	 *
	 * @param filename -
	 *            the name of the file to find.
	 * @param contentTypeDictId -
	 *            the type of file to find.
	 * @param includeBinaryData -
	 *            include the binary file data.
	 * @param requiredComponents -
	 *            the required components to attach.
	 * @return binaryFiles - collection of files found or an empty collection if nothing found.
	 */
	public Collection<BinaryFile> fetchByFilenameAndContentTypeDictId(String filename, Long contentTypeDictId,
			boolean includeBinaryData, ComponentMap requiredComponents) {
		Collection<BinaryFile> binaryFiles = binaryFileDao.fetchByFilenameAndContentTypeDictId(filename,
				contentTypeDictId, includeBinaryData);
		if (!binaryFiles.isEmpty())
			attachComponents(binaryFiles, requiredComponents);
		return binaryFiles;
	}


	public BinaryFile fetchById(Long id, boolean includeBinaryData, ComponentMap requiredComponents) {
		BinaryFile file = binaryFileDao.fetchById(id, includeBinaryData);

		if (file != null) {
			attachComponents(file, requiredComponents);
		}

		return file;
	}


	@Transactional
	public Long store(BinaryFile binaryFile, Person user) {
		return binaryFileDao.store(binaryFile, user);
	}


	@Override
	protected void attachComponents(BinaryFile object, ComponentMap requiredComponents) {

	}

	public BinaryFile fetchByName(String fileName, TableMetadataEnum tableName, Long fkRef) {
		return binaryFileDao.fetchByName(fileName,tableName, fkRef);
	}

}