/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.geneevidence;

import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.ComponentEnum;

public class MigGeneTargetingHits extends AuthenticatedDataObject {
	
	public enum Component implements ComponentEnum {
		ALL_COMPONENTS
	}
	
	private Long migGeneId;	  
    private Integer igtcHitCount;
	private Integer omnibankHitCount;

	/**
	 * Set the count of the number of times this gene has been knocked out according to the IGTC
	 * (International GeneTrap Consortium) database.
	 * 
	 * @param count is the number of times this gene appears in the IGTC database.
	 */
	public void setIgtcHitCount(Integer count) {
		igtcHitCount = count;
	}
	
	/**
	 * Get the count of the number of times this gene has been knocked out according to the IGTC
	 * (International GeneTrap Consortium) database.
	 * 
	 * @returns the number of times this gene appears in the IGTC database.
	 */
	public Integer getIgtcHitCount() {
		return igtcHitCount;
	}
	
	/**
	 * Set the count of the number of times this gene has been knocked out according to the
	 * Omnibank database.
	 * 
	 * @param count is the number of times this gene appears in the Omnibank database.
	 */
	public void setOmnibankHitCount(Integer count) {
		omnibankHitCount = count;
	}
	
	/**
	 * Get the count of the number of times this gene has been knocked out according to the 
	 * Omnibank database
	 * 
	 * @returns the number of times this gene appears in the Omnibank database.
	 */
	public Integer getOmnibankHitCount() {
		return omnibankHitCount;
	}

	public Long getMigGeneId() {
		return migGeneId;
	}

	public void setMigGeneId(Long migGeneId) {
		this.migGeneId = migGeneId;
	}
}