/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.geneevidence.controllers;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.SimpleFormController;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.gene.MigGene;
import uk.ac.sanger.mig.gene.services.MigGeneService;
import uk.ac.sanger.mig.geneevidence.MigGeneArticleRef;
import uk.ac.sanger.mig.geneevidence.forms.PubmedEvidenceForm;
import uk.ac.sanger.mig.geneevidence.services.MigGeneArticleRefService;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.pubmedsorter.Article;
import uk.ac.sanger.mig.pubmedsorter.PubmedSearchEngine;
import uk.ac.sanger.mig.pubmedsorter.services.ArticleService;

public class AddPubmedEvidenceController extends SimpleFormController {
	
	private MigGeneService migGeneService;
	private MigGeneArticleRefService migGeneArticleRefService;
	private ArticleService articleService;

	public void setMigGeneService(MigGeneService migGeneService) {
		this.migGeneService = migGeneService;
	}

	public void setMigGeneArticleRefService(MigGeneArticleRefService migGeneArticleRefService) {
		this.migGeneArticleRefService = migGeneArticleRefService;
	}

	public void setArticleService(ArticleService articleService) {
		this.articleService = articleService;
	}

	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, Object command, BindException arg3) throws Exception {
		
		Person user = (Person)request.getSession().getAttribute("user");
	
		PubmedEvidenceForm form = (PubmedEvidenceForm) command;
		MigGeneArticleRef migGeneArticleRef = form.getMigGeneArticleRef();	
		String pubmedId = migGeneArticleRef.getArticle().getPubmedId();
		Long migGeneId = migGeneArticleRef.getMigGeneId();
		
		PubmedSearchEngine pubmed = new PubmedSearchEngine();
		pubmed.setArticleService(articleService);
		Article article = pubmed.fetchArticle(pubmedId, user);
		migGeneArticleRef.setArticleId(article.getId());
		migGeneArticleRef.setArticle(article);
				
		migGeneArticleRefService.storeAuthenticated(migGeneArticleRef, user);
		
		return new ModelAndView(getSuccessView()+"?migGeneId="+migGeneId);
	}
		
	/**
	 * Prepopulate the form the correct migGeneId value (goes into a hidden form field).
	 */
	protected Object formBackingObject(HttpServletRequest request) throws Exception {
		//Create the form
		PubmedEvidenceForm addPubMedEvidenceForm = (PubmedEvidenceForm)createCommand();

		MigGeneArticleRef migGeneArticleRef = new MigGeneArticleRef();
		
		Long migGeneId = ServletRequestUtils.getRequiredLongParameter(request, "migGeneId");

		MigGene migGene = migGeneService.fetchById(migGeneId, new ComponentMap()); 
		
		Article article = new Article();
		migGeneArticleRef.setArticle(article);
		if (migGene != null) {
			migGeneArticleRef.setMigGeneId(migGeneId);
		}

		addPubMedEvidenceForm.setMigGeneArticleRef(migGeneArticleRef);
		
		return addPubMedEvidenceForm;		
	}

}
