/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.geneevidence.controllers;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.SimpleFormController;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.gene.MigGene;
import uk.ac.sanger.mig.gene.MigGeneMetaData;
import uk.ac.sanger.mig.gene.services.MigGeneService;
import uk.ac.sanger.mig.geneevidence.MigGeneSummaryScore;
import uk.ac.sanger.mig.geneevidence.forms.EditMigScoreForm;
import uk.ac.sanger.mig.geneevidence.services.MigGeneSummaryScoreService;
import uk.ac.sanger.mig.personnel.Person;

public class EditMigScoreController extends SimpleFormController {
	
	private MigGeneService migGeneService;
	private MigGeneSummaryScoreService migGeneSummaryScoreService;
	
	public void setMigGeneService(MigGeneService migGeneService) {
		this.migGeneService = migGeneService;
	}

	public void setMigGeneSummaryScoreService(
			MigGeneSummaryScoreService migGeneSummaryScoreService) {
		this.migGeneSummaryScoreService = migGeneSummaryScoreService;
	}	
	
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		EditMigScoreForm form = (EditMigScoreForm)command;
		Person user = RequestUtils.getUser(request);

		MigGeneSummaryScore newSummary = form.getMigGeneSummaryScore();
		newSummary.setEditDate(new java.util.Date());
		migGeneSummaryScoreService.storeAuthenticated(newSummary, user);	
		return new ModelAndView(getSuccessView()+"?migGeneId="+form.getMigGeneSummaryScore().getMigGeneId());
	}

	protected Object formBackingObject(HttpServletRequest request) throws Exception {
		EditMigScoreForm form = (EditMigScoreForm)createCommand();
		
		Long geneId = ServletRequestUtils.getRequiredLongParameter(request, "migGeneSummaryScore.migGeneId");
		form.getMigGeneSummaryScore().setMigGeneId(geneId);
		
		return form;
	}

	/**
	 * Prepopulate the form with existing summary data for the gene
	 */
	protected Map referenceData(HttpServletRequest request) throws Exception {
		Map<String, Object> referenceData = new HashMap<String, Object>();
		
		Long migGeneId = ServletRequestUtils.getRequiredLongParameter(request, "migGeneSummaryScore.migGeneId");
		ComponentMap migGeneComponentMap =
			ComponentMap.putAll(new ComponentMap(MigGene.Component.PRIMARY_BUILD_GENE, null));
		
		// add the migGene to the model		
		MigGene migGene = migGeneService.fetchById(migGeneId, migGeneComponentMap);
		referenceData.put("migGene", migGene);

		// add the migGeneMetaData to the model
		MigGeneMetaData migGeneMetaData = new MigGeneMetaData();
		migGeneMetaData.setGlobalScore(migGeneSummaryScoreService.fetchCurrentScore(migGeneId));
		referenceData.put("migGeneMetaData", migGeneMetaData);
		
		// collection of previous scores for this gene
		Collection<MigGeneSummaryScore> scoreHistoryList = null;
		ComponentMap migGeneSummaryScoreComponentMap =
			ComponentMap.putAll(new ComponentMap(MigGeneSummaryScore.Component.CREATOR, null));
		
		scoreHistoryList = migGeneSummaryScoreService.fetchAllMigGeneSummaryScoresByMigGeneId(migGeneId, migGeneSummaryScoreComponentMap);
		
		referenceData.put("scoreHistory", scoreHistoryList);
		
		return referenceData;
	}
}
