/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.geneevidence.dao;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.geneevidence.MgiPhenotypeAllele;

public class MgiPhenotypeAlleleDaoSpringImpl extends AbstractDaoSpringImpl<MgiPhenotypeAllele> implements MgiPhenotypeAlleleDao {

	/**
	 * Get the list of Knockout records from the database for this MigGene.
	 * 
	 * @param migGeneId is the id for the MigGene for which the Knockout records are required.
	 * @return an ArrayList of records of different knockout alleles for the supplied gene
	 * or an empty ArrayList if none are found.
	 */
	public Collection<MgiPhenotypeAllele> fetchAllMgiPhenotypeAllelesByMigGeneId(Long migGeneId) {

		String sql = "SELECT * FROM GEV_MGI_PHENOTYPE_ALLELE WHERE GENE_ID = ?";

		Collection<MgiPhenotypeAllele> mgiPhenotypeAlleleCollection = getSimpleJdbcTemplate().query(sql, getRowMapper(), migGeneId);
		
		return (mgiPhenotypeAlleleCollection == null) ? new ArrayList<MgiPhenotypeAllele>() : mgiPhenotypeAlleleCollection;
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, MgiPhenotypeAllele mgiPhenotypeAllele) {
		sql.addStringParam(mgiPhenotypeAllele.getType(), "TYPE");
		sql.addStringParam(mgiPhenotypeAllele.getDescription(), "DESCRIPTION");
		sql.addStringParam(mgiPhenotypeAllele.getPhenotypeId(), "MGI_PHENOTYPE_ID");
		sql.addLongParam(mgiPhenotypeAllele.getMigGeneId(), "GENE_ID");
		sql.addLongParam(mgiPhenotypeAllele.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(mgiPhenotypeAllele.getCreatedDate(), "CREATED_DATE");
		sql.addStringParam(mgiPhenotypeAllele.getEditedBy(), "EDITED_BY");
		sql.addDateParam(mgiPhenotypeAllele.getEditDate(), "EDIT_DATE");
		sql.addLongParam(mgiPhenotypeAllele.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(mgiPhenotypeAllele.getId(), "ID");
	}
}
