/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.geneevidence.dao;

import org.springframework.dao.IncorrectResultSizeDataAccessException;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.geneevidence.MigCuratedStatus;

public class MigCuratedStatusDaoSpringImpl extends AbstractDaoSpringImpl<MigCuratedStatus> implements MigCuratedStatusDao {

	public MigCuratedStatus fetchCurrentCuratedStatusByMigGeneId(Long migGeneId) {

		MigCuratedStatus migCuratedStatus = null;

		String sql = "SELECT * FROM gev_mig_curated_status WHERE GENE_ID=? ORDER BY EDIT_DATE DESC";
		
		try{
			migCuratedStatus = getSimpleJdbcTemplate().queryForObject(sql, getRowMapper(), migGeneId);
		}
		catch(IncorrectResultSizeDataAccessException e) {
			logger.debug("Table name=gev_mig_curated_status;" + e);
		}
		
		return migCuratedStatus;
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, MigCuratedStatus migCuratedStatus) {
		sql.addStringParam(migCuratedStatus.getStatus(), "STATUS");
		sql.addLongParam(migCuratedStatus.getMigGeneId(), "GENE_ID");
		sql.addLongParam(migCuratedStatus.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(migCuratedStatus.getCreatedDate(), "CREATED_DATE");
		sql.addStringParam(migCuratedStatus.getEditedBy(), "EDITED_BY");
		sql.addDateParam(migCuratedStatus.getEditDate(), "EDIT_DATE");
		sql.addLongParam(migCuratedStatus.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(migCuratedStatus.getId(), "ID");
	}
}
