/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.geneevidence.dao;

import java.util.ArrayList;
import java.util.Collection;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.dao.IncorrectResultSizeDataAccessException;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.geneevidence.MigGeneArticleRef;

public class MigGeneArticleRefDaoSpringImpl extends AbstractDaoSpringImpl<MigGeneArticleRef> implements MigGeneArticleRefDao {
	
	private static final Log logger = LogFactory.getLog(MigGeneArticleRefDaoSpringImpl.class); 
	
	public MigGeneArticleRef fetchById(Long id) {
		MigGeneArticleRef migGeneArticleRef = null;
		String sql = " select * from GEV_GENE_ARTICLE_REF where id = ? ";
		
		try {
			migGeneArticleRef = getSimpleJdbcTemplate().queryForObject(sql, getRowMapper(), id);			
		}
		catch(IncorrectResultSizeDataAccessException e) {
			logger.debug("Table name=GEV_GENE_ARTICLE_REF;" + e);
		}
		return migGeneArticleRef;
	}

	public Collection<MigGeneArticleRef> fetchAll() {
		String sql = " select * from GEV_GENE_ARTICLE_REF";
		Collection<MigGeneArticleRef> migGeneArticleRefs = getSimpleJdbcTemplate().query(sql, getRowMapper());	
		return (migGeneArticleRefs == null) ? new ArrayList<MigGeneArticleRef>() : migGeneArticleRefs;
	}
	
	public Collection<MigGeneArticleRef> fetchAllByMigGeneId(Long migGeneId) {
		Collection<MigGeneArticleRef> migGeneArticleRefs = null;
		String sql = "select * from GEV_GENE_ARTICLE_REF where gene_id = ? order by EDIT_DATE";
	
		migGeneArticleRefs = getSimpleJdbcTemplate().query(sql, getRowMapper(), migGeneId);	//get the ids for person and article etc, the fetch will be done by the rowmapper
			
		return (migGeneArticleRefs == null) ? new ArrayList<MigGeneArticleRef>() : migGeneArticleRefs;
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, MigGeneArticleRef migGeneArticleRef) {
		sql.addIntParam(migGeneArticleRef.getScore(), "SCORE");
		sql.addLongParam(migGeneArticleRef.getArticleId(), "ARTICLE_ID");
		sql.addStringParam(migGeneArticleRef.getNote(), "NOTE");
		sql.addLongParam(migGeneArticleRef.getMigGeneId(), "GENE_ID");
		sql.addLongParam(migGeneArticleRef.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(migGeneArticleRef.getCreatedDate(), "CREATED_DATE");
		sql.addStringParam(migGeneArticleRef.getEditedBy(), "EDITED_BY");
		sql.addDateParam(migGeneArticleRef.getEditDate(), "EDIT_DATE");
		sql.addLongParam(migGeneArticleRef.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(migGeneArticleRef.getId(), "ID");
	}
}

