/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.geneevidence.dao;

import java.util.ArrayList;
import java.util.Collection;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.dao.EmptyResultDataAccessException;
import org.springframework.dao.IncorrectResultSizeDataAccessException;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.geneevidence.MigGeneSummaryScore;

public class MigGeneSummaryScoreDaoSpringImpl extends AbstractDaoSpringImpl<MigGeneSummaryScore> implements MigGeneSummaryScoreDao{
	
	private static final Log logger = LogFactory.getLog(MigGeneSummaryScoreDaoSpringImpl.class); 
	
	public MigGeneSummaryScore fetchById(Long id) {
		MigGeneSummaryScore migGeneSummaryScore = null;
		String sql = " select * from gev_gene_summary where id = ? ";
		
		try {
			migGeneSummaryScore = getSimpleJdbcTemplate().queryForObject(sql, getRowMapper(), id);			
		}
		catch(IncorrectResultSizeDataAccessException e) {
			logger.debug("Table name=gev_gene_summary;" + e);
		}
		
		return migGeneSummaryScore;
	}	
	
	public Collection<MigGeneSummaryScore> fetchAllMigGeneSummaryScoresByMigGeneId(Long migGeneId) {
		String sql = " select * from gev_gene_summary where gene_id = ? order by edit_date desc";
		
		Collection<MigGeneSummaryScore> scores = getSimpleJdbcTemplate().query(sql, getRowMapper(), migGeneId);
		
		return (scores != null) ? scores : new ArrayList<MigGeneSummaryScore>();			
	}

	public int fetchCurrentScore(Long migGeneId) {
		String sql = "select score from (select score from gev_gene_summary where gene_id=? order by edit_date desc) where rownum=1";
		
		int currentScore;
		
		try {
			currentScore = getSimpleJdbcTemplate().queryForInt(sql, migGeneId);
		}
		catch(EmptyResultDataAccessException e) {
			currentScore = 0;
		}
			
		return currentScore;
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, MigGeneSummaryScore migGeneSummaryScore) {
		sql.addStringParam(migGeneSummaryScore.getRational(), "RATIONAL");
		sql.addLongParam(migGeneSummaryScore.getScore(), "SCORE");
		sql.addLongParam(migGeneSummaryScore.getMigGeneId(), "GENE_ID");
		sql.addLongParam(migGeneSummaryScore.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(migGeneSummaryScore.getCreatedDate(), "CREATED_DATE");
		sql.addStringParam(migGeneSummaryScore.getEditedBy(), "EDITED_BY");
		sql.addDateParam(migGeneSummaryScore.getEditDate(), "EDIT_DATE");
		sql.addLongParam(migGeneSummaryScore.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(migGeneSummaryScore.getId(), "ID");
	}
}
