/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.geneevidence.dao;

import org.springframework.dao.IncorrectResultSizeDataAccessException;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.geneevidence.MigGeneTargetingHits;

public class MigGeneTargetingHitsDaoSpringImpl extends AbstractDaoSpringImpl<MigGeneTargetingHits> implements MigGeneTargetingHitsDao{
	

	public MigGeneTargetingHits fetchTargetingHitsByMigGeneId(Long migGeneId) {
		
		MigGeneTargetingHits migGeneTargetingHits = null;
		
		String sql = "SELECT * FROM GEV_GENE_TARGETING_HITS WHERE GENE_ID = ? ORDER BY EDIT_DATE DESC";   
		
		try {
			migGeneTargetingHits = getSimpleJdbcTemplate().queryForObject(sql, getRowMapper(), migGeneId);	
	    }
	    catch(IncorrectResultSizeDataAccessException e) {
	    	logger.debug("Table name=GEV_GENE_TARGETING_HITS;" + e);
	    }		
	    
		return (migGeneTargetingHits == null) ? new MigGeneTargetingHits() : migGeneTargetingHits;
	}
	
	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, MigGeneTargetingHits migGeneTargetingHits) {
		sql.addIntParam(migGeneTargetingHits.getIgtcHitCount(), "IGTC_HITS");
		sql.addIntParam(migGeneTargetingHits.getOmnibankHitCount(), "OMNIBANK_HITS");
		sql.addLongParam(migGeneTargetingHits.getMigGeneId(), "GENE_ID");
		sql.addLongParam(migGeneTargetingHits.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(migGeneTargetingHits.getCreatedDate(), "CREATED_DATE");
		sql.addStringParam(migGeneTargetingHits.getEditedBy(), "EDITED_BY");
		sql.addDateParam(migGeneTargetingHits.getEditDate(), "EDIT_DATE");
		sql.addLongParam(migGeneTargetingHits.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(migGeneTargetingHits.getId(), "ID");
	}
}
