/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.geneevidence.services;

import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.geneevidence.FacultyVote;
import uk.ac.sanger.mig.geneevidence.dao.FacultyVoteDao;
import uk.ac.sanger.mig.personnel.Person;

public class FacultyVoteServiceImpl extends AbstractServiceImpl<FacultyVote> implements FacultyVoteService {
	
	FacultyVoteDao facultyVoteDao;

	/**
	 * Get all faculty votes associated with the supplied gene.
	 * 
	 */
	public Collection<FacultyVote> fetchAllFacultyVotesByMigGeneId(Long migGeneId, ComponentMap requiredComponents){
		Collection<FacultyVote> facultyVotes = facultyVoteDao.fetchAllFacultyVotesByMigGeneId(migGeneId);
		if(facultyVotes != null)
			for(FacultyVote facultyVote : facultyVotes)
				attachComponents(facultyVote, requiredComponents);
		return facultyVotes;		
	}

	/**
	 * Get the current vote (the last vote they made in terms of time) for a given
	 * Person on a given Gene.
	 * 
	 * @param gene is the Gene for which we need the current vote value.
	 * @param person is the Person whos vote we are interested in.
	 * @return either the current vote placed by the supplied user on the supplied
	 *     gene or the string 'NEUTRAL' if no vote has been cast.
	 */
	public FacultyVote fetchCurrentFacultyVoteWithMigGeneIdAndPersonId(Long migGeneId, Long personId, ComponentMap requiredComponents){
		FacultyVote facultyVote = facultyVoteDao.fetchCurrentFacultyVoteWithMigGeneIdAndPersonId(migGeneId, personId);
		if(facultyVote != null)
				attachComponents(facultyVote, requiredComponents);
		return facultyVote;
	}

	@Override
	protected void attachComponents(FacultyVote facultyVote, ComponentMap requiredComponents) {
		if(facultyVote == null) {
			throw new RuntimeException("Cannot attach components to null facultyVote");
		}
	}

	public FacultyVote fetchById(Long facultyVoteId, ComponentMap requiredComponents) {
		FacultyVote facultyVote = facultyVoteDao.fetchById(facultyVoteId);
		
		if(facultyVote != null)
			attachComponents(facultyVote, requiredComponents);
		
		return facultyVote;		
	}

	public Long storeAuthenticated(FacultyVote facultyVote, Person person) {
		if(facultyVote == null) {
			throw new RuntimeException("Cannot save a null facultyVote");
		}

		return facultyVoteDao.store(facultyVote, person);
	}	
	
	public void setFacultyVoteDao(FacultyVoteDao facultyVoteDao) {
		this.facultyVoteDao = facultyVoteDao;
	}
}
