/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.geneevidence.services;

import java.util.Collection;

import org.springframework.transaction.annotation.Transactional;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.geneevidence.MgiPhenotypeAllele;
import uk.ac.sanger.mig.geneevidence.dao.MgiPhenotypeAlleleDao;
import uk.ac.sanger.mig.personnel.Person;

public class MgiPhenotypeAlleleServiceImpl extends AbstractServiceImpl<MgiPhenotypeAllele> implements MgiPhenotypeAlleleService {

	public MgiPhenotypeAlleleDao mgiPhenotypeAlleleDao;


	@Transactional
	public Long storeAuthenticated(MgiPhenotypeAllele mgiPhenotypeAllele, Person person) {
		if(mgiPhenotypeAllele == null) {
			throw new RuntimeException("Cannot save a null mgiPhenotypeAllele");
		}

		return mgiPhenotypeAlleleDao.store(mgiPhenotypeAllele, person);
	}

	public MgiPhenotypeAllele fetchById(Long mgiPhenotypeAlleleId, ComponentMap requiredComponents){
		MgiPhenotypeAllele mgiPhenotypeAllele = mgiPhenotypeAlleleDao.fetchById(mgiPhenotypeAlleleId);
		if(mgiPhenotypeAllele != null)
			attachComponents(mgiPhenotypeAllele, requiredComponents);
		return mgiPhenotypeAllele;
	}

	/**
	 * Fetch all score update records from the database and render these into MgiPhenotypeAllele objects.
	 * The collection is returned as an ArrayList of these records.
	 * 
	 * @param g is the Gene for which the records are required.
	 * @return an ArrayList of all the MgiPhenotypeAllele objects associated with this Gene.
	 */
	public Collection<MgiPhenotypeAllele> fetchAllMgiPhenotypeAllelesByMigGeneId(Long migGeneId, ComponentMap requiredComponents){
		Collection<MgiPhenotypeAllele> mgiPhenotypeAlleles = mgiPhenotypeAlleleDao.fetchAllMgiPhenotypeAllelesByMigGeneId(migGeneId);
		
		if(mgiPhenotypeAlleles != null)
			for(MgiPhenotypeAllele mgiPhenotypeAllele : mgiPhenotypeAlleles)
				attachComponents(mgiPhenotypeAllele, requiredComponents);
		return mgiPhenotypeAlleles;
	}
	
	@Override
	protected void attachComponents(MgiPhenotypeAllele mgiPhenotypeAllele, ComponentMap requiredComponents){
		if(mgiPhenotypeAllele == null) {
			throw new RuntimeException("Cannot attach components to null mgiPhenotypeAllele");
		}
	}

	public void setMgiPhenotypeAlleleDao(MgiPhenotypeAlleleDao mgiPhenotypeAlleleDao) {
		this.mgiPhenotypeAlleleDao = mgiPhenotypeAlleleDao;
	}
}
