/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.geneevidence.services;

import java.util.Collection;

import org.springframework.transaction.annotation.Transactional;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.geneevidence.MigGeneArticleRef;
import uk.ac.sanger.mig.geneevidence.dao.MigGeneArticleRefDao;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.pubmedsorter.Article;
import uk.ac.sanger.mig.pubmedsorter.services.ArticleService;

public class MigGeneArticleRefServiceImpl extends AbstractServiceImpl<MigGeneArticleRef> implements MigGeneArticleRefService {

	public MigGeneArticleRefDao migGeneArticleRefDao;
	
	public ArticleService articleService;

	@Transactional
	public Long storeAuthenticated(MigGeneArticleRef migGeneArticleRef, Person person) {
		if(migGeneArticleRef == null) {
			throw new RuntimeException("Cannot save a null migGeneArticleRef");
		}

		return migGeneArticleRefDao.store(migGeneArticleRef, person);
	}

	public MigGeneArticleRef fetchById(Long migGeneArticleRefId, ComponentMap requiredComponents){
		MigGeneArticleRef migGeneArticleRef = migGeneArticleRefDao.fetchById(migGeneArticleRefId);
		
		if(migGeneArticleRef != null)
			attachComponents(migGeneArticleRef, requiredComponents);
		return migGeneArticleRef;
	}

	/**
	 * Fetch all score update records from the database and render these into GeneSummaryScore objects.
	 * The collection is returned as an ArrayList of these records.
	 * 
	 * @param g is the Gene for which the records are required.
	 * @return an ArrayList of all the GeneSummaryScore objects associated with this Gene.
	 */
	public Collection<MigGeneArticleRef> fetchAllByMigGeneId(Long migGeneId, ComponentMap requiredComponents){
		Collection<MigGeneArticleRef> migGeneArticleRefs = migGeneArticleRefDao.fetchAllByMigGeneId(migGeneId);
		if(migGeneArticleRefs != null)
			attachComponents(migGeneArticleRefs, requiredComponents);

		return migGeneArticleRefs;
	}

	@Override
	protected void attachComponents(MigGeneArticleRef migGeneArticleRef, ComponentMap requiredComponents){
		if(migGeneArticleRef == null) {
			throw new RuntimeException("Cannot attach components to null migGeneArticleRef");
		}		
		
		boolean fetchAll = false;
		
		if(requiredComponents != null) {
			
			if(requiredComponents.containsKey(MigGeneArticleRef.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}
						
			if(fetchAll || requiredComponents.containsKey(MigGeneArticleRef.Component.ARTICLE)) {
				migGeneArticleRef.setArticle(fetchArticle(migGeneArticleRef, requiredComponents.get(MigGeneArticleRef.Component.ARTICLE)));
			}
		}
	}
	
	private Article fetchArticle(MigGeneArticleRef migGeneArticleRef, ComponentMap components) {
		return articleService.fetchById(migGeneArticleRef.getArticleId(), components);
	}

	public void setMigGeneArticleRefDao(MigGeneArticleRefDao migGeneArticleRefDao) {
		this.migGeneArticleRefDao = migGeneArticleRefDao;
	}

	public void setArticleService(ArticleService articleService) {
		this.articleService = articleService;
	}	
}
