/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.geneevidence.services;

import java.util.Collection;

import org.springframework.transaction.annotation.Transactional;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.geneevidence.SupportEvidence;
import uk.ac.sanger.mig.geneevidence.dao.SupportEvidenceDao;
import uk.ac.sanger.mig.personnel.Person;

public class SupportEvidenceServiceImpl extends AbstractServiceImpl<SupportEvidence> implements SupportEvidenceService {

	public SupportEvidenceDao supportEvidenceDao;


	@Transactional
	public Long storeAuthenticated(SupportEvidence supportEvidence, Person person) {
		if(supportEvidence == null) {
			throw new RuntimeException("Cannot save a null SupportEvidence");
		}

		return supportEvidenceDao.store(supportEvidence, person);
	}

	public SupportEvidence fetchById(Long supportEvidenceId, ComponentMap requiredComponents){
		SupportEvidence supportEvidence = supportEvidenceDao.fetchById(supportEvidenceId);
		if(supportEvidence != null)
			attachComponents(supportEvidence, requiredComponents);
		return supportEvidence;		
	}

	/**
	 * Fetch all score update records from the database and render these into SupportEvidence objects.
	 * The collection is returned as an ArrayList of these records.
	 * 
	 * @param g is the Gene for which the records are required.
	 * @return an ArrayList of all the SupportEvidence objects associated with this Gene.
	 */
	public Collection<SupportEvidence> fetchAllSupportEvidenceByMigGeneId(Long migGeneId, ComponentMap requiredComponents){
		Collection<SupportEvidence> supportEvidenceCollection = supportEvidenceDao.fetchAllSupportEvidenceByMigGeneId(migGeneId);
		if(supportEvidenceCollection != null)
			for(SupportEvidence supportEvidence : supportEvidenceCollection)
				attachComponents(supportEvidence, requiredComponents);
		return supportEvidenceCollection;
	}
	
	@Override
	protected void attachComponents(SupportEvidence supportEvidence, ComponentMap requiredComponents){
		if(supportEvidence == null) {
			throw new RuntimeException("Cannot attach components to null supportEvidence");
		}
	}

	public void setSupportEvidenceDao(SupportEvidenceDao supportEvidenceDao) {
		this.supportEvidenceDao = supportEvidenceDao;
	}
}
