/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.geneset;

/**
 * This class serves as wrapper around domain object POJO for searching on particular fields that are set.
 * It also inherits orderBy and sortOrder methods from SortableSearchBean enabling sort functionlity.
 *
 * If you also need pagination functionality, subclass PaginatedSearchBean which extends SortableSearchBean
 * 
 * NOTE: Using wrapper is just one appraoch to search bean. You could alternatively created a standalone
 * search bean that effectively mimics all of the fields with getters and setters of your domain object POJO.
 */

import java.util.Date;

import uk.ac.sanger.mig.common.PaginatedSearchBean;

/**
 * @author dgm
 *
 */
public class MigGeneSetSearchBean extends PaginatedSearchBean {
	
	private Long id;
	private String name;
	private String description;
	private Date createdDateFrom;
	private Date createdDateTo;
	private Long creatorId;
	private MigGeneSet migGeneSet;
	private Long migGeneId;
	
	public Long getCreatorId() {
		return creatorId;
	}

	public void setCreatorId(Long creatorId) {
		this.creatorId = creatorId;
	}

	public Date getCreatedDateFrom() {
		return createdDateFrom;
	}

	public void setCreatedDateFrom(Date createdDateFrom) {
		this.createdDateFrom = createdDateFrom;
	}

	public Date getCreatedDateTo() {
		return createdDateTo;
	}

	public void setCreatedDateTo(Date createdDateTo) {
		this.createdDateTo = createdDateTo;
	}

	/**
	 * Add a pattern that should be searched for in the description field of a GeneSet. This will
	 * be converted into a string of the form '%description%' and will be inserted 
	 * into the query with a 'like' clause.
	 * @param description is the string that should be used as a match pattern on the description field.
	 */
	public void setDescription(String description) {
		this.description = description;
	}
	
	/**
	 * Set the primary key value associated with the required gene set.
	 * @param geneSetId is the primary key value for teh desired gete set.
	 */
	public void setId(Long geneSetId) {
		this.id = geneSetId;
	}
	
	/**
	 * Add a pattern that should be searched for in the name field of a gene set. This will
	 * be converted into a string of the form '%name%' and will be inserted 
	 * into the query with a 'like' clause.
	 * @param name is the string that should be used as a match pattern on the description field.
	 */	
	public void setName(String name) {
		this.name = name;
	}

	/**
	 * Get the description string that should be used in the query.
	 * @return the description string that should form part of the query string or null
	 *     if this is not required to form part of the query.
	 */
	public String getDescription() {
		return description;
	}

	/**
	 * Get the primary key value that should be used in the query creation.
	 * @return the primary key value for the desired gene set, or null if this 
	 *     is not required to form part of the query.
	 */
	public Long getId() {
		return id;
	}

	/**
	 * Get the name string that should be used in the query.
	 * @return the name string that should form part of the query string or null
	 *     if this is not required to form part of the query.
	 */
	public String getName() {
		return name;
	}

	/**
	 * 
	 * @param queryGeneSet
	 */
	public void setMigGeneSet(MigGeneSet migGeneSet) {
		this.migGeneSet = migGeneSet;
	}
	
	/**
	 * 
	 * @return
	 */
	public MigGeneSet getMigGeneSet() {
		return migGeneSet;
	}

	public Long getMigGeneId() {
		return migGeneId;
	}

	public void setMigGeneId(Long migGeneId) {
		this.migGeneId = migGeneId;
	}
}