/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.geneset.controllers;

import java.util.ArrayList;
import java.util.Collection;
import java.util.StringTokenizer;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.SimpleFormController;

import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.gene.MigGene;
import uk.ac.sanger.mig.gene.services.MigGeneService;
import uk.ac.sanger.mig.geneset.MigGeneSet;
import uk.ac.sanger.mig.geneset.forms.ImportMigGeneSetForm;
import uk.ac.sanger.mig.geneset.services.MigGeneSetService;
import uk.ac.sanger.mig.personnel.Person;

public class ImportMigGeneSetController extends SimpleFormController {
	
	private MigGeneService migGeneService;
	private MigGeneSetService migGeneSetService;
	
	public void setMigGeneSetService(MigGeneSetService migGeneSetService) {
		this.migGeneSetService = migGeneSetService;
	}

	public void setMigGeneService(MigGeneService migGeneService) {
		this.migGeneService = migGeneService;
	}

	@Override
	protected ModelAndView  onSubmit(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		
		ImportMigGeneSetForm form = (ImportMigGeneSetForm) command;
		
		MigGeneSet migGeneSet = new MigGeneSet();
		
		if(form.getMigGeneSet() != null){
			migGeneSet = form.getMigGeneSet();	
		}
		
		boolean isNewRequest = (migGeneSet.getId() == null);
				
		Person user = RequestUtils.getUser(request);
		
		//fetch individually to accommodate large uploads
		StringTokenizer stringTokenizer = new StringTokenizer( form.getMigGeneList() );

		Collection<MigGene> migGenes = new ArrayList<MigGene>();
		
		while (stringTokenizer.hasMoreTokens()){
	
			String geneName = stringTokenizer.nextToken();
			migGenes.addAll( migGeneService.fetchByName(geneName, null));					
		}
				
		migGeneSet.setMigGenes(migGenes);
		migGeneSet.setName(form.getSetName());
		migGeneSet.setDescription(form.getNotes());
	     
		Long requestId = migGeneSetService.storeMigGeneSet(migGeneSet, user);
	    
		String queryString = "?currentRecordId=" + requestId;

		// for new records filter by status and sort by descending ID
		if(isNewRequest) {
			queryString += "&bypassForm=true&newQuery=true&orderBy=id&orderDesc=true";
		}
		// for existing records, return to the last list page the user was on
		else {
			queryString += "&bypassForm=true&newQuery=false&retrieveFromSession=true";
		}

		return new ModelAndView(getSuccessView() + queryString);
	}
}
