/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.geneset.dao;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.common.PaginatedSearchUtils;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.geneset.MigGeneSet;
import uk.ac.sanger.mig.geneset.MigGeneSetSearchBean;

public class MigGeneSetDaoSpringImpl extends AbstractDaoSpringImpl<MigGeneSet>
		implements MigGeneSetDao {
	
	private PaginatedSearchUtils<MigGeneSet> paginator;

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, MigGeneSet geneSet) {
		sql.addStringParam(geneSet.getName(), "NAME");
		sql.addStringParam(geneSet.getDescription(), "DESCRIPTION");
		sql.addLongParam(geneSet.getCreatorId(), "CREATOR_ID");
		sql.addBooleanParam(geneSet.isCoreSet(), "IS_CORE_SET");
		sql.addLongParam(geneSet.getCheckNumber(), "CHECK_NUMBER");
		sql.addStringParam(geneSet.getEditedBy(), "EDITED_BY");
		sql.addDateParam(geneSet.getEditDate(), "EDIT_DATE");
		sql.addDateParam(geneSet.getCreatedDate(), "CREATED_DATE");
		sql.addLongParam(geneSet.getId(), "ID");
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see uk.ac.sanger.mig.geneset.dao.GeneSetDao#search(uk.ac.sanger.mig.geneset.GeneSetSearchBean)
	 */
	public Collection<MigGeneSet> search(MigGeneSetSearchBean searchBean) {
		
		Collection<Object> bindVariables = new ArrayList<Object>();
		
		String sql = " select * from GNM_GENE_SET gs where 1=1 ";
		
		if(searchBean.getName() != null) {
			sql += " and gs.name = ? ";
			bindVariables.add(searchBean.getName());
		}
		
		if(searchBean.getDescription() != null) {
			sql += " and gs.description = ? ";
			bindVariables.add(searchBean.getDescription());
		}
		
		if(searchBean.getCreatedDateFrom() != null) {
			sql += " and gs.created_date >= ? ";
			bindVariables.add(defaultDateFormat.format(searchBean.getCreatedDateFrom()));
		}
		
		if(searchBean.getCreatedDateTo() != null) {
			sql += " and gs.created_date <= ? ";
			bindVariables.add(defaultDateFormat.format(searchBean.getCreatedDateTo()));
		}
		
		if(searchBean.getCreatorId() != null) {
			sql += " and gs.creator_id = ?";
			bindVariables.add(searchBean.getCreatorId());
		}
		
		if(searchBean.getOrderBy() != null && searchBean.getOrderBy().length() > 0) {
			sql += " order by " + searchBean.getOrderBy();
			if(searchBean.isOrderDesc()) {
				sql += " desc ";
			}
		}	
		else {
			sql += " order by gs.created_date ";
		}
		
		return paginator.fetchSearchResults(sql, bindVariables, searchBean, getRowMapper());
	}
	
	public Collection<MigGeneSet> fetchAllWithMigGeneId(MigGeneSetSearchBean migGeneSetSearchBean) {
		
		Collection<Object>  bindVariables = new ArrayList<Object>();
		
		String sql = "select gs.* from GNM_GENE_SET gs, GNM_GENE_SET_2_GENE g2g where (gs.id = g2g.gene_set_id) and g2g.gene_id = ?";
		
		bindVariables.add(migGeneSetSearchBean.getMigGeneId());
		
		return paginator.fetchSearchResults(sql, bindVariables, migGeneSetSearchBean, getRowMapper());
	}	

	public Collection<MigGeneSet> fetchAll(MigGeneSetSearchBean migGeneSetSearchBean) {

		Collection<Object> bindVariables = new ArrayList<Object>();
		
		String sql = "select gs.* from GNM_GENE_SET gs order by gs.id asc";
		
		return paginator.fetchSearchResults(sql, bindVariables, migGeneSetSearchBean, getRowMapper());
	}

	public void setPaginator(PaginatedSearchUtils<MigGeneSet> paginator) {
		this.paginator = paginator;
	}
}