/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.geneset.services;

import java.util.Collection;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.geneset.MigGeneSet;
import uk.ac.sanger.mig.geneset.MigGeneSetSearchBean;
import uk.ac.sanger.mig.personnel.Person;
																
public interface MigGeneSetService {
	
	/**
	 * Stores MigGeneSet as record in database along with the relevant row 
	 * into the gnm_gene_set_2_gene table and returns the record's primary key
	 * @param migGeneSet
	 * @return
	 */
	public Long storeMigGeneSet(MigGeneSet migGeneSet, Person person);	
	
	/**
	 * Returns geneSet for a given id that maps to primary key
	 * of a record in a database table.
	 * @param id
	 * @return
	 */
	public MigGeneSet fetchById(Long id, ComponentMap componentMap);
	
	
	/**
	 * Takes search bean and returns a Collection of GeneSet objects
	 * based on set fields in bean *and* (this is important) your implementation
	 * of search method in Dao layer -- eg, are you testing for equality? 
	 * Greater than/less than, etc?
	 * @param geneSetSearchBean
	 * @return
	 */
	public Collection<MigGeneSet> search(MigGeneSetSearchBean geneSetSearchBean);
	
	public Collection<MigGeneSet> fetchAll(MigGeneSetSearchBean migGeneSetSearchBean);
	
	public Collection<MigGeneSet> fetchAllWithMigGeneId(MigGeneSetSearchBean migGeneSetSearchBean);
	
}