/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.genotyping;

import java.util.Collection;
import java.util.Date;

import uk.ac.sanger.mig.alleles.Allele;
import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.ComponentEnum;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.filesupport.BinaryFile;

public class Assay extends AuthenticatedDataObject  {

	public enum Component implements ComponentEnum {
		ALL_COMPONENTS,
		ALLELE,
		ASSAY_RESULTS,
		GEL_IMAGE_FILE,
		RAW_DATA_FILE,
		ASSAY_PLATE
	}

    private Long assayTypeDictId;
    private Date assayDate;
    private Long alleleId;
    private Long assayPlateId;
    private String comments;

    private DictionaryEntry assayType;
    private Allele allele;
    private Collection<AssayResult> assayResults;
    private BinaryFile gelImageFile;
    private BinaryFile rawDataFile;
    private AssayPlate assayPlate;

    public DictionaryEntry getAssayType() {
		return assayType;
	}

	public void setAssayType(DictionaryEntry assayType) {
		this.assayType = assayType;
	}

	public Allele getAllele() {
		return allele;
	}

	public void setAllele(Allele allele) {
		this.allele = allele;
	}

	public Long getAssayTypeDictId() {
        return assayTypeDictId;
    }

    public void setAssayTypeDictId(Long assayTypeDictId) {
        this.assayTypeDictId = assayTypeDictId;
    }
    public Date getAssayDate() {
        return assayDate;
    }

    public void setAssayDate(Date assayDate) {
        this.assayDate = assayDate;
    }
    public Long getAlleleId() {
        return alleleId;
    }

    public void setAlleleId(Long alleleId) {
        this.alleleId = alleleId;
    }

	public Collection<AssayResult> getAssayResults() {
		return assayResults;
	}

	public void setAssayResults(Collection<AssayResult> assayResults) {
		this.assayResults = assayResults;
	}

	public BinaryFile getGelImageFile() {
		return gelImageFile;
	}

	public void setGelImageFile(BinaryFile gelImageFile) {
		this.gelImageFile = gelImageFile;
	}

	public BinaryFile getRawDataFile() {
		return rawDataFile;
	}

	public void setRawDataFile(BinaryFile rawDataFile) {
		this.rawDataFile = rawDataFile;
	}

	public AssayPlate getAssayPlate() {
		return assayPlate;
	}

	public void setAssayPlate(AssayPlate assayPlate) {
		this.assayPlate = assayPlate;
	}

	public Long getAssayPlateId() {
		return assayPlateId;
	}

	public void setAssayPlateId(Long assayPlateId) {
		this.assayPlateId = assayPlateId;
	}

	public String getComments() {
		return comments;
	}

	public void setComments(String comments) {
		this.comments = comments;
	}
}