/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


package uk.ac.sanger.mig.genotyping;

import java.util.ArrayList;
import java.util.Collection;
import java.util.LinkedHashMap;

import uk.ac.sanger.mig.alleles.Allele;
import uk.ac.sanger.mig.mousetracking.Mouse;

public class AssayPlateFunctions {

	/**
	 * Method to traverse a plate and retrieve all the cage ids used, keyed by the colony.
	 * Use a LinkedHashMap to preserve the ordering so that the print buttons on view_one jsp(s)
	 * are in the same order as the colonies on the plate.
	 *
	 * @param AssayPlate plate
	 * @return LinkedHashMap<String, Collection<Long>> data structure for printing using the AssayPlateTasks tag.
	 */
	public static LinkedHashMap<String, Collection<Long>> getCageIdsByColony(AssayPlate plate) {
		LinkedHashMap<String, Collection<Long>> colonyCages = new LinkedHashMap<String, Collection<Long>>();

		AssayPlateWell[][] wellArray = plate.getWellArray();

		if(wellArray != null) {
			for(AssayPlateWell[] columns : wellArray) {
				for(AssayPlateWell well : columns) {
					if(well != null) {
						Mouse mouse = well.getMouse();
						if(mouse != null) {
							if(mouse.getDeathDate() == null) { // if mouse is dead, we get a null cageId.
							Long cageId = mouse.getCageId();
							String colonyName = mouse.getColonyInfo().getColonyPrefix();
							Collection<Long> cageIds = new ArrayList<Long>();
							if(colonyCages.containsKey(colonyName)) {
								cageIds = colonyCages.get(colonyName);
							}
							if(!cageIds.contains(cageId)) {
								cageIds.add(cageId);
							}
								colonyCages.put(colonyName, cageIds);
							}
						}
					}
				}
			}
		}
		return colonyCages;
	}

	public static Collection<Allele> getAllelesInRow(AssayPlate plate, Integer rowIndex) {
		return plate.getAllelesInRow(rowIndex);
	}
}
