/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.genotyping;

import java.util.Collection;

import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.ComponentEnum;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.mousetracking.Mouse;

public class AssayPlateWell extends AuthenticatedDataObject  {

	public enum Component implements ComponentEnum {
		ALL_COMPONENTS,
		MOUSE
	}

    private Long assayPlateId;
    private Long mouseId;
    private int plateRow;
    private int plateColumn;
    private Long wellTypeDictId;
    private Long earmarkDictId;
    private boolean locked;
    private Boolean sampleCollected;

    private Mouse mouse;
    private Collection<AssayResult> assayResults;
    private DictionaryEntry earmark;
    private String mouseName;
    private DictionaryEntry wellType;


	public String getMouseName() {
		return mouseName;
	}

	public void setMouseName(String mouseName) {
		this.mouseName = mouseName;
	}

	public Long getAssayPlateId() {
        return assayPlateId;
    }

    public void setAssayPlateId(Long assayPlateId) {
        this.assayPlateId = assayPlateId;
    }

    public Long getMouseId() {
        return mouseId;
    }

    public void setMouseId(Long mouseId) {
        this.mouseId = mouseId;
    }

    public Collection<AssayResult> getAssayResults() {
		return assayResults;
	}

	public void setAssayResults(Collection<AssayResult> assayResults) {
		this.assayResults = assayResults;
	}

	public int getPlateRow() {
        return plateRow;
    }

    public void setPlateRow(int plateRow) {
        this.plateRow = plateRow;
    }

    public int getPlateColumn() {
        return plateColumn;
    }

    public void setPlateColumn(int plateColumn) {
        this.plateColumn = plateColumn;
    }

    public Long getWellTypeDictId() {
        return wellTypeDictId;
    }

    public void setWellTypeDictId(Long wellTypeDictId) {
        this.wellTypeDictId = wellTypeDictId;
    }

    public Long getEarmarkDictId() {
        return earmarkDictId;
    }

    public void setEarmarkDictId(Long earmarkDictId) {
        this.earmarkDictId = earmarkDictId;
    }

    public boolean isLocked() {
        return locked;
    }

    public void setLocked(boolean isLocked) {
        this.locked = isLocked;
    }

	public DictionaryEntry getEarmark() {
		return earmark;
	}

	public void setEarmark(DictionaryEntry earmark) {
		this.earmark = earmark;
	}

	public Mouse getMouse() {
		return mouse;
	}

	public void setMouse(Mouse mouse) {
		this.mouse = mouse;
	}

	public DictionaryEntry getWellType() {
		return wellType;
	}

	public void setWellType(DictionaryEntry wellType) {
		this.wellType = wellType;
	}

    /**
     * Sample collected has 3 possible values:
     * TRUE - a sample (earclip or tissue) has been collected in the well.
     * FALSE - the user has explicitly indicated that there will be no sample in the well.
     * NULL - the user has not yet added tissue or indicated that no sample will be added.
     * @return true, false or null
	 */
	public Boolean getSampleCollected() {
		return sampleCollected;
	}

	/**
     * Sample collected can have 3 possible values:
     * TRUE - a sample (earclip or tissue) has been collected in the well.
     * FALSE - the user has explicitly indicated that there will be no sample in the well.
     * NULL - the user has not yet added tissue or indicated that no sample will be added.
	 * @param sampleCollected
	 */
	public void setSampleCollected(Boolean sampleCollected) {
		this.sampleCollected = sampleCollected;
	}

	public String getCoords() {
		return String.valueOf((char)(65+plateRow)) + (1+plateColumn);
	}

}