package uk.ac.sanger.mig.genotyping.controllers;

import static uk.ac.sanger.mig.genotyping.AssayPlateSampleTypeDictionary.EARCLIP;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.common.controllers.AbstractFormChangeController;
import uk.ac.sanger.mig.genotyping.forms.AddTissueForm;
import uk.ac.sanger.mig.personnel.Person;

public class AddTissueFormController extends AbstractFormChangeController{

	private AddTissueFormHelper formHelper;

	public void setFormHelper(AddTissueFormHelper formHelper) {
		this.formHelper = formHelper;
	}

	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		AddTissueForm form = (AddTissueForm)command;
		Person user = RequestUtils.getUser(request);

		Long plateId = formHelper.processForm(form, user);

		return new ModelAndView(getSuccessView(), "plateId", plateId);
	}

	@Override
	protected Object formBackingObject(HttpServletRequest request) throws Exception {
		RequestUtils.setLastReferer(request); //handle invalid back button
		Long plateId = ServletRequestUtils.getLongParameter(request, "id");
		AddTissueForm form = (AddTissueForm)createCommand();
		formHelper.initForm(form, plateId);
		return form;
	}


	@Override
	protected void onFormChange(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		AddTissueForm form = (AddTissueForm)command;
		String changeRequest = ServletRequestUtils.getRequiredStringParameter(request, "changeForm");

		if("scanSheetBarcode".equals(changeRequest)) {
			formHelper.scanSheetBarcode(form, errors);
		}
		else if("scanPlateBarcode".equals(changeRequest)) {
			formHelper.scanPlateBarcode(form, errors);
		}
		else if("selectSampleType".equals(changeRequest)){
			if(EARCLIP.equals(form.getPlate().getSampleTypeDictId())) {
				formHelper.setEarclipProcedure(form);
			}
			else {
				formHelper.setOtherTissueProcedure(form);
			}
		}
		else if("selectPostMortem".equals(changeRequest)) {
			if(EARCLIP.equals(form.getPlate().getSampleTypeDictId()) && Boolean.TRUE.equals(form.getPlate().getPostMortem())) {
				formHelper.setOtherTissueProcedure(form);
			}
			formHelper.checkIsProjectLicenceRequired(form);
		}

	}

	@Override
	protected Map referenceData(HttpServletRequest request, Object command, Errors errors) throws Exception {
		AddTissueForm form = (AddTissueForm)command;

		Map<String, Object> referenceData = new HashMap<String, Object>();

		Collection<DictionaryEntry> sampleTypes = formHelper.getSampleTypeDictionaryEntries(form);
		referenceData.put("sampleTypes", sampleTypes);

		//Yes/No list
		Map<Boolean, String> yesNo = new HashMap<Boolean, String>();
		yesNo.put(false,"No");
		yesNo.put(true,"Yes");
		referenceData.put("yesNo",yesNo);

		if(form.getPlate() != null) {
			Collection<DictionaryEntry> earmarks = formHelper.getEarmarkDictionaryEntries(form);
			referenceData.put("earmarks", earmarks);
			Collection<DictionaryEntry> gender = formHelper.getGenderDictionaryEntries(form);
			referenceData.put("gender", gender);
		}

		return referenceData;
	}

	@Override
	protected ModelAndView handleInvalidSubmit(HttpServletRequest request, HttpServletResponse response) throws Exception {
		return new ModelAndView("errors/handle_invalid_submit");
	}
}
