package uk.ac.sanger.mig.genotyping.controllers;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.common.controllers.AbstractFormChangeController;
import uk.ac.sanger.mig.genotyping.forms.EditAssayForm;
import uk.ac.sanger.mig.personnel.Person;

public class EditAssayFormController extends AbstractFormChangeController {

	private EditAssayFormHelper formHelper;

	public void setFormHelper(EditAssayFormHelper formChanger) {
		this.formHelper = formChanger;
	}

	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		EditAssayForm form = (EditAssayForm)command;
		Person person = RequestUtils.getUser(request);

		formHelper.processForm(form, person);

		Map<String, Object> queryParams = new HashMap<String, Object>();
		queryParams.put("barcode", form.getAssayPlate().getBarcode());
		queryParams.put("date", SIMPLE_DATE_FORMAT.format(form.getAssayDate()));

		return new ModelAndView(getSuccessView(), queryParams);
	}

	@Override
	protected void onFormChange(HttpServletRequest request,	HttpServletResponse response, Object command, BindException errors)	throws Exception {
		EditAssayForm form = (EditAssayForm)command;
		String changeRequest = ServletRequestUtils.getRequiredStringParameter(request, "changeForm");

		if("scanBarcode".equals(changeRequest)) {
			formHelper.scanBarcode(form, errors);
		}
		else if("selectAssay".equals(changeRequest)) {
			formHelper.selectAssay(form, errors);
		}
		else if("selectAssayDate".equals(changeRequest)) {
			formHelper.selectAssayDate(form);
		}

		form.handleUploadedFiles();
	}

	@Override
	protected Map referenceData(HttpServletRequest request, Object command, Errors errors) throws Exception {
		EditAssayForm form = (EditAssayForm)command;
		Map<String, Object> referenceData = new HashMap<String, Object>();
		Person user = RequestUtils.getUser(request);

		if(form.getAssayPlate() != null) {
			Map<String, String> assayOptions = formHelper.makeAssaySelectListOptions(form);
			referenceData.put("assayOptions", assayOptions);

			if(form.getAssayDate() != null) {
				referenceData.putAll(formHelper.fetchAssayResultSummary(user, form.getAssayPlate().getId(), form.getAssayDate()));
			}

			if(form.getSelectedAssay() != null) {
				referenceData.put("selectedAssayText", assayOptions.get(form.getSelectedAssay()));

				Collection<DictionaryEntry> assayResultOptions = formHelper.makeAssayResultSelectOptions();
				referenceData.put("resultOptions", assayResultOptions);
			}
		}

		return referenceData;
	}

	@Override
	protected Object formBackingObject(HttpServletRequest request) throws Exception {
		RequestUtils.setLastReferer(request);

		String barcode = ServletRequestUtils.getStringParameter(request, "barcode", "");
		String assayDate = ServletRequestUtils.getStringParameter(request, "date", "");

		EditAssayForm form = (EditAssayForm)createCommand();
		formHelper.initForm(form, barcode, assayDate);

		return form;
	}

	@Override
	protected ModelAndView handleInvalidSubmit(HttpServletRequest request, HttpServletResponse response) throws Exception {
		return new ModelAndView("errors/handle_invalid_submit");
	}
}
