package uk.ac.sanger.mig.genotyping.controllers;

import java.util.Collection;
import java.util.Collections;
import java.util.Comparator;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.common.controllers.AbstractFormChangeController;
import uk.ac.sanger.mig.genotyping.forms.EditAssayPlatesForm;
import uk.ac.sanger.mig.mousetracking.Cohort;
import uk.ac.sanger.mig.mousetracking.Mouse;
import uk.ac.sanger.mig.personnel.Person;


public class EditAssayPlatesFormController extends AbstractFormChangeController {

	private EditAssayPlatesFormHelper formHelper;

	public void setFormHelper(EditAssayPlatesFormHelper formHelper) {
		this.formHelper = formHelper;
	}

	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		EditAssayPlatesForm form = (EditAssayPlatesForm)command;
		Person user = RequestUtils.getUser(request);

		formHelper.processForm(form, user);

		Cohort cohort = formHelper.fetchCohort(form);

		return new ModelAndView(getSuccessView(),"cohortId",cohort.getId());
	}

	@Override
	protected void onFormChange(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		EditAssayPlatesForm form = (EditAssayPlatesForm)command;
		String changeRequest = ServletRequestUtils.getRequiredStringParameter(request, "changeForm");

		if("addPlate".equals(changeRequest)) {
			formHelper.addPlate(form);
		}
		else if("clearPlates".equals(changeRequest)) {
			formHelper.clearPlates(form);
			formHelper.addPlate(form);
		}
	}

	@Override
	protected Object formBackingObject(HttpServletRequest request) throws Exception {
		RequestUtils.setLastReferer(request);
		EditAssayPlatesForm form = (EditAssayPlatesForm)createCommand();

		Long cohortId = ServletRequestUtils.getRequiredLongParameter(request, "id");

		formHelper.initForm(form, cohortId);

		return form;
	}


	@Override
	protected Map referenceData(HttpServletRequest request, Object command, Errors errors) throws Exception {
		EditAssayPlatesForm form = (EditAssayPlatesForm)command;
		Map<String, Object> referenceData = new HashMap<String, Object>();

		Cohort cohort = formHelper.fetchCohort(form);
		Collection<Mouse> mice = cohort.getMice();
		Collections.sort((List<Mouse>) mice,new Comparator<Mouse>() {
			public int compare(Mouse o1, Mouse o2) {
				return(o1.getName().compareTo(o2.getName()));
			}
		});
		referenceData.put("mice", mice);
		referenceData.put("wellSelectOptions", formHelper.makeWellSelectOptions(cohort, form));
		referenceData.put("categoryOptions", formHelper.makePlateCategorySelectOptions());

		return referenceData;
	}



	@Override
	protected ModelAndView handleInvalidSubmit(HttpServletRequest request, HttpServletResponse response) throws Exception {
		return new ModelAndView("errors/handle_invalid_submit");
	}
}
