package uk.ac.sanger.mig.genotyping.controllers;

import java.util.ArrayList;
import java.util.Collection;
import java.util.LinkedHashMap;
import java.util.Map;
import java.util.Set;

import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.common.services.ComponentMapService;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.genotyping.AssayPlate;
import uk.ac.sanger.mig.genotyping.AssayPlateWell;
import uk.ac.sanger.mig.genotyping.AssayPlateWellTypeDictionary;
import uk.ac.sanger.mig.genotyping.forms.EditAssayPlatesForm;
import uk.ac.sanger.mig.genotyping.services.AssayPlateService;
import uk.ac.sanger.mig.mousetracking.Cohort;
import uk.ac.sanger.mig.mousetracking.Mouse;
import uk.ac.sanger.mig.mousetracking.services.CohortService;
import uk.ac.sanger.mig.personnel.Person;

public class EditAssayPlatesFormHelper {

	private CohortService cohortService;
	private AssayPlateService assayPlateService;
	private ComponentMapService componentMapService;
	private DictionaryService dictionaryService;


	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	public void setAssayPlateService(AssayPlateService assayPlateService) {
		this.assayPlateService = assayPlateService;
	}

	public void setComponentMapService(ComponentMapService componentMapService) {
		this.componentMapService = componentMapService;
	}

	public void setCohortService(CohortService cohortService) {
		this.cohortService = cohortService;
	}

	void addPlate(EditAssayPlatesForm form) {
		AssayPlate plate = new AssayPlate(AssayPlate.DEFAULT_ROWS,AssayPlate.DEFAULT_COLUMNS);
		assayPlateService.inflateAssayPlateComponents(plate);
		form.getArrayedPlates().add(plate);
		form.setSelectedPlateIndex(form.getArrayedPlates().size()-1);
	}

	void clearPlates(EditAssayPlatesForm form) {
		form.getArrayedPlates().clear();
	}

	/**
	 * List of selectable mice should exclude mice already on the plate(s)
	 * @param cohort
	 * @param form
	 * @return
	 */
	Map<Long, String> makeWellSelectOptions(Cohort cohort, EditAssayPlatesForm form) {
		Map<Long, String> wellSelectOptions = new LinkedHashMap<Long, String>();
		wellSelectOptions.put(-1L, "Blank");
		wellSelectOptions.put(-2L, "Control");

		Collection<Long> miceInPlates = new ArrayList<Long>();
		for(AssayPlate plate : form.getArrayedPlates()) {
			for(AssayPlateWell[] rows : plate.getWellArray()) {
				for(AssayPlateWell well : rows) {
					if(well.getMouseId() != null) {
						miceInPlates.add(well.getMouseId());
					}
				}
			}
		}

		for(Mouse mouse : cohort.getMice()) {
			if(!miceInPlates.contains(mouse.getId())) {
				wellSelectOptions.put(mouse.getId(), mouse.getName());
			}
		}

		return wellSelectOptions;
	}

	Cohort fetchCohort(EditAssayPlatesForm form) {
		return cohortService.fetchById(form.getCohortId(), componentMapService.getComponentMap("manageCohort"));
	}

	void initForm(EditAssayPlatesForm form, Long cohortId) {
		form.setCohortId(cohortId);

		Collection<AssayPlate> plates = assayPlateService.fetchByCohortId(cohortId, componentMapService.getComponentMap("viewOneAssayPlate"));

		if(plates.isEmpty()) {
			 plates = assayPlateService.fetchArrayedPlates(cohortId);
			 form.setDataPersisted(false);
		}
		else {
			form.setDataPersisted(true);
			AssayPlate plateForCat =  (AssayPlate)plates.toArray()[0];
			form.setPlateCategoryId(plateForCat.getPlateCategoryId());
		}

		for(AssayPlate plate : plates) {
			assayPlateService.inflateAssayPlateComponents(plate);
		}

		form.setArrayedPlates(plates);
	}

	Set<Long> processForm(EditAssayPlatesForm form, Person user) {
		Collection<AssayPlate> platesToProcess = new ArrayList<AssayPlate>();

		for(AssayPlate plate : form.getArrayedPlates()) {
			// Assign plate category.
			plate.setPlateCategoryId(form.getPlateCategoryId());

			//flag empty plates for delete
			boolean containsSamples = false;
			wells:
				for(AssayPlateWell[] rows : plate.getWellArray()) {
					for(AssayPlateWell well :rows) {
						if(AssayPlateWellTypeDictionary.EARCLIP.equals(well.getWellTypeDictId())||
								AssayPlateWellTypeDictionary.OTHER_TISSUE.equals(well.getWellTypeDictId())) {
							containsSamples = true;
							break wells;
						}
				}
			}

			// set cohort id in plates with mouse samples
			if(containsSamples) {
				plate.setCohortId(form.getCohortId());
				platesToProcess.add(plate);
			}
			// empty previously stored plates are deleted (empty new plates are ignored)
			else if(!plate.isNewRecord()){
				plate.setFlaggedForDelete(true);
				platesToProcess.add(plate);
			}

		}

		return assayPlateService.storeCollection(platesToProcess, user);
	}

	Collection<DictionaryEntry> makePlateCategorySelectOptions() {
		return dictionaryService.fetch(DictionaryEnum.GENOTYPING_ASSAY_PLATE_CATEGORY);
	}

}
