package uk.ac.sanger.mig.genotyping.controllers;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;
import java.util.Set;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.alleles.Allele;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.common.controllers.AbstractFormChangeController;
import uk.ac.sanger.mig.genotyping.forms.GenotypeAssignmentForm;
import uk.ac.sanger.mig.personnel.Person;

public class EditGenotypeAssignmentFormController extends AbstractFormChangeController {

	private EditGenotypeAssignmentFormHelper formHelper;

	public void setFormHelper(EditGenotypeAssignmentFormHelper formHelper) {
		this.formHelper = formHelper;
	}

	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		GenotypeAssignmentForm form = (GenotypeAssignmentForm)command;
		Person person = RequestUtils.getUser(request);

		int updatedRecords = formHelper.processForm(form, person);

		Map<String, Object> queryParams = new HashMap<String, Object>();
		queryParams.put("prevBarcode", form.getAssayPlate().getBarcode());
		queryParams.put("prevAlleleId", form.getSelectedAlleleId());
		queryParams.put("prevUpdatedRecords", updatedRecords);

		return new ModelAndView(getSuccessView(), queryParams);
	}

	@Override
	protected Object formBackingObject(HttpServletRequest request) throws Exception {
		RequestUtils.setLastReferer(request);

		String barcode = ServletRequestUtils.getStringParameter(request, "prevBarcode", "");
		Long alleleId = ServletRequestUtils.getLongParameter(request, "prevAlleleId");

		GenotypeAssignmentForm form = (GenotypeAssignmentForm)createCommand();
		formHelper.initForm(form, barcode, alleleId);

		// use simpledateformat to get todays date as a string for comparison in the JSP.
		form.setTodaysDateAsString(SimpleDateFormat.getDateInstance().format(new Date()));

		return form;
	}

	@Override
	protected Map referenceData(HttpServletRequest request, Object command, Errors errors) throws Exception {
		GenotypeAssignmentForm form = (GenotypeAssignmentForm)command;
		Map<String, Object> referenceData = new HashMap<String, Object>();

		if(form.getAssayPlate() != null) {
			Set<Allele> allelesInPlate = form.getAssayPlate().getAllelesInPlate();
			referenceData.put("allelesInPlate", allelesInPlate);

			Person user = RequestUtils.getUser(request);
			referenceData.putAll(formHelper.fetchGenotypeHistoryToday(form, user));
		}

		if(form.getSelectedAlleleId() != null) {
			referenceData.put("genotypeOptions", formHelper.makeGenotypeSelectOptions());
			referenceData.put("assayResultOptions", formHelper.makeAssayResultSelectOptions());
		}

		return referenceData;
	}

	@Override
	protected void onFormChange(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		GenotypeAssignmentForm form = (GenotypeAssignmentForm)command;
		String changeRequest = ServletRequestUtils.getRequiredStringParameter(request, "changeForm");

		if("scanBarcode".equals(changeRequest)) {
			formHelper.scanBarcode(form, errors);
		}
		else if("selectAllele".equals(changeRequest)) {
			formHelper.selectAllele(form, errors);
		}
	}

}
