package uk.ac.sanger.mig.genotyping.controllers;

import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.Map;

import org.apache.commons.lang.StringUtils;
import org.springframework.validation.BindException;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.common.Pair;
import uk.ac.sanger.mig.common.services.ComponentMapService;
import uk.ac.sanger.mig.customquery.CustomQuery;
import uk.ac.sanger.mig.customquery.forms.CustomQueryFilterEnum;
import uk.ac.sanger.mig.customquery.forms.CustomQueryForm;
import uk.ac.sanger.mig.customquery.forms.CustomQueryFormFilter;
import uk.ac.sanger.mig.customquery.forms.CustomQueryFormSort;
import uk.ac.sanger.mig.customquery.services.CustomQueryService;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.genotyping.Assay;
import uk.ac.sanger.mig.genotyping.AssayPlate;
import uk.ac.sanger.mig.genotyping.AssayPlateWell;
import uk.ac.sanger.mig.genotyping.AssayResult;
import uk.ac.sanger.mig.genotyping.forms.GenotypeAssignmentForm;
import uk.ac.sanger.mig.genotyping.forms.MouseSubform;
import uk.ac.sanger.mig.genotyping.services.AssayPlateService;
import uk.ac.sanger.mig.genotyping.services.AssayResultService;
import uk.ac.sanger.mig.genotyping.services.AssayService;
import uk.ac.sanger.mig.mousetracking.GenotypeHistory;
import uk.ac.sanger.mig.mousetracking.GenotypeHistorySourceDictionary;
import uk.ac.sanger.mig.mousetracking.Mouse;
import uk.ac.sanger.mig.mousetracking.MouseAllele;
import uk.ac.sanger.mig.mousetracking.services.MouseAlleleService;
import uk.ac.sanger.mig.personnel.Person;

public class EditGenotypeAssignmentFormHelper {

	private AssayPlateService assayPlateService;
	private AssayResultService assayResultService;
	private AssayService assayService;
	private ComponentMapService componentMapService;
	private DictionaryService dictionaryService;
	private MouseAlleleService mouseAlleleService;
	private CustomQueryService customQueryService;

	public void setAssayPlateService(AssayPlateService assayPlateService) {
		this.assayPlateService = assayPlateService;
	}

	public void setAssayResultService(AssayResultService assayResultService) {
		this.assayResultService = assayResultService;
	}

	public void setAssayService(AssayService assayService) {
		this.assayService = assayService;
	}

	public void setComponentMapService(ComponentMapService componentMapService) {
		this.componentMapService = componentMapService;
	}

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	public void setMouseAlleleService(MouseAlleleService mouseAlleleService) {
		this.mouseAlleleService = mouseAlleleService;
	}

	public void setCustomQueryService(CustomQueryService customQueryService) {
		this.customQueryService = customQueryService;
	}

	void initForm(GenotypeAssignmentForm form, String barcode, Long alleleId) {
		BindException errors = new BindException(form, "form");
		form.setBarcode(null);
		form.setAssayPlate(null);
		form.setSelectedAlleleId(null);
		form.setSelectedAllele(null);
		form.setSelectedMice(null);


		if(StringUtils.isNotEmpty(barcode)) {
			form.setBarcode(barcode);
			scanBarcode(form, errors);
		}

		if(alleleId != null) {
			form.setSelectedAlleleId(alleleId);
			selectAllele(form, errors);
		}
	}

	int processForm(GenotypeAssignmentForm form, Person user) {
		if(!form.isValidated()) {
			throw new IllegalStateException("form is not valid");
		}

		Collection<Pair<MouseAllele, GenotypeHistory>> mouseAllelesToUpdate = new ArrayList<Pair<MouseAllele, GenotypeHistory>>();
		for(MouseSubform mouseSubform : form.getSelectedMice()) {
			if(mouseSubform.getNewGenotypeDictId() != null) {
				MouseAllele mouseAllele = mouseSubform.getSelectedMouseAllele();
				mouseAllele.setGenotypeDictId(mouseSubform.getNewGenotypeDictId());
				if(mouseSubform.isFinalAssignment()) {
					mouseAllele.setLockedForUpdate(true);
				}

				GenotypeHistory genotypeHistory = new GenotypeHistory();
				genotypeHistory.setComments(mouseSubform.getComments());
				genotypeHistory.setSourceDictId(GenotypeHistorySourceDictionary.PCR);

				Pair<MouseAllele, GenotypeHistory> pair = new Pair<MouseAllele, GenotypeHistory>(mouseAllele, genotypeHistory);

				mouseAllelesToUpdate.add(pair);
			}
		}

		mouseAlleleService.storeCollectionWithHistory(mouseAllelesToUpdate, user);

		return mouseAllelesToUpdate.size();
	}

	void scanBarcode(GenotypeAssignmentForm form, BindException errors) {
		//reset all form fields and objects
		form.setAssayPlate(null);
		form.setSelectedAlleleId(null);

		form.setSelectedMice(null);

		if(form.getBarcode() != null) {
			ComponentMap plateComponents = componentMapService.getComponentMap("viewOneAssayPlate");

			AssayPlate assayPlate = assayPlateService.fetchByBarcode(form.getBarcode(), plateComponents);

			if(assayPlate == null) {
				errors.reject(null, "No assay plate found corresponding to barcode '" + form.getBarcode() + "'");
				form.setBarcode(null);
			}
			else {
				form.setAssayPlate(assayPlate);
			}
		}
	}

	void selectAllele(GenotypeAssignmentForm form, BindException errors) {
		form.setSelectedMice(null);

		if(form.getAssayPlate() == null) {
			errors.reject(null, "Form is in an inconsistent state. Cancel and try again.");
		}

		if(form.getSelectedAlleleId() != null) {
			addSelectedMiceToForm(form);
			addSelectedAssaysToForm(form);
		}
	}

	/**
	 * Add the list of mice that have the selected allele to the form with their assay results
	 * @param form
	 */
	private void addSelectedMiceToForm(GenotypeAssignmentForm form) {
		AssayPlate plate = form.getAssayPlate();

		Collection<AssayPlateWell> wells = plate.getWellsByAlleleId(form.getSelectedAlleleId());

		Collection<MouseSubform> selectedMice= new ArrayList<MouseSubform>();
		for(AssayPlateWell well : wells) {
			MouseSubform mouseSubform = new MouseSubform();

			Mouse mouse = well.getMouse();
			mouseSubform.setMouse(mouse);

			MouseAllele selectedAllele = getAllele(mouse.getAlleles(), form.getSelectedAlleleId());
			mouseSubform.setSelectedMouseAllele(selectedAllele);

			Collection<AssayResult> assayResults = assayResultService.fetchLatestByMouseAlleleId(selectedAllele.getId(), ComponentMap.of(AssayResult.Component.ASSAY));
			mouseSubform.setAssayResults(putAssayResultsInMap(assayResults));

			selectedMice.add(mouseSubform);
		}
		form.setSelectedMice(selectedMice);
	}

	/**
	 * Add the list of assays that have been performed on the plate for the given allele
	 * @param form
	 */
	private void addSelectedAssaysToForm(GenotypeAssignmentForm form) {
		AssayPlate plate = form.getAssayPlate();
		Collection<Assay> assays = assayService.fetchLatestByPlateAndAlleleId(plate.getId(), form.getSelectedAlleleId(), null);
		form.setAssays(putAssaysInMap(assays));
	}

	/**
	 * Returns a MouseAllele from a Collection of MouseAlleles based on the primary key (ID).
	 * The first occurance of a MouseAllele in the collection matching the input Id is returned.
	 * @param alleles Collection of MouseAlleles
	 * @param alleleId Long ID of allele of interest
	 * @return MouseAllele matching the input ID or null if none found matching.
	 */
	private MouseAllele getAllele(Collection<MouseAllele> alleles, Long alleleId) {
		MouseAllele alleleToReturn = null;
		if(alleles != null && alleleId != null) {
			for(MouseAllele mouseAllele : alleles) {
				if(mouseAllele.getAlleleId().equals(alleleId)) {
					alleleToReturn = mouseAllele;
					break;
				}
			}
		}
		return alleleToReturn;
	}

	/**
	 * Convert a collection of AssayResult into a map with the key being the assayTypeDictId
	 * @param results
	 * @return
	 */
	private Map<Long, AssayResult> putAssayResultsInMap(Collection<AssayResult> results) {
		Map<Long, AssayResult> resultsMap = new HashMap<Long, AssayResult>();

		for(AssayResult assayResult : results) {
			resultsMap.put(assayResult.getAssay().getAssayTypeDictId(), assayResult);
		}

		return resultsMap;
	}

	/**
	 * Convert a collection of Assay into a map with the key being the assayTypeDictId
	 * @param assays
	 * @return
	 */
	private Map<Long, Assay> putAssaysInMap(Collection<Assay> assays) {
		Map<Long, Assay> assaysMap = new LinkedHashMap<Long, Assay>();

		for(Assay assay : assays) {
			assaysMap.put(assay.getAssayTypeDictId(),assay);
		}

		return assaysMap;
	}

	Collection<DictionaryEntry> makeGenotypeSelectOptions() {
		return dictionaryService.fetch(DictionaryEnum.MOUSE_GENOTYPE);
	}

	Collection<DictionaryEntry> makeAssayResultSelectOptions() {
		return dictionaryService.fetch(DictionaryEnum.GENOTYPING_ASSAY_RESULT_TYPE);
	}

	Map<String, Object> fetchGenotypeHistoryToday(GenotypeAssignmentForm form, Person user) {
		Long plateId = form.getAssayPlate().getId();
		CustomQuery customQuery = customQueryService.fetchByUniqueName("genotypeHistoryToday", user.getId(), null);
		Long queryId = customQuery.getId();
		CustomQueryForm queryForm = new CustomQueryForm(queryId, user.getId(), "genotypeHistoryToday");

		CustomQueryFormFilter plateIdFilter = customQueryService.constructFormFilter(queryId, "assay_plate_id", false, CustomQueryFilterEnum.EQUALS, plateId);
		queryForm.addFilter(plateIdFilter);

		CustomQueryFormSort alleleSort = new CustomQueryFormSort("allele", false, false);
		queryForm.addSort(alleleSort);

		return customQueryService.fetchCustomQueryModel(queryForm);
	}
}
