/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.genotyping.dao;

import java.util.Collection;

import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.database.TypedDao;
import uk.ac.sanger.mig.genotyping.Assay;
import uk.ac.sanger.mig.genotyping.AssaySearchBean;

public interface AssayDao extends TypedDao<Assay> {

	/**
	 * Fetch the assayTypes that are independent of a specific allele and so are applicable to an
	 * entire assay plate. (E.g. LacZ)
	 *
	 * @return Collection of assay types that are plate scope
	 */
	public Collection<DictionaryEntry> fetchPlateAssayTypes();


	/**
	 * Fetch the assayTypes that are allele specific. (E.g. Mutant, Wildtype)
	 *
	 * @return Collection of assay types that are allele specific
	 */
	public Collection<DictionaryEntry> fetchAlleleAssayTypes();


	/**
	 * Fetch a collection of Assays associated with a plate.
	 *
	 * @param plateId
	 *            plate ID of interest
	 * @return Collection of Assays for a given plate Id.
	 */
	public Collection<Assay> fetchByPlateId(Long plateId);


	/**
	 * Fetch a specific Assay for a plate based on assay type, allele and assay date. If allele is
	 * null, then it is assumed that a plate-scope assay (E.g. LacZ) is returned
	 *
	 * @param assaySearchBean
	 *            bean containing the values for plateId, alleleId (optional), assayTypeId and
	 *            assayDate
	 * @return Assay or null if no record found
	 */
	public Assay fetchByPlateAlleleTypeAndDate(AssaySearchBean assaySearchBean);


	public Collection<Assay> fetchLatestByPlateAndAlleleId(Long plateId, Long alleleId);

}