/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.genotyping.dao;

import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.genotyping.AssayPlate;

public class AssayPlateDaoSpringImpl extends AbstractDaoSpringImpl<AssayPlate> implements AssayPlateDao {

	public AssayPlate fetchByBarcode(String barcode) {
		String sql = " select * from gtp_assay_plate where upper(?) in (plate_barcode, sheet_barcode) ";
		return fetchOne(sql, barcode);
	}

	public Collection<AssayPlate> fetchByCohortId(Long cohortId) {
		String sql = " select * from gtp_assay_plate where cohort_id = ? order by id ";
		return fetchCollection(sql, cohortId);
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, AssayPlate assayPlate) {
		sql.addLongParam(assayPlate.getCohortId(), "COHORT_ID");
		sql.addStringParam(assayPlate.getSheetBarcode(), "SHEET_BARCODE");
		sql.addStringParam(assayPlate.getPlateBarcode(), "PLATE_BARCODE");
		sql.addBooleanParam(assayPlate.isAutoPopulated(), "IS_AUTO_POPULATED");
		sql.addLongParam(assayPlate.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(assayPlate.getCreatedDate(), "CREATED_DATE");
		sql.addStringParam(assayPlate.getEditedBy(), "EDITED_BY");
		sql.addDateParam(assayPlate.getEditDate(), "EDIT_DATE");
		sql.addLongParam(assayPlate.getCheckNumber(), "CHECK_NUMBER");
		sql.addIntParam(assayPlate.getRowsOnPlate(), "ROWS_ON_PLATE");
		sql.addIntParam(assayPlate.getColumnsOnPlate(), "COLUMNS_ON_PLATE");
		sql.addLongParam(assayPlate.getPlateCategoryId(),"PLATE_CATEGORY_DICT_ID");
		sql.addLongParam(assayPlate.getSampleTypeDictId(), "SAMPLE_TYPE_DICT_ID");
		sql.addBooleanParam(assayPlate.getPostMortem(), "IS_POST_MORTEM");
		sql.addLongParam(assayPlate.getId(), "ID");
	}
}