/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.genotyping.dao;

import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.genotyping.AssayPlateWell;

public class AssayPlateWellDaoSpringImpl extends AbstractDaoSpringImpl<AssayPlateWell> implements AssayPlateWellDao {

	public Collection<AssayPlateWell> fetchByPlateId(Long plateId) {
		String sql = " select * from gtp_assay_plate_well where assay_plate_id = ? ";
		return fetchCollection(sql, plateId);
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, AssayPlateWell assayPlateWell) {
		sql.addLongParam(assayPlateWell.getAssayPlateId(), "ASSAY_PLATE_ID");
		sql.addLongParam(assayPlateWell.getMouseId(), "MOUSE_ID");
		sql.addIntParam(assayPlateWell.getPlateRow(), "PLATE_ROW");
		sql.addIntParam(assayPlateWell.getPlateColumn(), "PLATE_COLUMN");
		sql.addLongParam(assayPlateWell.getWellTypeDictId(), "WELL_TYPE_DICT_ID");
		sql.addLongParam(assayPlateWell.getEarmarkDictId(), "EARMARK_DICT_ID");
		sql.addBooleanParam(assayPlateWell.isLocked(), "IS_LOCKED");
		sql.addLongParam(assayPlateWell.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(assayPlateWell.getCreatedDate(), "CREATED_DATE");
		sql.addStringParam(assayPlateWell.getEditedBy(), "EDITED_BY");
		sql.addDateParam(assayPlateWell.getEditDate(), "EDIT_DATE");
		sql.addLongParam(assayPlateWell.getCheckNumber(), "CHECK_NUMBER");
		sql.addBooleanParam(assayPlateWell.getSampleCollected(), "IS_SAMPLE_COLLECTED");
		sql.addLongParam(assayPlateWell.getId(), "ID");
	}

}