/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.genotyping.dao;

import java.util.Collection;

import uk.ac.sanger.mig.database.TypedDao;
import uk.ac.sanger.mig.genotyping.AssayResult;
import uk.ac.sanger.mig.genotyping.views.AssayResultsView;

public interface AssayResultDao extends TypedDao<AssayResult> {

	/**
	 * Fetch the current collection of assay results for a given assay from the database
	 *
	 * @param assayId
	 *            assay of interest
	 * @return Collection of AssayResults or empty ArrayList if no results found
	 */
	public Collection<AssayResult> fetchByAssayId(Long assayId);


	/**
	 * Fetch the current assay result for a given assay plate well Id from the database
	 *
	 * @param id
	 *            assay plate well of interest
	 * @return AssayResult or null if no record found
	 */
	public AssayResult fetchByAssayPlateWellId(Long wellId);


	/**
	 * Fetch the list of latest assay results for a given mouseAllele
	 *
	 * @param mouseAlleleId
	 * @return Collection of AssayResults or empty ArrayList if no results found
	 */
	public Collection<AssayResult> fetchLatestByMouseAlleleId(Long mouseAlleleId);


	/**
	 * Fetch the assay results view for a given mouse
	 *
	 * @param mouseId
	 * @return Collection of AssayResults or empty ArrayList if no results found
	 */
	public Collection<AssayResultsView> fetchResultsViewByMouseId(Long mouseId);


	/**
	 * Fetch all assay results for a given mouse allele.
	 *
	 * @param mouseId -
	 *            the mouse id to find results for.
	 * @param alleleId -
	 *            the allele id to find results for.
	 * @return Collection of <code>AssayResult</code> objects.
	 */
	public Collection<AssayResult> fetchByMouseAllele(Long mouseId, Long alleleId);
}