/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.genotyping.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.genotyping.AssayPlateWell;

public class AssayPlateWellRowMapper implements ParameterizedRowMapper<AssayPlateWell> {

	private DictionaryService dictionaryService;

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	public AssayPlateWell mapRow(ResultSet rs, int rowNum) throws SQLException {

		AssayPlateWell assayPlateWell = new AssayPlateWell();

		assayPlateWell.setId(rs.getLong("ID"));
		assayPlateWell.setAssayPlateId(rs.getLong("ASSAY_PLATE_ID")); if(rs.wasNull()) {assayPlateWell.setAssayPlateId(null);}
		assayPlateWell.setMouseId(rs.getLong("MOUSE_ID")); if(rs.wasNull()) {assayPlateWell.setMouseId(null);}
		assayPlateWell.setPlateRow(rs.getInt("PLATE_ROW"));
		assayPlateWell.setPlateColumn(rs.getInt("PLATE_COLUMN"));
		assayPlateWell.setWellTypeDictId(rs.getLong("WELL_TYPE_DICT_ID")); if(rs.wasNull()) {assayPlateWell.setWellTypeDictId(null);}
		assayPlateWell.setEarmarkDictId(rs.getLong("EARMARK_DICT_ID")); if(rs.wasNull()) {assayPlateWell.setEarmarkDictId(null);}
		assayPlateWell.setLocked(rs.getBoolean("IS_LOCKED"));
		assayPlateWell.setCreatorId(rs.getLong("CREATOR_ID")); if(rs.wasNull()) {assayPlateWell.setCreatorId(null);}
		assayPlateWell.setCreatedDate(rs.getDate("CREATED_DATE"));
		assayPlateWell.setEditedBy(rs.getString("EDITED_BY"));
		assayPlateWell.setEditDate(rs.getDate("EDIT_DATE"));
		assayPlateWell.setCheckNumber(rs.getLong("CHECK_NUMBER")); if(rs.wasNull()) {assayPlateWell.setCheckNumber(null);}
		assayPlateWell.setSampleCollected(rs.getBoolean("IS_SAMPLE_COLLECTED")); if(rs.wasNull()) {assayPlateWell.setSampleCollected(null);}

		assayPlateWell.setEarmark(dictionaryService.fetchEntry(DictionaryEnum.MOUSE_EARMARK_DICT, assayPlateWell.getEarmarkDictId()));
		assayPlateWell.setWellType(dictionaryService.fetchEntry(DictionaryEnum.GENOTYPING_WELL_TYPE, assayPlateWell.getWellTypeDictId()));

		return assayPlateWell;
	}
}