/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.genotyping.services;

import java.util.Collection;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.common.services.CommonServices;
import uk.ac.sanger.mig.filesupport.BinaryFile;
import uk.ac.sanger.mig.genotyping.Assay;
import uk.ac.sanger.mig.genotyping.AssaySearchBean;
import uk.ac.sanger.mig.genotyping.dao.AssayDao;
import uk.ac.sanger.mig.personnel.Person;

public interface AssayService extends CommonServices<Assay> {

	/**
	 * @see AssayDao#fetchPlateAssayTypes()
	 */
	public Collection<DictionaryEntry> fetchPlateAssayTypes();


	/**
	 * @see AssayDao#fetchAlleleAssayTypes()
	 */
	public Collection<DictionaryEntry> fetchAlleleAssayTypes();


	/**
	 * @see AssayDao#fetchByPlateAlleleTypeAndDate(AssaySearchBean)
	 */
	public Assay fetchByPlateAlleleTypeAndDate(AssaySearchBean bean, ComponentMap requiredComponents);


	/**
	 * Stores an Assay and associated collection of AssayResults
	 *
	 * @param assay
	 * @param user
	 * @return Primary Key ID of the stored Assay
	 */
	public Long storeComplete(Assay assay, Person user);


	public Collection<Assay> fetchLatestByPlateAndAlleleId(Long plateId, Long alleleId, ComponentMap requiredComponents);


	public Collection<Assay> fetchByPlateId(Long plateId, ComponentMap componentMap);


	/**
	 * Stores an assay, it's associated collection of AssayResults, and add or delete associated
	 * files
	 *
	 * @param assay
	 * @param filesToAdd
	 * @param filesToDelete
	 * @param user
	 */
	public Long storeCompleteWithFiles(Assay assay, Collection<BinaryFile> assayFilesToAdd,
			Collection<BinaryFile> plateFilesToAdd, Collection<BinaryFile> filesToDelete, Person user);

}