package uk.ac.sanger.mig.genotyping.services;

import java.util.Comparator;

import uk.ac.sanger.mig.mousetracking.Mouse;

/**
 * Sort mice by gender (male first)then cageId
 *
 *
 * @author mng
 *
 */
public class CageSortComparator implements Comparator<Mouse> {

	public int compare(Mouse o1, Mouse o2) {

		Long cageId1 = o1.getCageId();
		Long cageId2 = o2.getCageId();

		boolean weaned1 = o1.isWeaned();
		boolean weaned2 = o2.isWeaned();

		// null cages ordered after non-null cages
		if(cageId1 == null && cageId2 != null) {
			return -1;
		}
		else if(cageId1 != null && cageId2 == null) {
			return 1;
		}
		// control cages have ID=-1 and are ordered after all other cages
		else if((cageId1 != null && cageId1 == -1) || (cageId2 != null && cageId2 == -1)) {
			return -1;
		}
		// equivalent caged mice are not ordered unless the mice within it are pre-wean in
		// which case sort by name.
		else if((cageId1 == null && cageId2 == null) || cageId1.equals(cageId2)) {
				return o1.getName().compareTo(o2.getName());
		}
		// male cages are ordered before female cages if mice have been weaned.
		else if (cageId1 == null || cageId1 > cageId2) {
			if(weaned1 && weaned2) {
				if(o1.isMale() && !o2.isMale()) {
					return -1;
				}else if(!o1.isMale() && o2.isMale()) {
					return 1;
				}
			}
			return 1;
		}
		else{
			return -1;
		}
	}
}
