package uk.ac.sanger.mig.genotyping.services;
import javax.swing.tree.DefaultMutableTreeNode;

/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

public class Node extends DefaultMutableTreeNode {

	private static final long serialVersionUID = 6200178322251782894L;

	private String key;
	private int sampleCount;
	private int realSampleCount;

	public Node(String name) {
		super(name);
	}

	public String getKey() {
		return key;
	}
	public void setKey(String key) {
		this.key = key;
	}
	public int getRealSampleCount() {
		return realSampleCount;
	}
	public void setRealSampleCount(int realSampleCount) {
		this.realSampleCount = realSampleCount;
		setSampleCount();
	}
	public int getWeight() {
		int level = this.getLevel();
		return (level > 0) ? realSampleCount / level : realSampleCount;

	}
	public void setSampleCount() {
		this.sampleCount = realSampleCount + calculateRowRoundup(realSampleCount);
	}
	public int getSampleCount() {
		return sampleCount;
	}
	/**
	 *  Round the samples up to the nearest 12 as alleles cant be mixed on rows.
	*/
	private int calculateRowRoundup(int numSamples) {
		int rowOffset = 0;
		if(numSamples % 12 < 12 && numSamples % 12 > 0) {
			rowOffset = 12 - (numSamples % 12);
		}
		return rowOffset;
	}


}
