package uk.ac.sanger.mig.genotyping.validators;

import java.util.Collection;

import org.springframework.validation.Errors;
import org.springframework.validation.Validator;

import uk.ac.sanger.mig.genotyping.AssayPlateSampleTypeDictionary;
import uk.ac.sanger.mig.genotyping.AssayPlateWell;
import uk.ac.sanger.mig.genotyping.forms.AddTissueForm;
import uk.ac.sanger.mig.mousetracking.forms.ProcedureSubform;

public class AddTissueFormValidator implements Validator {

	public boolean supports(Class clazz) {
		return AddTissueForm.class.equals(clazz);
	}

	public void validate(Object target, Errors errors) {
		AddTissueForm form = (AddTissueForm)target;
		form.setValidated(false);

		if(form.getSheetBarcode() == null) {
			errors.reject(null, "Sheet barcode is a required field.");
		}

		if(form.getPlateBarcode() == null) {
			errors.reject(null, "Plate barcode is a required field.");
		}

		if(form.getPlate() != null && form.getPlate().getSampleTypeDictId() == null) {
			errors.reject(null, "Tissue Type is a required field.");
		}

		if(form.getPlate() != null && form.getPlate().getPostMortem() == null) {
			errors.reject(null, "Post Mortem is a required field.");
		}

		if(AssayPlateSampleTypeDictionary.OTHER.equals(form.getPlate().getSampleTypeDictId()) && Boolean.FALSE.equals(form.getPlate().getPostMortem())) {
			errors.reject(null, "Other tissue type can only be used post-mortem.");
		}

		ProcedureSubform subform = form.getProcedureSubform();
		if(subform.getPersonalLicenceId() == null) {
			errors.reject(null, "PIL is a required field.");
		}
		if(subform.getProcedureStartDate() == null) {
			errors.reject(null, "Collection date is a required field.");
		}

		Collection<AssayPlateWell> wells = form.getPlate().getWells();
		for(AssayPlateWell well: wells) {
			if(Boolean.FALSE.equals(well.getSampleCollected()) && well.getEarmarkDictId() != null) {
				errors.reject(null, "Mouse "+well.getMouse().getName()+" ("+ well.getCoords() +") is not to be included on this plate but earclip has been recorded.");
			}
		}
		if(form.isProjectLicenceDefaultRequired() && form.getProcedureSubform().getProjectLicenceId() == null) {
			errors.reject(null, "Some mice have no PPL information, therefore Project Licence is a required field.");
		}

		if(!errors.hasErrors()) {
			form.setValidated(true);
		}
	}
}

