/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.genotyping.views;

import java.util.Date;

public class AssayResultsView implements Comparable<AssayResultsView> {
	private Long mouseId;
	private Long assayPlateWellId;
	private String sheetBarcode;
	private String plateBarcode;
	private Integer plateRow;
	private Integer plateColumn;
	private String assayType;
	private String assayScope;
	private Long assayId;
	private Long alleleId;
	private String assayResult;
	private Date resultDate;
	private Date assayDate;
	private String assayResultComments;

	public Long getAlleleId() {
		return alleleId;
	}
	public void setAlleleId(Long alleleId) {
		this.alleleId = alleleId;
	}
	public Date getAssayDate() {
		return assayDate;
	}
	public void setAssayDate(Date assayDate) {
		this.assayDate = assayDate;
	}
	public Long getAssayId() {
		return assayId;
	}
	public void setAssayId(Long assayId) {
		this.assayId = assayId;
	}
	public Long getAssayPlateWellId() {
		return assayPlateWellId;
	}
	public void setAssayPlateWellId(Long assayPlateWellId) {
		this.assayPlateWellId = assayPlateWellId;
	}
	public String getAssayResult() {
		return assayResult;
	}
	public void setAssayResult(String assayResult) {
		this.assayResult = assayResult;
	}
	public String getAssayScope() {
		return assayScope;
	}
	public void setAssayScope(String assayScope) {
		this.assayScope = assayScope;
	}
	public String getAssayType() {
		return assayType;
	}
	public void setAssayType(String assayType) {
		this.assayType = assayType;
	}
	public Long getMouseId() {
		return mouseId;
	}
	public void setMouseId(Long mouseId) {
		this.mouseId = mouseId;
	}
	public String getPlateBarcode() {
		return plateBarcode;
	}
	public void setPlateBarcode(String plateBarcode) {
		this.plateBarcode = plateBarcode;
	}
	public Integer getPlateColumn() {
		return plateColumn;
	}
	public void setPlateColumn(Integer plateColumn) {
		this.plateColumn = plateColumn;
	}
	public Integer getPlateRow() {
		return plateRow;
	}
	public void setPlateRow(Integer plateRow) {
		this.plateRow = plateRow;
	}
	public Date getResultDate() {
		return resultDate;
	}
	public void setResultDate(Date resultDate) {
		this.resultDate = resultDate;
	}
	public String getSheetBarcode() {
		return sheetBarcode;
	}
	public void setSheetBarcode(String sheetBarcode) {
		this.sheetBarcode = sheetBarcode;
	}
	public String getWellPosition() {
		StringBuilder wellPos = new StringBuilder();

		if (plateRow != null && plateRow >= 0 && plateRow <= 26) {
			wellPos.append((char)(plateRow.intValue()+65));
		}
		else {
			wellPos.append('?');
		}
		if (plateRow == null) {
			wellPos.append("?");
		}
		else {
			wellPos.append(plateColumn + 1);
		}
		return wellPos.toString();
	}
	public int compareTo(AssayResultsView other) {
		int compResult = 0;

		compResult = compareFields(this.mouseId,other.mouseId);
		if (compResult == 0) compResult = compareFields(this.sheetBarcode,other.sheetBarcode);
		if (compResult == 0) compResult = compareFields(this.plateBarcode,other.plateBarcode);
		if (compResult == 0) compResult = compareFields(this.plateRow,other.plateRow);
		if (compResult == 0) compResult = compareFields(this.plateColumn,other.plateColumn);
		if (compResult == 0) compResult = compareFields(this.assayDate,other.assayDate);
		if (compResult == 0) compResult = compareFields(this.resultDate,other.resultDate);
		if (compResult == 0) compResult = compareFields(this.assayScope,other.assayScope);
		if (compResult == 0) compResult = compareFields(this.alleleId,other.alleleId);
		if (compResult == 0) compResult = compareFields(this.assayType,other.assayType);
		if (compResult == 0) compResult = compareFields(this.assayId,other.assayId);
		if (compResult == 0) compResult = compareFields(this.assayResult,other.assayResult);
		if (compResult == 0) compResult = compareFields(this.assayPlateWellId,other.assayPlateWellId);

		return compResult;
	}

	@SuppressWarnings("unchecked")
	private int compareFields(Comparable o1, Comparable o2) {
		if (o1 == null || o2 == null) {
			return 0;
		}
		else {
			return o1.compareTo(o2);
		}
	}
	public String getAssayResultComments() {
		return assayResultComments;
	}
	public void setAssayResultComments(String assayResultComments) {
		this.assayResultComments = assayResultComments;
	}
}
