/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.havanarequest;

import uk.ac.sanger.mig.allelerequest.AlleleRequest;
import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.ComponentEnum;
import uk.ac.sanger.mig.common.DictionaryEntry;

public class HavanaRequest extends AuthenticatedDataObject {

	private String comments;
	private String vegaId;    
	private String updatedChromosomeName;
	private boolean pseudogene;
	private boolean startNotFound;
	private boolean endNotFound;
	private String updatedGeneName;
	private String criticalExonId;
	private boolean smallIntrons;
	private boolean multipleCodingTrancripts;
	private boolean symmetricalExons;
	private boolean largeCodingExon;
	private boolean lessThanThreeCodingExons;
	private boolean noNMDInduced;
	//legacy booleans
	
	//private boolean possibleReinitiation; 
	//private boolean assemblyError;
	//private boolean containsHydrophobicRegion;
	//private boolean criticalExonContainsATG;
	
	private boolean transMembraneDomain;
  	private boolean signalPeptide;
  
  //--
  	private boolean criticalExonToo3;
  	private boolean repeatRegion;
  	private boolean geneCluster;
  	private boolean overlappingLoci;
  	
  	
	private Long statusDictId;
	private DictionaryEntry status;
	private String chromosomeName;

	private Long alleleRequestId;
	private AlleleRequest alleleRequest;  
	
	public static long ANNOTATION_COMPLETE_DESIGN_COMPLETE = 30l;
  
  public enum Component implements ComponentEnum {
    ALL_COMPONENTS,
    //add additional component enums here as needed for this AuthenticatedDataObject
}

	public DictionaryEntry getStatus() {
		return status;
	}

	public void setStatus(DictionaryEntry status) {
		this.status = status;
	}

	public AlleleRequest getAlleleRequest() {
		return alleleRequest;
	}

	public void setAlleleRequest(AlleleRequest alleleRequest) {
		this.alleleRequest = alleleRequest;
	}             

	public String getComments() {
		return comments;
	}

	public void setComments(String comments) {
		this.comments = comments;
	}                                                                                                                                            

	public String getVegaId() {
		return vegaId;
	}

	public void setVegaId(String vegaId) {
		this.vegaId = vegaId;
	}

	public String getUpdatedChromosomeName() {
		return updatedChromosomeName;
	}

	public void setUpdatedChromosomeName(String chromosome) {
		this.updatedChromosomeName = chromosome;
	}

	public String getCriticalExonId() {
		return criticalExonId;
	}

	public void setCriticalExonId(String criticalExonId) {
		this.criticalExonId = criticalExonId;
	}

	public boolean isEndNotFound() {
		return endNotFound;
	}

	public void setEndNotFound(boolean endNotFound) {
		this.endNotFound = endNotFound;
	}

	public boolean isStartNotFound() {
		return startNotFound;
	}

	public void setStartNotFound(boolean startNotFound) {
		this.startNotFound = startNotFound;
	}

	public String getUpdatedGeneName() {
		return updatedGeneName;
	}

	public void setUpdatedGeneName(String updatedGeneName) {
		this.updatedGeneName = updatedGeneName;
	}


	public boolean isPseudogene() {
		return pseudogene;
	}

	public void setPseudogene(boolean pseudoGene) {
		this.pseudogene = pseudoGene;
	}

	public Long getAlleleRequestId() {
		return alleleRequestId;
	}

	public void setAlleleRequestId(Long alleleRequestId) {
		this.alleleRequestId = alleleRequestId;
	}

	public Long getStatusDictId() {
		return statusDictId;
	}

	public void setStatusDictId(Long statusId) {
		this.statusDictId = statusId;
	}

	public boolean isLargeCodingExon() {
		return largeCodingExon;
	}

	public void setLargeCodingExon(boolean largeCodingExon) {
		this.largeCodingExon = largeCodingExon;
	}

	public boolean isLessThanThreeCodingExons() {
		return lessThanThreeCodingExons;
	}

	public void setLessThanThreeCodingExons(boolean lessThanThreeCodingExons) {
		this.lessThanThreeCodingExons = lessThanThreeCodingExons;
	}

	public boolean isMultipleCodingTrancripts() {
		return multipleCodingTrancripts;
	}

	public void setMultipleCodingTrancripts(boolean multipleCodingTrancripts) {
		this.multipleCodingTrancripts = multipleCodingTrancripts;
	}

	public boolean isNoNMDInduced() {
		return noNMDInduced;
	}

	public void setNoNMDInduced(boolean noNMDInduced) {
		this.noNMDInduced = noNMDInduced;
	}


	public boolean isSymmetricalExons() {
		return symmetricalExons;
	}

	public void setSymmetricalExons(boolean symmetricalExons) {
		this.symmetricalExons = symmetricalExons;
	}

	public String getChromosomeName() {
		return chromosomeName;
	}

	public void setChromosomeName(String chromosomeName) {
		this.chromosomeName = chromosomeName;
	}

  public boolean isSignalPeptide() {
    return signalPeptide;
  }

  public void setSignalPeptide(boolean signalPeptide) {
    this.signalPeptide = signalPeptide;
  }

  public boolean isTransMembraneDomain() {
    return transMembraneDomain;
  }

  public void setTransMembraneDomain(boolean transMembraneDomain) {
    this.transMembraneDomain = transMembraneDomain;
  }

public boolean isCriticalExonToo3() {
	return criticalExonToo3;
}

public void setCriticalExonToo3(boolean criticalExonToo3) {
	this.criticalExonToo3 = criticalExonToo3;
}

public boolean isGeneCluster() {
	return geneCluster;
}

public void setGeneCluster(boolean geneCluster) {
	this.geneCluster = geneCluster;
}

public boolean isOverlappingLoci() {
	return overlappingLoci;
}

public void setOverlappingLoci(boolean overlappingLoci) {
	this.overlappingLoci = overlappingLoci;
}

public boolean isRepeatRegion() {
	return repeatRegion;
}

public void setRepeatRegion(boolean repeatRegion) {
	this.repeatRegion = repeatRegion;
}

public boolean isSmallIntrons() {
	return smallIntrons;
}

public void setSmallIntrons(boolean smallIntrons) {
	this.smallIntrons = smallIntrons;
}                                                                                                                                 
         
}