/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.havanarequest.controllers;


import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.AbstractWizardFormController;

import uk.ac.sanger.mig.allelerequest.AlleleRequest;
import uk.ac.sanger.mig.allelerequest.dao.AlleleRequestDao;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.designrequest.DesignRequest;
import uk.ac.sanger.mig.designrequest.dao.DesignDesignRequestListDao;
import uk.ac.sanger.mig.designrequest.services.DesignRequestService;
import uk.ac.sanger.mig.designrequest.views.DesignDesignRequestListView;
import uk.ac.sanger.mig.havanarequest.HavanaRequest;
import uk.ac.sanger.mig.havanarequest.enums.HavanaRequestComponent;
import uk.ac.sanger.mig.havanarequest.forms.HavanaRequestForm;
import uk.ac.sanger.mig.havanarequest.services.HavanaRequestService;
import uk.ac.sanger.mig.personnel.Person;


public class HavanaRequestFormController extends AbstractWizardFormController {


	private String successView;

	private DictionaryService dictionaryService;

	private AlleleRequestDao<AlleleRequest> alleleRequestDao;

	private HavanaRequestService havanaRequestService;

	private DesignDesignRequestListDao designDesignRequestListDao;

	private DesignRequestService designRequestService;

	private String successViewToDesignEdit;

	public void setSuccessViewToDesignEdit(String successViewToDesignEdit) {
		this.successViewToDesignEdit = successViewToDesignEdit;
	}


	public void setHavanaRequestService(HavanaRequestService havanaRequestService) {
		this.havanaRequestService = havanaRequestService;
	}


	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

  public void setAlleleRequestDao(
      AlleleRequestDao<AlleleRequest> alleleRequestDao) {
    this.alleleRequestDao = alleleRequestDao;
  }
  
  
  public void setDesignRequestService(DesignRequestService designRequestService) {
		this.designRequestService = designRequestService;
	}

	public void setDesignDesignRequestListDao(DesignDesignRequestListDao designDesignRequestListDao) {
		this.designDesignRequestListDao = designDesignRequestListDao;
	}
	/*
	 * This method gets called when the user flips though various pages in the abstract wizard
	 * Also called in case if user clicks refresh on any page
	 * Note the extra parameeter called page in this method when compared to other  controllers  
	 * @see org.springframework.web.servlet.mvc.AbstractWizardFormController#referenceData(javax.servlet.http.HttpServletRequest, java.lang.Object, org.springframework.validation.Errors, int)
	 */
	@Override
	protected Map referenceData(HttpServletRequest request, Object command,
			Errors errors, int page) throws Exception {
		//
		Map<String, Object> referenceData = new HashMap<String, Object>();
		logger.debug("In referenceData");
		Collection statuses = dictionaryService.fetch(DictionaryEnum.HAVANA_REQUEST_STATUS);
		referenceData.put("statuses", statuses);
		referenceData.put("pageNum", page);
		
		HavanaRequestForm form = (HavanaRequestForm) command;
		Long id = ServletRequestUtils.getLongParameter(request, "id");
		
		ComponentMap requiredComponents = ComponentMap.putAll(
				new ComponentMap(HavanaRequestComponent.ALLELE_REQUEST, 
						new ComponentMap(AlleleRequest.Component.GENE, null)
				)
		);
		//fetch the havana request object duly populated with component maps of gene and allele request
		HavanaRequest havanaRequest = havanaRequestService.fetchById(id, requiredComponents);
		
		//put gene in the referenceData for the view 
		referenceData.put("gene", havanaRequest.getAlleleRequest().getMigGene());

		if (havanaRequest == null) {
			havanaRequest = buildNewHavanaRequest();
		}

		//fetch the designDesignList and set the value for the form 
		form.setDesignListViews(
				designDesignRequestListDao.search(havanaRequest.getAlleleRequestId()));
		
		//set the vegaid for the havana request 
		String vegaIdfromForm = "";

		if (form.getHavanaRequest().getVegaId() != null) {
			vegaIdfromForm = form.getHavanaRequest().getVegaId();
		}
		form.setHavanaRequest(havanaRequest);
		form.getHavanaRequest().setVegaId(vegaIdfromForm);

		form.setInitialStatusId(havanaRequest.getStatus().getId().longValue());
		// in order to display vegaId across all pages
		// set the vegaId in the havana request object from the value set in form

		if (request.getParameter("havanaRequest.vegaId") != null) {
			form.getHavanaRequest().setVegaId(
					request.getParameter("havanaRequest.vegaId"));
		}

		referenceData.put("designDesignRequestList",
				form.getdesignDesignRequestList());
		//*****logic for different pages in the wizard ********
		if (page == 0) { // implies coming to the edit page first time or clicking refresh while on page 0
			
			
			//*****source page session attribute********
			// use a sourcePage session attribute in order to register which page user is currently
			// The valus will then be used to find which page a user is coming from, since
			// same jsp is used in the page hence user can for eg., directly to go page 2 form page 0
			// by clicking the Run for Designs' button.
			
			request.getSession().setAttribute("sourcePage", Integer.valueOf(0));
			
			// set the source page session attribute value to 0, since the current page is 0
			// and this value will be checked when user navigates away from this page  in order
			// to identify which page the user is coming from
			
			referenceData.put("hasImportResults", 0);
		} else if (page == 1) { // users can come to this page by clicking 'import otterlace data'
								// or by cliking refresh once they are on page 1
						
			//set the vegaId in the havana request object from the value set in form
			if (request.getParameter("havanaRequest.vegaId") != null) {  
				form.getHavanaRequest().setVegaId(
						request.getParameter("havanaRequest.vegaId"));
			}
			//--------------------------------------------------------------------
			
			
			Integer sourcePage = (Integer) request.getSession().getAttribute(
			"sourcePage");
			
			// IF(!sourcePage.equals(1) => this is not a refresh on the page 1 
			// instead it means user is going to page 1 from page 0 or page 2
			if (!sourcePage.equals(1)) {
				//set the source page session attribute value to 1, since the current page is 1
				// and this value will be checked when navigates away from this page
				
				request.getSession().setAttribute("sourcePage", Integer.valueOf(1));
				
				//-------------------------------------------------------------------
				//***following parameters to be sent to the Vivek's method syncDesignRequest(..) which calls
				//***a perl process in backend which does the updates and inserts in the MIG database
				//vegaId 
				//geneId  
				// hard coded value of otter build against which OTTMUS id is linked
				//alleleRequest Id
	
				String vegaId = form.getHavanaRequest().getVegaId();
				String geneId = String.valueOf(
						form.getHavanaRequest().getAlleleRequest().getMigGene().getId());
				String build = "otter_06_09_21";
				
				Long alleleRequestId = form.getHavanaRequest().getAlleleRequestId();
				//--------------------------------------------------------------------
				
				//--------------------------------------------------------------------
				//return value from the method is a String array which gets displayed 
				//first time user goes to page 1 (i.e. not a refresh)
				String[] importResults = designRequestService.synchDesignRequest(build,
						vegaId, geneId, String.valueOf(alleleRequestId));
				//--------------------------------------------------------------------
				
				//-------------------------------------------------------------------
				//***put the returned string array in to the reference data
				List<String> importToJsPPageResults = new ArrayList<String>();
				form.setImportResults(importResults);

				for (int i = 0; i < importResults.length; i++) {
					String line = importResults[i];
					String[] bits = line.split("<p>");

					for (int j = 0; j < bits.length; j++) {
						importToJsPPageResults.add(bits[j]);
					}
				}
				
				referenceData.put("importToJsPPageResults", importToJsPPageResults);
				//--------------------------------------------------------------------
				
				//--------------------------------------------------------------------
				// set the hasImportResults key parameter in referencedata 
				// to tell whether the method call to sync gene and design request 
				// has returned any string array or not
				
				if (form.getImportResults() != null
						&& form.getImportResults().length > 0) {
					referenceData.put("hasImportResults", 1);
				} else {
					referenceData.put("hasImportResults", 0);
				}
				//---------------------------------------------------------------------
				
				//-------------------------------------------------------------------
				// set the value of designdesignrequest list 
				form.setDesignListViews(
						designDesignRequestListDao.search(havanaRequest.getAlleleRequestId()));
				referenceData.put("designDesignRequestList",
						form.getdesignDesignRequestList());
				// form.setDesignRequest(designRequests);

			} else {  //=> This is a refresh on the page 1, set the value of designdesignrequest list
				form.setDesignListViews(
						designDesignRequestListDao.search(havanaRequest.getAlleleRequestId()));
				referenceData.put("designDesignRequestList",
						form.getdesignDesignRequestList());
			}
		} else if (page == 2) {
			//(page==2) => User has come to this page either by clicking 'Run for designs' or by 
			// hitting refresh on page 2 itself
			
			
			//-----------------------------------------------------------------------
			//get the sourcePage session attribute value in order to identify which page uer is coming from 
			Integer sourcePage = (Integer) request.getSession().getAttribute(
					"sourcePage");
			//IF CLAUSE below => if the user is coming from page 0 or 1 or from 2 (basically covers all cases)
			if (sourcePage < 2 || sourcePage == 2) {
				String[] designRunResults={};
				//set the sourcePage session Attribute value to 2 (i.e. the current page)
				request.getSession().setAttribute("sourcePage", Integer.valueOf(2));
				
				//***********************----------------------------------------
				// if there are DesignRequest present in the list, then loop through them and process the 
				// ones which have been ticked.
				// Collection<Boolean> runDesings in HavanaRequetForm is pointing to the collections
				// of checkboxes against each row in list view
				//runDesigns is set in the onBind(...) method
				
				if (form.getdesignDesignRequestList().size() > 0) {
					Iterator iter = form.getRunDesigns().iterator();
					for (DesignDesignRequestListView designListView : form.getdesignDesignRequestList()) {
						if(iter.hasNext() && (Boolean)iter.next() && designListView.getDesignId()==null)  {
							designRunResults = designRequestService.submitDesignCreation(
									String.valueOf(designListView.getDesignRequestId())); // { "1", "2"}; //
							//System.out.println("success");
						}
						if (designRunResults != null && designRunResults.length > 0) {
							referenceData.put("designRunResults", designRunResults);
							referenceData.put("hasDesignResults", 1);
						} else {
							referenceData.put("hasDesignResults", 0);
						}
						form.setDesignListViews(
								designDesignRequestListDao.search(havanaRequest.getAlleleRequestId()));
					}
				}//*********************--------------------------------------------
				referenceData.put("hasImportResults", 0);
				logger.debug("In page: 2");
			} else {  //coming from a diffetent source page (not sure will this block of code ever be called)
				form.setDesignListViews(
						designDesignRequestListDao.search(havanaRequest.getAlleleRequestId()));
				referenceData.put("designDesignRequestList",
						form.getdesignDesignRequestList());
			}
		}
		//------------------------------------------------------------------------------
		//--finally let the jsp know whether to render the designDesignRequest list.
		if (form.getdesignDesignRequestList().size() > 0) {
			referenceData.put("hasDesignRequests", 1);
		} else {
			referenceData.put("hasDesignRequests", 0);
		}
		return referenceData;

	}

	@Override
	protected Object formBackingObject(HttpServletRequest request)
	throws Exception {

		//filter specific URL fields
		String searchBy = ServletRequestUtils.getStringParameter(request, "searchBy")!=null ?
				ServletRequestUtils.getStringParameter(request, "searchBy"):"";
				String searchString = ServletRequestUtils.getStringParameter(request, "searchString")!=null ?
						ServletRequestUtils.getStringParameter(request, "searchString"):"";;

						String source = ServletRequestUtils.getStringParameter(request, "havanaRequest.alleleRequest.source.id")!=null ?
								ServletRequestUtils.getStringParameter(request, "havanaRequest.alleleRequest.source.id"): "";
								String status = ServletRequestUtils.getStringParameter(request, "havanaRequest.statusDictId")!=null ?
										ServletRequestUtils.getStringParameter(request, "havanaRequest.statusDictId") : "";
										String chromosome = ServletRequestUtils.getStringParameter(request, "havanaRequest.chromosomeName")!=null ?
												ServletRequestUtils.getStringParameter(request, "havanaRequest.chromosomeName") : "";

												//end of filter specific URL fields

												HavanaRequestForm form = (HavanaRequestForm) createCommand();
												form.setChromosome(chromosome);
												form.setStatus(status);
												form.setSource(source);
												form.setSearchBy(searchBy);
												form.setSearchString(searchString);
												form.setRunDesigns(new ArrayList<Boolean>());

												Long id = ServletRequestUtils.getLongParameter(request, "id");
												HavanaRequest havanaRequest = havanaRequestService.fetchById(id,
														ComponentMap.of(HavanaRequestComponent.ALLELE_REQUEST));

												if (havanaRequest == null) {
													havanaRequest = buildNewHavanaRequest();
												}
												form.setHavanaRequest(havanaRequest);

												// form.setDesignRequest(designRequests);
												form.setDesignListViews(
														designDesignRequestListDao.search(havanaRequest.getAlleleRequestId()));

												// this is used to compare if the status changes during editing of form.
												form.setInitialStatusId(havanaRequest.getStatus().getId().longValue());
												return form;

	}

	@Override
	protected void validatePage(Object command, Errors errors, int page) {}

	@Override
	protected ModelAndView processFinish(HttpServletRequest request,
			HttpServletResponse response, Object command, BindException errors) {

		HavanaRequestForm form = (HavanaRequestForm) command;
		HavanaRequest havanaRequest = form.getHavanaRequest();

		Person person = RequestUtils.getUser(request);

		havanaRequestService.store(havanaRequest, person);

		//sync the otter id with the Gene
		if(form.getHavanaRequest().getVegaId()!=null &&
				form.getHavanaRequest().getVegaId()!=""){
			String geneId = String.valueOf(
					form.getHavanaRequest().getAlleleRequest().getMigGeneId());
			String[] importResults = designRequestService.syncGene("otter_06_09_21",
					form.getHavanaRequest().getVegaId(), geneId);

		}

		if (havanaRequest.getStatus().getId().longValue()
				!= form.getInitialStatusId()) {

			// Set the allele request status to match the havana request and store
			AlleleRequest alleleRequest = havanaRequest.getAlleleRequest();

			alleleRequest.setStatus(havanaRequest.getStatus());
			alleleRequestDao.storeAuthenticated(alleleRequest, person);
		}
		for (DesignDesignRequestListView designListView : form.getdesignDesignRequestList()) {
			DesignRequest designRequest = new DesignRequest();

			designRequest.setId(designListView.getDesignRequestId());
			designDesignRequestListDao.updateDesigns(designRequest, designListView);
			designDesignRequestListDao.updateDesignRequests(designListView);

		}

		if(form.getDestinationPage() != null && form.getDestinationPage()!="") {
			return new ModelAndView(successViewToDesignEdit+"?id="+form.getDesignRequestIdToGo()+"&referrer=editHavanaRequest&havanaId="+havanaRequest.getId());//?bypassForm=true&havanaRequest.statusDictId=2&newQuery=true&paginated=true&orderBy=id");
		}
		else {
			return new ModelAndView(successView+"?retrieveFromSession=true&newQuery=false&bypassForm=true&currentRecordId=" + havanaRequest.getId());//?bypassForm=true&havanaRequest.statusDictId=2&newQuery=true&paginated=true&orderBy=id");
		}    
	}

	@Override
	protected ModelAndView processCancel(HttpServletRequest request,
			HttpServletResponse response, Object command, BindException errors)
	throws Exception {
		HavanaRequestForm form = (HavanaRequestForm) command;
		HavanaRequest havanaRequest = form.getHavanaRequest();
		return new ModelAndView(successView+"?retrieveFromSession=true&newQuery=false&bypassForm=true&currentRecordId=" + havanaRequest.getId());//?bypassForm=true&havanaRequest.statusDictId=2&newQuery=true&paginated=true&orderBy=id");

	}

	private HavanaRequest buildNewHavanaRequest() {
		HavanaRequest havanaRequest = new HavanaRequest();

		havanaRequest.setStatus(new DictionaryEntry(0L));
		havanaRequest.setAlleleRequest(new AlleleRequest());

		return havanaRequest;
	}

	protected void onBind(HttpServletRequest request, Object command,
			BindException errors) throws Exception {
		super.onBind(request, command, errors);
		HavanaRequestForm form = (HavanaRequestForm) command;

		// Set the design_request boolean fields
		//following are the parameters in the jsp that represent checkboxes for 
		// fulfillesRequest, promoterINclusion, conservedElement, containsATG, runDesignsIdentifier, 
		// possibleReinitiation, noNmdInduced
		//following names for checkbox fields in edit havana request jsp 
		
		//fulfillsRequest checkbox name is 1, 2, 3   and so 
		//promoterInclusionIdentifier name is 99,100,101  and so 
		//fulfillsRequest checkbox name is 199, 200, 201  and so on 
		//containsATG checkbox name is 299, 300, 301 and so on
		//runDesigns checkbox name is 399, 400, 401 and so on
		//possibleReinitiation checkbox name is 499, 500, 501 and so on
		//noNMDInduced checkbox name is 599, 600, 601 and so on
		
		// :) as you ca see the application may set inconsistent data if ever
		// there are more than 100 design requests for a given allele request
		
		Integer fulFillsRequestIdentifier = 1;
		Integer promoterInclusionIdentifier = 99;
		Integer conservedElementsIdentifier = 199;
		Integer containsATGIdentifier = 299;
		Integer runDesignsIdentifier = 399;
		Integer possibleReinitiationIdentifier = 499;
		Integer noNMDInducedIdentifier = 599;

		form.getRunDesigns().clear();


		for (DesignDesignRequestListView designRequestDetails : form.getdesignDesignRequestList()) {
			if (request.getParameter(fulFillsRequestIdentifier.toString()) != null) {
				designRequestDetails.setFulfillsRequest(true);
			} else {
				designRequestDetails.setFulfillsRequest(false);
			}
			fulFillsRequestIdentifier++;

			if (request.getParameter(promoterInclusionIdentifier.toString()) != null) {
				designRequestDetails.setPromoterInclusion(true);
			} else {
				designRequestDetails.setPromoterInclusion(false);
			}
			promoterInclusionIdentifier++;
			//set the conserved element value for design request 
			if (request.getParameter(conservedElementsIdentifier.toString()) != null) {
				designRequestDetails.setConservedElements(true);
			} else {
				designRequestDetails.setConservedElements(false);
			}
			conservedElementsIdentifier++;

			if (request.getParameter(containsATGIdentifier.toString()) != null) {
				designRequestDetails.setCriticalExonContainsATG(true);
			} else {
				designRequestDetails.setCriticalExonContainsATG(false);
			}
			containsATGIdentifier++;

			if(request.getParameter(runDesignsIdentifier.toString())!=null){
				form.getRunDesigns().add(true);
			}else{
				form.getRunDesigns().add(false);
			}
			runDesignsIdentifier++;

			if(request.getParameter(possibleReinitiationIdentifier.toString())!=null){
				designRequestDetails.setPossibleReinitiation(true);
			}else{
				designRequestDetails.setPossibleReinitiation(false);
			}
			possibleReinitiationIdentifier++;

			if(request.getParameter(noNMDInducedIdentifier.toString())!=null){
				designRequestDetails.setNoNMDInduced(true);
			}else{
				designRequestDetails.setNoNMDInduced(false);
			}
			noNMDInducedIdentifier++;

		}
	}


	public void setSuccessView(String successView) {
		this.successView = successView;
	}
}
