/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.havanarequest.controllers;

import java.util.Collection;
import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.AbstractSearchFormController;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.havanarequest.HavanaRequestSearchBean;
import uk.ac.sanger.mig.havanarequest.dao.HavanaRequestDao;
import uk.ac.sanger.mig.havanarequest.views.HavanaRequestListView;

public class HavanaRequestListController extends AbstractSearchFormController {

	private HavanaRequestDao havanaRequestDao;
	private DictionaryService dictionaryService; 

	public void setHavanaRequestDao(HavanaRequestDao havanaRequestDao) {
		this.havanaRequestDao = havanaRequestDao;
	}

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	@Override
	protected ModelAndView onSearch(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		HavanaRequestSearchBean searchBean = (HavanaRequestSearchBean)command;
		searchBean.setQueryName("listHavanaRequests");

		Map<String, Object> model = referenceData(request, command, errors);

		searchBean.setSearchBy(request.getParameter("searchBy"));
		searchBean.setSearchString(request.getParameter("searchString"));

		Collection<HavanaRequestListView> results = havanaRequestDao.search(searchBean);
		model.put("results", results);

		return new ModelAndView(getSuccessView(),model);
	}

	@Override	
	protected Map<String, Object> referenceData(HttpServletRequest request, Object command, Errors errors) throws Exception {

		Map<String, Object> model = new HashMap<String, Object>();	
		Collection<DictionaryEntry> statuses = dictionaryService.fetch(DictionaryEnum.HAVANA_REQUEST_STATUS);
		model.put("statuses", statuses);

		Collection<DictionaryEntry> sources = dictionaryService.fetch(DictionaryEnum.ALLELE_REQUEST_SOURCE);
		model.put("sources", sources);

		Collection<DictionaryEntry> chromosomes = dictionaryService.fetch(DictionaryEnum.CHROMOSOME_LIST);
		model.put("chromosomes", chromosomes);

		Map<String, String> searchByColumns = new LinkedHashMap<String, String>();
		searchByColumns.put("ID", "Request Number");
		searchByColumns.put("PRIMARY_NAME", "Gene Name");
		searchByColumns.put("VEGA_ID", "Vega Id");
		searchByColumns.put("ENSEMBL_ID", "Ensembl Id");
		model.put("searchByColumns", searchByColumns);

		return model;
	}
}
