/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.havanarequest.controllers;

import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.ParameterizableViewController;

import uk.ac.sanger.mig.allelerequest.AlleleRequest;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.gene.BuildGene;
import uk.ac.sanger.mig.gene.MigGene;
import uk.ac.sanger.mig.havanarequest.HavanaRequest;
import uk.ac.sanger.mig.havanarequest.enums.HavanaRequestComponent;
import uk.ac.sanger.mig.havanarequest.services.HavanaRequestService;

public class ViewOneHavanaRequestController extends	ParameterizableViewController {

	private HavanaRequestService havanaRequestService;

	public void setHavanaRequestService(HavanaRequestService havanaRequestService) {
		this.havanaRequestService = havanaRequestService;
	}

	protected ModelAndView handleRequestInternal(HttpServletRequest request, HttpServletResponse response) throws Exception {

		Map<String,Object> model = new HashMap<String,Object>();
		Long id = ServletRequestUtils.getRequiredLongParameter(request,"id");

		ComponentMap requiredComponents = ComponentMap.putAll(
				new ComponentMap(HavanaRequestComponent.ALL_HAVANA_REQUEST_COMPONENTS, null),
				new ComponentMap(HavanaRequestComponent.ALLELE_REQUEST,
						new ComponentMap(AlleleRequest.Component.GENE, 
								ComponentMap.putAll(
										new ComponentMap(MigGene.Component.PRIMARY_ENSEMBL_BUILD_GENE, null),
										new ComponentMap(MigGene.Component.PRIMARY_BUILD_GENE, 
												ComponentMap.putAll(
														new ComponentMap(BuildGene.Component.LOCUS, null),
														new ComponentMap(BuildGene.Component.BUILD, null)
												)
										)
								)
						)
				)
		);

		HavanaRequest havanaRequest = havanaRequestService.fetchById(id, requiredComponents);		 			

		model.put("gene", havanaRequest.getAlleleRequest().getMigGene());
		model.put("havanaRequest",havanaRequest);

		return new ModelAndView(getViewName(),"model",model);		
	}

}
