/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.havanarequest.dao;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.havanarequest.HavanaRequest;

public class HavanaRequestRowMapper implements ParameterizedRowMapper<HavanaRequest> {
	
	private DictionaryService dictionaryService;
	
	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	public HavanaRequest mapRow(ResultSet rs, int rowNum) throws SQLException {
		
		HavanaRequest havanaRequest = new HavanaRequest();
		
		havanaRequest.setId(rs.getLong("ID"));
		havanaRequest.setAlleleRequestId(rs.getLong("ALLELE_REQUEST_ID"));
		if(rs.wasNull()) havanaRequest.setAlleleRequestId(null);		
		havanaRequest.setStatusDictId(rs.getLong("STATUS_DICT_ID"));
		if(rs.wasNull()) havanaRequest.setStatusDictId(null);		
		havanaRequest.setCreatorId(rs.getLong("CREATED_BY"));
		if(rs.wasNull()) havanaRequest.setCreatorId(null);	
		havanaRequest.setCreatedDate(rs.getDate("CREATED_DATE"));
		havanaRequest.setEditedBy(rs.getString("EDITED_BY"));
		havanaRequest.setEditDate(rs.getDate("EDITED_DATE"));
		havanaRequest.setComments(rs.getString("COMMENTS"));
		havanaRequest.setVegaId(rs.getString("VEGA_ID"));
		havanaRequest.setUpdatedGeneName(rs.getString("UPDATED_GENE_NAME"));
		havanaRequest.setUpdatedChromosomeName(rs.getString("UPDATED_CHROMOSOME_NAME"));
		havanaRequest.setStartNotFound(rs.getBoolean("START_NOT_FOUND"));
		havanaRequest.setEndNotFound(rs.getBoolean("END_NOT_FOUND"));
		havanaRequest.setCriticalExonId(rs.getString("CRITICAL_EXON_ID"));
		havanaRequest.setPseudogene(rs.getBoolean("PSEUDOGENE"));
		//havanaRequest.setAssemblyError(rs.getBoolean("ASSEMBLY_ERROR"));
	    havanaRequest.setSmallIntrons(rs.getBoolean("SMALL_INTRONS"));
	    havanaRequest.setMultipleCodingTrancripts(rs.getBoolean("MULTIPLE_CODING_TRANSCRIPTS"));
	    havanaRequest.setSymmetricalExons(rs.getBoolean("SYMMETRICAL_EXON"));
	    havanaRequest.setLargeCodingExon(rs.getBoolean("LARGE_CODING_EXON"));
	    havanaRequest.setLessThanThreeCodingExons(rs.getBoolean("LESS_THAN_THREE_CODING_EXONS"));
	    havanaRequest.setNoNMDInduced(rs.getBoolean("NO_NMD_INDUCED"));
	    //havanaRequest.setPossibleReinitiation(rs.getBoolean("POSSIBLE_REINITIATION"));
	    //havanaRequest.setContainsHydrophobicRegion(rs.getBoolean("contains_hydrophobic_region"));
	    //havanaRequest.setCriticalExonContainsATG(rs.getBoolean("critical_exon_contains_ATG"));
	    havanaRequest.setTransMembraneDomain(rs.getBoolean("HAS_TRANSMEMBRANE_DOMAIN"));
	    havanaRequest.setSignalPeptide(rs.getBoolean("HAS_SIGNAL_PEPTIDE"));
	    
	    havanaRequest.setCriticalExonToo3(rs.getBoolean("critical_exon_too_3_prime"));
	    havanaRequest.setRepeatRegion(rs.getBoolean("REPEAT_REGION"));
	    havanaRequest.setGeneCluster(rs.getBoolean("GENE_CLUSTER"));
	    havanaRequest.setOverlappingLoci(rs.getBoolean("OVERLAPPING_LOCI"));
    
		havanaRequest.setStatus(dictionaryService.fetchEntry(DictionaryEnum.HAVANA_REQUEST_STATUS, havanaRequest.getStatusDictId()));
		
		return havanaRequest;
		
	}
}