/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.havanarequest.views;

import java.util.Date;

import uk.ac.sanger.mig.common.DataObject;

public class HavanaRequestListView extends DataObject implements Comparable<HavanaRequestListView> {

    private String editedBy;        
    private String buildVersion;        
    private String status;        
    private String comments;        
    private int chromosomeEnd;        
    private String ensemblId;
    private String primaryName;        
    private Date createdDate;
    private Date submitToQueueDate;
    private int chromosomeStart;     
    private String createdBy;        
    private int statusDictId;        
    private String chromosomeName;        
    private Date editedDate;        
    private String buildName;        
    private Long alleleRequestId;  
    private Long alleleRequesterId;  
    private String vegaId;
    private String updatedChromosomeName;
    private boolean startNotFound;
    private boolean endNotFound;
    private String updatedGeneName;
    private String criticalExonId;
    private String source;
    private int uniqueExonCount;
    private int totalExonCount;
   
    
    public int compareTo(HavanaRequestListView a) {
    	HavanaRequestListView b = this;
    	if(a.getId() > b.getId()) return 1;
    	if(a.getId() < b.getId()) return -1;
    	return 0;
	}

	public String getEditedBy() {
        return editedBy;
    }
    
    public void setEditedBy(String editedBy) {
        this.editedBy = editedBy;
    }                                                                                                                                            
    public String getBuildVersion() {
        return buildVersion;
    }
    
    public void setBuildVersion(String buildVersion) {
        this.buildVersion = buildVersion;
    }                                                                                                                                            
    public String getStatus() {
        return status;
    }
    
    public void setStatus(String status) {
        this.status = status;
    }                                                                                                                                            
    public String getComments() {
        return comments;
    }
    
    public void setComments(String comments) {
        this.comments = comments;
    }                                                                                                                                            
    public int getChromosomeEnd() {
        return chromosomeEnd;
    }
    
    public void setChromosomeEnd(int chromosomeEnd) {
        this.chromosomeEnd = chromosomeEnd;
    }                                                                                                                                            
                                                                                                                                              
    public String getPrimaryName() {
        return primaryName;
    }
    
    public void setPrimaryName(String primaryName) {
        this.primaryName = primaryName;
    }                                                                                                                                            
    public Date getCreatedDate() {
        return createdDate;
    }
    
    public void setCreatedDate(Date createdDate) {
        this.createdDate = createdDate;
    }                                                                                                                                            
    public int getChromosomeStart() {
        return chromosomeStart;
    }
    
    public void setChromosomeStart(int chromosomeStart) {
        this.chromosomeStart = chromosomeStart;
    }                                                                                                                                            
                                                                                                                                            
    public String getCreatedBy() {
        return createdBy;
    }
    
    public void setCreatedBy(String createdBy) {
        this.createdBy = createdBy;
    }                                                                                                                                            
    public int getStatusDictId() {
        return statusDictId;
    }
    
    public void setStatusDictId(int statusDictId) {
        this.statusDictId = statusDictId;
    }                                                                                                                                            
    public String getChromosomeName() {
        return chromosomeName;
    }
    
    public void setChromosomeName(String chromosomeName) {
        this.chromosomeName = chromosomeName;
    }                                                                                                                                            
    public Date getEditedDate() {
        return editedDate;
    }
   
    public void setEditedDate(Date editedDate) {
        this.editedDate = editedDate;
    }                                                                                                                                            
    public String getBuildName() {
        return buildName;
    }
    
    public void setBuildName(String buildName) {
        this.buildName = buildName;
    }                                                                                                                                            
    public Long getAlleleRequestId() {
        return alleleRequestId;
    }
    
    public void setAlleleRequestId(Long alleleRequestId) {
        this.alleleRequestId = alleleRequestId;
    }
    
	public String getVegaId() {
		return vegaId;
	}

	public void setVegaId(String vegaId) {
		this.vegaId = vegaId;
	}

	public String getUpdatedChromosomeName() {
		return updatedChromosomeName;
	}

	public void setUpdatedChromosomeName(String chromosome) {
		this.updatedChromosomeName = chromosome;
	}

	public String getCriticalExonId() {
		return criticalExonId;
	}

	public void setCriticalExonId(String criticalExonId) {
		this.criticalExonId = criticalExonId;
	}

	public boolean isEndNotFound() {
		return endNotFound;
	}

	public void setEndNotFound(boolean endNotFound) {
		this.endNotFound = endNotFound;
	}

	public boolean isStartNotFound() {
		return startNotFound;
	}

	public void setStartNotFound(boolean startNotFound) {
		this.startNotFound = startNotFound;
	}

	public String getUpdatedGeneName() {
		return updatedGeneName;
	}

	public void setUpdatedGeneName(String updatedGeneName) {
		this.updatedGeneName = updatedGeneName;
	}

	public String getSource() {
		return source;
	}

	public void setSource(String source) {
		this.source = source;
	}

	public int getTotalExonCount() {
		return totalExonCount;
	}

	public void setTotalExonCount(int totalExonCount) {
		this.totalExonCount = totalExonCount;
	}

	public int getUniqueExonCount() {
		return uniqueExonCount;
	}

	public void setUniqueExonCount(int uniqueExonCount) {
		this.uniqueExonCount = uniqueExonCount;
	}

	public Long getAlleleRequesterId() {
		return alleleRequesterId;
	}

	public void setAlleleRequesterId(Long alleleRequesterId) {
		this.alleleRequesterId = alleleRequesterId;
	}

  public Date getSubmitToQueueDate() {
    return submitToQueueDate;
  }

  public void setSubmitToQueueDate(Date submitToQueueDate) {
    this.submitToQueueDate = submitToQueueDate;
  }

public String getEnsemblId() {
	return ensemblId;
}

public void setEnsemblId(String ensemblId) {
	this.ensemblId = ensemblId;
}

	
}