package uk.ac.sanger.mig.histology;

import java.util.Collection;
import java.util.Date;

import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.BarcodeUtils;
import uk.ac.sanger.mig.common.ComponentEnum;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.common.UnattachedComponentException;
import uk.ac.sanger.mig.histology.views.BlockTypeView;
import uk.ac.sanger.mig.mousetracking.BarcodedObject;

public class Block extends AuthenticatedDataObject implements BarcodedObject, Comparable {

  public enum Component implements ComponentEnum{
    ALL_COMPONENTS,  //add additional component enums here as needed for this AuthenticatedDataObject
    BLOCK_TYPE,
    SLIDES,
    FIXATION
  }

  private Long fixationId;
  private Fixation fixation;

  private Long blockTypeId;
  private String barcode;
  private boolean selected;
  private BlockType blockType;
  private BlockTypeView blockTypeView;
  private String tissueType;
  private String comments;
  private Collection<Slide> slides;
  private DictionaryEntry programmeType;
  private Long programmeTypeId;
  private Date fixationEndTime;
  private Date programmeStartTime;
  private String name;


  public String getName() {
    return name;
  }

  public void setName(String name) {
    this.name = name;
  }

  public Date getFixationEndTime() {
    return fixationEndTime;
  }

  public void setFixationEndTime(Date fixationEndTime) {
    this.fixationEndTime = fixationEndTime;
  }

  public Date getProgrammeStartTime() {
    return programmeStartTime;
  }

  public void setProgrammeStartTime(Date programmeStartTime) {
    this.programmeStartTime = programmeStartTime;
  }

  public DictionaryEntry getProgrammeType() {
    return programmeType;
  }

  public void setProgrammeType(DictionaryEntry programmeType) {
    this.programmeType = programmeType;
  }

  public Long getProgrammeTypeId() {
    return programmeTypeId;
  }

  public void setProgrammeTypeId(Long programmeTypeId) {
    this.programmeTypeId = programmeTypeId;
  }

  public Collection<Slide> getSlides() {
    return slides;
  }

  public void setSlides(Collection<Slide> slides) {
    this.slides = slides;
  }

  public String getComments() {
    return comments;
  }

  public void setComments(String comments) {
    this.comments = comments;
  }

  public String getTissueType() {
    return tissueType;
  }

  public void setTissueType(String tissueType) {
    this.tissueType = tissueType;
  }

  public BlockType getBlockType() {
    return blockType;
  }

  public void setBlockType(BlockType blockType) {
    this.blockType = blockType;
  }

  public boolean isSelected() {
    return selected;
  }

  public void setSelected(boolean selected) {
    this.selected = selected;
  }


  public Long getBlockTypeId() {
    return blockTypeId;
  }

  public void setBlockTypeId(Long blockTypeId) {
    this.blockTypeId = blockTypeId;
  }
  public String getBarcode() {
    return barcode;
  }

  public void setBarcode(String barcode) {
    this.barcode = barcode;
  }

  public String getBarcodeDescription() {
    // TODO Auto-generated method stub
    return null;
  }

  public Long getFixationId() {
    return fixationId;
  }

  public void setFixationId(Long fixationId) {
    this.fixationId = fixationId;
  }

  public Fixation getFixation() {
    return fixation;
  }

  public void setFixation(Fixation fixation) {
    this.fixation = fixation;
  }

  public BarcodeType getBarcodeType() {
    return BarcodedObject.BarcodeType.BLOCK;
  }

  public int compareTo(Object o) throws ClassCastException{
    if (!(o instanceof Block))
      throw new ClassCastException("A Block object expected.");
    Block anotherBlock = (Block)o;

    int result = this.blockTypeId.compareTo( ((Block)anotherBlock).getBlockTypeId() );

    if (result == 0 && this.id != null && anotherBlock.getId() != null) {
      result = this.id.compareTo(anotherBlock.getId());
    }

    return result;
  }

  public BlockTypeView getBlockTypeView() {
    return blockTypeView;
  }

  public void setBlockTypeView(BlockTypeView blockTypeView) {
    this.blockTypeView = blockTypeView;
  }

  public int getSlideCount() {

  	if( getSlides() == null )
  		throw new UnattachedComponentException( Block.Component.SLIDES );

  	return getSlides().size();
  }

  public int getScanCount() {

	  	int scanCount = 0;

	  	if( getSlides() == null )
	  		throw new UnattachedComponentException( Block.Component.SLIDES );

	  	for(Slide slide : getSlides()) {

	  		scanCount += slide.getScanCount();
	  	}

	  	return scanCount;
  }

  public int getCropCount() {

	  	int cropCount = 0;

	  	if( getSlides() == null )
	  		throw new UnattachedComponentException( Block.Component.SLIDES );

	  	for(Slide slide : getSlides()) {

	  		cropCount += slide.getCropCount();
	  	}

	  	return cropCount;
}

	@Override
	public String toString() {

		if( blockType != null ) {
			return getName() + ": " + blockType;
		} else {
			return getName();
		}

	}

	public void generateBarcode() {
		this.barcode = BarcodeUtils.generateBarcode(getBarcodeType(), getId());
	}
}