package uk.ac.sanger.mig.histology;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Date;

import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.ComponentEnum;
import uk.ac.sanger.mig.common.UnattachedComponentException;

/**
 * A CropJob defines a unit of image cropping work involving a single Scan
 * and one or more Crop objects associated with that Scan.
 *
 * @author ae1
 *
 */
public class CropJob extends AuthenticatedDataObject  {

	public enum Component implements ComponentEnum {
		ALL_COMPONENTS,
		CROPS,
		SCAN,
		CREATOR
	}

	private Collection<Crop> crops;
    private Scan scan;
    private Long scanId;

    private Date startTime;
    private Date endTime;
    private Boolean success;
    private String failureReason;
    private int attempts;


    public void incrementAttempts() {
    	attempts++;
    }

    public int getAttempts() {
		return this.attempts;
	}

	public void setAttempts(int attempts) {
		this.attempts = attempts;
	}

	public int getSize() {

    	if(crops == null)
    		throw new UnattachedComponentException( CropJob.Component.CROPS );

    	return crops.size();
    }

    public Scan getScan() {
		return this.scan;
	}

	public void setScan(Scan scan) {
		this.scan = scan;
	}

	public Long getScanId() {
		return this.scanId;
	}

	public void setScanId(Long scanId) {
		this.scanId = scanId;
	}

	public Collection<Crop> getCrops() {
		return this.crops;
	}

	/**
	 * Returns a Collection of processed Crops -- i.e., those
	 * having a reference to an image.
	 *
	 * @return
	 */
	public Collection<Crop> getProcessedCrops() {

		Collection<Crop> processedCrops = new ArrayList<Crop>();

		if( getSize() > 0) {

			for(Crop crop : getCrops()  ) {

				if( crop.getResizedImagePath() != null ) {

					processedCrops.add( crop );
				}
			}
		}

		return processedCrops;
	}

	public void setCrops(Collection<Crop> crops) {
		this.crops = crops;
	}

	public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }
    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }



    public Boolean getSuccess() {
		return this.success;
	}

	public void setSuccess(Boolean isSuccess) {
		this.success = isSuccess;
	}

	public String getFailureReason() {
        return failureReason;
    }

    public void setFailureReason(String failureReason) {
        this.failureReason = failureReason;
    }

}