package uk.ac.sanger.mig.histology;

import java.util.Collection;
import java.util.Date;

import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.ComponentEnum;
import uk.ac.sanger.mig.common.UnattachedComponentException;

public class Fixation extends AuthenticatedDataObject  {

	public enum Component implements ComponentEnum {
		ALL_COMPONENTS,
		BLOCKS,
		NECROPSY
	}

	private Long necropsyId;
	private Necropsy necropsy;
	private Collection<Block> blocks;
	private  Date fixationStartTime;        
	private  Date fixationEndTime;
    
	public Date getFixationEndTime() {
		return fixationEndTime;
	}
	public void setFixationEndTime(Date fixationEndTime) {
		this.fixationEndTime = fixationEndTime;
	}
	public Date getFixationStartTime() {
		return fixationStartTime;
	}
	public void setFixationStartTime(Date fixationStartTime) {
		this.fixationStartTime = fixationStartTime;
	}
	  public Long getNecropsyId() {
	    return necropsyId;
	  }
	  public void setNecropsyId(Long necropsyId) {
	    this.necropsyId = necropsyId;
	  }
	  public Collection<Block> getBlocks() {
	    return blocks;
	  }
	  public void setBlocks(Collection<Block> blocks) {
	    this.blocks = blocks;
	  }
	  public Necropsy getNecropsy() {
	    return necropsy;
	  }
	  public void setNecropsy(Necropsy necropsy) {
	    this.necropsy = necropsy;
	  }
   
	    public int getBlockCount() {
	    	
	    	if( getBlocks() == null )
	    		throw new UnattachedComponentException( Fixation.Component.BLOCKS );    	
	
	    	return getBlocks().size();
	    }
	   
	    public int getSlideCount() {

	    	
	    	int slideCount = 0;
	    	
	    	if( getBlocks() == null )
	    		throw new UnattachedComponentException( Fixation.Component.BLOCKS );    	
	    	   	
	    	for(Block block : blocks)
	    		slideCount += block.getSlideCount();
	    	
	    	return slideCount;
	    }
	    
	    public int getScanCount() {
    	
	    	int scanCount = 0;
	    	
	    	if( getBlocks() == null )
	    		throw new UnattachedComponentException( Fixation.Component.BLOCKS );    	
	    	   	
	    	for(Block block : blocks) {

	    		scanCount += block.getScanCount();
	    	}
	    			    	
	    	return scanCount;
	    }
	    
	    public int getCropCount() {
	    	
	    	int cropCount = 0;
	    	
	    	if( getBlocks() == null )
	    		throw new UnattachedComponentException( Fixation.Component.BLOCKS );    	
	    	   	
	    	for(Block block : blocks) {

	    		cropCount += block.getCropCount();
	    	}
	    			    	
	    	return cropCount;
	    }
}