package uk.ac.sanger.mig.histology;

import java.io.File;
import java.util.Collection;
import java.util.Date;
import java.util.HashSet;
import java.util.Set;

import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.ComponentEnum;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.common.UnattachedComponentException;
import uk.ac.sanger.mig.filesupport.BinaryFile;


public class Scan extends AuthenticatedDataObject {

	static final long serialVersionUID = -1L;

	public enum Component implements ComponentEnum {
		ALL_COMPONENTS,
		CROP_JOBS, //children
		THUMBNAIL,
		SLIDE, //parent
		CREATOR;
	}

	public enum StatusDictEnum {

		AWAITING_THUMBNAIL_QC(4L),
		THUMBNAIL_QC_PASS(5L), //thumb and OKed
		THUMBNAIL_QC_FAIL_BAD_SCAN(6L),
		THUMBNAIL_QC_FAIL_BAD_SLIDE(7L),
		FLAGGED_FOR_RESELECTION(8L)
		;

		private Long id;

		StatusDictEnum(Long id) {
			this.id = id;
		}

		public Long getId() {return id;}
	}

    private File dmiFilePath;
    private int width;
    private int height;
    private float pixelWidth;
    private float pixelHeight;
    private int thumbWidth;
    private int thumbHeight;
    private Long slideId;
    private Long thumbnailId;
    private String comments;
    private Date scanDate;
    private String scanPersonName;
    private Long statusDictId;//required -- no null column in DB
    private Date sweepDate;
    private DictionaryEntry statusDict;
    private Integer versionNumber; //scan number for a given slide

    private Collection<CropJob> cropJobs;
    private Slide slide;
    private BinaryFile thumbnail;

    private boolean externalApproved;

    public Scan() {}


    /**
     * Round up to nearest 10th (e.g., 0.049 becomes 0.5)
     * @return
     */
   public float getPixelWidthRounded() {

	   float f = pixelWidth * 10;

	   return Math.round( f ) / 10f;

    }

	public boolean isExternalApproved() {
		return this.externalApproved;
	}

	public void setExternalApproved(boolean externalApproved) {
		this.externalApproved = externalApproved;
	}


	public String getName() {
    	return ( dmiFilePath != null) ?
    			dmiFilePath.getName() + ".v" + getVersionNumber() : "no name";
    }

	public void setVersionNumber(Integer versionNumber) {
		this.versionNumber = versionNumber;
	}

	/**
	 * Returns the version number of this scan (ie, the nth sibling). If Scan is an orphan
	 * without any parent Slide, version number is 0.
	 * @return
	 */
	public Integer getVersionNumber() {
		return this.versionNumber;
	}



    public boolean thumbnailAttached() {
    	return ( getThumbnail() != null );
    }

    public Date getSweepDate() {
		return this.sweepDate;
	}

	public void setSweepDate(Date sweepDate) {
		this.sweepDate = sweepDate;
	}

	public BinaryFile getThumbnail() {
		return this.thumbnail;
	}

	public void setThumbnail(BinaryFile thumbnail) {
		this.thumbnail = thumbnail;
	}

	public Long getThumbnailId() {
		return this.thumbnailId;
	}

	public void setThumbnailImageId(Long thumbnailId) {
		this.thumbnailId = thumbnailId;
	}


	public Date getScanDate() {
		return this.scanDate;
	}

	public void setScanDate(Date scanTime) {
		this.scanDate = scanTime;
	}

	public Collection<CropJob> getCropJobs() {
		return this.cropJobs;
	}

	public void setCropJobs(Collection<CropJob> cropJobs) {
		this.cropJobs = cropJobs;
	}

	public String getParentDirectory() {
		return dmiFilePath.getParent();
	}

	public String getFileSeparator() {
		return File.separator;
	}

	public String getFileName() {
		return dmiFilePath.getName();
	}

	/**
	 * Returns the canonical, system-specific file path
	 * of the source Dmetrix slide image for this Slide object.
	 * @return
	 */
	public String getCanonicalFilePath() {

		String canonicalPath = null;
		try {
			canonicalPath = dmiFilePath.getCanonicalPath();
		} catch(Exception e) {e.printStackTrace();}

		return canonicalPath;
	}

    public int getWidth() {
        return width;
    }

    public void setWidth(int width) {
        this.width = width;
    }
    public int getHeight() {
        return height;
    }

    public void setHeight(int height) {
        this.height = height;
    }
    public float getPixelWidth() {
        return pixelWidth;
    }

    public void setPixelWidth(float pixelWidth) {
        this.pixelWidth = pixelWidth;
    }
    public float getPixelHeight() {
        return pixelHeight;
    }

    public void setPixelHeight(float pixelHeight) {
        this.pixelHeight = pixelHeight;
    }

    public int getThumbWidth() {
        return thumbWidth;
    }

    public void setThumbWidth(int thumbWidth) {
        this.thumbWidth = thumbWidth;
    }
    public int getThumbHeight() {
        return thumbHeight;
    }

    public void setThumbHeight(int thumbHeight) {
        this.thumbHeight = thumbHeight;
    }


    public String getComments() {
        return comments;
    }

    public void setComments(String comments) {
        this.comments = comments;
    }

	public File getDmiFilePath() {
		return this.dmiFilePath;
	}

	public void setDmiFilePath(File dmiFilePath) {
		this.dmiFilePath = dmiFilePath;
	}

	public String getScanPersonName() {
		return this.scanPersonName;
	}

	public void setScanPersonName(String scanPersonName) {
		this.scanPersonName = scanPersonName;
	}

	public Slide getSlide() {
		return this.slide;
	}

	public void setSlide(Slide slide) {
		this.slide = slide;
	}

	public Long getSlideId() {
		return this.slideId;
	}

	public void setSlideId(Long slideId) {
		this.slideId = slideId;
	}

	public DictionaryEntry getStatusDict() {
		return this.statusDict;
	}

	public void setStatusDict(DictionaryEntry slideScanStatusDict) {
		this.statusDict = slideScanStatusDict;
	}

	public Long getStatusDictId() {
		return this.statusDictId;
	}

	public void setStatusDictId(Long statusDictId) {
		this.statusDictId = statusDictId;
	}

	public void setThumbnailId(Long thumbnailId) {
		this.thumbnailId = thumbnailId;
	}

	public double getThumbWidthScale() {
		return (double)thumbWidth/(double)width;
	}

	public double getThumbHeightScale() {
		return (double)thumbHeight/(double)height;
	}

	public String toString() {
		return getName();
	}

	public int getCropsQcFailCount() {

		int qcFailCount = 0;

		for(Crop crop : getCrops()) {

			if( crop.getQcPass() != null
				&& crop.getQcPass().equals( Boolean.FALSE ) ) {

				qcFailCount++;
			}
		}

		return qcFailCount;
	}

	public int getCropsQcPassCount() {

		int qcPassCount = 0;

		for(Crop crop : getCrops()) {

			if( crop.getQcPass() != null
				&& crop.getQcPass().equals( Boolean.TRUE ) ) {

				qcPassCount++;
			}
		}

		return qcPassCount;
	}

	public int getCropCount() {

		return getCrops().size();
    }

    /**
     * Returns a the Set of all processed Crops on this Scan. A processed Crop
     * is one that has a defined image reference.
     *
     * @return Empty set if there are no Crops
     * @throws UnattachedComponentException if Collection<CropJob> is null.
     */
    public Set<Crop> getCrops() {

    	if( cropJobs == null )
    		throw new UnattachedComponentException( Crop.Component.CROP_JOB );

    	Set<Crop> crops = new HashSet<Crop>();

    	for(CropJob cropJob : cropJobs) {

	    	Collection<Crop> myCrops = cropJob.getProcessedCrops();

	    	for(Crop crop : myCrops) {

	    		crops.add( crop );
	    	}
    	}

    	return crops;
    }
}