package uk.ac.sanger.mig.histology;

import java.util.Collection;

import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.BarcodeUtils;
import uk.ac.sanger.mig.common.ComponentEnum;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.common.UnattachedComponentException;
import uk.ac.sanger.mig.mousetracking.BarcodedObject;


public class Slide extends AuthenticatedDataObject implements BarcodedObject {

	static final long serialVersionUID = 101010101L;

	public enum Component implements ComponentEnum {
		ALL_COMPONENTS,
		SCANS, //children
		BLOCK, //parent
		CREATOR;
	}

	public enum StainingTypeDictEnum {
		H_AND_E(1L),
		LAC_Z(2L),
		NONE(3L),
		UNDETERMINED(4L);

		private Long id;

		StainingTypeDictEnum(Long id) {
			this.id = id;
		}

		public Long getId() {return id;}
	}

	

	public enum StatusDictEnum {
		//awaiting scan handled by scan bin table
		AWAITING_SCAN(1L), //A Slide awaiting scan state
		SCANNED(4L), //A Slide is in Scanned state
		QC_FAIL(3L); //Slide has failed QC

		private Long id;

		StatusDictEnum(Long id) {
			this.id = id;
		}

		public Long getId() {return id;}
	}


    private String barcode;
    private Long blockId;
    private Long stainingTypeDictId;
    private Long slideStatusDictId;
    private String comments;

    private Collection<Scan> scans;
    private DictionaryEntry stainingTypeDict;
    private DictionaryEntry statusDict;
    private Block block;
    private Integer versionNumber;
    private boolean selectedForPrintingLabel;


    public Slide() {}



	public Collection<Scan> getScans() {
		return this.scans;
	}

	public void setScans(Collection<Scan> slideScans) {
		this.scans = slideScans;
	}

	public DictionaryEntry getStatusDict() {
		return this.statusDict;
	}

	public void setStatusDict(DictionaryEntry slideStatusDict) {
		this.statusDict = slideStatusDict;
	}

	public Long getStatusDictId() {
		return this.slideStatusDictId;
	}

	public void setStatusDictId(Long slideStatusDictId) {
		this.slideStatusDictId = slideStatusDictId;
	}

	public Block getBlock() {
		return this.block;
	}

	public void setBlock(Block block) {
		this.block = block;
	}

	public DictionaryEntry getStainingTypeDict() {
		return this.stainingTypeDict;
	}

	public void setStainingTypeDict(DictionaryEntry stainingTypeDict) {
		this.stainingTypeDict = stainingTypeDict;
	}


    public String getBarcode() {
        return barcode;
    }

    public void setBarcode(String barcode) {
        this.barcode = barcode;
    }

    public Long getBlockId() {
        return blockId;
    }

    public void setBlockId(Long blockId) {
        this.blockId = blockId;
    }


    public Long getStainingTypeDictId() {
        return stainingTypeDictId;
    }

    public void setStainingTypeDictId(Long stainingTypeDictId) {
        this.stainingTypeDictId = stainingTypeDictId;
    }
    public String getComments() {
        return comments;
    }

    public void setComments(String comments) {
        this.comments = comments;
    }

	@Override
	public String toString() {

		return getBarcode() + ": " + getStainingTypeDict().getName();
	}

	public String getBarcodeDescription() {
		// TODO Auto-generated method stub
		return null;
	}

	public BarcodeType getBarcodeType() {
		return BarcodeType.SLIDE;
	}

	public boolean isSelectedForPrintingLabel() {
		return selectedForPrintingLabel;
	}

	public void setSelectedForPrintingLabel(boolean selectedForPrintingLabel) {
		this.selectedForPrintingLabel = selectedForPrintingLabel;
	}

	public Integer getVersionNumber() {
		return versionNumber;
	}

	public void setVersionNumber(Integer versionNumber) {

		this.versionNumber = versionNumber;
	}

    public int getCropsQcFailCount() {

    	if( getScanCount() == 0 )
    		return 0;

    	int qcFailCount = 0;

    	for( Scan scan : getScans() ) {

    		qcFailCount += scan.getCropsQcFailCount();
    	}

    	return qcFailCount;
    }

    public int getCropsQcPassCount() {

    	if( getScanCount() == 0 )
    		return 0;

    	int qcPassCount = 0;

    	for( Scan scan : getScans() ) {

    		qcPassCount += scan.getCropsQcPassCount();
    	}

    	return qcPassCount;
    }

    public int getCropCount() {

    	if( getScanCount() == 0 )
    		return 0;

    	int cropCount = 0;

    	for( Scan scan : getScans() ) {

    		cropCount += scan.getCropCount();
    	}

    	return cropCount;
    }

    public int getScansQcFailCount() {

    	int qcFailCount = 0;

    	for(Scan scan : getScans()) {

    		if(scan.getStatusDict().getId().equals(Scan.StatusDictEnum.THUMBNAIL_QC_FAIL_BAD_SCAN.getId())
    			|| scan.getStatusDict().getId().equals(Scan.StatusDictEnum.THUMBNAIL_QC_FAIL_BAD_SLIDE.getId())) {

    			qcFailCount++;
    		}
    	}

    	return qcFailCount;
    }

    public int getScansQcPassCount() {

    	int qcPassCount = 0;

    	for(Scan scan : getScans()) {

    		if(scan.getStatusDict().getId().equals(Scan.StatusDictEnum.THUMBNAIL_QC_PASS.getId())
    				|| scan.getStatusDict().getId().equals(Scan.StatusDictEnum.FLAGGED_FOR_RESELECTION.getId())) {

    			qcPassCount++;
    		}
    	}

    	return qcPassCount;
    }


    public int getScanCount() {

    	if( getScans() == null )
    		throw new UnattachedComponentException( Slide.Component.SCANS );

    	return getScans().size();
    }

	public void generateBarcode() {
		this.barcode = BarcodeUtils.generateBarcode(getBarcodeType(), getId());
	}
}