package uk.ac.sanger.mig.histology.applets.scancropper;

import java.applet.AudioClip;
import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.GridLayout;
import java.awt.Insets;
import java.net.URL;
import java.util.Collection;

import javax.swing.BorderFactory;
import javax.swing.Icon;
import javax.swing.ImageIcon;
import javax.swing.JApplet;
import javax.swing.JButton;
import javax.swing.JList;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.ListSelectionModel;
import javax.swing.ScrollPaneConstants;
import javax.swing.border.TitledBorder;

import uk.ac.sanger.mig.histology.applets.scancropper.controllers.ActionController;
import uk.ac.sanger.mig.histology.applets.scancropper.controllers.ManualCropController;
import uk.ac.sanger.mig.histology.applets.scancropper.controllers.ActionController.ButtonActionEnum;
import uk.ac.sanger.mig.histology.applets.scancropper.gui.ImagePanel;
import uk.ac.sanger.mig.histology.applets.scancropper.gui.InputParamControlPanel;
import uk.ac.sanger.mig.histology.applets.scancropper.gui.ScanListListener;
import uk.ac.sanger.mig.histology.applets.scancropper.gui.TextareaMessageListener;
import uk.ac.sanger.mig.histology.applets.scancropper.services.HttpRequestService;
import uk.ac.sanger.mig.histology.applets.scancropper.services.ImageProcessingService;
import uk.ac.sanger.mig.histology.applets.scancropper.services.MessageService;
import uk.ac.sanger.mig.histology.views.SerializableScanView;

public class ScanCropper extends JApplet implements TextareaMessageListener,
													ScanListListener {

   private static final long serialVersionUID = 1L;
   private JTextArea textArea;
   private JList scanList;
   private String baseUrl;


   public void init(){

	 baseUrl =  getBaseUrl();

	 HttpRequestService httpRequestService = new HttpRequestService( baseUrl );

	 ImageProcessingService imageProcessingService = new  ImageProcessingService();

	 buildGUI( httpRequestService, imageProcessingService );

     httpRequestService.fetchScanList();

   }

   public void updateTextArea(String message, boolean append) {

	   if( append )
			textArea.append( message );
		else
			textArea.setText( message );
	   //autoscroll to bottom
	   textArea.setCaretPosition( textArea.getDocument().getLength() );
   }

   public void updateScanList(Collection<SerializableScanView> scans, int defaultSelectedIndex) {

	   scanList.setListData( scans.toArray() );

	   if ( !scans.isEmpty() ) {

		   scanList.setEnabled( true );

		   if( defaultSelectedIndex > -1 ) {

			   scanList.setSelectedIndex( defaultSelectedIndex );
			   scanList.ensureIndexIsVisible( defaultSelectedIndex );
		   }

	   } else {//disable scan list with special message


		   scanList.clearSelection();
		   scanList.setEnabled( false );
	   }

   }

   ////////////////////////////////////////////////////////////////////////////////////
   /////////////////////////////// privates ///////////////////////////////////////////
   ////////////////////////////////////////////////////////////////////////////////////
   private String getBaseUrl() {
		String path = getDocumentBase().toString();
		return path.substring(0, path.lastIndexOf('/'));
   }

   private void buildGUI(HttpRequestService httpRequestService,
		   		         ImageProcessingService imageProcessingService) {

		 setLayout( new BorderLayout() );

		 //build barcode list...
	     scanList = new JList();
	     scanList.setSelectionMode( ListSelectionModel.MULTIPLE_INTERVAL_SELECTION );
	     scanList.setFixedCellWidth( 285 );

	     TitledBorder scanListBorder = BorderFactory.createTitledBorder(
	    		 BorderFactory.createEmptyBorder(4, 0, 0, 0), "Thumbnails Awaiting Region Selection/QC");

	     scanListBorder.setTitleColor(Color.BLUE);
	     scanListBorder.setTitleFont(new Font("dialog", Font.PLAIN, 14 ));
	     scanList.setBorder( scanListBorder );
	     scanList.setToolTipText("Click on a scan to select Regions of Interest.");
	     JScrollPane scanListScrollPane = new JScrollPane(scanList,
	    		 ScrollPaneConstants.VERTICAL_SCROLLBAR_AS_NEEDED,
	    		 ScrollPaneConstants.HORIZONTAL_SCROLLBAR_NEVER);
	     ///////////////////////////////////////////////////////////

	     //build textarea...
	     textArea = new JTextArea("Initializing...");

	     textArea.setFont(new Font("dialog", Font.PLAIN, 14 ));

	     textArea.setLineWrap( true );
	     textArea.setMargin(  new Insets(12, 12, 12, 12) );
	     JScrollPane textAreaScrollPane = new JScrollPane(textArea,
	    		 ScrollPaneConstants.VERTICAL_SCROLLBAR_AS_NEEDED,
	    		 ScrollPaneConstants.HORIZONTAL_SCROLLBAR_NEVER);
	     textAreaScrollPane.setPreferredSize(new Dimension(400,550));
	     TitledBorder textAreaScrollPaneBorder = BorderFactory.createTitledBorder(" output ");
	     textAreaScrollPaneBorder.setTitleJustification( TitledBorder.CENTER );
	     textAreaScrollPaneBorder.setTitleFont(new Font("dialog", Font.PLAIN, 17 ));
	     textAreaScrollPane.setBorder( textAreaScrollPaneBorder );
	     //////////////////////////////////////////////////////////////

	     JPanel buttonPanel = new JPanel();
	     buttonPanel.setLayout(new GridLayout(1,4));

	     JButton makeCropsButton   =      new JButton("Auto-Select");
	     JButton clearCropsButton  =      new JButton("Clear");
	     JButton submitCropsButton =      new JButton("Submit");
	     JButton rejectCrappyScanButton = new JButton("QC Reject");

	     makeCropsButton.setActionCommand(   ButtonActionEnum.MAKE_CROPS.toString() );
	     clearCropsButton.setActionCommand(  ButtonActionEnum.CLEAR_CROPS.toString() );
	     submitCropsButton.setActionCommand( ButtonActionEnum.SUBMIT_CROPS.toString() );
	     rejectCrappyScanButton.setActionCommand( ButtonActionEnum.REJECT_SCAN.toString() );

	     //initialize image panel...
	     ImagePanel imagePanel = new ImagePanel( new Dimension(300,600) );

	     AudioClip audioClip = null;
	     Icon warningIcon = null, decideIcon = null;
			try {
				warningIcon = new ImageIcon( new URL(baseUrl + "/images/meanFace.jpg") );
				decideIcon = new ImageIcon( new URL(baseUrl + "/images/question.jpg") );
				audioClip = getAudioClip( new URL(baseUrl + "/images/clip.wav") );

			} catch(Exception e) {}

	     //layout param control panel...
	     InputParamControlPanel inputParamControlPanel = new InputParamControlPanel( baseUrl + "/images/miceLogo.gif"  );

	     MessageService messageService = new MessageService();

	     //register listeners with centalized message service
	     messageService.setCropSetListener( imagePanel );
	     messageService.setImageUpdateListener( imagePanel );
	     messageService.setTissueLabelListener( imagePanel );
	     messageService.setTextareaMessageListener( this );
	     messageService.setInputParamChangeListener( inputParamControlPanel );
	     messageService.setScanListListener( this );
	     messageService.setHttpServiceListener( imageProcessingService );

	     //register message service with model classes for them to send updates to interested listeners
	     imageProcessingService.setMessageService( messageService );
	     httpRequestService.setMessageService( messageService );



	     //wire up services to controllers...
	     ActionController actionController = new ActionController( warningIcon, decideIcon, audioClip  );
	     actionController.setHttpRequestService( httpRequestService );
	     actionController.setImageProcessingService( imageProcessingService );

	     ManualCropController manualCropController = new ManualCropController();
	     manualCropController.setImageProcessingService( imageProcessingService );

	     //wire up controllers to GUI components...
	     makeCropsButton.addActionListener(        actionController );
	     clearCropsButton.addActionListener(       actionController );
	     submitCropsButton.addActionListener(      actionController );
	     rejectCrappyScanButton.addActionListener( actionController );

	     scanList.addListSelectionListener(     actionController );
	     inputParamControlPanel.addChangeListener(   actionController );
	     inputParamControlPanel.addActionListener(   actionController );

	     imagePanel.addMouseListener(       manualCropController );
	     imagePanel.addMouseMotionListener( manualCropController );


		 ////////////////////////////////////////////////////////////


	     //Assemble GUI components...........
	     buttonPanel.add( makeCropsButton );
	     buttonPanel.add( clearCropsButton );
	     buttonPanel.add( submitCropsButton );
	     buttonPanel.add( rejectCrappyScanButton );


	     JPanel centerPanel = new JPanel();
	     centerPanel.setLayout(new BorderLayout());
	     centerPanel.add("Center", textAreaScrollPane);
	     centerPanel.add("South", inputParamControlPanel);

	     add("Center", centerPanel);
	     add("South", buttonPanel);
	     add("West", scanListScrollPane);
	     add("East", imagePanel);
	     ////////////////////////////////////////////////
   }







}


























