/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.histology.applets.scancropper.controllers;

import java.awt.Point;
import java.awt.Rectangle;
import java.awt.event.MouseEvent;

import javax.swing.event.MouseInputListener;

import uk.ac.sanger.mig.histology.applets.scancropper.gui.ImagePanel;
import uk.ac.sanger.mig.histology.applets.scancropper.services.ImageProcessingService;

/**
 * 
 * @author ae1
 *
 */
public class ManualCropController implements MouseInputListener {

	private ImageProcessingService imageProcessingService;	
	private Rectangle newCropRectangle;
	
	public void mouseClicked(MouseEvent e) {
		//if right click and within 1 or crop rectangles, delete nearest rectangle
		//from CropSet, rem translate Point to  image ofsets  

		if(e.getButton() == MouseEvent.BUTTON3) {
			
			tranlateToImagePosition(e);
			Point point = e.getPoint();		
			imageProcessingService.removeCropsContainng(point);
		
		} else if( e.getButton() == MouseEvent.BUTTON1 ) {
			
			tranlateToImagePosition(e);
			Point point = e.getPoint();		
			imageProcessingService.toggleTilingFlags(point);		
		}
	}

	public void mousePressed(MouseEvent e) {
		tranlateToImagePosition(e);
		newCropRectangle = new Rectangle( e.getX(), e.getY(), 1, 1 );
	}

	public void mouseReleased(MouseEvent e) {
		//now update model (which then updates GUI)
		
		if(newCropRectangle != null && newCropRectangle.width > 1 && newCropRectangle.height > 1) {
			
			imageProcessingService.commitManualCropRectangle(newCropRectangle);
		}
		
		newCropRectangle = null;
	}
	
	public void mouseDragged(MouseEvent e) {
		//draw to GUI, don't update model until mouse release
		if( newCropRectangle != null ) {
			tranlateToImagePosition(e);
			newCropRectangle.width = e.getX() - newCropRectangle.x;
			newCropRectangle.height = e.getY() - newCropRectangle.y;
			imageProcessingService.drawNewCropRectangle( newCropRectangle );	
		}
	}
	
	private void tranlateToImagePosition(MouseEvent e) {
		ImagePanel imagePanel = (ImagePanel)e.getSource();
		e.translatePoint(-imagePanel.getXOffset(), -imagePanel.getYOffset());
	}
	
	public void setImageProcessingService(
			ImageProcessingService imageProcessingService) {
		this.imageProcessingService = imageProcessingService;
	}

	public void mouseMoved(MouseEvent e) {}
	public void mouseEntered(MouseEvent e) {}
	public void mouseExited(MouseEvent e) {}
	
	
}
