package uk.ac.sanger.mig.histology.applets.scancropper.gui;

import java.awt.BorderLayout;
import java.awt.Font;
import java.awt.GridLayout;
import java.awt.event.ActionListener;

import javax.swing.BorderFactory;
import javax.swing.ButtonGroup;
import javax.swing.Icon;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JSpinner;
import javax.swing.SpinnerNumberModel;
import javax.swing.event.ChangeListener;

import uk.ac.sanger.mig.histology.applets.scancropper.controllers.ActionController.RadioActionEnum;
import uk.ac.sanger.mig.histology.applets.scancropper.model.SegmentationConstants;

/**
 * GUI component for setting segmentation parameter controls.
 *
 * @author ae1
 *
 */
public class InputParamControlPanel extends JPanel implements InputParamChangeListener {

	private JSpinner dilationCountSpinner;
	private JLabel dilationCountLabel;

	private JRadioButton cropNowButton;
	private JRadioButton cropOvernightButton;

	public InputParamControlPanel( String miceLogoUrl ) {

	     setLayout(new GridLayout(1,3));

	     setBorder(BorderFactory.createEmptyBorder(6, 6, 6, 6));


	     JLabel logoLabel = new JLabel("<html>&nbsp;&nbsp;<img src='"+miceLogoUrl
	    		 +"' /><font color='#aaaaaa' size='20' font-family='arial'><b>&nbsp;MIG</b></font></html>");

	     /////////////////////////////////////////////////////////////

	     //build dilationCountSpinner....
	     JPanel dilationCountContainer = new JPanel();

	     dilationCountContainer.setLayout(new BorderLayout());

	     dilationCountContainer.setBorder(BorderFactory.createEmptyBorder(0,6,0,0));

	     SpinnerNumberModel dilationCountModel = new SpinnerNumberModel(
	    		 SegmentationConstants.DIALATION_COUNT_DEFAULT.getIntValue(),
	    		 SegmentationConstants.DIALATION_COUNT_MIN.getIntValue(),
	    		 SegmentationConstants.DIALATION_COUNT_MAX.getIntValue(), 1);

	     dilationCountSpinner = new JSpinner( dilationCountModel );

	     dilationCountLabel = new JLabel();
	     dilationCountLabel.setBorder(BorderFactory.createEmptyBorder(0,0,12,0));
	     dilationCountLabel.setText("Dilations");

	     dilationCountContainer.add("North", dilationCountLabel );
	     dilationCountContainer.add("Center", dilationCountSpinner );
	     /////////////////////////////////////////////////////////////


	     cropNowButton = new JRadioButton("Crop Now");
	     cropNowButton.setActionCommand(RadioActionEnum.CROP_NOW.toString());
	     cropOvernightButton = new JRadioButton("Crop Overnight");
	     cropOvernightButton.setActionCommand(RadioActionEnum.CROP_OVERNIGHT.toString());
	     cropOvernightButton.setSelected( true );//default

	     //Group the radio buttons.
	     ButtonGroup buttonGroup = new ButtonGroup();
	     buttonGroup.add(cropNowButton);
	     buttonGroup.add(cropOvernightButton);

	     JPanel radioPanel = new JPanel();
	     radioPanel.setLayout(new GridLayout(2,1));
	     radioPanel.add(cropOvernightButton);
	     radioPanel.add(cropNowButton);

	     //assemble componenets...
	     add( logoLabel );
	     add( dilationCountContainer );
	     add( radioPanel );

	}


	public void updateCropNowParam(boolean cropNow) {

		if( cropNow )
			cropNowButton.setSelected( true );
		else
			cropOvernightButton.setSelected( true );

	}

	public void updateDialationParam(int dialations) {
		dilationCountSpinner.setValue( dialations );
	}



	/**
	 * Registers ChangeListener with the controls in this JPanel.
	 * @param changeListener
	 */
	public void addChangeListener(ChangeListener eventListener ) {

			dilationCountSpinner.addChangeListener( eventListener );
	}

	/**
	 * Registers  ActionListener with the controls in this JPanel.
	 * @param eventListener
	 */
	public void addActionListener(ActionListener eventListener ) {

			cropNowButton.addActionListener( eventListener );
			cropOvernightButton.addActionListener( eventListener );

	}


}


