package uk.ac.sanger.mig.histology.applets.scancropper.model;

import java.awt.Point;
import java.awt.Rectangle;

/**
 * Defines the rectangular bounds of a labeled connected component
 * ie, set of contiguous pixels.
 *
 *
 * @author ae1
 *
 */
public class ConnectedComponentBounds {

	public int label;//exposed public for speed
	public int maxX = 0, minX = Integer.MAX_VALUE;
	public int maxY = 0, minY = Integer.MAX_VALUE;

	public int area;

	public boolean flaggedForTiling;

	public boolean isFlaggedForTiling() {
		return this.flaggedForTiling;
	}

	public void setFlaggedForTiling(boolean flaggedForTiling) {
		this.flaggedForTiling = flaggedForTiling;
	}

	/**
	 * Constructs a ConnectedComponent with the given label.
	 * @param label
	 */
	public ConnectedComponentBounds(int label) {
		this.label = label;
	}

	/**
	 * Returns the bounds of this ConnectedComponent as a Rectangle.
	 * @return
	 */
	public Rectangle getAsRectangle() {
		return new Rectangle(minX, minY, maxX - minX, maxY - minY);
	}

	/**
	 * Determines if a point lies within the rectangular bounds
	 * of this ConnectedComponent, returning true if so.
	 * @param point
	 * @return
	 */
	public boolean contains(Point point) {

		return getAsRectangle().contains(point);
	}

	@Override
	public String toString() {
		Rectangle rect = getAsRectangle();
		return "x:" + rect.x + ", y:" + rect.y + ", w:"+rect.width+", h:"+rect.height+", tiling: " + isFlaggedForTiling();
	}

	/* Equal if bounding box and label identical
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	@Override
	public boolean equals(Object obj) {

		if( obj == null || !(obj instanceof ConnectedComponentBounds) )
			return false;

		ConnectedComponentBounds cc = (ConnectedComponentBounds)obj;

		if(cc == this) return true;

		return ( this.maxX == cc.maxX && this.maxY == cc.maxY &&
				 this.minX == cc.minX && this.minY == cc.minY);

	}

	/* Must return same int if equals true for two different obj--ie,
	 * they must hash to same bin location
	 * @see java.lang.Object#hashCode()
	 */
	@Override
	public int hashCode() {
		return this.maxX + this.maxY +
			   this.minX + this.minY;
	}

}
