package uk.ac.sanger.mig.histology.applets.scancropper.model;

import java.awt.Rectangle;
import java.awt.geom.Rectangle2D;

/**
 * Encapsulates raw image pixel data, CropSet and parameters for making CropSet.
 * @author ae1
 *
 */
public class ImageModel {

	private Integer dilationCount 			= SegmentationConstants.DIALATION_COUNT_DEFAULT.getIntValue();
	private SegmentationAlgorithmEnum algorithm = SegmentationAlgorithmEnum.SAT_THRESHOLD;

	public enum SegmentationAlgorithmEnum {
		BRIGHT_THRESH,
		SAT_THRESHOLD;
	}

	private CropSet cropSet;
	private int[] pixels;
	private final int[] originalCache;
	private final int width, height;




	/**
	 * Constructs an ImageModel object.
	 * @param pixels
	 * @param width
	 * @param height
	 */
	public ImageModel( final int[] originalCache, final int width, final int height, CropSet cropSet ) {

		if( originalCache == null )
			throw new IllegalArgumentException("int[] pixels cannot be null!");

		if( cropSet == null )
			throw new IllegalArgumentException("CropSet cannot be null!");

		this.cropSet = cropSet;
		this.originalCache = originalCache;
		this.pixels = new int[ this.originalCache.length  ];

		restorePixels();

		this.width = width;
		this.height = height;
	}

	/**
	 * Clears the crops from this ImageModel's CropSet
	 *
	 */
	public void clearCrops() {
		cropSet.clear();
	}

	public void setPixels(int[] pixels) {
		this.pixels = pixels;
	}

	/**
	 * Restores pixels to those set when this ImageModel was instantiated.
	 *
	 */
	public void restorePixels() {
		System.arraycopy(this.originalCache, 0, this.pixels, 0, this.originalCache.length);
	}

	/**
	 * Returns the height of the image represented by this ImageModel
	 * @return
	 */
	public int getHeight() {
		return this.height;
	}

	/**
	 * Returns pixel array of the image represented by this ImageModel
	 * @return
	 */
	public int[] getPixels() {
		return this.pixels;
	}

	/**
	 * Returns the width of the image represented by this ImageModel
	 * @return
	 */
	public int getWidth() {
		return this.width;
	}

	public Rectangle2D getAsRectangle() {
		return new Rectangle(0,0,width,height);
	}

	public CropSet getCropSet() {
		return this.cropSet;
	}

	public void setCropSet(CropSet cropSet) {
		this.cropSet = cropSet;
	}

	public SegmentationAlgorithmEnum getAlgorithm() {
		return algorithm;
	}

	public void setAlgorithm(SegmentationAlgorithmEnum algorithm) {
		this.algorithm = algorithm;
	}

	public Integer getDilationCount() {
		return this.dilationCount;
	}

	public void setDilationCount(Integer dilationCount) {
		this.dilationCount = dilationCount;
	}



}
