package uk.ac.sanger.mig.histology.applets.scancropper.services;

import java.awt.Rectangle;
import java.util.Collection;

import uk.ac.sanger.mig.histology.applets.scancropper.gui.CropSetListener;
import uk.ac.sanger.mig.histology.applets.scancropper.gui.ImageUpdateListener;
import uk.ac.sanger.mig.histology.applets.scancropper.gui.InputParamChangeListener;
import uk.ac.sanger.mig.histology.applets.scancropper.gui.ScanListListener;
import uk.ac.sanger.mig.histology.applets.scancropper.gui.TextareaMessageListener;
import uk.ac.sanger.mig.histology.applets.scancropper.gui.TissueLabelListener;
import uk.ac.sanger.mig.histology.applets.scancropper.model.CropSet;
import uk.ac.sanger.mig.histology.applets.scancropper.model.ImageModel;
import uk.ac.sanger.mig.histology.views.SerializableScanView;


/**
 * @author ae1
 *
 */
public class MessageService  {

	//model-change listeners
	private ImageUpdateListener imageUpdateListener;
	private CropSetListener cropSetLListener;
	private TextareaMessageListener textareaMessageListener;
	private InputParamChangeListener inputParamChangeListener;
	private HttpServiceListener httpServiceListener;
	private ScanListListener scanListListener;
	private TissueLabelListener tissueLabelListener;


	public void setTissueLabelListener(TissueLabelListener tissueLabelListener) {
		this.tissueLabelListener = tissueLabelListener;
	}


	public void setScanListListener(ScanListListener slideListListener) {
		this.scanListListener = slideListListener;
	}


	public void sendTissueLabelUpdate(String text) {
		if( tissueLabelListener != null )
			tissueLabelListener.updateTissueLabel( text );
	}

	public void sendScanListChangeUpdate(Collection<SerializableScanView> scans, int defaultSelectedIndex) {
		if( scanListListener != null )
			scanListListener.updateScanList( scans, defaultSelectedIndex );
	}



	public void setHttpServiceListener(HttpServiceListener httpServiceListener) {
		this.httpServiceListener = httpServiceListener;
	}

	public void setTextareaMessageListener(TextareaMessageListener listener) {
		this.textareaMessageListener = listener;
	}

	public void setInputParamChangeListener(
			InputParamChangeListener inputParamChangeListener) {
		this.inputParamChangeListener = inputParamChangeListener;
	}


	public void sendDialationUpdate(int dialations) {
		if( inputParamChangeListener != null) {
			inputParamChangeListener.updateDialationParam(dialations);
		}
	}

	public void sendCropNowUpdate(boolean cropNow) {
		if( inputParamChangeListener != null) {
			inputParamChangeListener.updateCropNowParam(cropNow);
		}
	}

	public void setImageUpdateListener(ImageUpdateListener imageUpdateListener) {
		this.imageUpdateListener = imageUpdateListener;
	}

	public void setCropSetListener (
			CropSetListener connectedComponentListener) {
		this.cropSetLListener = connectedComponentListener;
	}

	public void sendCropSetUpdate(CropSet cropSet, Rectangle newCropRectangle, long delay) {
		if( cropSetLListener != null)
			cropSetLListener.updateCropSet(cropSet, newCropRectangle, delay);
	}

	public void sendTextareaUpdate(String message, boolean append) {
		if( textareaMessageListener != null )
			textareaMessageListener.updateTextArea( message, append );
	}

	public void sendImageUpdate(ImageModel imageModel, long delay) {
		if( imageUpdateListener != null)
			imageUpdateListener.updateImage( imageModel, delay );
	}


	public void sendSubmittedUpdate(Long scanId) {
		if( httpServiceListener != null )
			httpServiceListener.notifySubmitted( scanId );
	}

	public void sendRejectedUpdate(Long scanId) {
		if( httpServiceListener != null )
			httpServiceListener.notifyRejected( scanId );
	}

	public void sendScansFetchedUpdate(Collection<SerializableScanView> scans) {
		if( httpServiceListener != null )
			httpServiceListener.notifyScansFetched( scans );
	}

}
