/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.histology.applets.scancropper.services.operations;


import uk.ac.sanger.mig.histology.applets.scancropper.model.ImageModel;

/**
 * Noise reduction.
 * 
 * @author ae1
 *
 */
public class NoiseFilterOperation implements ImageOperation {
	
	public void process(ImageModel imageModel) {
		
		int[] pixels = imageModel.getPixels(); 
		int width = imageModel.getWidth();
		int height = imageModel.getHeight();

		int[] newPixels = new int[width * height];
		System.arraycopy(pixels, 0, newPixels, 0, newPixels.length);	
		
	    for (int y = 2; y < height - 2; y++) { 
	      for (int x = 2; x < width - 2; x++) {

				int[] kernel = {pixels[(y - 1) * width + (x - 1)],
								pixels[(y - 1) * width + x], //pixels[(y - 2) * width + x],
								pixels[(y - 1) * width + (x + 1)],
								pixels[y * width + (x - 1)], //pixels[y * width + (x - 2)],
								pixels[y * width + (x + 1)], //pixels[y * width + (x + 2)],
								pixels[(y + 1) * width + (x - 1)],
								pixels[(y + 1) * width + x], //pixels[(y + 2) * width + x],
								pixels[(y + 1) * width + (x + 1)]
							};
				
				int[] tempRGB;
				
				int totalRed =0, totalGreen = 0, totalBlue = 0;
				
				for(int i = 0; i < kernel.length; i++) {
					tempRGB = extractRGB( kernel[i] );			
					totalRed   = totalRed   + tempRGB[0];
					totalGreen = totalGreen + tempRGB[1];
					totalBlue   = totalBlue + tempRGB[2];
				}
	    	  
				int avgRed   = (int)( ((float)totalRed) / ((float)kernel.length) );
				int avgGreen = (int)( ((float)totalGreen) / ((float)kernel.length) );
				int avgBlue  = (int)( ((float)totalBlue) / ((float)kernel.length) );
	      
	      
				newPixels[y * width + x] = 0xff000000 | avgRed << 16 | avgGreen << 8 | avgBlue;
				
	      }
	    }
	    
	    imageModel.setPixels( newPixels );
	    
	}

    private int[] extractRGB(int pixel) {
    	
		int red = (pixel >> 16) & 0xff;
		int green = (pixel >> 8) & 0xff;
		int blue = (pixel) & 0xff;
		return new int[] {red, green, blue};
    	
    }
	 

  
}
