/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.histology.controllers;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.AbstractSearchFormController;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.histology.CropSearchBean;
import uk.ac.sanger.mig.histology.services.BlockTypeService;
import uk.ac.sanger.mig.histology.services.CropService;
import uk.ac.sanger.mig.histology.views.CropView;

public class CropSearchController extends AbstractSearchFormController {

	private CropService cropService;
	private DictionaryService dictionaryService;
	private BlockTypeService blockTypeService;

	@Override
	protected ModelAndView onSearch(HttpServletRequest request, HttpServletResponse response,
			Object command, BindException errors) throws Exception {

		CropSearchBean searchBean = (CropSearchBean)command;

		searchBean.setQueryName("cropSearch");

		//searchBean.setRecordSetLength( 5 );

		Collection<CropView> records = cropService.search(searchBean);

		Map<String, Object> model = referenceData(request);
		model.put("records", records);
		return new ModelAndView(getSuccessView(),model);

	}

	@Override
	protected Map<String, Object> referenceData(HttpServletRequest request) throws Exception {

		Map<String, Object> referenceData = new HashMap<String, Object>();

		referenceData.put("qcStatusOptions", CropSearchBean.QcStatus.values() );
		referenceData.put("genotypeOptions", dictionaryService.fetch(DictionaryEnum.MOUSE_GENOTYPE));
		referenceData.put("genderOptions", dictionaryService.fetch(DictionaryEnum.MOUSE_GENDER_DICT));
		referenceData.put("blockOptions", blockTypeService.fetchAllBlockTypes( null ));

		referenceData.put("referencePage", "cropSearch");

		return referenceData;
	}


	public void setCropService(CropService cropService) {
		this.cropService = cropService;
	}

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	public void setBlockTypeService(BlockTypeService blockTypeService) {
		this.blockTypeService = blockTypeService;
	}






}



