package uk.ac.sanger.mig.histology.controllers;

import java.util.Date;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.annotation.controllers.OntologyLookupView;
import uk.ac.sanger.mig.common.AbstractCancellableFormController;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.common.services.ComponentMapService;
import uk.ac.sanger.mig.histology.Crop;
import uk.ac.sanger.mig.histology.forms.CropForm;
import uk.ac.sanger.mig.histology.services.CropService;
import uk.ac.sanger.mig.histology.services.CropService.QcFailAction;
import uk.ac.sanger.mig.mousetracking.MouseAge;
import uk.ac.sanger.mig.personnel.Person;


public class ExamineCropController extends AbstractCancellableFormController {

	private ComponentMapService componentMapService;
	private CropService cropService;
	private String slideSuccessView;
	private String blockSuccessView;
	private String cropSearchSuccessView;

	@Override
	protected Object formBackingObject(HttpServletRequest request)
			throws Exception {

		CropForm cropForm = (CropForm) createCommand();

		Long cropId = ServletRequestUtils.getRequiredLongParameter(request, "cropId");

		String referencePage = ServletRequestUtils.getRequiredStringParameter(request,"referencePage");
		cropForm.setReferencePage( referencePage );

		ComponentMap componentMap = componentMapService.getComponentMap("cropDetail");

		Crop crop = cropService.fetchById(cropId, componentMap);

		cropForm.setCrop(crop);

		if (cropForm.getMouseCropIds() == null) {
			cropForm.setMouseCropIds(cropService.fetchCropIdsByMouse(
					 crop.getCropJob().getScan()
					.getSlide().getBlock()
					.getFixation().getNecropsy()
					.getMouseId()));
		}

		return cropForm;
	}

	@Override
	protected Map referenceData(HttpServletRequest request, Object command,
			Errors errors) throws Exception {

		CropForm cropForm = (CropForm) command;

		Map<String, Object> referenceData = new HashMap<String, Object>();

		referenceData.put("scan", cropForm.getCrop().getCropJob().getScan());

		referenceData.put("mouseAge", new MouseAge(
				 cropForm.getCrop().getCropJob()
				.getScan().getSlide().getBlock()
				.getFixation().getNecropsy().getMouse() ) );

		referenceData.put("qcFailActions", QcFailAction.values());

		referenceData.put("keyValueSeparator", OntologyLookupView.keyValueSeparator);

		return referenceData;
	}


	@Override
	protected ModelAndView onSubmit(HttpServletRequest request,
			HttpServletResponse response, Object command, BindException errors)
			throws Exception {

		CropForm cropForm = (CropForm) command;

		Person user =  RequestUtils.getUser(request);


		if( Boolean.TRUE.equals( cropForm.getCrop().getQcPass() ) &&
				cropForm.getCrop().isQcLocked() ) {
			throw new RuntimeException("Cannot pass a Crop that is QC-locked!");
		}

	    //default persist form data
		cropService.storeAnnotated(cropForm.getCrop(), cropForm.getSelectedAnnotations(), user );

		//persist additional data depending on user fail action
		if( cropForm.getQcFailAction() != null ) {

			cropService.initiateQcFailAction( cropForm.getCrop(), cropForm.getQcFailAction(), user);
		}

		String viewName = null;

		String advance = cropForm.getAdvance();

		long browserCacheEvadeOnRedirect = (new Date()).getTime();

		if( advance.equals("next")) {

			viewName = getSuccessView() + "?rnd="+(browserCacheEvadeOnRedirect - 1)+"&cropId=" + cropForm.getNextId()
				+ "&referencePage="+cropForm.getReferencePage();

		} else if( advance.equals("prev")) {

			viewName = getSuccessView() + "?rnd="+(browserCacheEvadeOnRedirect)+"&cropId=" + cropForm.getPreviousId()
				+  "&referencePage="+cropForm.getReferencePage();

		} else if( advance.equals("exit")) {

			viewName = getExitView( cropForm );
		}

		return new ModelAndView(viewName);
	}

	@Override
	protected ModelAndView onCancel(Object command) throws Exception {

		CropForm cropForm = (CropForm) command;

		String viewName = getExitView( cropForm );

		return new ModelAndView(viewName);

	}

	@Override
	protected boolean isCancelRequest(HttpServletRequest request) {

		return ServletRequestUtils.getBooleanParameter(request,
				"cancel",false);

	}

	private String getExitView(CropForm cropForm) {

		String viewName = null;

		if( "slidesByBlock".equals( cropForm.getReferencePage() ) ) {

			viewName = getBlockSuccessView()
			+ "?blockId=" + cropForm.getCrop().getCropJob().getScan().getSlide().getBlockId();

		} else if( "scansBySlide".equals( cropForm.getReferencePage() ) ) {

			viewName = getSlideSuccessView()
			+ "?slideId=" + cropForm.getCrop().getCropJob().getScan().getSlideId();

		} else if( "cropSearch".equals( cropForm.getReferencePage() ) ) {

			viewName = getCropSearchSuccessView()
			+ "?retrieveFromSession=true&newQuery=false&bypassForm=true&currentRecordId=" + cropForm.getCrop().getId();

		} else
			throw new RuntimeException("String referencePage is required in this controller!");

		return viewName;
	}

	// //////////////////////////////////////////////////////////////////////////////
	// /////////////////////////// dependencies
	// /////////////////////////////////////
	// //////////////////////////////////////////////////////////////////////////////
	public void setCropService(CropService cropService) {
		this.cropService = cropService;
	}

	public void setComponentMapService(ComponentMapService componentMapService) {
		this.componentMapService = componentMapService;
	}

	public String getSlideSuccessView() {
		return this.slideSuccessView;
	}

	public void setSlideSuccessView(String slideSuccessView) {
		this.slideSuccessView = slideSuccessView;
	}

	public String getBlockSuccessView() {
		return this.blockSuccessView;
	}

	public void setBlockSuccessView(String blockSuccessView) {
		this.blockSuccessView = blockSuccessView;
	}

	public String getCropSearchSuccessView() {
		return this.cropSearchSuccessView;
	}

	public void setCropSearchSuccessView(String cropSearchSuccessView) {
		this.cropSearchSuccessView = cropSearchSuccessView;
	}





}
