package uk.ac.sanger.mig.histology.controllers;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.propertyeditors.CustomDateEditor;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.bind.ServletRequestBindingException;
import org.springframework.web.bind.ServletRequestDataBinder;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.AbstractCancellableFormController;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.common.services.ComponentMapService;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.histology.Block;
import uk.ac.sanger.mig.histology.BlockType;
import uk.ac.sanger.mig.histology.Event;
import uk.ac.sanger.mig.histology.Necropsy;
import uk.ac.sanger.mig.histology.NecropsyTissue;
import uk.ac.sanger.mig.histology.Tissue;
import uk.ac.sanger.mig.histology.TissueComparator;
import uk.ac.sanger.mig.histology.forms.NecropsyForm;
import uk.ac.sanger.mig.histology.services.BlockService;
import uk.ac.sanger.mig.histology.services.BlockTypeService;
import uk.ac.sanger.mig.histology.services.NecropsyService;
import uk.ac.sanger.mig.histology.services.TissueService;
import uk.ac.sanger.mig.histology.views.BlockListView;
import uk.ac.sanger.mig.mousetracking.Mouse;
import uk.ac.sanger.mig.mousetracking.services.MouseService;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.personnel.Team;
import uk.ac.sanger.mig.personnel.services.PersonService;
import uk.ac.sanger.mig.personnel.services.TeamService;

public class NecropsyFormController extends AbstractCancellableFormController {

	private NecropsyService necropsyService;
	private TissueService tissueService;
	private MouseService mouseService;
	private DictionaryService dictionaryService;
	private TeamService teamService;
	private PersonService personService;
	private BlockService blockService;
	private BlockTypeService blockTypeService;
	private String batchView;
	private ComponentMapService componentMapService;
	private static final SimpleDateFormat DATE_TIME_FORMAT = new SimpleDateFormat("dd-MMM-yyyy HH:mm");

	public String getBatchView() {
		return batchView;
	}

	public void setBatchView(String batchView) {
		this.batchView = batchView;
	}
	public void setComponentMapService(ComponentMapService componentMapService) {
		this.componentMapService = componentMapService;
	}
	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}
	public void setMouseService(MouseService mouseService) {
		this.mouseService = mouseService;
	}
	public void setTissueService(TissueService tissueService) {
		this.tissueService = tissueService;
	}
	public void setNecropsyService(NecropsyService necropsyService) {
		this.necropsyService = necropsyService;
	}
	public void setPersonService(PersonService personService) {
		this.personService = personService;
	}
	public void setTeamService(TeamService teamService) {
		this.teamService = teamService;
	}
	public void setBlockService(BlockService blockService) {
			this.blockService = blockService;
	}
	public void setBlockTypeService(BlockTypeService blockTypeService) {
		this.blockTypeService = blockTypeService;
	}

	@Override
	protected void initBinder(HttpServletRequest request, ServletRequestDataBinder binder) throws Exception {
		super.initBinder(request, binder);
		binder.registerCustomEditor( Date.class,  new CustomDateEditor( DATE_TIME_FORMAT, true ) );

	}

	@Override
	protected Object formBackingObject(HttpServletRequest request)
			throws Exception {

		NecropsyForm form = (NecropsyForm)createCommand();
		Long mouseId = ServletRequestUtils.getLongParameter(request, "mouseId");
		Long cohortId = ServletRequestUtils.getLongParameter(request, "cohortId");

		if(mouseId != null){
			form.setMouseId(mouseId);
			form.setMainView(false);
			onFormChangeByMouse(form,request);
		}else{
			form.setMainView(true);
		}
		form.setCohortId(cohortId);
		return form;
	}

	@Override
	protected Map referenceData(HttpServletRequest arg0, Object arg1, Errors arg2) throws Exception {
		Map<String, Object> referenceData = new HashMap<String,Object>();
		Collection<Team> teams = teamService.fetchAll();
		Collection<BlockType> blockTypeDropDown = blockTypeService.fetchActiveBlockTypes(false,null);

		Collection<DictionaryEntry> reasons = dictionaryService.fetch(DictionaryEnum.HTL_NECROPSY_REASON_DICT);
		referenceData.put("reasons", reasons);
		referenceData.put("teams", teams);
		referenceData.put("type",blockTypeDropDown);
		return referenceData;
	}

	@Override
	protected boolean isFormChangeRequest(HttpServletRequest request) {
		/*boolean formChange = ServletRequestUtils.getBooleanParameter(request, "onFormChange", false);
		boolean addTissue = ServletRequestUtils.getBooleanParameter(request, "addTissue", false);
		boolean addEvent = ServletRequestUtils.getBooleanParameter(request, "addEvent", false);
		boolean getTeam = ServletRequestUtils.getBooleanParameter(request, "getTeam", false);

		if( formChange || addTissue || addEvent || getTeam)
			return true;
		else
			return super.isFormChangeRequest( request );*/
		String changeRequest = null;

		try{
			changeRequest = ServletRequestUtils.getStringParameter(request, "changeForm");
		}
		catch(ServletRequestBindingException e) {

		}

		if(changeRequest != null && changeRequest.length() >0) {
			return true;
		}
		else {
			return false;
		}
	}

	@Override
	protected void onFormChange(HttpServletRequest request, HttpServletResponse response,
			Object command, BindException bindEx) throws Exception {
		NecropsyForm necropsyForm = (NecropsyForm)command;
		String changeRequest = ServletRequestUtils.getRequiredStringParameter(request, "changeForm");

		Collection<NecropsyTissue> necropsyTissues = new ArrayList<NecropsyTissue>();
		Collection<NecropsyTissue> displayTissues = new ArrayList<NecropsyTissue>();
		Collection<Event> events = new ArrayList<Event>();
		Collection<Event> displayEvents = new ArrayList<Event>();
		necropsyTissues = necropsyForm.getSelectedNecTissues();
		displayTissues = necropsyForm.getDisplayNecTissues();
		events =  necropsyForm.getNecropsyEvents();
		displayEvents = necropsyForm.getDisplayNecropsyEvents();

		if(changeRequest.equalsIgnoreCase("addNewTissue")){
			this.onFormChangeByAddTissue(necropsyForm,necropsyTissues,displayTissues);
		}else if(changeRequest.equalsIgnoreCase("addEvent")){
			this.onFormChangeByAddEvent(necropsyForm,events,displayEvents);
		}else if(changeRequest.equalsIgnoreCase("deleteEvent")) {
			this.deleteEvent(necropsyForm, RequestUtils.getUser(request));
		}else if(changeRequest.equalsIgnoreCase("deleteTissue")) {
			this.deleteTissue(necropsyForm, RequestUtils.getUser(request));
		}else if(changeRequest.equalsIgnoreCase("deleteExtraBlock")){
			this.deleteExtraBlock(necropsyForm);
		}else if(changeRequest.equalsIgnoreCase("addExtraBlock")) {
			this.onFormChangeByAddBlock(necropsyForm);
		}else if(changeRequest.equalsIgnoreCase("getTeam")) {
			this.onFormChangeOfTeam(necropsyForm);
		}else if(changeRequest.equalsIgnoreCase("mouseBarcode")){
			this.onFormChangeByMouse(necropsyForm, request);
		}else{
			throw new RuntimeException("OnFormChange parameter is missing.");
		}
		this.resetForm(necropsyForm);
	}

	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response,
				Object command, BindException errors) throws Exception {
		NecropsyForm necropsyForm = (NecropsyForm) command;
		necropsyService.storeNecropsyInfo(necropsyForm, RequestUtils.getUser(request));

		if(necropsyForm.getCohortId()==null){
			return new ModelAndView(getSuccessView());
		}else{
			return new ModelAndView(getBatchView()+"id="+necropsyForm.getCohortId());
		}
	}

	/*
	 * private methods for onFormChange
	 */
	private void onFormChangeByAddEvent(NecropsyForm necropsyForm, Collection<Event> events, Collection<Event> displayEvents) {
		Collection<DictionaryEntry> dropDownEvent = necropsyForm.getDropDownEvents();
		DictionaryEntry eventDict = dictionaryService.fetchEntry(DictionaryEnum.HTL_NECROPSY_EVENT_DICT,necropsyForm.getEventDictId());
		Event event = new Event();

		event.setNecropsyEventDictId(necropsyForm.getEventDictId());
		event.setNecropsyEventDict(eventDict);

		events.add(event);
		displayEvents.add(event);
		dropDownEvent.remove(eventDict);
	}

	private void onFormChangeByAddBlock(NecropsyForm necropsyForm){
		Collection<Block> selectedBlocks = necropsyForm.getExtraBlocks();
		Collection<BlockListView> displayBlocks = necropsyForm.getDisplayBlocks();
		BlockType blockType= blockTypeService.fetchById(necropsyForm.getBlockTypeDictId(), null);
		Block block = new Block();
		block.setFixationId(necropsyForm.getNecropsy().getFixation().getId());
		block.setBlockTypeId(necropsyForm.getBlockTypeDictId());
		block.setBlockType(blockType);
		block.setComments(necropsyForm.getBlockComments());

		BlockListView blockView = new BlockListView();
		blockView.setMouseId(necropsyForm.getMouse().getId());
		blockView.setBlockTypeId(necropsyForm.getBlockTypeDictId());
		blockView.setBlockTypeDesc(blockType.getDescription());
		blockView.setComments(necropsyForm.getBlockComments());

		selectedBlocks.add(block);
		displayBlocks.add(blockView);
	}

	private void onFormChangeOfTeam(NecropsyForm necropsyForm) {

		Long technicianId = necropsyForm.getTechnicianId();
		if(technicianId != null){
			Person technician = personService.fetchById(technicianId, ComponentMap.of(Person.Component.TEAM));
			necropsyForm.setTechnician(technician);
			necropsyForm.getNecropsy().setTeam(technician.getTeam());
		}else{
			throw new RuntimeException("No technician specified!");
		}
	}

	private void onFormChangeByAddTissue(NecropsyForm necropsyForm, Collection<NecropsyTissue> necropsyTissues,Collection<NecropsyTissue> displayTissues) {
		Tissue chosenTissue = tissueService.fetchById(necropsyForm.getTissueId(), null);
		List<Tissue> dropDownTissues = new ArrayList<Tissue>(necropsyForm.getDropDownTissues());
		NecropsyTissue necropsyTissue = new NecropsyTissue();

		necropsyTissue.setTissueId(necropsyForm.getTissueId());
		necropsyTissue.setComments(necropsyForm.getTissueComments());
		necropsyTissue.setTissue(chosenTissue);

		necropsyTissues.add(necropsyTissue);
		displayTissues.add(necropsyTissue);
		necropsyForm.setSelectedNecTissues(necropsyTissues);
		dropDownTissues.remove(chosenTissue);
		Collections.sort(dropDownTissues, new TissueComparator());
		necropsyForm.setDropDownTissues(dropDownTissues);
	}

	private void onFormChangeByMouse(NecropsyForm necropsyForm,HttpServletRequest request) {
		Mouse mouse = null;
		//could come from the cohort working page or the main menu
		if(necropsyForm.getMouseBarcode()!=null) {
			mouse = mouseService.fetchByBarcode(necropsyForm.getMouseBarcode().trim(), componentMapService.getComponentMap("mouseToFixation"));
		}else if(necropsyForm.getMouseId() !=null){
			mouse = mouseService.fetchById(necropsyForm.getMouseId(), componentMapService.getComponentMap("mouseToFixation"));
		}
		/* no mouse fetched by the barcode => the barcode is not valid;
		 no necropsy and fixatin associcate with the mouse => the mouse has not been put into htl cohort yet
		 otherwise show the page*/
		if(mouse == null){
			necropsyForm.setBarcodeErrorMessage("Invalid Barcode");
		}else if(mouse.getExperimentData().getNecropsy()!=null && mouse.getExperimentData().getNecropsy().getFixation()!=null){
			necropsyForm.setMouse(mouse);
			fillInNecropsyForm(necropsyForm,mouse,RequestUtils.getUser(request));
		}else{
			necropsyForm.setBarcodeErrorMessage("The mouse is not in a histology batch. Put the mouse in a batch first!");
		}
	}

	private void fillInNecropsyForm(NecropsyForm necropsyForm,Mouse mouse,Person person){
		Necropsy necropsy = necropsyService.fetchAllComponentsByMouseId(mouse.getId());
		Collection<BlockListView> displayBlocks = blockService.fetchStandardByMouseId(mouse.getId(),false);
		List<Tissue> dropDownTissueList = new ArrayList<Tissue>(tissueService.fetchAll(null));
		Collection<DictionaryEntry> dropDownEventList = dictionaryService.fetch(DictionaryEnum.HTL_NECROPSY_EVENT_DICT);

		necropsyForm.setDisplayBlocks(displayBlocks);

		if(necropsy.getTechnician()!=null){
			necropsyForm.setTechnicianId(necropsy.getTechnician().getId());
			necropsyForm.setDisplayText(necropsy.getTechnician().getDisplayText());
		}else{
			necropsyForm.setDisplayText(person.getDisplayText());
			necropsyForm.setTechnicianId(person.getId());
			Team team = teamService.fetchById(person.getTeamId(),null);
			necropsy.setTeam(team);
		}
		if(necropsy.getReasonDictId() == null){
			necropsy.setReasonDictId(NecropsyService.NECROPSY_REASON_DICT_ID);
		}
		necropsyForm.setComments(necropsy.getComments());
		necropsyForm.setFixationStartDateTime(necropsy.getFixation().getFixationStartTime());
		necropsyForm.setDisplayNecTissues(necropsy.getNecropsyTissues());
		necropsyForm.setDisplayNecropsyEvents(necropsy.getNecropsyEvents());
		necropsyForm.setNecropsy(necropsy);
		//get the drop down list for tissues and events(no dupilicate recode added)
		List<Tissue> existingTissueList = new ArrayList<Tissue>();
		for(NecropsyTissue nTissue : necropsy.getNecropsyTissues()) {
			existingTissueList.add(nTissue.getTissue());
		}
		Collection<DictionaryEntry> existingEventList = new ArrayList<DictionaryEntry>();
		for(Event nEvent: necropsy.getNecropsyEvents()) {
			existingEventList.add(nEvent.getNecropsyEventDict());
		}
		dropDownTissueList.removeAll(existingTissueList);
		dropDownEventList.removeAll(existingEventList);
		Collections.sort(dropDownTissueList,new TissueComparator());

		necropsyForm.setDropDownTissues(dropDownTissueList);
		necropsyForm.setDropDownEvents(dropDownEventList);
	}

	@Transactional
	private void deleteEvent(NecropsyForm necropsyForm, Person person) {
		Collection<Event> selectedEvents = necropsyForm.getNecropsyEvents();
		Collection<Event> displayedEvents = necropsyForm.getDisplayNecropsyEvents();
		Collection<DictionaryEntry> dropDownEvents = necropsyForm.getDropDownEvents();
		Collection<Event> existingEventDelete = necropsyForm.getEventDelete();

		DictionaryEntry eventDict = dictionaryService.fetchEntry(DictionaryEnum.HTL_NECROPSY_EVENT_DICT, necropsyForm.getDeleteEventId());
		Event dEvent = new Event();

		// if the deleted items is in  the list cahed to store
		for(Event event: selectedEvents) {
			if(event.getNecropsyEventDictId().equals(necropsyForm.getDeleteEventId())){
				dEvent = event;
				break;
			}
		}

		if(dEvent != null && dEvent.getNecropsyEventDictId() != null) {
			selectedEvents.remove(dEvent);
			displayedEvents.remove(dEvent);
		}else{//delete a row from the database
			for(Event event: displayedEvents) {
				if(event.getNecropsyEventDictId().equals(necropsyForm.getDeleteEventId())){
					dEvent = event;
					existingEventDelete.add(event);
					break;
				}
			}
			displayedEvents.remove(dEvent);
		}
		dropDownEvents.add(eventDict);
	}

	@Transactional
	private void deleteTissue(NecropsyForm necropsyForm, Person person) {
		Collection<NecropsyTissue> selectedTissues = necropsyForm.getSelectedNecTissues();
		Collection<NecropsyTissue> displayedTissues = necropsyForm.getDisplayNecTissues();
		List<Tissue> dropDownTissues = new ArrayList<Tissue>(necropsyForm.getDropDownTissues());//need for sorting
		NecropsyTissue dTissue = new NecropsyTissue();
		Tissue dTissueForDropDown = tissueService.fetchById(necropsyForm.getDeleteTissueId(), null);
		Collection<NecropsyTissue> existingNTissue = necropsyForm.getNTissuesDelete();

		// if the deleted items is in  the list cahed to store
		for(NecropsyTissue tissue: selectedTissues) {
			if(tissue.getTissueId().equals(necropsyForm.getDeleteTissueId())){
				dTissue = tissue;
				break;
			}
		}
		if(dTissue != null && dTissue.getTissueId() != null) {
			selectedTissues.remove(dTissue);
			displayedTissues.remove(dTissue);
		}else{//existing record in DB, delete the list on submit
			for(NecropsyTissue tissue: displayedTissues) {
				if(tissue.getTissueId().equals(necropsyForm.getDeleteTissueId())){
					dTissue = tissue;
					existingNTissue.add(tissue);
					break;
				}
			}
			displayedTissues.remove(dTissue);
		}
		dropDownTissues.add(dTissueForDropDown);
		Collections.sort(dropDownTissues, new TissueComparator());
		necropsyForm.setDropDownTissues(dropDownTissues);
	}

	private void deleteExtraBlock(NecropsyForm necropsyForm) {
		Collection<Block> extraBlocks = necropsyForm.getExtraBlocks();
		Collection<BlockListView> displayBlocks = necropsyForm.getDisplayBlocks();
		Block dBlock = null;
		BlockListView dblockListView = null;
		for(Block block: extraBlocks){
			if(block.getComments().equals(necropsyForm.getDeleteComments())
					&& block.getBlockTypeId().equals(necropsyForm.getDeleteExtraBlockTypeId())){
				dBlock = block;
				break;
			}
		}

		for(BlockListView blockListView: displayBlocks){
			if(blockListView.getComments().equals(necropsyForm.getDeleteComments())
					&& blockListView.getBlockTypeId().equals(necropsyForm.getDeleteExtraBlockTypeId())){
				dblockListView = blockListView;
				break;
			}
		}

		if(dBlock != null){
			extraBlocks.remove(dBlock);

		}else{
			throw new RuntimeException("No Extra Block to delete!");
		}
		if(dblockListView != null){
			displayBlocks.remove(dblockListView);
		}else{
			throw new RuntimeException("No Extra Block to delete from the display block list!");
		}
	}

	private void resetForm(NecropsyForm necropsyForm) {
		necropsyForm.setTissueId(null);
		necropsyForm.setTissueComments(null);
		necropsyForm.setEventDictId(null);
		necropsyForm.setDeleteEventId(null);
		necropsyForm.setDeleteTissueId(null);
		necropsyForm.setDeleteBlockId(null);
		necropsyForm.setDeleteComments(null);
		necropsyForm.setDeleteExtraBlockTypeId(null);
		necropsyForm.setBlockComments(null);
		necropsyForm.setBlockTypeDictId(null);
	}
}