package uk.ac.sanger.mig.histology.controllers;

import java.util.Collection;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.ParameterizableViewController;

import uk.ac.sanger.mig.histology.services.BlockService;
import uk.ac.sanger.mig.histology.services.BlockService.CassettePrinter;
import uk.ac.sanger.mig.histology.views.BlockListView;
import uk.ac.sanger.mig.mousetracking.Mouse;
import uk.ac.sanger.mig.mousetracking.services.MouseService;

public class PrintCassettesController extends ParameterizableViewController {

	private BlockService blockService;
	private MouseService mouseService;


	public void setMouseService(MouseService mouseService) {
		this.mouseService = mouseService;
	}

	public void setBlockService(BlockService blockService) {
		this.blockService = blockService;
	}

	@Override
	protected ModelAndView handleRequestInternal(HttpServletRequest request,
			HttpServletResponse response) throws Exception {

		Long mouseId = ServletRequestUtils.getLongParameter(request, "mouseId");
		boolean standard = ServletRequestUtils.getRequiredBooleanParameter(request, "standard");
		Long cohortId = ServletRequestUtils.getRequiredLongParameter(request, "cohortId");

		String cassettePrinter = ServletRequestUtils.getRequiredStringParameter(request, "printer");
		CassettePrinter printer = CassettePrinter.valueOf(cassettePrinter);

		Mouse mouse = mouseService.fetchById(mouseId, null);
		String successViewName = getViewName()+"id="+cohortId;


		if (mouseId == null) {
			// Print extra cassettes for this batch
			String errorMessage = blockService.printExtraCassettes(cohortId, false,printer);
			if(errorMessage == null){
				successViewName +="&oraclePrinting="+"All non-standard cassettes were sent to the printer";
			}else{
				errorMessage = "Cassette printing failed:" + errorMessage;
				successViewName +="&oraclePrinting="+errorMessage;
			}
		}
		else {
			// Print the default cassettes for a mouse
			Collection<BlockListView> blocks = blockService.fetchStandardByMouseId(mouseId, standard);

			if(blocks == null){
				throw new RuntimeException("There are no blocks associated with "+mouse.getBarcode());
			}

			String errorMessage = blockService.printCassettes(blocks,printer);

			if(errorMessage == null){
				errorMessage = "Cassette for "+mouse.getBarcode()+" were sent to the printer";
			}else {
				errorMessage = "Cassettes printing failed: "+errorMessage;
			}

			successViewName +="&oraclePrinting="+errorMessage;

		}
		return new ModelAndView(successViewName);
	}
}
