package uk.ac.sanger.mig.histology.controllers;


import java.util.Collection;
import java.util.concurrent.TimeoutException;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.ParameterizableViewController;

import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.histology.Slide;
import uk.ac.sanger.mig.histology.services.SlideService;
import uk.ac.sanger.mig.mousetracking.Mouse;
import uk.ac.sanger.mig.mousetracking.services.MouseService;


public class PrintSlidesController extends ParameterizableViewController {

	private SlideService slideService;
	private MouseService mouseService;


	public void setMouseService(MouseService mouseService) {
		this.mouseService = mouseService;
	}

	public SlideService getSlideService() {
		return slideService;
	}

	public void setSlideService(SlideService slideService) {
		this.slideService = slideService;
	}


	@Override
	protected ModelAndView handleRequestInternal(HttpServletRequest request,
			HttpServletResponse response) throws Exception {

		Long mouseId = ServletRequestUtils.getLongParameter(request, "mouseId");
		Long cohortId = ServletRequestUtils.getRequiredLongParameter(request, "cohortId");
		Mouse mouse = mouseService.fetchById(mouseId, null);
		
		try{
			Collection<Slide> slides = slideService.createDefaultSlides(mouseId, RequestUtils.getUser(request));
			slideService.printSlides(slides);

			return new ModelAndView(getViewName()+"id="+cohortId+"&oraclePrinting="
					+mouse.getBarcode()+" : Default Slides Printing job successfully sent to the printer.");
		}catch(TimeoutException e){
			String errorView = getViewName()+"id="+cohortId+"&oraclePrinting="
			+mouse.getBarcode()+": Default Slides Printing Failed! The printing job has timed out, Please contact Mouse Informatics Group!";
			return new ModelAndView(errorView);
		}catch(InterruptedException e){
			String errorView = getViewName()+"id="+cohortId+"&oraclePrinting="
			+mouse.getBarcode()+" : Default Slides Printing Failed! The printing job has been interrupted, Please contact Mouse Informatics Group!";
			return new ModelAndView(errorView);
		}catch(RuntimeException e){
			String errorView = getViewName()+"id="+cohortId+"&oraclePrinting="
			+mouse.getBarcode()+" : Default Slides Printing Failed! Please make sure your slides are selected and the printer is on and working properly!";
			return new ModelAndView(errorView);
		}
	}

}
