package uk.ac.sanger.mig.histology.controllers;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.ParameterizableViewController;

import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.common.controllers.SerializedObjectView;
import uk.ac.sanger.mig.histology.Scan;
import uk.ac.sanger.mig.histology.services.ScanService;
import uk.ac.sanger.mig.histology.services.SlideService;

public class RejectScanController  extends ParameterizableViewController {

	private ScanService scanService;
	private SlideService slideService;

	protected ModelAndView handleRequestInternal(HttpServletRequest request,
			HttpServletResponse response) throws Exception {

		Long id = ServletRequestUtils.getRequiredLongParameter( request, "id" );
		boolean badSlide = ServletRequestUtils.getRequiredBooleanParameter( request, "badSlide" );
		ModelAndView modelAndView = null;

		try {

			Scan scan = scanService.fetchById(id, null);

			if( badSlide ) {

				if( scan.getSlideId() != null) {//start by try rejecting parent slide if we have one


					boolean failedOK = slideService.gentlyFailAndReorder(scan.getSlideId(),  RequestUtils.getUser(request));

					String msg = "\n\n*** OK ***\nA new Slide will be recreated from the apropriate Block.";

					if( failedOK ) {

						msg+="\nOld Slide/Scan have been failed.";

					} else {
						msg += "\nOld Slide/Scan could not be failed because good regions still exist.";
					}

					modelAndView = new ModelAndView(  new SerializedObjectView(), getViewName(), msg);

				}  else
					throw new IllegalStateException("Scan found without Slide ID!");

			} else {


				boolean failedOK = scanService.gentlyFailAndReorder(scan.getId(),
						 RequestUtils.getUser(request));

				String msg = "\n\n*** OK ***\n.";

				if( failedOK ) {

					msg+="\nScan has been failed.";

				} else {

					msg += "\nScan could not be failed because good regions still exist.";
				}

				modelAndView = new ModelAndView(  new SerializedObjectView(), getViewName(), msg );
			}

		} catch(Exception e) {

			StringBuffer sb = new StringBuffer("\n\n******************Remote Stack Trace******************\n" + e.getMessage());
			StackTraceElement[] stack = e.getStackTrace();
			for(StackTraceElement elem : stack) {
				sb.append("\n" + elem);
			}

			modelAndView = new ModelAndView(  new SerializedObjectView(), getViewName(),
					"Rejection of Scan " + id + " failed!\n" + sb.toString());
		}

		return modelAndView;
	}

	/////////////////////////////////////////////////////////////////////////////////////////////
	////////////////////////////////// dependencies /////////////////////////////////////////////
	/////////////////////////////////////////////////////////////////////////////////////////////
	public void setScanService(ScanService scanService) {
		this.scanService = scanService;
	}

	public void setSlideService(SlideService slideService) {
		this.slideService = slideService;
	}
}
