package uk.ac.sanger.mig.histology.controllers;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.AbstractCancellableFormController;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.common.services.ComponentMapService;
import uk.ac.sanger.mig.histology.Slide;
import uk.ac.sanger.mig.histology.forms.RecreateFlaggedSlidesForm;
import uk.ac.sanger.mig.histology.services.SlideService;


public class ReworkSlidesController extends AbstractCancellableFormController {

	private SlideService slideService;
	private ComponentMapService componentMapService;
	
	@Override
	protected Object formBackingObject(HttpServletRequest request)
			throws Exception {
		
		return createCommand();
	}

	@Override
	protected Map referenceData(HttpServletRequest request, Object command,
			Errors errors) throws Exception {
		
		RecreateFlaggedSlidesForm recreateSlidesForm = (RecreateFlaggedSlidesForm) command;
		
		ComponentMap slideMap = componentMapService.getComponentMap("reworkSlide");
		
		Collection<Slide> recreationSlides = slideService.fetchRecreationBin( slideMap );
		
		Collection<Slide> toScanSlides = slideService.fetchScanningBin( slideMap );
		
		recreateSlidesForm.initialize( recreationSlides );
		
		Map<String, Object> model = new HashMap<String, Object>();
		
		model.put("recreationSlides", recreationSlides);	
		model.put("recreationSlideCount", recreationSlides.size());
		
		model.put("toScanSlides", toScanSlides);
		model.put("toScanSlideCount", toScanSlides.size());
		
		return model;
	}
	
	@Override
	protected ModelAndView onSubmit(HttpServletRequest request,
			HttpServletResponse response, Object command, BindException errors)
			throws Exception {

		RecreateFlaggedSlidesForm recreateSlidesForm = (RecreateFlaggedSlidesForm) command;

		Collection<Long> selectedSlideIds = recreateSlidesForm.getSelectedSlideIds();
		
		Collection<Slide> slides 
			= slideService.recreateAll( selectedSlideIds, RequestUtils.getUser(request) );
		
		slideService.printSlides( slides );
		
		return new ModelAndView( getSuccessView() );
	}

	
	@Override
	protected void onFormChange(HttpServletRequest request,
			HttpServletResponse response, Object command) throws Exception {
		
		RecreateFlaggedSlidesForm recreateFlaggedSlidesForm = (RecreateFlaggedSlidesForm) command;
		
		
		if(recreateFlaggedSlidesForm.getRemoveSlideId() != null) {
			
			if( recreateFlaggedSlidesForm.isDeleteRecreate()) {
				
				slideService.removeFromRecreationBin( 
						recreateFlaggedSlidesForm.getRemoveSlideId()  );
				/*
				 * only need if we want manual way of flagging slide recreation on rework page
				if(recreateFlaggedSlidesForm.getAddSlideId() != null  )
					slideService.flagForRecreation( recreateFlaggedSlidesForm.getAddSlideId()  );		
				*/
				
				ComponentMap slideMap = componentMapService.getComponentMap("reworkSlide");
				
				Collection<Slide> recreationSlides = slideService.fetchRecreationBin( slideMap );
							
				recreateFlaggedSlidesForm.initialize( recreationSlides );
			
			} else if( recreateFlaggedSlidesForm.isDeleteRescan() ) {
				
				slideService.removeFromScanningBin( recreateFlaggedSlidesForm.getRemoveSlideId()  );
				
			}
		}
	
		
	}

	@Override
	protected boolean isFormSubmission(HttpServletRequest request) {

		boolean formSubmission = ServletRequestUtils.getBooleanParameter( 
				request, "formSubmission", false );
		
		if( formSubmission ) {
						
			return true;
		
		} else {
		
			return super.isFormSubmission(request);
		}
		
	}
	
	@Override
	protected boolean isFormChangeRequest(HttpServletRequest request,
			Object command) {
	
		RecreateFlaggedSlidesForm recreateFlaggedSlidesForm = (RecreateFlaggedSlidesForm) command;
		
		if( recreateFlaggedSlidesForm.isAddOrRemove() ) {
			
			return true;
		
		} else {
		
			return super.isFormChangeRequest(request, command);
		}		
	}
	

	
	////////////////////////////////////////////////////////////////////////////////
	///////////////////////////// dependencies ///////////////////////////////////// 
	////////////////////////////////////////////////////////////////////////////////
	
	public void setSlideService(SlideService slideService) {
		this.slideService = slideService;
	}

	public void setComponentMapService(ComponentMapService componentMapService) {
		this.componentMapService = componentMapService;
	}	
	
}
