package uk.ac.sanger.mig.histology.controllers;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.AbstractCancellableFormController;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.histology.SweepScanException;
import uk.ac.sanger.mig.histology.services.ScanService;
import uk.ac.sanger.mig.histology.views.SerializableScanView;
import uk.ac.sanger.mig.personnel.Person;

public class SweepScanController extends AbstractCancellableFormController {
	
	private ScanService scanService;
	
	@Override
	protected Object formBackingObject(HttpServletRequest httpServletRequest) throws Exception {
		return createCommand();				    	
	}
		
	@Override
	protected Map referenceData(HttpServletRequest httpServletRequest) throws Exception {
		
		String[] sweepFiles = scanService.fetchSweepFiles();
		
		Collection<SerializableScanView> awaitingCropSelection 
			= scanService.fetchCropSelectionBinSerialized();
		
		String sweepDir = scanService.getSweepDirectory().getCanonicalPath();
		String finalDir = scanService.getDmiRootDirectory().getCanonicalPath();
		
		Map<String,Object> formMetaData = new HashMap<String,Object>();
		formMetaData.put("sweepFiles", sweepFiles);
		
		formMetaData.put("awaitingCropSelection", awaitingCropSelection);
		
		formMetaData.put("sweepDir", sweepDir);
		formMetaData.put("finalDir", finalDir);
		
		return formMetaData;
	} 
	
	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, 
				Object command, BindException errors) throws Exception {
		
		
		sweepScans( RequestUtils.getUser(request) );
		
		return new ModelAndView( getSuccessView()); // show list view
	}

	
	/*
	 * Performs batch import of Dmetrix (*.dmi) image files and
	 * scan meta data into the MIG Database.
	 * 
	 * Based on the Slide barcode parsed from the dmi file name  
	 * a new Scan record is inserted into in the HTL_SCAN table with foreign
	 * key references to its parent Slide and to its thumbnail image (stored as BLOB
	 * in APP_BINARY_FILE).  The Scan is also added to Crop selection bin for 
	 * segmentation purposes.
	 * 
	 * Static configuration parameters are defined in XML via the Spring application 
	 * context and injected at startup time (eg, sweep directory location, thumnail file 
	 * extension, etc). 
	 * 
	 */
	private void sweepScans(Person user)  {
		
		//1.
		String[] fileNames = scanService.fetchSweepFiles();
		
		int successCount = 0;
		
		for(String fileName : fileNames) {
			
			try {
				
				scanService.process( fileName, user );
				
				successCount++;
				
			} catch(SweepScanException e) {
				
				logger.warn( "Metadata/thumbnail extraction failed! Scan of Slide *not* stored, and DMI file will remain in sweep directory. CAUSE:\n", e );
				
				continue;	
			}	
			
			
		}	
		
		logger.debug(successCount + " of " + fileNames.length + " images in sweep directory successfully processed.");
	}
	
	/////////////////////////////////////////////////////////////////////////////////////////////
	////////////////////////////////// dependencies /////////////////////////////////////////////
	/////////////////////////////////////////////////////////////////////////////////////////////
	public void setScanService(ScanService slideScanService) {
		this.scanService = slideScanService;
	}
	
}