package uk.ac.sanger.mig.histology.controllers;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.ParameterizableViewController;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.services.ComponentMapService;
import uk.ac.sanger.mig.histology.Slide;
import uk.ac.sanger.mig.histology.services.SlideService;
import uk.ac.sanger.mig.mousetracking.MouseAge;

public class ViewScansBySlideController extends ParameterizableViewController {
	
	private SlideService slideService;
	private ComponentMapService componentMapService;
		
	
	protected ModelAndView handleRequestInternal(HttpServletRequest request, 
			HttpServletResponse response) throws Exception {

		Long id = ServletRequestUtils.getRequiredLongParameter( request, "slideId" );
		
		//tell our jsp whether to hide crops and show thumnail only
		boolean supressCrops = ServletRequestUtils.getBooleanParameter( request, "supressCrops", false );
		
		ComponentMap slideMap = componentMapService.getComponentMap("scansBySlide");
		
		Slide slide = slideService.fetchById( id, slideMap);	 			

		//fetch shallow map of sibling Slides for lateral navigation
		Collection<Slide> allBlockSlides 
			= slideService.fetchAllByBlockId(slide.getBlockId(), null);
		
		Map<String, Object> model = new HashMap<String, Object>();
		
		model.put("slide", slide);
		
		model.put("supressCrops", supressCrops);
		
		model.put("referencePage", "scansBySlide");
		
		model.put("allBlockSlides", allBlockSlides);
		
		model.put("mouseAge", new MouseAge( slide.getBlock().getFixation().getNecropsy().getMouse() ) );
			
		return new ModelAndView(getViewName(), model);		
	}

	/////////////////////////////////////////////////////////////////////////////////////////////
	////////////////////////////////// dependencies /////////////////////////////////////////////
	/////////////////////////////////////////////////////////////////////////////////////////////
	public void setSlideService(SlideService slideSlideService) {
		this.slideService = slideSlideService;
	}

	public void setComponentMapService(ComponentMapService componentMapService) {
		this.componentMapService = componentMapService;
	}
	

	
}
