/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.histology.controllers;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.ParameterizableViewController;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.services.ComponentMapService;
import uk.ac.sanger.mig.histology.Block;
import uk.ac.sanger.mig.histology.services.BlockService;
import uk.ac.sanger.mig.mousetracking.MouseAge;

/**
 * 
 * Handles requests for histology Slides grouped by Block.
 * 
 * @author ae1
 *
 */
public class ViewSlidesByBlockController extends ParameterizableViewController {
	
	private BlockService blockService;
	private ComponentMapService componentMapService;

	
	@Override
	protected ModelAndView handleRequestInternal(HttpServletRequest request,
			HttpServletResponse response) throws Exception {
		
		Long blockId = ServletRequestUtils.getRequiredLongParameter( request, "blockId" );
		
		//tell our jsp whether to hide crops and show thumnail only
		boolean supressCrops = ServletRequestUtils.getBooleanParameter( request, "supressCrops", false );
		
		ComponentMap blockMap = componentMapService.getComponentMap("slidesByBlock");
		
		Block block = blockService.fetchById(blockId, blockMap);
		
		//fetch shallow map of sibling Blocks for lateral navigation
		Collection<Block> allFixationBlocks 
			= blockService.fetchByFixationId( block.getFixationId(), 
					ComponentMap.of( Block.Component.BLOCK_TYPE ));
		
		Map<String, Object> model = new HashMap<String, Object>();
		
		model.put("block", block);
		
		model.put("supressCrops", supressCrops);
		
		model.put("referencePage", "slidesByBlock");
		
		model.put("mouseAge", new MouseAge( block.getFixation().getNecropsy().getMouse() ) );
		
		model.put("allFixationBlocks", allFixationBlocks);
		
		return new ModelAndView( getViewName(), model );
	}

	////////////////////////////////////////////////////////////////////////////////
	///////////////////////////// dependencies /////////////////////////////////////
	////////////////////////////////////////////////////////////////////////////////	
	public void setComponentMapService(ComponentMapService componentMapService) {
		this.componentMapService = componentMapService;
	}

	public void setBlockService(BlockService blockService) {
		this.blockService = blockService;
	}

}
