/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.histology.dao;

import java.util.Collection;

import uk.ac.sanger.mig.database.TypedDao;
import uk.ac.sanger.mig.histology.Block;
import uk.ac.sanger.mig.histology.BlockSearchBean;
import uk.ac.sanger.mig.histology.views.BlockListView;
																
	/**
	 * Takes search bean and returns a Collection of Block OBJECTS
	 * based on set fields in bean *and* (THIS IS IMPORTANT) your implementation
	 * of search method in Dao layer -- eg, are you testing for equality? 
	 * Greater than/less than, etc?
	 * @param blockSearchBean
	 * @return
	 */
	 
	public interface BlockDao extends TypedDao<Block> {
	
	public Collection<Block> search(BlockSearchBean blockSearchBean);

	public Collection<Block> fetchAllBlocksByMouseBarcode(String mouseBarcode);
	
	public Block fetchByBarcode(String barcode);
	
	public Collection<BlockListView> fetchAllByMouseId(Long mouseId, boolean standardBlock);

	public Collection<BlockListView> fetchListViewsByMouseId(Long mouseId);
	
	public Collection<Block> fetchByFixationId(Long fixationId);
	
	public Collection<Block> fetchByMouseId(Long mouseId);
	
	public BlockListView fetchBLockListViewById(Long id);
	
	public int fetchNextNumberForBlockType(Long fixationId, Long blockType);
	
}