/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.histology.dao;

import java.util.ArrayList;
import java.util.Collection;

import org.springframework.dao.IncorrectResultSizeDataAccessException;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.histology.Block;
import uk.ac.sanger.mig.histology.BlockSearchBean;
import uk.ac.sanger.mig.histology.dao.rowmappers.BlockListRowMapper;
import uk.ac.sanger.mig.histology.views.BlockListView;

public class BlockDaoSpringImpl extends AbstractDaoSpringImpl<Block> implements BlockDao {

	private BlockListRowMapper blockListRowMapper;

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, Block block) {
	  sql.addStringParam(block.getName(), "NAME");
		sql.addLongParam(block.getFixationId(), "FIXATION_ID");
		sql.addLongParam(block.getBlockTypeId(), "BLOCK_TYPE_ID");
		sql.addLongParam(block.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(block.getCreatedDate(), "CREATED_DATE");
		sql.addStringParam(block.getEditedBy(), "EDITED_BY");
		sql.addDateParam(block.getEditDate(), "EDIT_DATE");
		sql.addLongParam(block.getCheckNumber(), "CHECK_NUMBER");
		sql.addStringParam(block.getBarcode(), "BARCODE");
		sql.addStringParam(block.getComments(), "COMMENTS");
		sql.addDateParam(block.getFixationEndTime(), "FIXATION_END_TIME");
		sql.addDateParam(block.getProgrammeStartTime(), "PROGRAM_START_TIME");
		sql.addLongParam(block.getProgrammeTypeId(), "PROGRAM_DICT_ID");
		sql.addLongParam(block.getId(), "ID");
	}

	public Collection<Block> search(BlockSearchBean blockSearchBean) {
		// TODO Auto-generated method stub
		return null;
	}

	public Collection<Block> fetchAllBlocksByMouseBarcode(String mouseBarcode) {
		StringBuffer sql = new StringBuffer();
		sql.append("select * from " + getTableName() + " where mouse_id = (select id from mts_mouse where barcode = ?)"); 
		Collection<Block> blocks = getSimpleJdbcTemplate().query(sql.toString(), getRowMapper(), mouseBarcode);
		return (blocks!=null)? blocks:null;
	}

	public Block fetchByBarcode(String barcode) {
		String sql = "select * from " + getTableName() +" where barcode = upper(?)";
		Block block = null;
		try{
			block = getSimpleJdbcTemplate().queryForObject(sql, getRowMapper(), barcode);
		}catch(IncorrectResultSizeDataAccessException e) {
			logger.warn(e);
		}
		
		return block;
		
	}
	
	
	
	public Collection<Block> fetchByFixationId(Long fixationId) {
		StringBuffer sql = new StringBuffer();
		sql.append("select * from " + getTableName() + " where fixation_id = ?"); 
		Collection<Block> blocks = getSimpleJdbcTemplate().query(sql.toString(), getRowMapper(), fixationId);
		return blocks;
		
	}
	
	public Collection<Block> fetchByMouseId(Long mouseId) {
    String sql = "select b.* from HTL_NECROPSY n"
        + " join HTL_FIXATION f on n.id = f.NECROPSY_ID"
        + " join " + getTableName() + " b on b.FIXATION_ID = f.id"
        + " where n.mouse_id = ?";
    
    Collection<Block> blocks = getSimpleJdbcTemplate().query(sql, getRowMapper(), mouseId);
    return blocks;
    
  }
	
	public Collection<BlockListView> fetchAllByMouseId(Long mouseId, boolean standardBlock) {
		String sql = "select * from htl_block_vw where mouse_id = ?";
		if(standardBlock){
			sql += " and standard_block = 1";
		}else if(!standardBlock){
			sql +=" and standard_block = 0";
		}
		Collection<BlockListView> blocks = getSimpleJdbcTemplate().query(sql,getBlockListRowMapper(),mouseId);
		
		return (blocks == null)? new ArrayList<BlockListView>() : blocks;
	}
	
	
	public Collection<BlockListView> fetchListViewsByMouseId(Long mouseId) {
		String sql = "select * from htl_block_vw where mouse_id = ?";

		Collection<BlockListView> blocks = getSimpleJdbcTemplate().query(sql,getBlockListRowMapper(),mouseId);

		return (blocks == null)? new ArrayList<BlockListView>() : blocks;
	}
	
	public BlockListView fetchBLockListViewById(Long id) {
		String sql = "select * from htl_block_vw where id = ?";
		BlockListView blockListView = null;
		try{
			blockListView = getSimpleJdbcTemplate().queryForObject(sql, getBlockListRowMapper(), id);
		}catch(IncorrectResultSizeDataAccessException e) {
			logger.warn(e);
		}
		return blockListView;
	}
	
	public BlockListRowMapper getBlockListRowMapper() {
		return blockListRowMapper;
	}

	public void setBlockListRowMapper(BlockListRowMapper blockListRowMapper) {
		this.blockListRowMapper = blockListRowMapper;
	}

  public int fetchNextNumberForBlockType(Long fixationId, Long blockTypeId) {
    String sql = "select count(b.id) +1 from htl_block_type bt" +
                  " join htl_block b on (b.name like (bt.name || '.%') or bt.name = b.name)" +
                  " where bt.id = ?" +
                  " and b.FIXATION_ID = ?";
       
    return getSimpleJdbcTemplate().queryForInt(sql, new Object[]{blockTypeId, fixationId});
  }

}