package uk.ac.sanger.mig.histology.dao;

import java.util.ArrayList;
import java.util.Collection;

import org.springframework.dao.IncorrectResultSizeDataAccessException;
import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.histology.BlockType;
import uk.ac.sanger.mig.histology.dao.rowmappers.BlockTypeViewRowMapper;
import uk.ac.sanger.mig.histology.views.BlockTypeView;

public class BlockTypeDaoSpringImpl extends AbstractDaoSpringImpl<BlockType> implements BlockTypeDao {

	private BlockTypeViewRowMapper blockTypeViewRowMapper;
	 private ParameterizedRowMapper<DictionaryEntry> dictionaryRowMapper;
	 
	public BlockTypeViewRowMapper getBlockTypeViewRowMapper() {
		return blockTypeViewRowMapper;
	}


	public void setBlockTypeViewRowMapper(
			BlockTypeViewRowMapper blockTypeViewRowMapper) {
		this.blockTypeViewRowMapper = blockTypeViewRowMapper;
	}


	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, BlockType blockType) {
		sql.addStringParam(blockType.getDescription(), "DESCRIPTION");
		sql.addBooleanParam(blockType.getActive(), "ACTIVE");
		sql.addStringParam(blockType.getName(), "NAME");
		sql.addIntParam(blockType.getOrderBy(), "ORDER_BY");
		sql.addLongParam(blockType.getCassetteTypeDictId(), "CASSETTE_TYPE_DICT_ID");
		sql.addBooleanParam(blockType.isStandardBlock(),"STANDARD_BLOCK");
		sql.addLongParam(blockType.getId(), "ID");
	}
	

	public Collection<BlockType> fetchActiveBlockTypes(boolean isStandard) {
		String sql = "select * from "+getTableName()+" where ACTIVE = 1 and STANDARD_BLOCK = ?";
		
		
		Collection<BlockType> blockTypes = getSimpleJdbcTemplate().query(sql,getRowMapper(),isStandard);

		return (blockTypes == null)? new ArrayList<BlockType>():blockTypes;
	}

	public Collection<BlockType> fetchAllBlockTypes() {
		
		String sql = "select * from "+getTableName();
		
		Collection<BlockType> blockTypes = getSimpleJdbcTemplate().query(sql,getRowMapper());

		return (blockTypes == null)? new ArrayList<BlockType>():blockTypes;
	}
	
	public BlockTypeView fetchViewById(Long id){
		String sql = "select * from htl_block_type_vw where id = ?";
		BlockTypeView blockTypeView = null;
		
		try{
			blockTypeView = getSimpleJdbcTemplate().queryForObject(sql,getBlockTypeViewRowMapper(),id);
			
		}catch(IncorrectResultSizeDataAccessException e){
			
		}
		return blockTypeView;
	}
	
	public Collection<DictionaryEntry> fetchDefaultStains(Long blockTypeId) {
    String sql = "select s.* from HTL_BLOCK_TYPE_2_DEFAULT_STAIN b " +
                 "join HTL_STAINING_TYPE_DICT s on b.stain_dict_id = s.id " +
                 "where b.block_type_id = ? ";
    
    return getSimpleJdbcTemplate().query(sql,dictionaryRowMapper,blockTypeId);
  }
  
  public void setDictionaryRowMapper(ParameterizedRowMapper<DictionaryEntry> dictionaryRowMapper) {
    this.dictionaryRowMapper = dictionaryRowMapper;
  }
	
}