package uk.ac.sanger.mig.histology.dao;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.histology.CropJob;


public class CropJobDaoSpringImpl extends AbstractDaoSpringImpl<CropJob> implements CropJobDao {

	public Collection<CropJob> fetchByScanId(Long scanId) {
		String sql = " select * from " + getTableName() + " where scan_id = ? ";
		Collection<CropJob> cropJobs = getSimpleJdbcTemplate().query(sql, getRowMapper(), scanId);
		return (cropJobs == null) ? new ArrayList<CropJob>() : cropJobs;
	}

	public Collection<CropJob> fetchAwaitProcessing(int maxAttempts) {

		String sql = "select * from htl_crop_job where (is_success is null) " +
		"or (is_success = 0 and (attempts < ? or attempts is null)) order by created_date desc";
		Collection<CropJob> cropJobs = getSimpleJdbcTemplate().query(sql, getRowMapper(), maxAttempts);
		return (cropJobs == null) ? new ArrayList<CropJob>() : cropJobs;
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, CropJob cropJob) {

		sql.addDateParam(cropJob.getStartTime(), "START_TIME");
		sql.addLongParam(cropJob.getScanId(), "SCAN_ID");
		sql.addDateParam(cropJob.getEndTime(), "END_TIME");
		sql.addBooleanParam(cropJob.getSuccess(), "IS_SUCCESS");
		sql.addIntParam(cropJob.getAttempts(), "ATTEMPTS");

		sql.addStringParam(cropJob.getFailureReason(), "FAILURE_REASON");
		sql.addDateParam(cropJob.getEditDate(), "EDIT_DATE");
		sql.addStringParam(cropJob.getEditedBy(), "EDITED_BY");
		sql.addDateParam(cropJob.getCreatedDate(), "CREATED_DATE");
		sql.addLongParam(cropJob.getCreatorId(), "CREATOR_ID");
		sql.addLongParam(cropJob.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(cropJob.getId(), "ID");
	}


}