package uk.ac.sanger.mig.histology.dao;

import java.util.ArrayList;
import java.util.Collection;

import org.springframework.dao.IncorrectResultSizeDataAccessException;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.histology.Scan;
import uk.ac.sanger.mig.histology.ScanSearchBean;
import uk.ac.sanger.mig.histology.dao.rowmappers.SerializableScanViewRowMapper;
import uk.ac.sanger.mig.histology.views.SerializableScanView;

public class ScanDaoSpringImpl extends AbstractDaoSpringImpl<Scan> implements ScanDao {

	private SerializableScanViewRowMapper serializableScanViewRowMapper;
	private String cropSelectionBin;

	public Scan removeFromCropSelectionBin(Long scanId) {

		Scan scan =  fetchById(scanId);
		String sqlString = " delete "+getCropSelectionBin()+" where SCAN_ID = ? ";
		ParameterizedSqlUpdate delete = new ParameterizedSqlUpdate(getJdbcTemplate());
		delete.addLongParam(scan.getId());
		delete.execute(sqlString);
		return scan;
	}

	/**
	 * Throws RT Exception if scan id dupe
	 */
	public void addToCropSelectionBin(Long scanId) {
		ParameterizedSqlUpdate sql = new ParameterizedSqlUpdate(getJdbcTemplate());
		sql.addLongParam(scanId, "SCAN_ID");
		sql.executeInsert( getCropSelectionBin() );
	}

	public boolean existsInCropSelectionBin(Long scanId) {

		if( scanId == null )
			throw new IllegalArgumentException("scanId cannot be null!");

		Scan scan = null;

		String sql = "select s.* from " + getCropSelectionBin() + " bin, "+getTableName()
			+" s where bin.scan_id = ? and bin.scan_id = s.id ";

		try {
			scan = getSimpleJdbcTemplate().queryForObject(sql, getRowMapper(), scanId);
		} catch(IncorrectResultSizeDataAccessException e) {}

		return (scan != null);

	}

	public Collection<SerializableScanView> fetchCropSelectionBinSerialized() {
		String sql = "select s.*, b.added_on from HTL_SCAN_VW s, "+ getCropSelectionBin() +" b where b.scan_id = s.id  and rownum < 51 order by slide_id, version_number";
		Collection<SerializableScanView> scanViews
			= getSimpleJdbcTemplate().query(sql, getSerializableScanViewRowMapper());
		return ( scanViews != null ) ? scanViews : new ArrayList<SerializableScanView>();
	}

	public Scan fetchByCropJobId(Long cropJobId) {

		if( cropJobId == null )
			throw new IllegalArgumentException("cropJobId cannot be null!");

		Scan scan = null;

		String sql = "select s.* from htl_crop_job cj"
		          + " join htl_scan s on cj.SCAN_ID = s.ID"
		          + " where cj.id = ?"
		          + " and rownum = 1";


		try {
			scan = getSimpleJdbcTemplate().queryForObject(sql, getRowMapper(),cropJobId);
		} catch(IncorrectResultSizeDataAccessException e) {}

		return scan;
	}

	public Collection<Scan> fetch(ScanSearchBean searchBean) {


		Collection<Object> bindVariables = new ArrayList<Object>();

		String selectSql = " select scan.* ";
		String fromSql = " from " + getTableName() + " scan ";
		String whereSql = " where 1=1 ";

		//id
		if(searchBean.getId() != null) {
			whereSql += " and scan.id = ? ";
			bindVariables.add(searchBean.getId());
		}

		//SCAN_STATUS_DICT_ID
		if(searchBean.getStatusDictId() != null) {
			whereSql += " and scan.STATUS_DICT_ID = ? ";
			bindVariables.add( searchBean.getStatusDictId() );
		}

		//SWEEP_DATE (on same day)
		if(searchBean.getSweepDate() != null) {
			whereSql += " and trunc(scan.SWEEP_DATE) = trunc(?) ";
			bindVariables.add( searchBean.getSweepDate() );
		}

		//SWEEP_DATE (on same day)
		if(searchBean.getSlideId() != null) {
			whereSql += " and scan.SLIDE_ID = ? ";
			bindVariables.add( searchBean.getSlideId() );
		}

		String sql = selectSql + fromSql + whereSql;

		//logger.debug(sql);

		Collection<Scan> scan = getSimpleJdbcTemplate().query(sql, getRowMapper(), bindVariables.toArray());
		return (scan == null) ? new ArrayList<Scan>() : scan;


	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, Scan scan) {

		sql.addFilePathParam(scan.getDmiFilePath(), "FILE_PATH");
		sql.addLongParam(scan.getSlideId(), "SLIDE_ID");

		sql.addIntParam(scan.getWidth(), "WIDTH");
		sql.addIntParam(scan.getHeight(), "HEIGHT");
		sql.addFloatParam(scan.getPixelWidth(), "PIXEL_WIDTH");
		sql.addFloatParam(scan.getPixelHeight(), "PIXEL_HEIGHT");

		sql.addIntParam(scan.getThumbWidth(), "THUMB_WIDTH");
		sql.addIntParam(scan.getThumbHeight(), "THUMB_HEIGHT");

		sql.addIntParam(scan.getVersionNumber(), "VERSION_NUMBER");

		sql.addLongParam(scan.getThumbnailId(), "THUMBNAIL_ID");

		sql.addStringParam(scan.getComments(), "COMMENTS");
		sql.addDateParam(scan.getScanDate(), "SCAN_DATE");

		sql.addStringParam(scan.getScanPersonName(), "SCAN_PERSON_NAME");

		sql.addDateParam(scan.getSweepDate(), "SWEEP_DATE");

		sql.addLongParam(scan.getStatusDictId(), "STATUS_DICT_ID");

		sql.addDateParam(scan.getEditDate(), "EDIT_DATE");
		sql.addStringParam(scan.getEditedBy(), "EDITED_BY");
		sql.addDateParam(scan.getCreatedDate(), "CREATED_DATE");
		sql.addLongParam(scan.getCreatorId(), "CREATOR_ID");
		sql.addLongParam(scan.getCheckNumber(), "CHECK_NUMBER");

		sql.addBooleanParam( scan.isFlaggedForDelete(), "is_flagged_for_delete" );
		sql.addBooleanParam( scan.isExternalApproved(), "is_externally_approved" );

		sql.addLongParam(scan.getId(), "ID");
	}

	public void setSerializableScanViewRowMapper(
			SerializableScanViewRowMapper serializableScanViewRowMapper) {
		this.serializableScanViewRowMapper = serializableScanViewRowMapper;
	}

	public SerializableScanViewRowMapper getSerializableScanViewRowMapper() {
		return this.serializableScanViewRowMapper;
	}

	public String getCropSelectionBin() {
		return this.cropSelectionBin;
	}

	public void setCropSelectionBin(String cropSelectionBin) {
		this.cropSelectionBin = cropSelectionBin;
	}




}