package uk.ac.sanger.mig.histology.dao;

import java.util.ArrayList;
import java.util.Collection;

import org.springframework.dao.IncorrectResultSizeDataAccessException;
import org.springframework.jdbc.object.SqlUpdate;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.histology.Block;
import uk.ac.sanger.mig.histology.Slide;
import uk.ac.sanger.mig.mousetracking.BarcodedObject;
import uk.ac.sanger.mig.mousetracking.Mouse;

public class SlideDaoSpringImpl extends AbstractDaoSpringImpl<Slide> implements SlideDao {

	private String slideRecreationBin;
	private String slideScanningBin;


	public Collection<Slide> fetchScanningBin() {

	      String sql = " select sl.* from " + getTableName() +
	      " sl, " + getSlideScanningBin() + " rs where sl.id = rs.slide_id ";

	      return getSimpleJdbcTemplate().query(sql, getRowMapper());
	}


	public boolean existsInScanningBin(Long slideId) {

		if( slideId == null )
			throw new IllegalArgumentException("scanId cannot be null!");

		Slide slide = null;

		String sql = "select sl.* from " + getSlideScanningBin() + " bin, "+
			getTableName()+" sl where bin.slide_id = ? and bin.slide_id = sl.id";

		try {
			slide = getSimpleJdbcTemplate().queryForObject(sql, getRowMapper(), slideId);
		} catch(IncorrectResultSizeDataAccessException e) {}

		logger.debug("Found slide in crop selection bin: " + slide);

		return (slide != null);

	}

	public boolean existsInRecreationBin(Long slideId) {

		if( slideId == null )
			throw new IllegalArgumentException("scanId cannot be null!");

		Slide slide = null;

		String sql = "select sl.* from " + getSlideRecreationBin() + " bin, "+
		getTableName()+" sl where bin.slide_id = ? and bin.slide_id = sl.id";

		try {
			slide = getSimpleJdbcTemplate().queryForObject(sql, getRowMapper(), slideId);
		} catch(IncorrectResultSizeDataAccessException e) {}

		logger.debug("Found slide in crop selection bin: " + slide);

		return (slide != null);

	}

	public void addToScanningBin(Long slideId) {
		ParameterizedSqlUpdate sql = new ParameterizedSqlUpdate(getJdbcTemplate());
		sql.addLongParam(slideId, "SLIDE_ID");
		sql.executeInsert( getSlideScanningBin() );
	}

	public void removeFromScanningBin(Long slideId) {

		String sqlString = " delete " + getSlideScanningBin() + " where SLIDE_ID = ? ";
		ParameterizedSqlUpdate delete = new ParameterizedSqlUpdate(getJdbcTemplate());
		delete.addLongParam(slideId);
		delete.execute(sqlString);
	}

	public Collection<Slide> fetchRecreationBin() {

	      String sql = " select sl.* from " + getTableName() +
	      " sl, " + getSlideRecreationBin() + " rs where sl.id = rs.slide_id ";

	      return getSimpleJdbcTemplate().query(sql, getRowMapper());
	}

	public void addToRecreationBin(Long slideId) {

		SqlUpdate sqlUpdate = new SqlUpdate(getDataSource(),null);
		sqlUpdate.setJdbcTemplate(getJdbcTemplate());
		ParameterizedSqlUpdate sql = new ParameterizedSqlUpdate(getJdbcTemplate());
		sql.addLongParam(slideId, "SLIDE_ID");
		sql.executeInsert( getSlideRecreationBin() );

	}

	public void removeFromRecreationBin(Long slideId) {

		String sqlString = " delete " + getSlideRecreationBin() + " where SLIDE_ID = ? ";
		ParameterizedSqlUpdate delete = new ParameterizedSqlUpdate(getJdbcTemplate());
		delete.addLongParam(slideId);
		delete.execute(sqlString);
	}

	public Slide fetchByBarcode(String barcode) {
		String sql = " select * from " + getTableName() + " where barcode = ? ";
		Slide slide = null;
		try {
			slide = getSimpleJdbcTemplate().queryForObject(sql, getRowMapper(), barcode);
		} catch(IncorrectResultSizeDataAccessException e) {}
		return slide;
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, Slide slide) {

		sql.addStringParam(slide.getBarcode(), "BARCODE");
		sql.addLongParam(slide.getBlockId(), "BLOCK_ID");
		sql.addLongParam(slide.getStainingTypeDictId(), "STAINING_TYPE_DICT_ID");
		sql.addLongParam(slide.getStatusDictId(), "SLIDE_STATUS_DICT_ID");
		sql.addStringParam(slide.getComments(), "COMMENTS");
		sql.addDateParam(slide.getEditDate(), "EDIT_DATE");
		sql.addStringParam(slide.getEditedBy(), "EDITED_BY");
		sql.addDateParam(slide.getCreatedDate(), "CREATED_DATE");
		sql.addLongParam(slide.getCreatorId(), "CREATOR_ID");
		sql.addLongParam(slide.getCheckNumber(), "CHECK_NUMBER");
		sql.addIntParam(slide.getVersionNumber(), "VERSION_NUMBER");
		sql.addLongParam(slide.getId(), "ID");
	}

  public Collection<Slide> fetchAllByBlockId(Long blockId) {
      String sql = " select * from " + getTableName() + " where block_id = ? ";
      return getSimpleJdbcTemplate().query(sql, getRowMapper(), blockId);
  }

  public Collection<Slide> fetchByMouseId(Long mouseId) {

	  String sql = "select s.* from htl_necropsy n, mts_mouse m, " +
	  "htl_fixation f, htl_block b, htl_block_type bt, " +
	   getTableName() + " s where m.id = n.mouse_id and n.id = f.necropsy_id " +
	  "and f.id = b.fixation_id and b.id = s.block_id and m.id = ? " +
	  "and bt.id = b.block_type_id order by bt.description, s.id asc ";

	  Collection<Slide> slides = getSimpleJdbcTemplate().query(sql, getRowMapper(), mouseId);

	  return ( slides != null ) ? slides : new ArrayList<Slide>();
  }

  public boolean slidesAlreadyPresent(BarcodedObject barcodedObject) {
	  StringBuffer sql = new StringBuffer();
		sql.append("select count(*) from " + getTableName() + " where");
		boolean flag = false;
		//if(fieldType.equalsIgnoreCase("mouse")){
		if(barcodedObject instanceof Block){
		sql.append(" block_id = ?");
			int count = getSimpleJdbcTemplate().queryForInt(sql.toString(), barcodedObject.getId());
			if(count>0) {
				flag = true;
			}else{
				flag = false;
			}
		}else if(barcodedObject instanceof Mouse){
			sql.append(" block_id in (select id from htl_block where mouse_id =?)");
			int count = getSimpleJdbcTemplate().queryForInt(sql.toString(), barcodedObject.getId());
			if(count>0) {
				flag = true;
			}else{
				flag = false;
			}
		}else if(barcodedObject instanceof Slide){
			sql.append(" id = ?");
			int count = getSimpleJdbcTemplate().queryForInt(sql.toString(), barcodedObject.getId());
			if(count>0) {
				flag = true;
			}else{
				flag = false;
			}
		}
		return flag;
}

	public Collection<Slide> fetchByBlockIdAndStainDictId(Long blockId, Long stainId) {
		StringBuffer sql = new StringBuffer();
		sql.append("select * from " + getTableName() + " where block_id = ? and staining_type_dict_id = ?");
		Object[] args = new Object[2];
		args[0] = blockId;
		args[1] = stainId;
		Collection<Slide> slides = getSimpleJdbcTemplate().query(sql.toString(), getRowMapper(), args);
		return slides == null ? null : slides;
	}

	public String getSlideRecreationBin() {
		return this.slideRecreationBin;
	}

	public void setSlideRecreationBin(String slideRecreationBin) {
		this.slideRecreationBin = slideRecreationBin;
	}

	public String getSlideScanningBin() {
		return this.slideScanningBin;
	}

	public void setSlideScanningBin(String slideScanBin) {
		this.slideScanningBin = slideScanBin;
	}








}