package uk.ac.sanger.mig.histology.dao;

import java.util.ArrayList;
import java.util.Collection;

import org.springframework.dao.IncorrectResultSizeDataAccessException;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.histology.Tissue;

public class TissueDaoSpringImpl extends AbstractDaoSpringImpl<Tissue> implements TissueDao {


	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, Tissue tissue) {
		sql.addStringParam(tissue.getDescription(), "DESCRIPTION");
		sql.addBooleanParam(tissue.getActive(), "ACTIVE");
		sql.addStringParam(tissue.getName(), "NAME");
		sql.addIntParam(tissue.getOrderBy(), "ORDER_BY");
		sql.addLongParam(tissue.getGenderDictId(), "GENDER_DICT_ID");
		sql.addLongParam(tissue.getId(), "ID");
	}
	
	/* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.dao.TissueDao#search(uk.ac.sanger.mig.histology.TissueSearchBean)
	 */
	/*
	public Collection<Tissue> search(TissueSearchBean tissueSearchBean) {
		// TODO Auto-generated method stub
		return null;
	}
	*/
	
	/* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.dao.TissueDao#fetchAll()
	 */
	public Collection<Tissue> fetchAll() {
		String sql = "select * from " +getTableName();
		Collection<Tissue> tissues = null;
		
		try {
			tissues = getSimpleJdbcTemplate().query(sql, getRowMapper());
		}
		catch(IncorrectResultSizeDataAccessException e) {
			
		}
		
		return tissues;
	}

	public Collection<Tissue> fetchByBlockTypeId(Long blockTypeId) {
		Collection<Tissue> tissues = new ArrayList<Tissue>();
				
		if(blockTypeId!=null)
		{
			String sql = "select t.* from "+getTableName()+ " t" +
			            " join HTL_BLOCK_TYPE_2_TISSUE bt2t on bt2t.TISSUE_ID = t.ID " +
			            " where bt2t.BLOCK_TYPE_ID = ?";
			tissues = getSimpleJdbcTemplate().query(sql, getRowMapper(), blockTypeId);
		}
		
		return (tissues == null)? new ArrayList<Tissue>():tissues;
	}
}