package uk.ac.sanger.mig.histology.dao.rowmappers;

import java.io.File;
import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.histology.Crop;

public class CropRowMapper implements ParameterizedRowMapper<Crop> {
	
	
	public Crop mapRow(ResultSet rs, int rowNum) throws SQLException {
		
		Crop crop = new Crop();
		
		crop.setCropJobId(rs.getLong("CROP_JOB_ID"));
		if(rs.wasNull()) crop.setCropJobId(null);
		
		crop.setId(rs.getLong("ID"));

		crop.setCropWidth(rs.getInt("WIDTH"));

		crop.setCropHeight(rs.getInt("HEIGHT"));
	
		crop.setX(rs.getInt("X_LOCATION"));

		crop.setY(rs.getInt("Y_LOCATION"));
		
		String fullImagePathStr = rs.getString("FULL_IMAGE_PATH");
	
		//set as File object
		if(fullImagePathStr != null)
			crop.setFullImagePath( new File(fullImagePathStr) );
		else 
			crop.setFullImagePath( null );	

		String resizedImagePathStr = rs.getString("RESIZED_IMAGE_PATH");
		
		if(resizedImagePathStr != null)
			crop.setResizedImagePath( new File(resizedImagePathStr) );
		else 
			crop.setResizedImagePath( null );
			
		crop.setTileEdgeExponent( rs.getInt("TILE_EDGE_EXPONENT"));
		
		crop.setZoomRadix( rs.getInt("ZOOM_RADIX"));
		
		crop.setTiled( rs.getBoolean("TILED"));
		
		crop.setComments(rs.getString("COMMENTS"));
		
		crop.setStainingPresent(rs.getBoolean("STAINING_PRESENT"));
		
		crop.setExternalApproved( rs.getBoolean("IS_EXTERNALLY_APPROVED") );
			
		crop.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) crop.setCheckNumber(null);		
		crop.setEditedBy(rs.getString("EDITED_BY"));
		crop.setEditDate(rs.getDate("EDIT_DATE"));

		crop.setCreatorId(rs.getLong("CREATOR_ID"));
		if(rs.wasNull()) crop.setCreatorId(null);		
		crop.setCreatedDate(rs.getDate("CREATED_DATE"));
		
		crop.setFlaggedForDelete( rs.getBoolean("IS_FLAGGED_FOR_DELETE") );
		
		crop.setFlaggedForTiling( rs.getBoolean("IS_FLAGGED_FOR_TILING") );
		
		crop.setQcLocked( rs.getBoolean("QC_LOCKED") );
		
		crop.setQcPass( rs.getBoolean("qc_pass") );
		if(rs.wasNull()) crop.setQcPass( null );
		
		crop.setTissueId( rs.getLong("tissue_id"));
		if(rs.wasNull()) crop.setTissueId(null);	
		
		crop.setQcFailReason( rs.getString("qc_fail_reason"));
		
		return crop;
		
	}
	
	
	
}