/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.histology.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.histology.views.CropView;

public class CropViewRowMapper implements ParameterizedRowMapper<CropView> {

	public CropView mapRow(ResultSet rs, int rowNum) throws SQLException {

		CropView cropView = new CropView();

		cropView.setId(rs.getLong("ID"));

		cropView.setMouseBarcode(rs.getString("MOUSE_BARCODE"));

		cropView.setResizedImagePath(rs.getString("resized_image_path"));

		cropView.setWidth(rs.getInt("width"));
		cropView.setHeight(rs.getInt("height"));

		cropView.setMouseId(rs.getLong(("mouse_id")));

		cropView.setSlideId(rs.getLong("slide_id"));

		cropView.setId(rs.getLong("ID"));

		cropView.setCreatedDate(rs.getTimestamp("CREATED_DATE"));

		cropView.setEditDate(rs.getTimestamp("EDIT_DATE"));

		cropView.setFullImagePath(rs.getString("FULL_IMAGE_PATH"));

		cropView.setQcPass(rs.getBoolean("QC_PASS"));
		if( rs.wasNull() ) cropView.setQcPass( null );

		cropView.setTissueName(rs.getString("TISSUE_NAME"));

		cropView.setTissueId(rs.getLong("TISSUE_ID"));

		cropView.setScanId(rs.getLong("SCAN_ID"));

		cropView.setSourceBlockId(rs.getLong("SOURCE_BLOCK_ID"));

		cropView.setSourceBlockDescription(rs.getString("SOURCE_BLOCK_DESCRIPTION"));

		cropView.setSlideBarcode(rs.getString("SLIDE_BARCODE"));

		cropView.setStaining(rs.getString("STAINING"));

		cropView.setStainingDictId(rs.getLong("STAINING_DICT_ID"));

		cropView.setGender(rs.getString("gender"));

		cropView.setGenderDictId(rs.getLong("gender_dict_id"));

		//cropView.setGenotypeAllele(rs.getString("genotype_allele"));

		cropView.setAlleleId(rs.getLong("allele_id"));
		if( rs.wasNull() ) cropView.setAlleleId( null );

		cropView.setGenotypeDictId(rs.getLong("genotype_dict_id"));
		if( rs.wasNull() ) cropView.setGenotypeDictId( null );

		cropView.setGeneName(rs.getString("gene_name"));
		cropView.setAlleleName(rs.getString("allele_name"));
		cropView.setPipeline(rs.getString("pipeline"));
		cropView.setComments(rs.getString("comments"));

		cropView.setAnnotations(rs.getString("annotations"));

		cropView.setGenotypeName(rs.getString("genotype_name"));
		return cropView;

	}
}