package uk.ac.sanger.mig.histology.dao.rowmappers;

import java.io.File;
import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.histology.Scan;

public class ScanRowMapper implements ParameterizedRowMapper<Scan> {

	private DictionaryService dictionaryService;
	
	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}
	
	public Scan mapRow(ResultSet rs, int rowNum) throws SQLException {
		
		Scan scan = new Scan();
		
		scan.setId(rs.getLong("ID"));

		scan.setSlideId(rs.getLong("SLIDE_ID"));
		if(rs.wasNull()) scan.setSlideId(null);
			
		String filePathStr = rs.getString("FILE_PATH");
		//set as File object
		if(filePathStr != null)
			scan.setDmiFilePath( new File(filePathStr) );
		else 
			scan.setDmiFilePath( null );

		scan.setWidth(rs.getInt("WIDTH"));

		scan.setHeight(rs.getInt("HEIGHT"));

		scan.setPixelWidth(rs.getFloat("PIXEL_WIDTH"));

		scan.setPixelHeight(rs.getFloat("PIXEL_HEIGHT"));


		scan.setThumbWidth(rs.getInt("THUMB_WIDTH"));

		scan.setThumbHeight(rs.getInt("THUMB_HEIGHT"));
	

		scan.setThumbnailImageId(rs.getLong("THUMBNAIL_ID"));
		if(rs.wasNull()) scan.setThumbnailImageId(null);		

		
		scan.setComments(rs.getString("COMMENTS"));
		
		scan.setScanDate(rs.getTimestamp("SCAN_DATE"));
		
		scan.setScanPersonName(rs.getString("SCAN_PERSON_NAME"));
		
		scan.setSweepDate(rs.getTimestamp("SWEEP_DATE"));
		
		scan.setVersionNumber( rs.getInt("VERSION_NUMBER") );
	
		scan.setStatusDictId( rs.getLong("STATUS_DICT_ID") );
		if(rs.wasNull()) scan.setStatusDictId( null );
		
		scan.setStatusDict( dictionaryService.fetchEntry( 
				DictionaryEnum.HTL_SCAN_STATUS_DICT, 
				scan.getStatusDictId()));
	
		scan.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) scan.setCheckNumber(null);		
		scan.setEditedBy(rs.getString("EDITED_BY"));
		scan.setEditDate(rs.getDate("EDIT_DATE"));

		scan.setCreatorId(rs.getLong("CREATOR_ID"));
		if(rs.wasNull()) scan.setCreatorId(null);		
		scan.setCreatedDate(rs.getDate("CREATED_DATE"));
		
		scan.setExternalApproved( rs.getBoolean("is_externally_approved") );
		
		scan.setFlaggedForDelete( rs.getBoolean("is_flagged_for_delete"));
		
		return scan;
		
	}
}