/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.histology.dao.rowmappers;

import java.sql.Blob;
import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.histology.views.SerializableScanView;
import uk.ac.sanger.mig.histology.views.SerializableScanViewImpl;

public class SerializableScanViewRowMapper implements ParameterizedRowMapper<SerializableScanView> {

	public SerializableScanView mapRow(ResultSet rs, int rowNum) throws SQLException {

		SerializableScanView serializableScan = new SerializableScanViewImpl();


		serializableScan.setId(rs.getLong("ID"));

		serializableScan.setFilePath(rs.getString("FILE_PATH"));

		serializableScan.setVersionNumber(rs.getInt("VERSION_NUMBER"));

		serializableScan.setWidth(rs.getInt("WIDTH"));

		serializableScan.setHeight(rs.getInt("HEIGHT"));

		Blob thumbnailBlob = rs.getBlob("THUMBNAIL");

		serializableScan.setThumbnail(
				thumbnailBlob.getBytes(1, (int)thumbnailBlob.length() ));

		serializableScan.setThumbWidth(rs.getInt("THUMB_WIDTH"));

		serializableScan.setThumbHeight(rs.getInt("THUMB_HEIGHT"));

		serializableScan.setStaining(rs.getString("STAINING"));

		serializableScan.setBlockName(rs.getString("BLOCK_NAME"));

		serializableScan.setBlockDescription(rs.getString("BLOCK_DESCRIPTION"));

		serializableScan.setMouseBarcode(rs.getString("MOUSE_BARCODE"));

		serializableScan.setSlideId(rs.getLong("SLIDE_ID"));
		if( rs.wasNull() ) serializableScan.setSlideId( null );

		serializableScan.setSweepDate(rs.getDate("SWEEP_DATE"));

		serializableScan.setStatusDictId( rs.getLong("status_dict_id") );

		serializableScan.setStatusDictName(rs.getString("status"));

		serializableScan.setGenotype(rs.getString("genotype"));

		return serializableScan;

	}
}