package uk.ac.sanger.mig.histology.forms;


import java.util.Collection;
import java.util.LinkedList;
import java.util.List;

import org.apache.commons.collections15.list.LazyList;

import uk.ac.sanger.mig.annotation.Annotation;
import uk.ac.sanger.mig.annotation.AnnotationFactory;
import uk.ac.sanger.mig.database.TableMetadataEnum;
import uk.ac.sanger.mig.histology.Crop;
import uk.ac.sanger.mig.histology.services.CropService.QcFailAction;

/**
 *
 * Encapsulates data user sends to controller.
 *
 * @author ae1
 *
 */
public class CropForm {

	private String advance; //if true do next crop, if false, the previous
	private Crop crop;
	private List<Long> mouseCropIds;
	private String referencePage; //where to return to
	private QcFailAction qcFailAction;
	private Collection<Annotation> selectedAnnotations;

	public QcFailAction getQcFailAction() {
		return this.qcFailAction;
	}

	public void setQcFailAction(QcFailAction qcAction) {
		this.qcFailAction = qcAction;
	}

	public List<Long> getMouseCropIds() {
		return this.mouseCropIds;
	}

	/**
	 * Caches a List of Crop ids
	 *
	 * @param crops
	 */
	public void setMouseCropIds(List<Long> mouseCropIds) {

		this.mouseCropIds = mouseCropIds;
	}

	public int getTotalMouseCrops() {
		return ( this.mouseCropIds != null ) ? this.mouseCropIds.size() : 0;
	}

	/**
	 * Returns the next sibling Crop id relative to the current Crop id
	 * in the family list of Crops ids.
	 *
	 * Crop ids are ordered by position in scan, starting at top-left and ordered
	 * left to right, top down (like reading).
	 *
	 * If the current Crop id is the last element in the list, that id is returned.
	 *
	 * @return
	 */
	public Long getNextId() {

		if( mouseCropIds == null )
			throw new IllegalStateException("Collection<Long> mouseCropIds cannot be null!");

		if(  getCurrentCropIndex() == mouseCropIds.size() - 1 ) {

			return crop.getId();

		} else {

			return mouseCropIds.get( getCurrentCropIndex()  + 1  );
		}
	}

	/**
	 * Returns the previous sibling Crop id relative to the current Crop id
	 * in the family list of Crops ids.
	 *
	 * Crop ids are ordered by position in scan, starting at top-left and ordered
	 * lef to right, top down (like reading).
	 *
	 * If the current Crop id is the first element in the list, that id is returned.
	 *
	 * @return
	 */
	public Long getPreviousId() {
		if( mouseCropIds == null ) {
			throw new IllegalStateException("Collection<Long> mouseCropIds cannot be null!");
		}

		if( getCurrentCropIndex() == 0 ) {

			return crop.getId();

		} else {

			return mouseCropIds.get( getCurrentCropIndex()  - 1 );
		}

	}

	public int getCurrentCropIndex() {

		return mouseCropIds.indexOf( crop.getId() );
	}


	public Crop getCrop() {
		return crop;
	}

	public void setCrop(Crop crop) {

		this.crop = crop;
	}

	public String getAdvance() {
		return this.advance;
	}

	public void setAdvance(String advance) {
		this.advance = advance;
	}

	public String getReferencePage() {
		return this.referencePage;
	}

	public void setReferencePage(String referencePage) {
		this.referencePage = referencePage;
	}

	public Collection<Annotation> getSelectedAnnotations() {
		
		if( selectedAnnotations == null ) {
			selectedAnnotations =  LazyList.decorate(
			        new LinkedList<Annotation>(),
			        new AnnotationFactory(TableMetadataEnum.HTL_CROP, crop.getId()));
		}
		
		return this.selectedAnnotations;
	}




}
