package uk.ac.sanger.mig.histology.forms;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Set;
import java.util.TreeSet;

import uk.ac.sanger.mig.common.DataObjectIdComparator;
import uk.ac.sanger.mig.mousetracking.Cohort;
import uk.ac.sanger.mig.mousetracking.Mouse;

public class ManageBatchForm {

  public String selectorDescription;
  public Long selectorId;
  public String changeRequest;
  
  private List<BatchCheckbox> miceToSelectFrom = new ArrayList<BatchCheckbox>();
  private List<BatchCheckbox> miceInBatch = new ArrayList<BatchCheckbox>();
  private Cohort batch;
  private Long cohortIdForBatch;

  public Cohort getBatch() {
    return batch;
  }
  public void setBatch(Cohort batch) {
    this.batch = batch;
  }
  public List<BatchCheckbox> getMiceInBatch() {
    return miceInBatch;
  }
  public List<BatchCheckbox> getMiceToSelectFrom() {
    return miceToSelectFrom;
  }
  public String getSelectorDescription() {
    return selectorDescription;
  }
  public void setSelectorDescription(String barcodeOrCohortDescription) {
    this.selectorDescription = barcodeOrCohortDescription;
  }
  public String getChangeRequest() {
    return changeRequest;
  }
  public void setChangeRequest(String changeRequest) {
    this.changeRequest = changeRequest;
  }
  public Long getSelectorId() {
    return selectorId;
  }
  public void setSelectorId(Long selectorId) {
    this.selectorId = selectorId;
  }
  public Long getCohortIdForBatch() {
    return cohortIdForBatch;
  }
  public void setCohortIdForBatch(Long cohortIdForBatch) {
    this.cohortIdForBatch = cohortIdForBatch;
  }
  
  public void addMouseToSelectFrom(Mouse mouse, boolean isAlreadyInHistologyBatch) {
    if (!isMouseInBatch(mouse)) {
      BatchCheckbox mouseCheckbox = new BatchCheckbox(mouse, false, isAlreadyInHistologyBatch);
      miceToSelectFrom.add(mouseCheckbox);
    }
  }
  
  public void clearMiceToSelectFrom() {
    miceToSelectFrom.clear();
  }
  
  private boolean isMouseInBatch(Mouse m) {
    boolean inBatch = false;
    
    if (batch.getMice() != null) {
      for(Mouse bm : batch.getMice()) {
        if (m.getId().equals(bm.getId())) {
          inBatch = true;
          break;
        }
      }
    }
    
    return inBatch;
  }
  
  
  public void initMiceInBatch() {
    Set<Mouse> mice = new TreeSet<Mouse>(new DataObjectIdComparator());
    mice.addAll(batch.getMice());
    
    miceInBatch.clear();
    for (Mouse m : mice) {
      BatchCheckbox mc = new BatchCheckbox(m, true, false);
      miceInBatch.add(mc);
    }
  }
  
  public void update() {
    
    // Remove unchecked items from the batch
    for (MouseCheckbox removableMouse : miceInBatch) {
      if (!removableMouse.isChecked()) {
        batch.getMice().remove(removableMouse.getMouse());
      }
    }
    
    // Add checked items to the batch, and remove them from the list to select from
 
    for (Iterator<BatchCheckbox> iter = miceToSelectFrom.iterator(); iter.hasNext(); ) {
      MouseCheckbox addableMouse = iter.next();
      if (addableMouse.isChecked()) {
        batch.getMice().add(addableMouse.getMouse());
        iter.remove();
      }
    }
    
    initMiceInBatch();
  }
  
}
