/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.histology.forms;

import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.Map;
import java.util.Set;

import uk.ac.sanger.mig.histology.Slide;

/**
 * Form to record user selected Slides for recreation.
 * 
 * @author ae1
 *
 */
public class RecreateFlaggedSlidesForm {

	private Map<Long, Boolean> selectedSlideMap;
	private Long removeSlideId; 
	private Long addSlideId;
	private boolean deleteRescan;
	private boolean deleteRecreate;
	
	public RecreateFlaggedSlidesForm() {
		selectedSlideMap = new HashMap<Long, Boolean>();
	}
	
	/**
	 * Returns true if user has selected a Slide to remove or add
	 * from a re-work list.
	 * 
	 * @return
	 */
	public boolean isAddOrRemove() {
		return ( getRemoveSlideId() != null || getAddSlideId() != null );
	}
	
	/**
	 * Initializes this RecreateSlidesForm. 
	 * 
	 * All slideMap values default to Boolean.FALSE
	 * 
	 * @param slides
	 */
	public void initialize(Collection<Slide> slides) {
	
		selectedSlideMap.clear();
		
		removeSlideId = null;
		
		addSlideId = null;
		
		for( Slide slide : slides ) {
			
			selectedSlideMap.put( slide.getId(), Boolean.FALSE );
		}
	}


	public Set<Long> getSlides() {
		return selectedSlideMap.keySet();
	}

	public Map<Long, Boolean> getSelectedSlideMap() {
		return this.selectedSlideMap;
	}

	public void setSlideMap(Map<Long, Boolean> slideMap) {
		this.selectedSlideMap = slideMap;
	}

	/**
	 * 
	 * Returns a Collection of Slides selected to recreate in this form.
	 * 
	 * @return
	 */
	public Collection<Long> getSelectedSlideIds() {
		
		Collection<Long> slideIds = new ArrayList<Long>();
		
		for(Long key : selectedSlideMap.keySet()) {
			
			if( Boolean.TRUE.equals( selectedSlideMap.get( key ) ) ) {
				
				slideIds.add( key );
			}
		}
		
		return slideIds;
		
	}

	public Long getRemoveSlideId() {
		return this.removeSlideId;
	}

	public void setRemoveSlideId(Long removeSlideId) {
		this.removeSlideId = removeSlideId;
	}

	public Long getAddSlideId() {
		return this.addSlideId;
	}

	public void setAddSlideId(Long addSlideId) {
		this.addSlideId = addSlideId;
	}

	public boolean isDeleteRescan() {
		return this.deleteRescan;
	}

	public void setDeleteRescan(boolean deleteRescan) {
		this.deleteRescan = deleteRescan;
	}

	public boolean isDeleteRecreate() {
		return this.deleteRecreate;
	}

	public void setDeleteRecreate(boolean deleteRecreate) {
		this.deleteRecreate = deleteRecreate;
	}




	
}
