/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.histology.services;

import java.util.Collection;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.histology.Block;
import uk.ac.sanger.mig.histology.Fixation;
import uk.ac.sanger.mig.histology.views.BlockListView;
import uk.ac.sanger.mig.personnel.Person;

public interface BlockService {

	public enum CassettePrinter {
		TISSUE_TEK("Tissue Tek"),
		MICROWRITER("MicroWriter");

		private CassettePrinter(String printerName){
			this.printerName = printerName;
		}
		public String printerName;
		public String getPrinterName() {
			return this.printerName;
		}
		public String getValue() {
			return this.name();
		}
	}

	public final static Long SOFT_TISSUE_PRINTER_ID = 50L;
	public final static Long HARD_TISSUE_PRINTER_ID = 51L;
	public final static Long BRAIN_TISSUE_PRINTER_ID = 52L;
	public final static Long EMBRYO_TISSUE_PRINTER_ID = 53L;

	//cassette type in  HTL_CASSETTE_TYPE_DICT
	public final static Long SOFT_TISSUE_CASSETTE_DICT_ID = 1L;
	public final static Long HARD_TISSUE_CASSETTE_DICT_ID = 2L;
	public final static Long BRAINTISSUE_CASSETTE_DICT_ID = 3L;
	public final static Long EMBRYO_TISSUE_CASSETTE_DICT_ID = 4L;

	public final static int HTL_BLOCK_PRINTING_TIME_OUT = 90;

	/**
	 * Stores Block as record in database and returns the record's primary key
	 * @param block
	 * @return
	 */
	public Long store(Block block, Person person);

	/**
	 * Returns block for a given id/barcode that maps to primary key
	 * of a record in a database table.
	 * @param id
	 * @return
	 */
	public Block fetchById(Long id, ComponentMap componentMap);
	public Block fetchByBarcode(String barcode, ComponentMap map);


	//fetch a list of block object by mouse id
	public Collection<Block> fetchByMouseId(Long mouseId, ComponentMap map);
	public Collection<Block> fetchByFixationId(Long fixationId, ComponentMap map);

	//fetch block list view
	public Collection<BlockListView> fetchStandardByMouseId(Long mouseId, boolean standard);
	public Collection<BlockListView> fetchListViewByMouseId(Long mouseId);
	public BlockListView fetchBlockListViewById(Long id);

	public String printCassettes(Collection<BlockListView> cassettes, CassettePrinter printer);
	public String printExtraCassettes(Long cohortId, boolean standard, CassettePrinter printer);

	//methods for creatStandardBlocks for mice when creating the batches
	public void createStandardBlocks(Fixation fixation, Person user);
	public void storeBlocks(Collection<Block> blocks, Person user);

	public String fetchNextBlockName(Long fixationId, Long blockTypeId);

}