package uk.ac.sanger.mig.histology.services;

import java.util.Collection;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.histology.BlockType;
import uk.ac.sanger.mig.histology.views.BlockTypeView;
import uk.ac.sanger.mig.personnel.Person;
																
public interface BlockTypeService {
	
	/**
	 * Stores BlockType as record in database and returns the record's primary key
	 * @param blockType
	 * @return
	 */
	public Long store(BlockType blockType, Person person);	
	
	/**
	 * Returns blockType for a given id that maps to primary key
	 * of a record in a database table.
	 * @param id
	 * @return
	 */
	public BlockType fetchById(Long id, ComponentMap componentMap);
	
	public BlockTypeView fetchViewById(Long id);
	
	
	/**
	 * Takes search bean and returns a Collection of BlockType objects
	 * based on set fields in bean *and* (this is important) your implementation
	 * of search method in Dao layer -- eg, are you testing for equality? 
	 * Greater than/less than, etc?
	 * @param blockTypeSearchBean
	 * @return
	 */
	//public Collection<BlockType> search(BlockTypeSearchBean blockTypeSearchBean);
	
	public Collection<BlockType> fetchActiveBlockTypes(boolean isStandard, ComponentMap componentMap);
	
	/**
	 * Returns a Collection of all BlockTypes with components attached per componentMap.
	 * 
	 * If componentMap is null no components will be attached.
	 * 
	 * @param componentMap
	 * @return
	 */
	public Collection<BlockType> fetchAllBlockTypes(ComponentMap componentMap);
}