package uk.ac.sanger.mig.histology.services;

import java.util.Collection;

import org.springframework.transaction.annotation.Transactional;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.histology.BlockType;
import uk.ac.sanger.mig.histology.dao.BlockTypeDao;
import uk.ac.sanger.mig.histology.views.BlockTypeView;
import uk.ac.sanger.mig.personnel.Person;

public class BlockTypeServiceImpl extends AbstractServiceImpl<BlockType> implements BlockTypeService {
	
	private BlockTypeDao blockTypeDao;
	private DictionaryService dictionaryService;
	private TissueService tissueService;
	
	public void setTissueService(TissueService tissueService) {
		this.tissueService = tissueService;
	}

	public void setBlockTypeDao(BlockTypeDao blockTypeDao) {
		this.blockTypeDao = blockTypeDao;
	}

	@Transactional
	public Long store(BlockType blockType, Person user) {
		if(blockType == null) {
			throw new RuntimeException("Cannot save a null blockType");
		}
		
		return blockTypeDao.store(blockType, user);
	}
	
	public BlockType fetchById(Long blockTypeId, ComponentMap requiredComponents) {
		BlockType blockType = blockTypeDao.fetchById(blockTypeId);
		
		if(blockType != null)
			attachComponents(blockType, requiredComponents);
		
		return blockType;
	}
	
	public Collection<BlockType> fetchActiveBlockTypes(boolean isStandard, ComponentMap requiredComponents){
		Collection<BlockType> blockTypes = blockTypeDao.fetchActiveBlockTypes(isStandard);
		attachComponents(blockTypes, requiredComponents);
		return blockTypes;
	}

	public Collection<BlockType> fetchAllBlockTypes(ComponentMap requiredComponents){
		Collection<BlockType> blockTypes = blockTypeDao.fetchAllBlockTypes();
		attachComponents(blockTypes, requiredComponents);
		return blockTypes;
	}
	
	@Override
	protected void attachComponents(BlockType blockType, ComponentMap requiredComponents) {
		if(blockType == null) {
			throw new RuntimeException("Cannot attach components to null blockType");
		}		
		
		boolean fetchAll = false;
		
		if(requiredComponents != null) {
			
			if(requiredComponents.containsKey(BlockType.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}
			
			if(fetchAll || requiredComponents.containsKey(BlockType.Component.CASSETTE_TYPE)){
				blockType.setCassetteTypeDict(dictionaryService.fetchEntry(DictionaryEnum.HTL_CASSETTE_TYPE_DICT, blockType.getCassetteTypeDictId()));
			}
			
			if(fetchAll || requiredComponents.containsKey(BlockType.Component.TISSUES)) {
			  blockType.setTissues(tissueService.fetchByBlockTypeId(blockType.getId()));
			}
			
			if(fetchAll || requiredComponents.containsKey(BlockType.Component.DEFAULT_STAINS)){
			  blockType.setDefaultStains(blockTypeDao.fetchDefaultStains(blockType.getId()));
			}
		}
	}

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}
	
	public BlockTypeView fetchViewById(Long id) {
		return blockTypeDao.fetchViewById(id);
	}
}
								