package uk.ac.sanger.mig.histology.services;

import java.util.Collection;

import org.springframework.transaction.annotation.Transactional;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.histology.Event;
import uk.ac.sanger.mig.histology.dao.EventDao;
import uk.ac.sanger.mig.personnel.Person;

public class EventServiceImpl extends AbstractServiceImpl<Event> implements EventService {
	
	private EventDao eventDao;
	
	//IMPORTANT: add other dependencies here: Should be other services *not* dao typically
	/**
	 * eg 	private EventDao eventDao;
	 *    private MouseService mouseService
	 *    private PersonService personService; 
	 */
	
	public void setEventDao(EventDao eventDao) {
		this.eventDao = eventDao;
	}

	@Transactional
	public Long store(Event event, Person user) {
		if(event == null) {
			throw new RuntimeException("Cannot save a null event");
		}
		
		return eventDao.store(event, user);
	}
	
	public Event fetchById(Long eventId, ComponentMap requiredComponents) {
		Event event = eventDao.fetchById(eventId);
		
		if(event != null)
			attachComponents(event, requiredComponents);
		
		return event;
	}

	@Override
	protected void attachComponents(Event event, ComponentMap requiredComponents) {
		if(event == null) {
			throw new RuntimeException("Cannot attach components to null event");
		}		
		
		boolean fetchAll = false;
		
		if(requiredComponents != null) {
			
			if(requiredComponents.containsKey(Event.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}
			
			// query required components map and fetch/attach sub-components as needed
			// ...........
			
		}
	}
	
	
	public Collection<Event> fetchByNecropsyId(Long id, ComponentMap componentMap) {
		
		Collection<Event> events = eventDao.fetchByNecropsyId(id);
		attachComponents(events, componentMap);
		
		return events;
	}
	
	@Transactional
	public void delete(Event event, Person person) {
		
		if(event != null ){
			eventDao.delete(event, person);
		}else{
			throw new IllegalArgumentException("Event is required to delete the record!");
		}
		
	}
}
								