package uk.ac.sanger.mig.histology.services;

import java.util.Collection;

import org.springframework.transaction.annotation.Transactional;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.histology.Block;
import uk.ac.sanger.mig.histology.Fixation;
import uk.ac.sanger.mig.histology.Necropsy;
import uk.ac.sanger.mig.histology.dao.FixationDao;
import uk.ac.sanger.mig.personnel.Person;

public class FixationServiceImpl extends AbstractServiceImpl<Fixation> implements FixationService {
	
	private FixationDao fixationDao;
	private NecropsyService necropsyService;
	private BlockService blockService;
	
	public void setNecropsyService(NecropsyService necropsyService) {
    this.necropsyService = necropsyService;
  }


  public void setBlockService(BlockService blockService) {
    this.blockService = blockService;
  }

  //IMPORTANT: add other dependencies here: Should be other services *not* dao typically
	/**
	 * eg 	private FixationDao fixationDao;
	 *    private MouseService mouseService
	 *    private PersonService personService; 
	 */
	
	public void setFixationDao(FixationDao fixationDao) {
		this.fixationDao = fixationDao;
	}

	@Transactional
	public Long store(Fixation fixation, Person user) {
		if(fixation == null) {
			throw new RuntimeException("Cannot save a null fixation");
		}
		
		return fixationDao.store(fixation, user);
	}
	
	@Transactional
  public Fixation createFixation(Long necropsyId, Person user) {
	  if (necropsyId == null || necropsyId < 1L) {
	    throw new IllegalArgumentException("Cannot create a fixation record without a necropsy ID.");
	  }
	  
  	  Fixation fixation = new Fixation();
  	  
  	  fixation.setNecropsyId(necropsyId);
      
  	  store(fixation,user);
      
      blockService.createStandardBlocks(fixation, user);
      
	  return fixation;
  }
	
	public Fixation fetchById(Long fixationId, ComponentMap requiredComponents) {
		Fixation fixation = fixationDao.fetchById(fixationId);
		
		if(fixation != null)
			attachComponents(fixation, requiredComponents);
		
		return fixation;
	}

	@Override
	protected void attachComponents(Fixation fixation, ComponentMap requiredComponents) {
		if(fixation == null) {
			throw new RuntimeException("Cannot attach components to null fixation");
		}		
		
		boolean fetchAll = false;
		
		if(requiredComponents != null) {
			
			if(requiredComponents.containsKey(Fixation.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}
			
			if(fetchAll || requiredComponents.containsKey(Fixation.Component.BLOCKS)) {
			  Collection<Block> blocks = blockService.fetchByFixationId(fixation.getId(), requiredComponents.get(Fixation.Component.BLOCKS));
			  fixation.setBlocks(blocks);
			}
			
			if(fetchAll || requiredComponents.containsKey(Fixation.Component.NECROPSY)) {
        Necropsy necropsy = necropsyService.fetchById(fixation.getNecropsyId(), requiredComponents.get(Fixation.Component.NECROPSY));
        fixation.setNecropsy(necropsy);
      }
			
			
		}
	}
	
	
	public Fixation fetchByNecropsyId(Long necropsyId, ComponentMap componentMap) {
		Fixation fixation = fixationDao.fetchByNecropsyId(necropsyId);
		
		if(fixation != null) {
			attachComponents(fixation, componentMap);
		}
		
		return fixation;
	}
	
}
								