package uk.ac.sanger.mig.histology.services;

import java.util.Calendar;
import java.util.Collection;

import org.springframework.transaction.annotation.Transactional;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.histology.Block;
import uk.ac.sanger.mig.histology.Event;
import uk.ac.sanger.mig.histology.Fixation;
import uk.ac.sanger.mig.histology.Necropsy;
import uk.ac.sanger.mig.histology.NecropsySearchBean;
import uk.ac.sanger.mig.histology.NecropsyTissue;
import uk.ac.sanger.mig.histology.dao.NecropsyDao;
import uk.ac.sanger.mig.histology.forms.NecropsyForm;
import uk.ac.sanger.mig.mousetracking.Mouse;
import uk.ac.sanger.mig.mousetracking.services.MouseService;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.personnel.Team;
import uk.ac.sanger.mig.personnel.services.PersonService;
import uk.ac.sanger.mig.personnel.services.TeamService;

public class NecropsyServiceImpl extends AbstractServiceImpl<Necropsy> implements NecropsyService {

	private NecropsyDao necropsyDao;
	private NecropsyTissueService necropsyTissueService;
	private EventService eventService;
	private FixationService fixationService;
	private PersonService personService;
	private MouseService mouseService;
	private TeamService teamService;
	private BlockService blockService;

	public void setBlockService(BlockService blockService) {
		this.blockService = blockService;
	}

	public TeamService getTeamService() {
		return teamService;
	}

	public void setTeamService(TeamService teamService) {
		this.teamService = teamService;
	}

	public void setMouseService(MouseService mouseService) {
		this.mouseService = mouseService;
	}

	public void setPersonService(PersonService personService) {
		this.personService = personService;
	}

	public void setFixationService(FixationService fixationService) {
		this.fixationService = fixationService;
	}


	public void setEventService(EventService eventService) {
		this.eventService = eventService;
	}

	public void setNecropsyTissueService(NecropsyTissueService necropsyTissueService) {
		this.necropsyTissueService = necropsyTissueService;
	}

	public void setNecropsyDao(NecropsyDao necropsyDao) {
		this.necropsyDao = necropsyDao;
	}

	public Long store(Necropsy necropsy, Person user) {
		if(necropsy == null) {
			throw new RuntimeException("Cannot save a null necropsy");
		}

		return necropsyDao.store(necropsy, user);
	}

	public Necropsy fetchById(Long necropsyId, ComponentMap requiredComponents) {
		Necropsy necropsy = necropsyDao.fetchById(necropsyId);

		if(necropsy != null)
			attachComponents(necropsy, requiredComponents);

		return necropsy;
	}

	@Override
	protected void attachComponents(Necropsy necropsy, ComponentMap requiredComponents) {
		if(necropsy == null) {
			throw new RuntimeException("Cannot attach components to null necropsy");
		}

		boolean fetchAll = false;

		if(requiredComponents != null) {

			if(requiredComponents.containsKey(Necropsy.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}
			if(fetchAll || requiredComponents.containsKey(Necropsy.Component.NECROPSY_TISSUES)) {
				necropsy.setNecropsyTissues(fetchNecropsyTissues(necropsy, requiredComponents.get(Necropsy.Component.NECROPSY_TISSUES)));
			}

			if(fetchAll || requiredComponents.containsKey(Necropsy.Component.NECROPSY_EVENT)) {
				necropsy.setNecropsyEvents(fetchNecropsyEvents(necropsy, requiredComponents.get(Necropsy.Component.NECROPSY_EVENT)));
			}
			if(fetchAll || requiredComponents.containsKey(Necropsy.Component.TECHNICIAN)) {
				necropsy.setTechnician(fetchNecropsyTechnician(necropsy, requiredComponents.get(Necropsy.Component.TECHNICIAN)));
			}
			if(fetchAll || requiredComponents.containsKey(Necropsy.Component.TEAM)) {
				necropsy.setTeam(fetchTeam(necropsy, requiredComponents.get(Necropsy.Component.TEAM)));
			}
			if(fetchAll || requiredComponents.containsKey(Necropsy.Component.FIXATION)) {
				necropsy.setFixation(fetchFixation(necropsy, requiredComponents.get(Necropsy.Component.FIXATION)));
			}

			if(fetchAll || requiredComponents.containsKey(Necropsy.Component.MOUSE)) {
				necropsy.setMouse(fetchMouse(necropsy.getMouseId(), requiredComponents.get(Necropsy.Component.MOUSE)));
			}

		}
	}

	private Mouse fetchMouse(Long mouseId, ComponentMap componentMap) {
		return mouseService.fetchById(mouseId, componentMap);
	}

	private Fixation fetchFixation(Necropsy necropsy, ComponentMap componentMap) {

		return fixationService.fetchByNecropsyId(necropsy.getId(), componentMap);
	}


	/**
	 * @param necropsy
	 * @param map
	 * @return
	 */
	private Team fetchTeam(Necropsy necropsy, ComponentMap map) {

		return teamService.fetchById(necropsy.getTeamId(), map);
	}


	/**
	 * @param necropsy
	 * @param map
	 * @return
	 */
	private Collection<Event> fetchNecropsyEvents(Necropsy necropsy, ComponentMap map) {

		return eventService.fetchByNecropsyId(necropsy.getId(), map);
	}

	private Person fetchNecropsyTechnician(Necropsy necropsy, ComponentMap map) {

		return personService.fetchById(necropsy.getTechnicianId(), map);
	}


	/**
	 * @param necropsy
	 * @param map
	 * @return
	 */
	private Collection<NecropsyTissue> fetchNecropsyTissues(Necropsy necropsy, ComponentMap requiredComponents) {
		return necropsyTissueService.fetchByNecropsyId(necropsy.getId(), requiredComponents);
	}


	/* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.services.NecropsyService#search(uk.ac.sanger.mig.histology.NecropsySearchBean)
	 */
	public Collection<Necropsy> search(NecropsySearchBean necropsySearchBean) {
		// TODO Auto-generated method stub
		return null;
	}

	public Necropsy fetchByMouseId(Long mouseId, ComponentMap componentMap) {
		Necropsy necropsy = necropsyDao.fetchByMouseId(mouseId);
		if(necropsy != null) {
			attachComponents(necropsy, componentMap);
		}

		return necropsy;
	}


	public Necropsy inflateNecropsyComponents(Necropsy necropsy) {


		if(necropsy == null) {
			throw new RuntimeException("Necropsy cannot be null when inflating components.");
		}

		if(necropsy.getMouse() == null) necropsy.setMouse(new Mouse());
		if(necropsy.getCreator() == null) necropsy.setCreator(new Person());
		if(necropsy.getTechnician() == null) necropsy.setTechnician(new Person());
		if(necropsy.getTeam() == null) necropsy.setTeam(new Team());


		return necropsy;
	}

	@Transactional
	public Long storeNecropsyInfo(NecropsyForm necropsyForm, Person creator) {
		Necropsy necropsy = necropsyForm.getNecropsy();
		Collection<NecropsyTissue> tissues = necropsyForm.getSelectedNecTissues();
		Collection<Event> events = necropsyForm.getNecropsyEvents();
		Collection<Block> blocks = necropsyForm.getExtraBlocks();
		Fixation fixation = new Fixation();
		Long necropsyId;

		if(necropsy == null) {
			throw new RuntimeException("Necropsy cannot be null when storing.");
		}

		necropsy.setMouseId(necropsyForm.getMouse().getId());
		necropsy.setTechnicianId(necropsyForm.getTechnicianId());
		necropsy.setTeamId(necropsyForm.getNecropsy().getTeam().getId());
		necropsy.setReasonDictId(necropsyForm.getNecropsy().getReasonDictId());
		necropsy.setComments(necropsyForm.getComments());
		necropsyId = necropsyDao.store(necropsy, creator);

		for(NecropsyTissue tissue: tissues){
			tissue.setNecropsyId(necropsyId);
			necropsyTissueService.store(tissue, creator);
		}
		for(Event event: events){
			event.setNecropsyId(necropsyId);
			eventService.store(event, creator);
		}
		for(Block block:blocks){
			blockService.store(block,creator);
		}
		if(necropsyForm.getFixationStartDateTime()!=null){
			fixation = necropsyForm.getNecropsy().getFixation();
			fixation.setFixationStartTime(necropsyForm.getFixationStartDateTime());
			fixationService.store(fixation, creator);
		}
		//mark the mouse to be dead in the DB if its still alive
		Mouse mouse = mouseService.fetchById(necropsyForm.getMouseId(), null);
		if(mouse != null && mouse.isAlive()) {

			Calendar mouseDeathDate = Calendar.getInstance();
			mouseDeathDate.setTime(necropsyForm.getFixationStartDateTime());
			mouse.setDeathDate(mouseDeathDate.getTime());
			mouse.setCauseOfDeathDictId(MouseService.CAUSE_OF_DEATH_CULLED);
			mouseService.store(mouse, creator);
		}
		//delete the unwanted tissue records from the DB
		for(NecropsyTissue necropsyTissue:necropsyForm.getNTissuesDelete()) {
			necropsyTissueService.delete(necropsyTissue, creator);
		}
		//delete unwanted events from DB
		for(Event event: necropsyForm.getEventDelete()) {
			eventService.delete(event, creator);
		}

		return necropsyId;
	}

	public Necropsy fetchAllComponentsByMouseId(Long mouseId){
		ComponentMap necropsyMap = new ComponentMap();
		necropsyMap =
			ComponentMap.putAll(
					new ComponentMap(
							Necropsy.Component.NECROPSY_TISSUES,
								ComponentMap.putAll(
										new ComponentMap(NecropsyTissue.Component.TISSUE, null))),

					new ComponentMap(Necropsy.Component.NECROPSY_EVENT,null),
					new ComponentMap(Necropsy.Component.TECHNICIAN,null),
					new ComponentMap(Necropsy.Component.TEAM,null),
					new ComponentMap(Necropsy.Component.FIXATION, ComponentMap.of(Fixation.Component.BLOCKS))
					);
		Necropsy necropsy = this.fetchByMouseId(mouseId, necropsyMap);

		return necropsy;
	}
	/*
	 * create necropsy and fixation record for the given mouse
	 */
	@Transactional
	public Long createNecropsy(Long mouseId, Person creator) {
	  Necropsy necropsy = fetchByMouseId(mouseId, null);
	  Long necropsyId = null;

	  if (necropsy == null) {
  		necropsy = new Necropsy();
  		necropsy.setMouseId(mouseId);

  		necropsyId = store(necropsy, creator);

  		fixationService.createFixation(necropsyId, creator);
	  }
	  else {
	    necropsyId = necropsy.getId();
	  }

		return necropsyId;
	}
}
