package uk.ac.sanger.mig.histology.services;

import java.util.Collection;

import org.springframework.transaction.annotation.Transactional;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.histology.Necropsy;
import uk.ac.sanger.mig.histology.NecropsyTissue;
import uk.ac.sanger.mig.histology.Tissue;
import uk.ac.sanger.mig.histology.dao.NecropsyTissueDao;
import uk.ac.sanger.mig.personnel.Person;

public class NecropsyTissueServiceImpl extends AbstractServiceImpl<NecropsyTissue> implements NecropsyTissueService {
	
	private NecropsyTissueDao necropsyTissueDao;
	private TissueService tissueService;
	private NecropsyService necropsyService;
	
	public void setNecropsyService(NecropsyService necropsyService) {
		this.necropsyService = necropsyService;
	}

	public void setTissueService(TissueService tissueService) {
		this.tissueService = tissueService;
	}
	
	public void setNecropsyTissueDao(NecropsyTissueDao necropsyTissueDao) {
		this.necropsyTissueDao = necropsyTissueDao;
	}

	@Transactional
	public Long store(NecropsyTissue necropsyTissue, Person user) {
		if(necropsyTissue == null) {
			throw new RuntimeException("Cannot save a null necropsyTissue");
		}
		
		return necropsyTissueDao.store(necropsyTissue, user);
	}
	
	public NecropsyTissue fetchById(Long necropsyTissueId, ComponentMap requiredComponents) {
		NecropsyTissue necropsyTissue = necropsyTissueDao.fetchById(necropsyTissueId);
		
		if(necropsyTissue != null)
			attachComponents(necropsyTissue, requiredComponents);
		
		return necropsyTissue;
	}
	

	public Collection<NecropsyTissue> fetchByNecropsyId(Long necropsyId, ComponentMap componentMap) {
		Collection<NecropsyTissue> tissues = necropsyTissueDao.fetchByNecropsyId(necropsyId);
		attachComponents(tissues, componentMap);
		return tissues;
	}

	@Transactional
	public void delete(NecropsyTissue necropsyTissue, Person person) {
		if(necropsyTissue != null) {
			necropsyTissueDao.delete(necropsyTissue, person);
		}else{
			throw new IllegalArgumentException("NecropsyTissue is null.");
		}
	}
	@Override
	protected void attachComponents(NecropsyTissue necropsyTissue, ComponentMap requiredComponents) {
		if(necropsyTissue == null) {
			throw new RuntimeException("Cannot attach components to null necropsyTissue");
		}		
		
		boolean fetchAll = false;
		
		if(requiredComponents != null) {
			
			if(requiredComponents.containsKey(NecropsyTissue.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}
			if(fetchAll || requiredComponents.containsKey(NecropsyTissue.Component.TISSUE)){
				necropsyTissue.setTissue(fetchTissue(necropsyTissue,ComponentMap.of(NecropsyTissue.Component.TISSUE)));
			}
			if(fetchAll || requiredComponents.containsKey(NecropsyTissue.Component.NECROPSY)){
				necropsyTissue.setNecropsy(fetchNecropsy(necropsyTissue,ComponentMap.of(NecropsyTissue.Component.NECROPSY)));
			}
		}
	}
	

	private Necropsy fetchNecropsy(NecropsyTissue necropsyTissue, ComponentMap componentMap) {
	
		return necropsyService.fetchById(necropsyTissue.getNecropsyId(), componentMap);
	}

	private Tissue fetchTissue(NecropsyTissue necropsyTissue, ComponentMap componentMap) {
    	
    	   return tissueService.fetchById(necropsyTissue.getTissueId(), componentMap);
    }
	
}
								