package uk.ac.sanger.mig.histology.services;

import java.util.Collection;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.TimeoutException;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.histology.Slide;
import uk.ac.sanger.mig.histology.forms.PrintSlideCheckbox;
import uk.ac.sanger.mig.personnel.Person;

public interface SlideService {

	public final static Long HTL_SLIDE_PRINTER_ID = 54L;
	public final static int HTL_REPORT_TIME_OUT = 90;

	public boolean gentlyFailAndReorder(Long id, Person user);


	/**
	 * Adds a Slide to scanning bin if it has no already been added.
	 * 
	 * @param slideId
	 * @return TODO
	 */
	public Long addToScanningBin(Long slideId);
	
	/**
	 * Adds a Slide to re-creation bin if it has no already been added.
	 * 
	 * @param slideId
	 * @return TODO
	 */
	public Long addToRecreationBin(Long slideId);
	
	/**
	 * Removes Slide from the Slide rescan bin.
	 * 
	 * @param slideId
	 * @return TODO
	 */
	public Long removeFromScanningBin(Long slideId);
	

	
	/**
	 * Removes Slide from the Slide recreation list.
	 * 
	 * @param slideId
	 * @return TODO
	 */
	public Long removeFromRecreationBin(Long slideId);
	
	/**
	 * Returns a Collection of all Slides awaiting recreation.
	 * 
	 * If componentMap is null, no components will be attached.
	 * 
	 * @param componentMap
	 * @return
	 */
	public Collection<Slide> fetchRecreationBin(ComponentMap componentMap);

	/**
	 * Returns a Collection of all Slides awaiting scanning.
	 * 
	 * If componentMap is null, no components will be attached.
	 * 
	 * @param componentMap
	 * @return
	 */
	public Collection<Slide> fetchScanningBin(ComponentMap componentMap);
	
	
	/**
	 * Recreates the original Slides and removes them from
	 * the Slide Recreation list in database.
	 * 
	 * @param originalSlideIds
	 * @param user
	 * @return
	 */
	public Collection<Slide> recreateAll(Collection<Long> originalSlideIds, Person user);
	
	
	/**
	 * Fails this slide if it has no passed crops. 
	 * 
	 * Any child Scans, as well as any crops they may have, are 
	 * flagged as QC Failed if they are not already passed.
	 * 
	 * @param id
	 * @param user
	 * @return
	 */
	public boolean gentlyFail(Long id, Person user);
	
	/**
	 * Stores a simple Slide object.
	 *   
	 * Throws IllegalArgumentException if slide is null.
	 * 
	 * @param slideScan
	 * @param user
	 * @return
	 */
	public Long store(Slide slide, Person user);


	/**
	 * Returns slide for a given id that maps to primary key
	 * of a record in a database table.
	 * @param id
	 * @return
	 */
	public Slide fetchById(Long id, ComponentMap componentMap);

	/**
	 * Returns Slide object referred to by the given barcode.
	 * @param barcode
	 * @param componentMap
	 * @return
	 */
	public Slide fetchByBarcode(String barcode,  ComponentMap componentMap);

	/**
	 * Returns a collection of Slides for a particular mouse with 
	 * the given search criteria.
	 * 
	 * @param mouseId
	 * @param componentMap
	 * @return
	 */
	public Collection<Slide> fetchByMouseId(Long mouseId, ComponentMap componentMap) ;

	/**
	 * Returns all slides for a block, or an empty collection if the block does not exist.
	 * 
	 * @param blockId
	 * @param componentMap
	 * @return
	 */

	public Collection<Slide> fetchAllByBlockId(Long blockId, ComponentMap map);


	public Collection<Slide> createAll(Collection<PrintSlideCheckbox> checkboxes, Person user);
	
	public Collection<Slide> createDefaultSlides(Long mouseId, Person user);
	
	public void printSlides(Collection<Slide> slides) throws InterruptedException, ExecutionException, TimeoutException ;
	
}