/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.histology.services;

import javax.servlet.ServletOutputStream;

import uk.ac.sanger.mig.histology.Crop;
import uk.ac.sanger.mig.histology.CropProcessingException;
import uk.ac.sanger.mig.histology.Tile;
import uk.ac.sanger.mig.personnel.Person;

public interface TileService {


	/**
	 * Tiles Crop in a pyramid of zoom levels.
	 *
	 * Tiles are stored in database referenced by cropId, zoom level
	 * and Tile Array Index.
	 *
	 *
	 * @param crop
	 * @param user
	 * @throws CropProcessingException
	 */
	public void makeTilePyramid(Crop crop, Person user) throws CropProcessingException;


	/**
	 * Returns default zoom radix--i.e., base to the nth (zoom level) power
	 * for deriving resized resolutions in pyramid.
	 *
	 * @return
	 */
	public int getDefaultZoomRadix();


	/**
	 * Exponent of zoom radix to determine edge length.  For a given zoom radix,
	 * allows resizing on tile-per-tile basis to be guaranteed always
	 * to be evenly divided.
	 *
	 * e.g., radix = 2, exponent = 8, therefore tile = 256x256
	 * Sub-sampling of tile will be 128, 64, etc.
	 *
	 * @return
	 */
	public int getDefaultEdgeExponent();

	/**
	 * Fetches Tile identified by Crop ID, Zoom Level
	 * and
	 *
	 * @return
	 */
	public Tile fetch(Long cropId, int zoomLevel, int arrayIndex);

	/**
	 * Deletes all tiles in database for a given Crop.
	 *
	 * @param cropId
	 */
	public void deleteAllByCropId(Long cropId);

}