package uk.ac.sanger.mig.histology.services;

import java.util.Collection;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.histology.Tissue;
import uk.ac.sanger.mig.personnel.Person;
																
public interface TissueService {
	
	/**
	 * Stores Tissue as record in database and returns the record's primary key
	 * @param tissue
	 * @return
	 */
	public Long store(Tissue tissue, Person person);	
	
	/**
	 * Returns tissue for a given id that maps to primary key
	 * of a record in a database table.
	 * @param id
	 * @return
	 */
	public Tissue fetchById(Long id, ComponentMap componentMap);
	
	
	/**
	 * Takes search bean and returns a Collection of Tissue objects
	 * based on set fields in bean *and* (this is important) your implementation
	 * of search method in Dao layer -- eg, are you testing for equality? 
	 * Greater than/less than, etc?
	 * @param tissueSearchBean
	 * @return
	 */
	//public Collection<Tissue> search(TissueSearchBean tissueSearchBean);
	
	public Collection<Tissue> fetchAll(ComponentMap componentMap);
	
	/**
	 * Takes a block type id and fetches associated tissues for that particular block type.
	 * Note that it will fetch tissues only of the block type id is less than 19 as there are
	 * no specific tissues attached to block types greater than 19.
	 */
	
	public Collection<Tissue> fetchByBlockTypeId(Long blockTypeId);
	
}