package uk.ac.sanger.mig.histology.services;

import java.util.Collection;

import org.springframework.transaction.annotation.Transactional;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.histology.Tissue;
import uk.ac.sanger.mig.histology.dao.TissueDao;
import uk.ac.sanger.mig.personnel.Person;

public class TissueServiceImpl extends AbstractServiceImpl<Tissue> implements TissueService {
	
	private TissueDao tissueDao;
	
	//IMPORTANT: add other dependencies here: Should be other services *not* dao typically
	/**
	 * eg 	private TissueDao tissueDao;
	 *    private MouseService mouseService
	 *    private PersonService personService; 
	 */
	
	public void setTissueDao(TissueDao tissueDao) {
		this.tissueDao = tissueDao;
	}

	@Transactional
	public Long store(Tissue tissue, Person user) {
		if(tissue == null) {
			throw new RuntimeException("Cannot save a null tissue");
		}
		
		return tissueDao.store(tissue, user);
	}
	
	public Tissue fetchById(Long tissueId, ComponentMap requiredComponents) {
		Tissue tissue = tissueDao.fetchById(tissueId);
		if(tissue != null)
			attachComponents(tissue, requiredComponents);
		
		return tissue;
	}

	@Override
	protected void attachComponents(Tissue tissue, ComponentMap requiredComponents) {
		if(tissue == null) {
			throw new RuntimeException("Cannot attach components to null tissue");
		}		
		
		boolean fetchAll = false;
		
		if(requiredComponents != null) {
			
			if(requiredComponents.containsKey(Tissue.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}
		}
	}
	
	public Collection<Tissue> fetchAll(ComponentMap componentMap) {
		Collection<Tissue> tissues = tissueDao.fetchAll();
		
		if(tissues != null){
			attachComponents(tissues, componentMap);
		}
		
		return tissues;
	}

	public Collection<Tissue> fetchByBlockTypeId(Long blockTypeId) {
		
		return tissueDao.fetchByBlockTypeId(blockTypeId);
	}
	
}
								