/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.histology.views;

import java.util.Date;

import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.histology.services.BlockService;

public class BlockListView extends AuthenticatedDataObject {

    private Long id;        
    private Long mouseId;        
    private Long blockTypeId;
    private Long creatorId;       
    private String barcode;        
    private String comments;        
    private Date fixationEndTime;        
    private Long programDictId;        
    private Date programStartTime;        
    private String blockTypeDesc;        
    private boolean standardBlock;
    private Long cassetteTypeDictId;
    private boolean selected;
    private String blockName;
    private String blockTypeName;
    
	public String getBlockTypeName() {
      return blockTypeName;
    }
    public void setBlockTypeName(String blockTypeName) {
      this.blockTypeName = blockTypeName;
    }
  public String getBlockName() {
		return blockName;
	}
	public void setBlockName(String blockName) {
		this.blockName = blockName;
	}
	public boolean isSelected() {
		return selected;
	}
	public void setSelected(boolean selected) {
		this.selected = selected;
	}
	public Long getId() {
		return id;
	}
	public void setId(Long id) {
		this.id = id;
	}
	public Long getMouseId() {
		return mouseId;
	}
	public void setMouseId(Long mouseId) {
		this.mouseId = mouseId;
	}
	public Long getBlockTypeId() {
		return blockTypeId;
	}
	public void setBlockTypeId(Long blockTypeId) {
		this.blockTypeId = blockTypeId;
	}
	public String getBarcode() {
		return barcode;
	}
	public void setBarcode(String barcode) {
		this.barcode = barcode;
	}
	public String getComments() {
		return comments;
	}
	public void setComments(String comments) {
		this.comments = comments;
	}
	public Date getFixationEndTime() {
		return fixationEndTime;
	}
	public void setFixationEndTime(Date fixationEndTime) {
		this.fixationEndTime = fixationEndTime;
	}
	public Long getProgramDictId() {
		return programDictId;
	}
	public void setProgramDictId(Long programDictId) {
		this.programDictId = programDictId;
	}
	public Date getProgramStartTime() {
		return programStartTime;
	}
	public void setProgramStartTime(Date programStartTime) {
		this.programStartTime = programStartTime;
	}
	public String getBlockTypeDesc() {
		return blockTypeDesc;
	}
	public void setBlockTypeDesc(String blockTypeDesc) {
		this.blockTypeDesc = blockTypeDesc;
	}
	public boolean isStandardBlock() {
		return standardBlock;
	}
	public void setStandardBlock(boolean standardBlock) {
		this.standardBlock = standardBlock;
	}
	public Long getCassetteTypeDictId() {
		return cassetteTypeDictId;
	}
	public void setCassetteTypeDictId(Long cassetteTypeDictId) {
		this.cassetteTypeDictId = cassetteTypeDictId;
	}   
    
    public boolean isSoftTissue(){
    	return (this.cassetteTypeDictId.equals(BlockService.SOFT_TISSUE_CASSETTE_DICT_ID));
    }
    
    public boolean isHardTissue(){
    	return(this.cassetteTypeDictId.equals(BlockService.HARD_TISSUE_CASSETTE_DICT_ID));
    }

    public boolean isBrainTissue(){
    	return(this.cassetteTypeDictId.equals(BlockService.BRAINTISSUE_CASSETTE_DICT_ID));
    }
    
    public boolean isEmbryoTissue(){
    	return(this.cassetteTypeDictId.equals(BlockService.EMBRYO_TISSUE_CASSETTE_DICT_ID));
    }
	public Long getCreatorId() {
		return creatorId;
	}
	public void setCreatorId(Long creatorId) {
		this.creatorId = creatorId;
	}

}

   