/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.histology.views;

import java.util.Date;


public class CropView   {

	private Long id;
    private Long mouseId;
    private String mouseBarcode;
    private String fullImagePath;
    private Boolean qcPass;
    private String tissueName;
    private Long tissueId;
    private Long scanId;
    private Long sourceBlockId;
    private String sourceBlockDescription;
    private String slideBarcode;
    private Long slideId;
    private String staining;
    private Long stainingDictId;
    private Date createdDate;
    private Date editDate;

    private String gender;
    private Long genderDictId;

    private String resizedImagePath;
    private int width, height;



    private Long genotypeDictId;
    private String genotypeName;
    private String genotypeAllele;
    private Long alleleId;
    private String alleleName;
    private String geneName;
    private String pipeline;
    private String comments;
    private String annotations;

	public String getComments() {
		return this.comments;
	}

	public void setComments(String comments) {
		this.comments = comments;
	}

	public Long getGenotypeDictId() {
		return this.genotypeDictId;
	}

	public void setGenotypeDictId(Long genotypeDictId) {
		this.genotypeDictId = genotypeDictId;
	}

	public String getGenotypeName() {
		return this.genotypeName;
	}

	public void setGenotypeName(String genotypeName) {
		this.genotypeName = genotypeName;
	}

	public String getGenotypeAllele() {
		return this.genotypeAllele;
	}

	public void setGenotypeAllele(String genotypeAllele) {
		this.genotypeAllele = genotypeAllele;
	}

	public Long getAlleleId() {
		return this.alleleId;
	}

	public void setAlleleId(Long alleleId) {
		this.alleleId = alleleId;
	}

	public String getAlleleName() {
		return this.alleleName;
	}

	public void setAlleleName(String alleleName) {
		this.alleleName = alleleName;
	}

	public String getGeneName() {
		return this.geneName;
	}

	public void setGeneName(String geneName) {
		this.geneName = geneName;
	}

	public String getPipeline() {
		return this.pipeline;
	}

	public void setPipeline(String pipeline) {
		this.pipeline = pipeline;
	}

	public Long getSlideId() {
		return this.slideId;
	}

	public void setSlideId(Long slideId) {
		this.slideId = slideId;
	}

	public String getResizedImagePath() {
		return this.resizedImagePath;
	}

	public void setResizedImagePath(String resizedImagePath) {
		this.resizedImagePath = resizedImagePath;
	}

	public int getWidth() {
		return this.width;
	}

	public void setWidth(int width) {
		this.width = width;
	}

	public int getHeight() {
		return this.height;
	}

	public void setHeight(int height) {
		this.height = height;
	}


	public Date getCreatedDate() {
		return this.createdDate;
	}

    public String getQcStatus() {

    	if( qcPass != null ) {

    		if( qcPass )
    			return "Pass";
    		else
    			return "Fail";

    	} else {
    		return "Awaiting QC";
    	}
    }

	public Long getId() {
		return this.id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public Long getMouseId() {
		return this.mouseId;
	}

	public void setMouseId(Long mouseId) {
		this.mouseId = mouseId;
	}

	public String getMouseBarcode() {
		return this.mouseBarcode;
	}

	public void setMouseBarcode(String mouseBarcode) {
		this.mouseBarcode = mouseBarcode;
	}

	public String getFullImagePath() {
		return this.fullImagePath;
	}

	public void setFullImagePath(String fullImagePath) {
		this.fullImagePath = fullImagePath;
	}

	public Boolean getQcPass() {
		return this.qcPass;
	}

	public void setQcPass(Boolean qcPass) {
		this.qcPass = qcPass;
	}

	public String getTissueName() {
		return this.tissueName;
	}

	public void setTissueName(String tissueName) {
		this.tissueName = tissueName;
	}

	public Long getTissueId() {
		return this.tissueId;
	}

	public void setTissueId(Long tissueId) {
		this.tissueId = tissueId;
	}

	public Long getScanId() {
		return this.scanId;
	}

	public void setScanId(Long scanId) {
		this.scanId = scanId;
	}

	public Long getSourceBlockId() {
		return this.sourceBlockId;
	}

	public void setSourceBlockId(Long sourceBlockId) {
		this.sourceBlockId = sourceBlockId;
	}

	public String getSourceBlockDescription() {
		return this.sourceBlockDescription;
	}

	public void setSourceBlockDescription(String sourceBlockDescription) {
		this.sourceBlockDescription = sourceBlockDescription;
	}

	public String getSlideBarcode() {
		return this.slideBarcode;
	}

	public void setSlideBarcode(String slideBarcode) {
		this.slideBarcode = slideBarcode;
	}

	public String getStaining() {
		return this.staining;
	}

	public void setStaining(String staining) {
		this.staining = staining;
	}

	public Long getStainingDictId() {
		return this.stainingDictId;
	}

	public void setStainingDictId(Long stainingDictId) {
		this.stainingDictId = stainingDictId;
	}

	public Date getEditDate() {
		return this.editDate;
	}

	public void setEditDate(Date editDate) {
		this.editDate = editDate;
	}

	public void setCreatedDate(Date createdDate) {
		this.createdDate = createdDate;
	}

	public String getGender() {
		return this.gender;
	}

	public void setGender(String gender) {
		this.gender = gender;
	}

	public Long getGenderDictId() {
		return this.genderDictId;
	}

	public void setGenderDictId(Long genderDictId) {
		this.genderDictId = genderDictId;
	}

	public String getAnnotations() {
		return this.annotations;
	}

	public void setAnnotations(String annotations) {
		this.annotations = annotations;
	}



}