/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.histology.views;

import java.io.Serializable;
import java.util.Date;

/**
 * @author ae1
 *
 */
public interface SerializableScanView extends Serializable {

	public String getGenotype();

	public void setGenotype(String genotype);

	public abstract String getDisplayableBitmapSize();

	/**
	 * Returns true if the scan has no parent Slide.
	 *
	 * @return
	 */
	public boolean isOrphan();

	public double getWidthScaleFactor();

	public double getHeightScaleFactor();

	public String getAreaDescription();

	public String getThumbnailAreaDescription();

	public String getFileName();

	public String toString();

	public Long getId();

	public void setId(Long id);

	public String getFilePath();

	public void setFilePath(String filePath);

	public int getVersionNumber();

	public void setVersionNumber(int versionNumber);

	public int getWidth();

	public void setWidth(int width);

	public int getHeight();

	public void setHeight(int height);

	public byte[] getThumbnail();

	public void setThumbnail(byte[] thumbnail);

	public int getThumbWidth();

	public void setThumbWidth(int thumbWidth);

	public int getThumbHeight();

	public void setThumbHeight(int thumbHeight);

	public String getStaining();

	public void setStaining(String staining);

	public String getBlockName();

	public void setBlockName(String blockName);

	public String getBlockDescription();

	public void setBlockDescription(String blockDescription);

	public String getMouseBarcode();

	public void setMouseBarcode(String mouseBarcode);

	public Date getSweepDate();

	public void setSweepDate(Date sweepDate);

	public Long getSlideId();

	public void setSlideId(Long slideId);

	public Long getStatusDictId();

	public void setStatusDictId(Long statusDictId);

	public String getStatusDictName();

	public void setStatusDictName(String statusDictName);

}