/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.histology.views;

import java.io.File;
import java.io.Serializable;
import java.util.Date;

/**
 *
 * Encapsulates Scan data in Serializable form.
 *
 * @author ae1
 *
 */
public class SerializableScanViewImpl implements SerializableScanView {

	private static final long serialVersionUID = -1L;


    private Long id;
    private String filePath;
    private int versionNumber;
    private int width;
    private int height;
    private byte[] thumbnail;
    private int thumbWidth;
    private int thumbHeight;
    private String staining;
    private String blockName;
    private String blockDescription;
    private String mouseBarcode;
    private Date sweepDate;
    private Long slideId;
    private Long statusDictId;
    private String statusDictName;
    private String genotype;


    public String getGenotype() {
		return this.genotype;
	}

	public void setGenotype(String genotype) {
		this.genotype = genotype;
	}

	public String getDisplayableBitmapSize() {

      	return Math.round( ( getHeight()  /  Math.pow(1024.0, 2)  ) * getWidth() * 3 ) + " MB";

    }

    /* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#isOrphan()
	 */
    public boolean isOrphan() {
    	return (slideId == null);
    }

    /* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#getWidthScaleFactor()
	 */
    public double getWidthScaleFactor() {

    	return ( (double)getWidth() ) / ( (double)getThumbWidth() );
    }

    /* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#getHeightScaleFactor()
	 */
    public double getHeightScaleFactor() {

		return ( (double)getHeight() ) / ( (double)getThumbHeight() );
    }

    /* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#getAreaDescription()
	 */
    public String getAreaDescription() {
    	return getWidth() + " x " + getHeight();
    }

    /* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#getThumbnailAreaDescription()
	 */
    public String getThumbnailAreaDescription() {
    	return getThumbWidth() + " x " + getThumbHeight();
    }

    /* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#getFileName()
	 */
    public String getFileName() {

    	return new File( getFilePath() ).getName();

    }

    /* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#toString()
	 */
    @Override
    public String toString() {

    	if( ! new Long( 8L ).equals( getStatusDictId() )  )
    		return	getFileName() + ".v" + getVersionNumber();
    	else
    		return	getFileName() + ".v" + getVersionNumber() + "*";//flagged reselect
    }

    /* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#getId()
	 */
    public Long getId() {
        return id;
    }

    /* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#setId(java.lang.Long)
	 */
    public void setId(Long id) {
        this.id = id;
    }
    /* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#getFilePath()
	 */
    public String getFilePath() {
        return filePath;
    }

    /* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#setFilePath(java.lang.String)
	 */
    public void setFilePath(String filePath) {
        this.filePath = filePath;
    }
    /* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#getVersionNumber()
	 */
    public int getVersionNumber() {
        return versionNumber;
    }

    /* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#setVersionNumber(int)
	 */
    public void setVersionNumber(int versionNumber) {
        this.versionNumber = versionNumber;
    }
    /* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#getWidth()
	 */
    public int getWidth() {
        return width;
    }

    /* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#setWidth(int)
	 */
    public void setWidth(int width) {
        this.width = width;
    }
    /* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#getHeight()
	 */
    public int getHeight() {
        return height;
    }

    /* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#setHeight(int)
	 */
    public void setHeight(int height) {
        this.height = height;
    }
    /* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#getThumbnail()
	 */
    public byte[] getThumbnail() {
        return thumbnail;
    }

    /* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#setThumbnail(byte[])
	 */
    public void setThumbnail(byte[] thumbnail) {
        this.thumbnail = thumbnail;
    }
    /* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#getThumbWidth()
	 */
    public int getThumbWidth() {
        return thumbWidth;
    }

    /* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#setThumbWidth(int)
	 */
    public void setThumbWidth(int thumbWidth) {
        this.thumbWidth = thumbWidth;
    }
    /* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#getThumbHeight()
	 */
    public int getThumbHeight() {
        return thumbHeight;
    }

    /* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#setThumbHeight(int)
	 */
    public void setThumbHeight(int thumbHeight) {
        this.thumbHeight = thumbHeight;
    }
    /* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#getStaining()
	 */
    public String getStaining() {
        return staining;
    }

    /* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#setStaining(java.lang.String)
	 */
    public void setStaining(String staining) {
        this.staining = staining;
    }
    /* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#getBlockName()
	 */
    public String getBlockName() {
        return blockName;
    }

    /* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#setBlockName(java.lang.String)
	 */
    public void setBlockName(String blockName) {
        this.blockName = blockName;
    }
    /* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#getBlockDescription()
	 */
    public String getBlockDescription() {
        return blockDescription;
    }

    /* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#setBlockDescription(java.lang.String)
	 */
    public void setBlockDescription(String blockDescription) {
        this.blockDescription = blockDescription;
    }
    /* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#getMouseBarcode()
	 */
    public String getMouseBarcode() {
        return mouseBarcode;
    }

    /* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#setMouseBarcode(java.lang.String)
	 */
    public void setMouseBarcode(String mouseBarcode) {
        this.mouseBarcode = mouseBarcode;
    }

	/* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#getSweepDate()
	 */
	public Date getSweepDate() {
		return this.sweepDate;
	}

	/* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#setSweepDate(java.util.Date)
	 */
	public void setSweepDate(Date sweepDate) {
		this.sweepDate = sweepDate;
	}

	/* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#getSlideId()
	 */
	public Long getSlideId() {
		return this.slideId;
	}

	/* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#setSlideId(java.lang.Long)
	 */
	public void setSlideId(Long slideId) {
		this.slideId = slideId;
	}

	/* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#getStatusDictId()
	 */
	public Long getStatusDictId() {
		return this.statusDictId;
	}

	/* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#setStatusDictId(java.lang.Long)
	 */
	public void setStatusDictId(Long statusDictId) {
		this.statusDictId = statusDictId;
	}

	/* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#getStatusDictName()
	 */
	public String getStatusDictName() {
		return this.statusDictName;
	}

	/* (non-Javadoc)
	 * @see uk.ac.sanger.mig.histology.views.SerializableScanView#setStatusDictName(java.lang.String)
	 */
	public void setStatusDictName(String statusDictName) {
		this.statusDictName = statusDictName;
	}




}