/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.jsptags;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.jsp.tagext.TagSupport;

import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.personnel.Person;

/**
 * This is a simple tag example to show how content is added to the
 * output stream when a tag is encountered in a JSP page. 
 */
public class AccessControlTag extends TagSupport {
	private static final long serialVersionUID = -1770156551393504900L;
		
	private String[] roles;
	private Long recordOwnerId;
	private String[] teams;
	private Boolean test;
	private boolean accessGranted;
	protected Person user;
	private boolean hideHtml;

	public void setTeamNumbers(String commaSeparatedListofTeams) {
		teams = commaSeparatedListofTeams.split(",");
		//guarantee trimmed strings		
		for(int i = 0; i < teams.length; i++) {
			teams[i] = teams[i].trim();
		}	
	}

	public void setRecordOwnerId(Long recordOwnerId) {
		this.recordOwnerId = recordOwnerId;
	}
	
	public void setRoles(String commaSeparatedListofRoles) {		
		roles = commaSeparatedListofRoles.split(",");
		//guarantee trimmed strings
		for(int i = 0; i < roles.length; i++) {
			roles[i] = roles[i].trim();
		}
	}	

	public void setTest(Boolean test) {
		this.test = test;
	}
	
	public void setHideHtml(boolean hideHtml) {
		this.hideHtml = hideHtml;
	}
	
	/**
	 *  doStartTag is called by the JSP container when the tag is encountered
	 */
	public int doStartTag() {
		user = RequestUtils.getUser((HttpServletRequest)pageContext.getRequest());
		checkAccess();
		
		// reverse the outcome of the test f hideHtml is true
		if(hideHtml) {
			accessGranted = !accessGranted;
		}
		
		//return based on the value of accessGranted
		if(accessGranted) {
			return EVAL_BODY_INCLUDE;
		}
		else {
			return SKIP_BODY;
		}	
	}	
	
	/**
	 * doEndTag is called by the JSP container when the tag is closed
	 */
	public int doEndTag(){
		return EVAL_PAGE; //continue eval-ing rest of jsp page
	}
	
	public boolean checkAccess() {
		accessGranted = false;
				
		if(user != null) {
			
			if(roles != null) {
				accessGranted = user.isAuthorised(roles) ? true : false;			
			}
			
			if(!accessGranted) {
				accessGranted = (user.getId().equals(recordOwnerId)) ? true : false;
			}
			
			if(!accessGranted) { 			
				accessGranted = isUserInTeam(teams, user);			
			}			
		}
		
		if(!accessGranted && test != null) {
			accessGranted = test;
		}
		
		return accessGranted;
	}	
	
	private boolean isUserInTeam(String[] teams, Person user) {
		boolean result = false;
		
		if(teams != null && user.getTeam() != null && user.getTeam().getTeamNumber() != null) {
			String userTeam = user.getTeam().getTeamNumber();
			for(String teamName : teams) {
				if(teamName.equalsIgnoreCase(userTeam)) {
					result = true;
					break;
				}
			}
		}		
		
		return result;
	}		

	public boolean isAccessGranted() {
		return accessGranted;
	}


}
