/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.jsptags;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Collection;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.JspWriter;
import javax.servlet.jsp.tagext.TagSupport;

import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.common.LookupListElement;

public class AlphabetLinkTag extends TagSupport {

	private static final long serialVersionUID = -4348274313777921532L;
	private Collection collection;
	
	// Collection of elements to be displayed.
	public void setCollection(Collection collection) {
		this.collection = collection;
	}
	
	@Override
	public int doStartTag() throws JspException {

		JspWriter out = pageContext.getOut();

		StringBuffer buffer = new StringBuffer();
		
		// Array for links on page.
		ArrayList<String> links = new ArrayList<String>();
	
		// Iterate collection and fetch first char of display text.
		// uppercase and add into links if not entered already.
		for(Object o : collection) {
			String s = null;
			if(o instanceof LookupListElement) {
				LookupListElement element = (LookupListElement) o;
				if(element.getDisplayText() != null && element.getDisplayText().length() > 0) {
					s = element.getDisplayText().substring(0,1).toUpperCase();
				}
			}
			else if(o instanceof DictionaryEntry) {
				DictionaryEntry element = (DictionaryEntry)o;
				if(element.getDisplayText() != null && element.getDisplayText().length() > 0) {
					s = element.getDisplayText().substring(0,1).toUpperCase();
				}				
				s = element.getDisplayText().substring(0,1).toUpperCase();
			}
			else{
				throw new JspException("Object must be an instance of LookupListElement or DictionaryEntry: " + o);
			}
			if(!links.contains(s)) {
				links.add(s);				
			}
		}
			
		if(links.size() > 0) {
			buffer.append("<span id='quickLinksHeading' style='font-family: Arial, Sans-Serif;font-size:12px;font-weight:bold;text-align:left;'>Quick Filters</span>");
			buffer.append("<table onmouseover=\"document.body.style.cursor = 'pointer';\" onmouseout=\"document.body.style.cursor = 'default';\"><tr>");
			buffer.append("<td width='5' style='background-color:#f1f1f1; border: 1px solid #777;'><a href=\"javascript:showAll();\" style='font-size:small;font-size:12px; text-decoration:none; color: #000;' >All</a>");
			for(int i = 0; i<links.size(); i++) {
				buffer.append("<td width='5' onclick=\"filterList('"+links.get(i)+"');\" style='background-color:#f1f1f1; border: 1px solid #777;'>");
				buffer.append(links.get(i));
				buffer.append("</td>");
			}
			buffer.append("</tr></table>");
		}
		try {
			out.print(buffer.toString());
		} catch (IOException e) {
			throw new JspException(e.getMessage());
		}

		return EVAL_BODY_INCLUDE;
	}
	
	@Override
	public int doEndTag() throws JspException {	
		return EVAL_PAGE;
	}
}