/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.jsptags;

import java.io.IOException;
import java.lang.reflect.Method;
import java.text.SimpleDateFormat;
import java.util.Date;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.JspWriter;
import javax.servlet.jsp.tagext.TagSupport;

public class DisplayFieldTag extends TagSupport {

	private static final long serialVersionUID = 3125055584017336691L;
	
	private static final SimpleDateFormat sdf = new SimpleDateFormat("dd-MMM-yyyy");
	
	private Object object;
	private String getter;
	private String datatype;
	
	public void setDatatype(String datatype) {
		this.datatype = datatype;
	}

	public void setGetter(String getter) {
		this.getter = getter;
	}

	public void setObject(Object object) {
		this.object = object;
	}

	public int doStartTag() throws JspException {
		JspWriter out = pageContext.getOut();
		String buffer = "";		
			
		Method method = null;
		
		try {
			method = object.getClass().getMethod(getter, new Class[0]);
		}
		catch(NoSuchMethodException e) {
			throw new JspException("No method matching '" + getter + "' in class " + object.getClass().getName());
		}
		
		if(method != null) {
			
			Object result = null;
			
			try { 
				result = method.invoke(object, new Object[0]);
			}
			catch(Exception e) {
				throw new JspException("Failed to invoke " + object.getClass().getName() + "." + getter + "() - " + e);
			}
			
			if(result != null) {
				if(datatype != null && datatype.equals("boolean") && result instanceof Boolean) {
					buffer += ((Boolean)result).booleanValue() ? "Yes" : "No";
				}
				else if(datatype != null && datatype.equals("date") && result instanceof Date) {
					buffer += sdf.format((Date)result);
				}
				else {
					buffer += result.toString();
				}
			}			
		}		
		
		try { 
			out.print(buffer); 
		} 
		catch (IOException e) { 
			throw new JspException(e.getMessage()); 
		}
		
		return SKIP_BODY;
	}
	
	public int doEndTag() throws JspException {
		return EVAL_PAGE; 
	}
}
