/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.jsptags;

import java.io.IOException;
import java.util.Iterator;
import java.util.List;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.JspWriter;
import javax.servlet.jsp.tagext.TagSupport;

import org.springframework.context.MessageSourceResolvable;
import org.springframework.validation.Errors;
import org.springframework.web.servlet.support.JspAwareRequestContext;

public class ErrorListTag extends TagSupport {

	private static final long serialVersionUID = 3030199099278582440L;
	private boolean disabled = false;
	private String width = "100%";
	private String padding = "12px";
	private String align = "center";
	private String id = "errorList";
	private String background = "#f1f1f1";
	private String title = "Validation Error(s)";
	private String titleFont = "15px";
	private String titleColor = "#000";
	private String commandName = null; //form backing object to which errors are bound
	private String formErrorClass ="formError";

	@Override
	public int doStartTag() throws JspException {
		JspAwareRequestContext requestContext = new JspAwareRequestContext(this.pageContext);
		Errors errors = requestContext.getErrors( commandName );

		///requestContext.

		List errorList = errors.getAllErrors();
		if(disabled || errorList.isEmpty()) return SKIP_BODY;

		JspWriter out = this.pageContext.getOut();
		StringBuffer buffer = new StringBuffer();

		buffer.append("<div class=\"errorBox\">");
		buffer.append("<table class=\"errorBox\">");
		buffer.append("<tr>");
		buffer.append("<td class=\"errorBox\">");
		buffer.append("<table class=\"errorBoxInner\">");
		buffer.append("<tr>");
		buffer.append("<td style=\"padding: 0px;\">");

		buffer.append("<table id=\"");
		buffer.append( id );
		buffer.append("\" cellpadding=0 cellspacing=0 align='");
		buffer.append( align );
		buffer.append("' style='width:");
		buffer.append( width );
		buffer.append( ";'><tr>\n");
		buffer.append("<td");
		buffer.append(" style=\"background:");
		buffer.append( background ); buffer.append("; color:");
		buffer.append( titleColor ); buffer.append("; width:");
		buffer.append( width ); buffer.append("; align:");
		buffer.append( align ); buffer.append("; padding:");
		buffer.append( padding ); buffer.append("; font-size:");
		buffer.append( titleFont ); buffer.append(";\">\n");

		if( title != null && !title.equals("") ) {
			buffer.append("<span style='margin-bottom: 4px; font-size: ");
			buffer.append( titleFont ); buffer.append(";'><b>");
			buffer.append( title ); buffer.append("</b></span>\n");
		}

		buffer.append("<ul class='formError'>");

		for( Iterator it = errorList.iterator();  it.hasNext(); ) {
			MessageSourceResolvable objectError = (MessageSourceResolvable)it.next();
			String errorMessage = requestContext.getMessage(objectError);

			buffer.append("<li class='");
			buffer.append( formErrorClass );
			buffer.append("' >\n");

			buffer.append( errorMessage );
			buffer.append("</li>");
		}
		buffer.append("</ul></td></tr></table></td></tr></table></td></tr></table></div>\n");

		try { out.print(buffer.toString()); }
		catch (IOException e) { throw new JspException(e.getMessage()); }
		return EVAL_BODY_INCLUDE;
	}

	@Override
	public int doEndTag() throws JspException {
		return EVAL_PAGE;
	}

	public void setAlign(String align) {
		this.align = align;
	}

	public void setBackground(String background) {
		this.background = background;
	}

	public void setId(String id) {
		this.id = id;
	}

	public void setPadding(String padding) {
		this.padding = padding;
	}

	public void setTitle(String title) {
		this.title = title;
	}

	public void setTitleColor(String titleColor) {
		this.titleColor = titleColor;
	}

	public void setTitleFont(String titleFont) {
		this.titleFont = titleFont;
	}

	public void setWidth(String width) {
		this.width = width;
	}

	public void setDisabled(boolean disabled) {
		this.disabled = disabled;
	}

	public void setCommandName(String commandName) {
		this.commandName = commandName;
	}

	public void setBorderClass(String borderClass) {

	}

	public void setFormErrorClass(String formErrorClass) {
		this.formErrorClass = formErrorClass;
	}

}