package uk.ac.sanger.mig.jsptags;

import java.lang.reflect.Method;
import java.util.Collection;
import java.util.Map;

import org.apache.commons.lang.StringUtils;
import org.apache.commons.lang.math.NumberUtils;
import org.cheffo.jeplite.JEP;
import org.cheffo.jeplite.ParseException;

public class Functions {

	/**
	 * Returns a comma separated list of items from a collection.
	 * If a field name is specified, the corresponding 'get' method will
	 * be invoked on each object in the collection.
	 * If no field name is specified, the toString() method will be invoked
	 * on each object in the collection.
	 * @param collection
	 * @param fieldName
	 * @return String comma separated list of values
	 */
	public static String commaSeparate(Collection collection, String fieldName) {
		String output = "";
		String methodName = "get" + StringUtils.capitalize(fieldName);

		if(collection != null) {
			for(Object o : collection) {
				if(o != null) {
					if(StringUtils.isNotEmpty(fieldName)) {
						try {
							Method m = o.getClass().getMethod(methodName, new Class[0]);
							Object f = m.invoke(o, new Object[0]);
							output += f.toString();
						}
						catch(Exception e) {

						}
					}
					else {
						output += o.toString();
					}
					output += ",";
				}
			}
			output = StringUtils.removeEnd(output, ",");
		}

		return output;
	}

	/**
	 * Method to take 3 params specified construct an expression string for evaluation.
	 * Used for the gui:evalDynamic tag in custom queries.
	 * NB. Only works with numeric expressions.
	 * @param toTest
	 * @param conditionalTest
	 * @param conditionalValue
	 * @return
	 */
	public static boolean evalDynamic(String toTest, String conditionalTest, String conditionalValue, Map<Object, Object> rowData) {

		if(toTest == null || toTest.equals("")){
			return true;
		}
		if(conditionalTest == null || conditionalTest.equals("")) {
			return true;
		}

		String conditionalValueToUse = (NumberUtils.isNumber(conditionalValue)) ? conditionalValue : rowData.get(conditionalValue).toString();

		// create experssion string.
		String evalString = toTest+" "+conditionalTest+" "+conditionalValueToUse;
		// use JepLite ... Java Expression Parser.
		JEP jep = new JEP();
		jep.addStandardFunctions();
		jep.parseExpression(evalString);

		// jep returns values as doubles, hence 1.0 = true, 0.0 = false;
		double retVal = 1.0; // true;
		try {
			retVal = jep.getValue();
		} catch (ParseException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		if(retVal == 1.0) {
			return true;
		}else{
			return false;
		}
	}

}
