/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.jsptags;

import java.io.IOException;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.JspWriter;
import javax.servlet.jsp.tagext.TagSupport;

public class LinkButtonTag extends TagSupport {

	private static final long serialVersionUID = 3100671832538538173L;
	private String href;
	private String onclick;
	private String text;
	private String style;
	private boolean mouseOver = true;
	private String cssClass = "smallButton";
	private String cssClassHover = "smallButtonYellow";
	private boolean disabled = false;
	private String hoverText;
	private String id;
	private String name;

	public void setCssClass(String cssClass) {
		this.cssClass = cssClass;
	}

	public void setDisabled(boolean disabled) {
		this.disabled = disabled;
	}

	public void setMouseOverColor(String mouseOverColor) {

	}

	public void setMouseOver(boolean mouseOver) {
		this.mouseOver = mouseOver;
	}

	public void setHref(String href) {
		this.href = href;
	}

	public void setStyle(String style) {
		this.style = style;
	}

	public void setText(String text) {
		this.text = text;
	}

	public void setHoverText(String hoverText) {
		this.hoverText = hoverText;
	}

	public void setOnclick(String onclick) {
		this.onclick = onclick;
	}

	public void setCssClassHover(String cssClassHover) {
		this.cssClassHover = cssClassHover;
	}

	public void setId(String id) {
		this.id = id;
	}

	public void setName(String name) {
		this.name = name;
	}

	@Override
	public int doStartTag() throws JspException {

		JspWriter out = pageContext.getOut();

		StringBuffer buffer = new StringBuffer();
		String mouseOverString = "";
		if( mouseOver ) {
			mouseOverString = "onMouseOver=\"this.className='"+cssClassHover+"';\" onMouseOut=\"this.className='"+cssClass+"';\"";
		}
		buffer.append("<input ");

		if(id != null) {
			buffer.append("id=\"" + id + "\" ");
		}

		if(name != null) {
			buffer.append("name=\"" + name + "\" ");
		}

		buffer.append(" onclick=\"");
		if(onclick != null) {
			buffer.append(onclick);
		}
		if(href != null) {
			buffer.append(";location.href='");
			buffer.append(href);
			buffer.append("';");
		}

		buffer.append("\"");
		if(style != null) {
			buffer.append(" style='");
			buffer.append(style);
			buffer.append("' ");
		}
		buffer.append(" type='button' value='");
		buffer.append( text );
		buffer.append("' class='");
		if( disabled ) {
			buffer.append( "smallButtonDisabled" );
		} else {
			buffer.append( cssClass );
		}
		buffer.append("' ");
		buffer.append(mouseOverString);
		if(hoverText != null) {
			buffer.append(" title='");
			buffer.append(hoverText);
			buffer.append("' ");
		}

		if( disabled )
			buffer.append(" disabled='disabled'");

		buffer.append("/>\n");

		try {
			out.print(buffer.toString());
		} catch (IOException e) {
			throw new JspException(e.getMessage());
		}

		return EVAL_BODY_INCLUDE;
	}

	@Override
	public int doEndTag() throws JspException {
		return EVAL_PAGE;
	}
}