/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.jsptags;

import java.io.IOException;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.JspWriter;
import javax.servlet.jsp.tagext.TagSupport;

public class MenuPageTag extends TagSupport {

	private static final long serialVersionUID = 8007120310188816382L;
	private String title;
	private String userName;
	private String menuFrame;
	private String mainFrame;
	private String stylesheet = "migMenu";

	public void setTitle(String value) {
		title = value;
	}

	public void setUserName(String value) {
		userName = value;
	}

	public void setMainFrame(String mainFrame) {
		this.mainFrame = mainFrame;
	}

	public void setMenuFrame(String menuFrame) {
		this.menuFrame = menuFrame;
	}

	public void setStylesheet(String value) {
		stylesheet = value;
	}

	public int doStartTag() throws JspException {
		JspWriter out = pageContext.getOut();

		StringBuffer buffer = new StringBuffer();
		buffer.append("<html>");
		buffer.append("<head>");
		buffer.append("<title>");
		buffer.append(title);
		buffer.append("</title>");
		buffer.append("<meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\">");
		if (stylesheet != "")
		{
			buffer.append("<link rel=\"stylesheet\" href=\"");
			buffer.append("css/");
			buffer.append(stylesheet);
			buffer.append(".css\">");
		}
		buffer.append("<script language=\"Javascript\">");
		buffer.append(" function go(menu, content) {");
		buffer.append("   if (content != '') {");
		buffer.append("   parent.");
		buffer.append(mainFrame);
		buffer.append(".location = content;");
		buffer.append("   }");
		buffer.append("   parent.");
		buffer.append(menuFrame);
		buffer.append(".location = menu;");
		buffer.append(" }");
		buffer.append("</script>");
		buffer.append("</head>");

		buffer.append("<body>");
		buffer.append("<table border=\"0\" cellpadding=\"0\" cellspacing=\"0\" width=\"100%\">");
		buffer.append("<tr>");
		buffer.append("<td class=\"mainMenuHeader\">");
		buffer.append("<table width=\"100%\" cellpadding=\"0\" cellspacing=\"0\" border=\"0\">");
		buffer.append("<tr>");
		buffer.append("<td valign=top width=\"65%\" nowrap><img src=\"");
		buffer.append("images/logo.png\" border=\"0\"><font class=\"mainMenuFont\">" + title + "</font></td>");
		buffer.append("<td style=\"vertical-align: bottom; padding-bottom: 3px; text-align: right;\" nowrap>");
		buffer.append("<a href=\"mailto:mig-help@sanger.ac.uk\" target=\"_top\"><font class=\"mainMenuSmallFont\">User Feedback</font></a>");
		buffer.append("<font style=\"color: white\">&nbsp;&nbsp;|&nbsp;&nbsp;</font>");
		buffer.append("<a href=\"logout.do\" target=\"_top\"><font class=\"mainMenuSmallFont\">Log Off ");
		buffer.append(userName);
		buffer.append("&nbsp;&nbsp;</font></a>");

		buffer.append("</tr></table>");
		buffer.append("</td>");
		buffer.append("</tr>");
		buffer.append("</table>");

		try {
			out.print(buffer.toString());
		} catch (IOException e) {
			throw new JspException(e.getMessage());
		}

		return EVAL_BODY_INCLUDE;
	}


	public int doEndTag() throws JspException {
		JspWriter out = pageContext.getOut();
		try {
			out.print("</body>");
			out.print("</html>");
		}
		catch (IOException e) {
			throw new JspException(e.getMessage());
		}
		return EVAL_PAGE;
	}

}
