/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.jsptags;

import java.io.IOException;
import java.util.HashMap;
import java.util.Set;
import java.util.StringTokenizer;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.JspWriter;
import javax.servlet.jsp.tagext.TagSupport;


public class MigBoxTag extends TagSupport {

	private static final long serialVersionUID = -6357274273828269091L;

	private String label;
	private String divId;
	private String height = "";
	private String style = "";

	private HashMap<String,String> links;
	private String linkButtonClass = "smallButton";
	private String linkButtonClassOver = "smallButtonYellow";


	public int doStartTag() throws JspException {
		JspWriter out = pageContext.getOut();
		StringBuffer buffer = new StringBuffer();


		if (divId != null && divId.length() > 0) {
			buffer.append("<div class=\"migBox\" id=\"" + divId + "\" style=\"" + style + "\">\n");
		}
		else {
			buffer.append("<div class=\"migBox\" style=\"" + style + "\">\n");
		}

		if(label != null && label.length() > 0) {
			buffer.append("<div class=\"migBoxHeading\" style=\"" + style + "\">");
			buffer.append( label );
			printButtons( buffer );
			buffer.append("</div>\n");
		} else if(links != null){//buttons only
			printButtons( buffer );
		}

		if (height != "") {
			buffer.append("<table class=\"migBox\" style=\"height: " + height + ";\">\n");
		} else {
			buffer.append("<table class=\"migBox\">\n");
		}
		buffer.append("<tr>\n");
		buffer.append("<td class=\"migBox\">\n");
		try { out.print(buffer.toString()); }
		catch (IOException e) { throw new JspException(e.getMessage()); }
		return EVAL_BODY_INCLUDE;
	}

	@Override
	public int doEndTag() throws JspException {
		JspWriter out = pageContext.getOut();
		StringBuffer buffer = new StringBuffer();
		buffer.append("</td>\n</tr>\n</table>\n</div>\n");
		try { out.print(buffer.toString()); }
		catch (IOException e) { throw new JspException(e.getMessage()); }
		return EVAL_PAGE;
	}

	private HashMap<String,String> parseLinks(String contatenatedString) {
		HashMap<String,String> links = new HashMap<String,String>();
		if(contatenatedString != null && !contatenatedString.equals("")) {
			StringTokenizer st = new StringTokenizer(contatenatedString,";");
			while(st.hasMoreTokens()) {
				String nameUrlPair = st.nextToken();
				StringTokenizer st2 = new StringTokenizer(nameUrlPair,"|");
				String name = "";
				String url = "";
				try { name = st2.nextToken().trim(); }
				catch(Exception e) {}
				try { url = st2.nextToken().trim(); }
				catch(Exception e) {}
				links.put(name,url);
			}//while
		}
		return links;
	}

	private void printButtons(StringBuffer buffer) {
		if(links != null) {
			buffer.append("&nbsp;&nbsp;");
			Set<String> names = links.keySet();
			for(String name : names) {
				String url = links.get( name );
				if( url != null ) {
					if(url.startsWith("onclick=")) {
						url = url.replaceFirst("onclick=", "");
					}
					else {
						url = "location.href='" + url + "';";
					}
					buffer.append("<input type='button' value='" + name + "' class='" + linkButtonClass + "' onclick=\"" + url + "\"  onmouseover=\"this.className='" +
							linkButtonClassOver + "';\"  onmouseout=\"this.className='" +
							linkButtonClass + "';\" />");
				}
			}
		}
	}

	public void setLinkButtonClass(String linkButtonClass) {
		this.linkButtonClass = linkButtonClass;
	}

	public void setLinkButtonClassOver(String linkButtonClassOver) {
		this.linkButtonClassOver = linkButtonClassOver;
	}

	public void setLinks(String linkString) {
		links = parseLinks(linkString);
	}

	public void setHeight(String height) {
		this.height = height;
	}

	public void setStyle(String style) {
		this.style = style;
	}

	public void setLabel(String label) {
		this.label = label;
	}

	public void setDivId(String divId) {
		this.divId = divId;
	}
}