/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.jsptags;

import java.io.IOException;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.JspWriter;
import javax.servlet.jsp.tagext.TagSupport;

public class MigFooterTag extends TagSupport {		

	private static final long serialVersionUID = -8992489731758048236L;
	private String width = "100%"; //default
	private String align = "center"; //default
	private boolean showImage = true;
	private boolean showLinks = true;
	private String barColor = "#999";
	
	public void setBarColor(String barColor) {
		this.barColor = barColor;
	}

	public void setShowImage(boolean showImage) {
		this.showImage = showImage;
	}

	public void setAlign(String align) {
		this.align = align;
	}	
	
	public void setShowLinks(boolean showLinks) {
		this.showLinks = showLinks;
	}

	public void setWidth(String width) {
		this.width = width;
	}
		
	public int doStartTag() throws JspException {	
		JspWriter out = pageContext.getOut();	
		StringBuffer buffer = new StringBuffer();
	
		buffer.append("<div style='margin-top:5px;text-align:");				
		buffer.append( align );
		buffer.append(";'>\n");
		buffer.append("<table style='border:0;width:");
		buffer.append( width );
		buffer.append("'>\n");
		buffer.append("<tr>\n");
		buffer.append("<td style='text-align:");
		buffer.append( align );
		buffer.append(";' vAlign='bottom'>\n");		
		buffer.append("<hr width='100%' color='");
		buffer.append( barColor );
		buffer.append("' size=1 style='color:");
		buffer.append( barColor );
		buffer.append("; margin-top:0px;'>\n");  
		if(showLinks) {	
			buffer.append("<a style='font-size:13px;font-family:arial;font-weight:normal;' href='mailto:team110g@sanger.ac.uk?subject=Team 110 User Feedback'>User Feedback</a>\n");
			buffer.append("&nbsp;&nbsp;|&nbsp;&nbsp; \n");
		    buffer.append("<a style='font-size:13px;font-family:arial;font-weight:normal;' href='http://www.ensembl.org/index.html' target='_blank'>Ensembl Home</a>\n");
			buffer.append("&nbsp;&nbsp;|&nbsp;&nbsp; \n");
			buffer.append("<a style='font-size:13px;font-family:arial;font-weight:normal;' href='http://www.sanger.ac.uk/' target='_blank'>Sanger Home</a>\n");
			buffer.append("&nbsp;&nbsp;|&nbsp;&nbsp; \n");
			buffer.append("<a style='font-size:13px;font-family:arial;font-weight:normal;' href='http://www.sanger.ac.uk/Teams/Team109/' target='_blank'>Mouse Genetics Home</a>\n");
		}  
		
		if(showImage) {
			//	buffer.append("<img src='images/smallMiceDate.png'>");
		}
		
		buffer.append("</td>\n");
		buffer.append("</tr>\n");
		buffer.append("</table>\n");
		buffer.append("</div>\n");	
		try { out.print(buffer.toString()); } 
		catch (IOException e) { throw new JspException(e.getMessage()); }	
		return SKIP_BODY;
	}
	
}