/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.jsptags;

import java.io.IOException;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Set;
import java.util.StringTokenizer;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.JspWriter;
import javax.servlet.jsp.tagext.TagSupport;

public class MigHeaderTag extends TagSupport {		

	private static final long serialVersionUID = -7952270535827894487L;
	private HashMap<String,String> links; //hash name -> url
	private String width = "100%"; //default
	private String align = "center"; //default
	private static final int PADDING = 8; //pixels
	private boolean noMainLink = false; //used to supress the Main Menu link
	
	public void setAlign(String align) {
		this.align = align;
	}
	
	public void setWidth(String width) {
		this.width = width;
	}
	
	public void setLinks(String linkString) {
		links = parseLinks(linkString);
	}
	
	public void setNoMainLink(boolean noMainLink) {
		this.noMainLink = noMainLink;
	}

	public int doStartTag() throws JspException {
		JspWriter out = pageContext.getOut();	
		StringBuffer buffer = new StringBuffer();
		buffer.append("<div style='margin-top:8px;width:100%;'><table align='"+align+"' cellpadding=0 cellspacing=0 \n");
		buffer.append("	style='border: 1px solid #aaa; background:#fff; width:"+width+";'>\n");
		buffer.append("	<tr>\n");
		buffer.append("	<td \n");
		buffer.append("	style='background:#ffffff;font-family: Arial; font-weight:bold;" +
				"letter-spacing: 0.05em; font-size: 16pt; color: #004869;" +
				"padding:"+(PADDING+3)+"px "+PADDING+"px "+PADDING+"px "+PADDING+"px'>\n");
		buffer.append("	<img src='images/wtsi-logo-banner.png' height='16'>\n");
		
		try { out.print(buffer.toString()); } 
		catch (IOException e) { throw new JspException(e.getMessage()); }	
		return EVAL_BODY_INCLUDE;
	}
	
	public int doEndTag() throws JspException {
		JspWriter out = pageContext.getOut();	
		StringBuffer buffer = new StringBuffer();		
		buffer.append("	</td>\n");		
		
		int tableWidth = 150;
		
		if(links != null) {
			tableWidth += (links.size() * 150);
		}
		
		buffer.append("	<td style='" +
				"padding:"+PADDING+"px "+PADDING+"px "+PADDING+"px "+PADDING+"px'>\n");
		buffer.append("	<div align='right'>\n");
		buffer.append("	<table style='width:" + tableWidth + ";background:#e1e1e1; border:0; " +
		"font-size:22; text-align:center;' cellpadding=0 cellspacing=0>\n");
		buffer.append("	<tr>\n");
		
		if(links != null && !links.isEmpty() ) {
			Set<String> fields = links.keySet();
			Iterator i = fields.iterator();
			while( i.hasNext() ) {
				String name = (String)i.next();
				String url = links.get(name);
				buffer.append("	<td style='width:150;border-right:3px solid #fff;padding:1px 6px 4px 6px;'>\n");
				buffer.append("	<a href='"+url+"' style='font-size:13px; font-family:arial;' >"+name+"</a>\n");
				buffer.append("	</td>\n");				
			}
		}
		
		if(!noMainLink) {
			buffer.append("	<td style='width:150;padding:1px 6px 4px 6px;'>\n");
			buffer.append("		<a href='view_main.do' style='font-size:13px;font-family:arial;'>Main Menu</a>\n");
			buffer.append("	</td>\n");
		}
		
		buffer.append("	</tr>\n");
		buffer.append("	</table>\n");
		buffer.append("</div>\n");
		buffer.append("</td>\n");
		
		
		buffer.append("</tr>\n");
		buffer.append("<tr>\n");
		buffer.append("<td colspan='2' style='background-color: #004869; font-size:8px;'>\n");
		buffer.append("&nbsp;\n");
		buffer.append("</td>\n");	
		buffer.append("</tr>\n");
		buffer.append("</table></div>\n");		
		
		try { out.print(buffer.toString()); } 
		catch (IOException e) { throw new JspException(e.getMessage()); }			
		return EVAL_PAGE; 
	}
	
	private HashMap<String,String> parseLinks(String contatenatedString) {	
		HashMap<String,String> links = new HashMap<String,String>();
		if(contatenatedString != null && !contatenatedString.equals("")) {
			StringTokenizer st = new StringTokenizer(contatenatedString,";");
			while(st.hasMoreTokens()) {
				String nameUrlPair = st.nextToken();	
				StringTokenizer st2 = new StringTokenizer(nameUrlPair,"|");
				String name = "";
				String url = "";
				try { name = st2.nextToken().trim(); } 
				catch(Exception e) {}
				try { url = st2.nextToken().trim(); } 
				catch(Exception e) {}	
				links.put(name,url);
			}//while
		}	
		return links;
	}
	
	
	
}