/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.jsptags;

import java.io.IOException;

import javax.servlet.http.HttpSession;
import javax.servlet.jsp.JspException;
import javax.servlet.jsp.JspWriter;
import javax.servlet.jsp.tagext.TagSupport;

import uk.ac.sanger.mig.personnel.Person;

public class MigUserInfoTag extends TagSupport {		

	private static final long serialVersionUID = 3090163487242249763L;
	private String width = "100%"; //default
	private String align = "center"; //default
	private boolean borderTop = false;  //default
	private boolean borderBottom = false;  //default

	
	public int doStartTag() throws JspException {
		JspWriter out = pageContext.getOut();	
		HttpSession session = pageContext.getSession();
		Person user = (Person)session.getAttribute("user");
		String fullName = user.getFullName();
		
		String teamNumber = "";
		String teamName = "";	
		if(user.getTeam() != null) {
			teamNumber = (user.getTeam().getTeamNumber() != null) ? user.getTeam().getTeamNumber() : "";
			teamName = (user.getTeam().getTeamName() != null) ? user.getTeam().getTeamName() : "";
		}
		
		String roomNumber = (user.getRoomNumber() != null) ? user.getRoomNumber() : "";
		String phoneNumber = (user.getPhoneNumber() != null) ? user.getPhoneNumber() : "";
		
		StringBuffer buffer = new StringBuffer();
		buffer.append("<div style='text-align:");
		buffer.append( align );
		buffer.append(";'>");	
		buffer.append("<table style='border:0; ");//eliminate any cascading borders		
		if(borderTop) buffer.append("border-top:1px solid #777; ");
		if(borderBottom) buffer.append("border-bottom:1px solid #777; ");
		buffer.append("width:");
		buffer.append( width );
		buffer.append(";' cellpadding=0 cellspacing=0 align='"+align+"'>");
		buffer.append("<tr>");
		buffer.append("<td width=20% style='font-family:arial;vertical-align:top;padding-bottom:14px;font-face:arial;'><div style='color:#444; font-family:arial; font-size:10px;'>Current User</div>");
		buffer.append("<div style='color:#222; font-weight:bold; font-family:arial; font-size:12px; padding:2px 6px 2px 6px; background:#e1e1e1; margin: 0px 4px 0px 0px;'>");		
		
		buffer.append( fullName );
		buffer.append("</div>");
		buffer.append("	 </td>");
		buffer.append("  <td width=20% style='vertical-align:top;font-family:arial;'>");
		buffer.append(" <div style='color:#444; font-size:10px;margin-left:4px;'>Team</div>");
		buffer.append(" <div style='color:#222; font-weight:bold;  font-family:arial;font-size:12px ;padding:2px 6px 2px 6px; background:#e1e1e1; margin: 0px 4px 0px 4px;'>");
		if( teamNumber.length() > 0 ) {
			buffer.append("	#");
			buffer.append( teamNumber );
			if(teamName.length() > 0) {
				buffer.append(" - ");
				buffer.append(teamName);
			}
		}
		
		buffer.append("  &nbsp;</div>");
		buffer.append("   </td>");
		buffer.append("  <td width=20% style='vertical-align:top;'>");
		buffer.append(" <div style='color:#444; font-size:10px;font-family:arial;margin-left:4px;'>Room</div>");
		buffer.append("    <div style='color:#222; font-weight:bold;font-family:arial; font-size:12px; padding:2px 6px 2px 6px; background:#e1e1e1;margin: 0px 4px 0px 4px;'>");
		buffer.append( roomNumber );
		buffer.append("	 &nbsp;</div>");
		buffer.append("</td>");
		buffer.append("<td width=20% style='vertical-align:top;font-family:arial;'>");
		buffer.append(" <div style='color:#444; font-size:10px;margin-left:4px;'>Phone</div>");
		buffer.append(" <div style='color:#222; font-weight:bold; font-family:arial; font-size:12px; padding:2px 6px 2px 6px; background:#e1e1e1;margin: 0px 0px 0px 4px;'>");
		buffer.append( phoneNumber );
		buffer.append("  &nbsp;</div>");
		buffer.append("   </td>");	
		buffer.append(" </tr>");
		buffer.append("</table></div>");
		
		try { out.print(buffer.toString()); } 
		catch (IOException e) { throw new JspException(e.getMessage()); }	
		return EVAL_BODY_INCLUDE;
	}
	
	
	public void setAlign(String align) {
		this.align = align;
	}

	public void setWidth(String width) {
		this.width = width;
	}
	
	public void setBorderBottom(boolean borderBottom) {
		this.borderBottom = borderBottom;
	}

	public void setBorderTop(boolean borderTop) {
		this.borderTop = borderTop;
	}	
}