/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.jsptags;

import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;

public class ObjectMethodEval {
	
	private String actualReturnValueAsString  = null;
	private String expectedReturnValueAsString = null;
	
	public ObjectMethodEval(Object object, String methodString, String expectedReturnValue) {
	
		if(object != null 
				&& methodString != null 
				&& expectedReturnValue != null) {
			
			this.expectedReturnValueAsString = expectedReturnValue;
			
			try {	
				Method method = object.getClass().getMethod(methodString, (Class[])null);	
				Object returnValue = method.invoke(object, (Object[])null);
				actualReturnValueAsString = returnValue.toString();
			} catch (IllegalAccessException e) {
				e.printStackTrace();
			} catch (SecurityException e) {
				e.printStackTrace();
			} catch (NoSuchMethodException e) {
				e.printStackTrace();
			} catch (IllegalArgumentException e) {
				e.printStackTrace();
			} catch (InvocationTargetException e) {
				e.printStackTrace();
			} 	
		} 
	}
	
	
	
	/**
	 * Returns true if valid method called on valid object returns value 
	 * whose String representation equals expected value
	 * @return
	 */
	public boolean evaluate() {
		return (this.actualReturnValueAsString != null 
				&& this.actualReturnValueAsString.equals(expectedReturnValueAsString));
	}
	
	
	
	
	
}
