/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.jsptags;

import java.io.IOException;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.JspWriter;
import javax.servlet.jsp.tagext.TagSupport;

public class PageHeaderTag extends TagSupport {

	private static final long serialVersionUID = 8507551711774345159L;
	private String name = "";
	private String nameWidth = "";
	private String middle = "";
	private String right = "";
	private String backUrl = "JavaScript:history.back()";
	private boolean showBackUrl = true;
	private boolean showPrintFrame = false;

	public void setName(String value) {
		name = value;
	}

	public void setNameWidth(String value) {
		nameWidth = value;
	}
	public void setMiddle(String value) {
		middle = value;
	}

	public void setRight(String value) {
		right = value;
	}

	public void setBackUrl(String backUrl) {
		this.backUrl = backUrl;
	}

	public void setShowBackUrl(boolean showBackUrl) {
		this.showBackUrl = showBackUrl;
	}

	public void setShowPrintFrame(boolean showPrintFrame) {
		this.showPrintFrame = showPrintFrame;
	}

	@Override
	public int doStartTag() throws JspException {

		JspWriter out = pageContext.getOut();

		StringBuffer buffer = new StringBuffer();

		buffer.append("\n");
		buffer.append("<div class=\"pageHeader\">");
		buffer.append("<table width=\"100%\" border=\"0\">\n");
		buffer.append("<tr valign=\"middle\">\n");
		buffer.append("<td class=\"pageHeader\" width=\"");
		buffer.append(nameWidth);
		buffer.append("\" align=\"left\">");

		//Add print button
		if (showPrintFrame) {
			buffer.append("<img class=\"printFrame\" src=\"images/printIcon.gif\" title=\"Print this frame\" onclick=\"window.print();\" />");
		}

		buffer.append(name);

		try {
			out.print(buffer.toString());
		} catch (IOException e) {
			throw new JspException(e.getMessage());
		}

		return EVAL_BODY_INCLUDE;
	}

	@Override
	public int doEndTag() throws JspException {
		JspWriter out = pageContext.getOut();

		StringBuffer buffer = new StringBuffer();

		buffer.append("</td>\n");

		if (middle != "") {
			buffer.append("<td class=\"pageHeaderMiddle\">");
			buffer.append(middle);
			buffer.append("</td>\n");
		}
		if (right != "") {
			buffer.append("<td class=\"pageHeaderRight\">");
			buffer.append(right);
			buffer.append("</td>\n");
		}

		if(showBackUrl) {
			buffer.append("<td align=\"right\" width=\"40px\"><a href=\"");
			buffer.append(backUrl);
			buffer.append("\"><img title=\"Back\" id=\"backButton\" src=\"images/prev.gif\" /></a></td>");
		}
		buffer.append("</tr>\n");
		buffer.append("</table>\n");
		buffer.append("</div>\n");
		buffer.append("\n");

		try {
			out.print(buffer.toString());
		} catch (IOException e) {
			throw new JspException(e.getMessage());
		}

		return EVAL_PAGE;
	}
}