/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.jsptags;

import java.io.IOException;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.JspWriter;
import javax.servlet.jsp.tagext.TagSupport;

import uk.ac.sanger.mig.common.PaginatedSearchBean;
import uk.ac.sanger.mig.customquery.forms.CustomQueryForm;

public class PaginateTag extends TagSupport {

	private static final long serialVersionUID = 8399161131540026738L;
	private PaginatedSearchBean bean;
	private boolean hideDisplayText = false;

	public void setBean(PaginatedSearchBean bean) {
		this.bean = bean;
	}

	public void setHideDisplayText(boolean hideDisplayText) {
		this.hideDisplayText = hideDisplayText;
	}

	public int doStartTag() throws JspException {

		JspWriter out = pageContext.getOut();
		String output = "";

		// Load js library and populate hidden form fields
		output += "<script src=\"js/paginate.js\"></script>\n";
		output += "<input id=\"sessionId\" name=\"sessionId\" type=\"hidden\" value=\"" + pageContext.getSession().getId() + "\"/>\n";
		output += "<input id=\"newQuery\" name=\"newQuery\"  type=\"hidden\" value=\"" + bean.isNewQuery() + "\"/>\n";
		output += "<input id=\"paginated\" name=\"paginated\" type=\"hidden\" value=\"" + bean.isPaginated() + "\"/>\n";
		output += "<input id=\"allRecords\" name=\"allRecords\" type=\"hidden\" value=\"" + bean.isAllRecords() + "\"/>\n";
		output += "<input id=\"suppressValidation\" name=\"suppressValidation\" type=\"hidden\" value=\"true\"/>\n";
		output += "<input id=\"recordSetOffset\" name=\"recordSetOffset\" type=\"hidden\" value=\"" + bean.getRecordSetOffset() + "\"/>\n";
		output += "<input id=\"recordSetLength\" name=\"recordSetLength\" type=\"hidden\" value=\"" + bean.getRecordSetLength() + "\"/>\n";
		output += "<input id=\"recordSetTotal\" name=\"recordSetTotal\" type=\"hidden\" value=\"" + bean.getRecordSetTotal() + "\"/>\n";
		output += "<input id=\"orderBy\" name=\"orderBy\" type=\"hidden\" value=\"" + bean.getOrderBy() + "\"/>\n";
		output += "<input id=\"orderDesc\" name=\"orderDesc\" type=\"hidden\" value=\"" + bean.isOrderDesc() + "\"/>\n";
		output += "<input id=\"retrieveFromSession\" name=\"retrieveFromSession\" type=\"hidden\" value=\"true\"/>\n";

		if(bean instanceof CustomQueryForm) {
			output += "<input id=\"sessionObjectName\" name=\"sessionObjectName\" type=\"hidden\" value=\"stored_session_customQuery_" + ((CustomQueryForm)bean).getUniqueName() + "\"/>\n";
		}

		if(!hideDisplayText) {
			if(bean.getRecordSetTotal() == 0) {
				output += "<div class=\"listRecordsNumber\">No records found.</div>\n";
			}
			else {
				if(bean.isAllRecords() || !bean.isPaginated()) {
					output  += "<div class=\"listRecordsNumber\">Displaying all " + bean.getRecordSetTotal() + " records</div>\n";
				}
				else if(bean.isSelectedOnly()) {
					output  += "<div class=\"listRecordsNumber\">Displaying " + bean.getSelectedRecordCount() + " selected records</div>\n";
				}
				else {
					output += "<div class=\"listRecordsNumber\">Displaying records " + bean.getRecordSetOffset() + " to ";
					output += (!bean.isPaginated() || (bean.getRecordSetTotal() < (bean.getRecordSetOffset() + bean.getRecordSetLength()))) ? bean.getRecordSetTotal() : bean.getRecordSetOffset() + bean.getRecordSetLength() -1;
					output += " of " + bean.getRecordSetTotal() +"</div>\n";
				}

				if(bean.isPaginated()) {
					output += PaginateTagUtils.navigationBar(bean);
				}
			}
		}
		try {
			out.print(output);
		} catch (IOException e) {
			throw new JspException(e.getMessage());
		}

		return SKIP_BODY;
	}
}