/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.jsptags;

import java.io.IOException;
import java.util.Collection;
import java.util.Iterator;
import java.util.StringTokenizer;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.JspWriter;
import javax.servlet.jsp.tagext.TagSupport;

public class RadioButtonsTag extends TagSupport {		
	
	private static final long serialVersionUID = -4637937312765904534L;
	private Collection collection;
	private String name = "";
	private String defaultValue;
	private String selectedValue;
	private String tokens = "";
	private String onClick = "";
	private String textPosition = "";
	private String style = "";
	
	public String getSelectedValue() {
		return selectedValue;
	}

	
	public void setSelectedValue(String selectedValue) {
		this.selectedValue = selectedValue;
	}

	public void setName(String name) {
		this.name = name;
	}

	public void setCollection(Collection collection) {
		this.collection = collection;
	}
	
	public void setDefaultValue(String defaultValue) {
		this.defaultValue = defaultValue;
	}	
	
	public void setTokens(String tokens) {
		this.tokens = tokens;
	}
	
	public void setOnClick(String onClick) {
		this.onClick = onClick;
	}

	public void setTextPosition(String textPosition) {
		this.textPosition = textPosition;
	}

	public void setStyle(String style) {
		this.style = style;
	}

	public int doStartTag() throws JspException {
		
		JspWriter out = pageContext.getOut();
		
		StringBuffer buffer = new StringBuffer();
		
		if(collection != null) {
			
			boolean isSelectOption = false;
			
			if(collection instanceof RadioButton) {
				isSelectOption = true;
			}
			
			for(Iterator ii = collection.iterator(); ii.hasNext(); ) {
				if(isSelectOption) {
					RadioButton radioButton = (RadioButton)ii.next();			
					addRadioButton(buffer, radioButton);
				}
				else {
					addStringRadioButton(buffer, ii.next().toString());
				}
			}
		}
		
		if(tokens != null && !tokens.equals("")) {
			StringTokenizer st = new StringTokenizer(tokens,";");
			while(st.hasMoreTokens()) {
				String radioButtonString = st.nextToken();
				
				StringTokenizer st2 = new StringTokenizer(radioButtonString,"|");
				String radioButtonDescription = "";
				String radioButtonValue = "";
				try{
					radioButtonDescription = st2.nextToken().trim();
				}
				catch(Exception e) {}
				try {
					radioButtonValue = st2.nextToken().trim();
				}
				catch(Exception e) {
					radioButtonValue = radioButtonDescription;
				}
				SimpleRadioButton radioButton = new SimpleRadioButton(radioButtonValue,radioButtonDescription);
				addRadioButton(buffer, radioButton);
			}//while
		}	

		buffer.append("\n");
		
		try {
			out.print(buffer.toString());
		} 
		catch (IOException e) {
			throw new JspException(e.getMessage());
		}
		
		return SKIP_BODY;
	}
	
	private void addStringRadioButton(StringBuffer buffer, String radioButtonString) {
		addRadioButton(buffer, new SimpleRadioButton(radioButtonString,radioButtonString));
	}
	
	private void addRadioButton(StringBuffer buffer, RadioButton radioButton) {
		
		String radioButtonLabel = radioButton.getRadioButtonDescription();
		String radioButtonValue = radioButton.getRadioButtonValue();
		
		if( !textPosition.toLowerCase().equals("right") )
			buffer.append(radioButtonLabel);
		
		buffer.append("<input type=\"radio\" name=\"");
		buffer.append(name);
		buffer.append("\"");		
		buffer.append(" value=\"");
		buffer.append(radioButtonValue);
		buffer.append("\"");
		
		if( !onClick.equals("") ) {
			buffer.append(" onClick=\"");
			buffer.append(onClick);
			buffer.append("\"");
		}
		
		if( !style.equals("") ) {
			buffer.append(" style=\"");
			buffer.append(style);
			buffer.append("\"");
		}
			
		if(selectedValue == null || selectedValue.equals("")) {
			if(radioButtonValue.equals(defaultValue)) {
				buffer.append(" CHECKED");
			}
		} else {
			if(radioButtonValue.equals(selectedValue)) {
				buffer.append(" CHECKED");
			}			
		}
		buffer.append(">");
		
		if( textPosition.toLowerCase().equals("right") )
			buffer.append(radioButtonLabel);
		buffer.append("\n");
	}
}