/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.jsptags;

import java.io.IOException;
import java.util.Collection;
import java.util.Iterator;
import java.util.Map;
import java.util.StringTokenizer;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.JspWriter;
import javax.servlet.jsp.tagext.TagSupport;

public class SelectOptionsTag extends TagSupport {		
	
	private static final long serialVersionUID = -7782258346156700649L;
	private Collection collection;
	private String defaultValue = null;
	private String tokens = "";
	
	public void setMap(Map map) {
		if(map != null) {
			this.collection = map.values();
		}
	}
	
	public void setCollection(Collection collection) {
		this.collection = collection;
	}
	
	public void setDefaultValue(String defaultValue) {
		this.defaultValue = defaultValue;
	}	
	
	public void setTokens(String tokens) {
		this.tokens = tokens;
	}
	
	public int doStartTag() throws JspException {
		
		JspWriter out = pageContext.getOut();
		
		StringBuffer buffer = new StringBuffer();
		
		if(collection != null) {
			
			for(Iterator ii = collection.iterator(); ii.hasNext(); ) {
				
				Object option = ii.next();
				
				if(option instanceof SelectOption) {			
					addSelectOption(buffer, (SelectOption)option);
				}
				else {
					addStringOption(buffer, option.toString());
				}
			}
		}
		
		if(tokens != null && !tokens.equals("")) {
			StringTokenizer st = new StringTokenizer(tokens,";");
			while(st.hasMoreTokens()) {
				String optionString = st.nextToken();
				
				StringTokenizer st2 = new StringTokenizer(optionString,"|");
				String optionDescription = "";
				String optionValue = "";
				try{
					optionDescription = st2.nextToken().trim();
				}
				catch(Exception e) {}
				try {
					optionValue = st2.nextToken().trim();
				}
				catch(Exception e) {
					optionValue = optionDescription;
				}
				SimpleSelectOption selectOption = new SimpleSelectOption(optionValue,optionDescription);
				addSelectOption(buffer, selectOption);
			}//while
		}	

		buffer.append("\n");
		
		try {
			out.print(buffer.toString());
		} 
		catch (IOException e) {
			throw new JspException(e.getMessage());
		}
		
		return SKIP_BODY;
	}
	
	private void addStringOption(StringBuffer buffer, String stringOption) {
		buffer.append("\n<option value=\"");
		buffer.append(stringOption);
		buffer.append("\"");
		if(stringOption.equals(defaultValue)) {
			buffer.append(" SELECTED");
		}
		buffer.append(">");
		buffer.append(stringOption);
		buffer.append("</option>"); 		
	}
	
	private void addSelectOption(StringBuffer buffer, SelectOption option) {
		buffer.append("\n<option value=\"");
		buffer.append(option.getOptionValue());
		buffer.append("\"");
		if(option.getOptionValue().equals(defaultValue)) {
			buffer.append(" SELECTED");
		}
		buffer.append(">");
		buffer.append(option.getOptionDescription());
		buffer.append("</option>"); 
	}
}