/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.jsptags;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.tagext.TagSupport;

/**
 * This class toggles a page attribute called "rowClass" between two String values:
 * "even" and "odd". Used in conjuction with CSS, this helps render alternate rows
 * (of a table) with different styles.
 *
 * Use within an iterator tag, e.g:
 * <pre>
 * <c:forEach...>
 *   <toggleRowClass />
 *   <tr class="${rowClass}">...</tr>
 * </c:forEach>
 * </pre>
 *
 */
public class ToggleRowClassTag extends TagSupport {

	private static final long serialVersionUID = -4279127709217768523L;

	private static final String ROW_CLASS_ATTRIBUTE = "rowClass";

	private static final String EVEN_CLASS = "even";
	private static final String ODD_CLASS = "odd";
	private static final String HIGHLIGHT_SUFFIX = "Highlight";

	private Long recordId1 = null;
	private Long recordId2 = null;

	private Long recordId3 = null;
	private Long recordId4 = null;

	public void setRecordId1(Long recordId1) {
		this.recordId1 = recordId1;
	}

	public void setRecordId2(Long recordId2) {
		this.recordId2 = recordId2;
	}

	public void setRecordId3(Long recordId3) {
		this.recordId3 = recordId3;
	}

	public void setRecordId4(Long recordId4) {
		this.recordId4 = recordId4;
	}

	public int doStartTag() throws JspException {

		String rowClass = (String)pageContext.findAttribute(ROW_CLASS_ATTRIBUTE);

		if(rowClass!= null && EVEN_CLASS.indexOf(rowClass) == 0) {
			rowClass = ODD_CLASS;
		}
		else {
			rowClass = EVEN_CLASS;
		}

		if(recordId1 != null && recordId1.equals(recordId2)) {
			rowClass += HIGHLIGHT_SUFFIX;
		}

		if(recordId3 != null && (!recordId3.equals(0L)) &&(!recordId3.equals(recordId4))) {
			rowClass += HIGHLIGHT_SUFFIX;
		}

		pageContext.setAttribute(ROW_CLASS_ATTRIBUTE, rowClass);

		return SKIP_BODY;
	}


}