/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.jsptags;

import java.io.IOException;
import java.util.Collection;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.JspWriter;
import javax.servlet.jsp.tagext.TagSupport;

public class TotalRecordsTag extends TagSupport {	

	private static final long serialVersionUID = -6541591291058149552L;
	private Collection collection;
	private String recordType;
	
	
	/**
	 * @param recordType the recordType to set
	 */
	public void setRecordType(String recordType) {
			this.recordType = recordType;
	}

	public void setCollection(Collection collection) {
		this.collection = collection;
	}

	public int doStartTag() throws JspException {
		
		JspWriter out = pageContext.getOut();
		
		StringBuffer buffer = new StringBuffer();
		
		if(recordType == null || recordType.equals("")) {
			recordType = "matching";
		}
		
		int collectionSize = 0;
		
		if(collection != null) {
			collectionSize = collection.size();
		}
		
		String collectionSizeString = "";
		if(collectionSize == 1) {
			collectionSizeString = " " + recordType + " record.";
		}
		else {
			collectionSizeString = " " + recordType + " records.";			
		}
				
		buffer.append("<!-- total-records-tag start -->\n");
		buffer.append("\n");
		
		buffer.append("<div style=\"width: 100%;\"><b>Displaying " + collectionSize + collectionSizeString + "</b></div>\n");

		buffer.append("\n");
		buffer.append("<!-- total-records-tag end -->\n");
		
		try {
			out.print(buffer.toString());
		} catch (IOException e) {
			throw new JspException(e.getMessage());
		}
		
		return SKIP_BODY;
	}
}