/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.licensing;

import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.ComponentEnum;
import uk.ac.sanger.mig.common.LookupListElement;
import uk.ac.sanger.mig.common.LookupListUtil;
import uk.ac.sanger.mig.personnel.Person;

public class PersonalLicence extends AuthenticatedDataObject implements LookupListElement, Cloneable {
	
	public enum Component implements ComponentEnum {
		ALL_COMPONENTS,
		PERSON
	}

	private Person person;
	
	private String licenceNumber;
    private Long personId;           
    private String personName; 
    private String displayText;
    
    @Override
    public PersonalLicence clone() {
    	PersonalLicence clone = new PersonalLicence();
    	
    	clone.setId(getId());    	
    	clone.setPersonId(getPersonId());
    	clone.setPersonName(getPersonName());
    	clone.setDisplayText(getDisplayText());
    	
    	return clone;
    }
	
	public Person getPerson() {
		return person;
	}
	public void setPerson(Person person) {
		this.person = person;
	}
	public String getLicenceNumber() {
		return licenceNumber;
	}
	public void setLicenceNumber(String licenceNumber) {
		this.licenceNumber  = licenceNumber;
	}
	public Long getPersonId() {
		return personId;
	}
	public void setPersonId(Long personId) {
		this.personId = personId;
	}
	public String getPersonName() {
		return personName;
	}
	public void setPersonName(String personName) {
		this.personName = personName;
	}
	public String getDisplayText() {
		if(displayText != null) {
			return displayText;
		}
		else {
			displayText = "";
			if(person  != null) {
				displayText += person.getDisplayText();
			}
			if(licenceNumber != null) {
				displayText += " (" + licenceNumber + ")";
			}
		}
		return displayText;
	}
	public String getElementData() {
		return
			LookupListUtil.format("personalLicenceId", getId()) +
			LookupListUtil.format("personalLicenceNumber", getLicenceNumber()) +
			LookupListUtil.format("personId", getPersonId()) + 
			LookupListUtil.format("personalLicenceDisplayText", getDisplayText());
	}

	public void setDisplayText(String displayText) {
		this.displayText = displayText; 		
	}
	
	public void setElementData(String elementData) {
		// TODO Auto-generated method stub
		
	}
}
