/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.licensing;

import java.sql.Date;
import java.util.Collection;

import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.ComponentEnum;
import uk.ac.sanger.mig.common.LookupListElement;
import uk.ac.sanger.mig.common.LookupListUtil;
import uk.ac.sanger.mig.personnel.Person;

public class ProjectLicence extends AuthenticatedDataObject implements LookupListElement {

	public enum Component implements ComponentEnum {
		ALL_COMPONENTS,
		RESPONSIBLE_PERSON,
		PROTOCOLS
	}

    private String licenceNumber;
    private String title;
    private Date startDate;
    private Date endDate;
    private Long deputy1PersonId;
    private Long deputy2PersonId;
    private Long deputy3PersonId;
    private String displayText;
    private String protocolElementData;

    private Person responsiblePerson;
    private Long responsiblePersonId;

    private Collection<Protocol> protocols;

    public void setProtocols(Collection<Protocol> protocols) {
		this.protocols = protocols;
	}

	public Collection<Protocol> getProtocols() {
		return protocols;
	}

	public Long getResponsiblePersonId() {
        return responsiblePersonId;
    }

    public void setResponsiblePersonId(Long responsiblePersonId) {
        this.responsiblePersonId = responsiblePersonId;
    }

    public String getLicenceNumber() {
        return licenceNumber;
    }

    public void setLicenceNumber(String licenceNumber) {
        this.licenceNumber = licenceNumber;
    }
    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }
    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }
    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }
    public Long getDeputy1PersonId() {
        return deputy1PersonId;
    }

    public void setDeputy1PersonId(Long deputy1PersonId) {
        this.deputy1PersonId = deputy1PersonId;
    }
    public Long getDeputy2PersonId() {
        return deputy2PersonId;
    }

    public void setDeputy2PersonId(Long deputy2PersonId) {
        this.deputy2PersonId = deputy2PersonId;
    }
    public Long getDeputy3PersonId() {
        return deputy3PersonId;
    }

    public void setDeputy3PersonId(Long deputy3PersonId) {
        this.deputy3PersonId = deputy3PersonId;
    }

	public Person getResponsiblePerson() {
		return responsiblePerson;
	}

	public void setResponsiblePerson(Person responsiblePerson) {
		this.responsiblePerson = responsiblePerson;
	}

	public boolean isExpired() {
		if(endDate != null) {
			return endDate.before(new java.util.Date());
		}
		else {
			//assume if no end date the licence is still valid.
			return false;
		}
	}

	/**
	 * Display licence number and title for lookup lists
	 * E.g. "00/1234 Breeding of Transgenic Mice"
	 *
	 * @return licence number and title (if available)
	 */
	public String getDisplayText() {
		String temp = "";
		if(displayText == null) {
			if(isExpired()) {
				temp += "(Expired)";
			}

			if(getLicenceNumber() != null) {
			temp += getLicenceNumber();
			}

			if(title != null) {
				temp += " " + title;
			}
			setDisplayText(temp);
		}

		return displayText;
	}

	/**
	 * Return element data for lookup lists.
	 * <pre>
	 * Data returned and fields mapped are:
	 * getId() --> projectLicenceId
	 * getDisplayText() -->  projectLicenceDisplayText
	 * </pre>
	 * @return element data for lookup list
	 */
	public String getElementData() {
		return LookupListUtil.format("projectLicenceId", getId()) +
			LookupListUtil.format("projectLicenceDisplayText", getDisplayText()) +
			protocolElementData;
	}

	public void setDisplayText(String displayText) {
		this.displayText = displayText;
	}

	public void setElementData(String elementData) {
		// TODO Auto-generated method stub
	}

	public void setProtocolElementData(String protocolElementData) {
		this.protocolElementData = protocolElementData;
	}

	public String getLabelName() {
		String fullName = this.licenceNumber;
		if(this.getResponsiblePerson() != null) {
		fullName = fullName + "-" + this.getResponsiblePerson().getFullName();
		}
		return fullName;
	}
}
