/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.licensing;

import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.ComponentEnum;
import uk.ac.sanger.mig.common.LookupListElement;
import uk.ac.sanger.mig.common.LookupListUtil;

public class Protocol extends AuthenticatedDataObject implements LookupListElement {

	public enum Component implements ComponentEnum {
		ALL_COMPONENTS,
		PROJECT_LICENCE
	}

	private Long projectLicenceId;  
	private ProjectLicence projectLicence;

	private String protocolCode;        
	private String title;      
	private String displayText;
	private boolean harmfulMutant;

	public Long getProjectLicenceId() {
		return projectLicenceId;
	}

	public void setProjectLicenceId(Long projectLicenceId) {
		this.projectLicenceId = projectLicenceId;
	}                                                                                                                                            
	public String getProtocolCode() {
		return protocolCode;
	}

	public void setProtocolCode(String protocolCode) {
		this.protocolCode = protocolCode;
	}                                                                                                                                            
	public String getTitle() {
		return title;
	}

	public void setTitle(String title) {
		this.title = title;
	}

	public ProjectLicence getProjectLicence() {
		return projectLicence;
	}

	public void setProjectLicence(ProjectLicence projectLicence) {
		this.projectLicence = projectLicence;
	}

	/**
	 * Display licence number and title for lookup lists
	 * E.g. "PR01 Protocol Title" or "PR02 Protocol Title (harmful mutant)"
	 * 
	 * @return licence number and title (if available)
	 */
	public String getDisplayText() {
		if(displayText == null) {
			String temp = getProtocolCode();

			if(title != null) {
				temp += " " + title + (isHarmfulMutant() ? " (harmful mutant)" : "");
			}
			setDisplayText(temp);
		}

		return displayText;
	}

	/**
	 * Return element data for lookup lists.
	 * <pre>
	 * Data returned and fields mapped are:
	 * getId() --> protocolId
	 * getDisplayText() -->  protocolDisplayText 
	 * </pre>
	 * @return element data for lookup list
	 */
	public String getElementData() {
		return LookupListUtil.format("protocolId", getId()) +
		LookupListUtil.format("protocolDisplayText", getDisplayText());		
	}

	public void setDisplayText(String displayText) {
		this.displayText = displayText;

	}

	public void setElementData(String elementData) {
		// TODO Auto-generated method stub

	}

	public boolean isHarmfulMutant() {
		return harmfulMutant;
	}

	public void setHarmfulMutant(boolean harmfulMutant) {
		this.harmfulMutant = harmfulMutant;
	}

}
