/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.licensing.controllers;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.bind.ServletRequestBindingException;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.AbstractCancellableFormController;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.licensing.ProjectLicence;
import uk.ac.sanger.mig.licensing.Protocol;
import uk.ac.sanger.mig.licensing.forms.ProcedureMappingForm;
import uk.ac.sanger.mig.licensing.services.ProjectLicenceService;
import uk.ac.sanger.mig.licensing.services.ProtocolService;

public class AddProcedureMappingFormController extends
		AbstractCancellableFormController {

	private DictionaryService dictionaryService;
	private ProjectLicenceService projectLicenceService;
	private ProtocolService protocolService;
	
	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	public void setProjectLicenceService(ProjectLicenceService projectLicenceService) {
		this.projectLicenceService = projectLicenceService;
	}

	public void setProtocolService(ProtocolService protocolService) {
		this.protocolService = protocolService;
	}

	@Override
	protected boolean isFormChangeRequest(HttpServletRequest request) {
		String changeRequest = null;
		
		try{ 
			changeRequest = ServletRequestUtils.getStringParameter(request, "changeForm");
		}
		catch(ServletRequestBindingException e) {			
			
		}
		
		if(changeRequest != null && changeRequest.length() >0) {
			return true;
		}
		else {
			return false;
		}
	}


	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		ProcedureMappingForm form = (ProcedureMappingForm)command;
		
		protocolService.linkToProcedure(form.getProcedure().getId(), form.getProtocol().getId());
		
		return new ModelAndView(getSuccessView());
	}
	
	@Override
	protected Object formBackingObject(HttpServletRequest request) throws Exception {
		ProcedureMappingForm form = (ProcedureMappingForm)createCommand();
		Long procedureDictId = ServletRequestUtils.getRequiredLongParameter(request, "procedureDictId");
		DictionaryEntry procedure = dictionaryService.fetchEntry(DictionaryEnum.MOUSE_PROCEDURE_DICT, procedureDictId);
		
		Protocol protocol = new Protocol();
		protocol.setProjectLicence(new ProjectLicence());
		
		form.setProcedure(procedure);
		form.setProtocol(protocol);		
		
		return form;		
	}

	@Override
	protected Map referenceData(HttpServletRequest request, Object command, Errors errors) throws Exception {
		ProcedureMappingForm form = (ProcedureMappingForm)command;
		Map<String, Object> referenceData = new HashMap<String, Object>();
		
		Collection<ProjectLicence> projectLicences = projectLicenceService.fetchForAddToProcedure(form.getProcedure().getId(), null);		
		referenceData.put("projectLicences", projectLicences);
		
		if(form.getProtocol().getProjectLicence().getId() != null) {
			Collection<Protocol> protocols = protocolService.fetchByProjectLicenceId(form.getProtocol().getProjectLicence().getId(), null);
			referenceData.put("protocols", protocols);
		}
		
		return referenceData;		
	}
}
