/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.licensing.controllers;

import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.AbstractCancellableFormController;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.licensing.ProjectLicence;
import uk.ac.sanger.mig.licensing.Protocol;
import uk.ac.sanger.mig.licensing.forms.ProtocolForm;
import uk.ac.sanger.mig.licensing.services.ProjectLicenceService;
import uk.ac.sanger.mig.licensing.services.ProtocolService;
import uk.ac.sanger.mig.personnel.Person;

public class EditProtocolFormController extends AbstractCancellableFormController {

	private ProtocolService protocolService;
	private ProjectLicenceService projectLicenceService;
	
	public void setProjectLicenceService(ProjectLicenceService projectLicenceService) {
		this.projectLicenceService = projectLicenceService;
	}

	public void setProtocolService(ProtocolService protocolService) {
		this.protocolService = protocolService;
	}

	@Override
	protected Map referenceData(HttpServletRequest request, Object command, Errors errors) throws Exception {
		Map<String, Object> referenceData = new HashMap<String, Object>();
		ProtocolForm form = (ProtocolForm)command;
		
		ProjectLicence projectLicence = projectLicenceService.fetchById(form.getProjectLicenceId(), ComponentMap.of(ProjectLicence.Component.RESPONSIBLE_PERSON));
		referenceData.put("projectLicence", projectLicence);
		
		//Yes/No list
		Map<Boolean, String> yesNo = new HashMap<Boolean, String>();
		yesNo.put(false,"No");	
		yesNo.put(true,"Yes");	
		referenceData.put("yesNo",yesNo);
		
		return referenceData;
	}

	@Override
	protected Object formBackingObject(HttpServletRequest request) throws Exception {
		ProtocolForm form = (ProtocolForm)createCommand();
		Long projectLicenceId = ServletRequestUtils.getRequiredLongParameter(request, "projectLicenceId");
		Long protocolId = ServletRequestUtils.getLongParameter(request, "id");
		
		form.setProjectLicenceId(projectLicenceId);
		
		Protocol protocol = null;
		if(protocolId != null) {
			protocol = protocolService.fetchById(protocolId, null);
		}
		
		if(protocol == null) {
			protocol = new Protocol();
		}
		
		protocol.setProjectLicenceId(projectLicenceId);
		form.setProtocol(protocol);
		
		return form;
	}

	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		ProtocolForm form = (ProtocolForm)command;
		
		Person user = RequestUtils.getUser(request);
		Protocol protocol = form.getProtocol();
		protocolService.store(protocol, user);
		
		return new ModelAndView(getSuccessView() + "?id=" + form.getProjectLicenceId());
	}

}
