/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.licensing.controllers;

import java.util.Collection;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.ParameterizableViewController;

import uk.ac.sanger.mig.common.LookupListUtil;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.licensing.ProjectLicence;
import uk.ac.sanger.mig.licensing.Protocol;
import uk.ac.sanger.mig.licensing.services.ProjectLicenceService;
import uk.ac.sanger.mig.licensing.services.ProtocolService;
import uk.ac.sanger.mig.personnel.Person;

public class ProjectLicenceLookupListController extends ParameterizableViewController {

	private ProjectLicenceService projectLicenceService;
	private ProtocolService protocolService;

	public void setProjectLicenceService(ProjectLicenceService projectLicenceService) {
		this.projectLicenceService = projectLicenceService;
	}

	public void setProtocolService(ProtocolService protocolService) {
		this.protocolService = protocolService;
	}

	@Override
	protected ModelAndView handleRequestInternal(HttpServletRequest request, HttpServletResponse response) throws Exception {
		Long personId = ServletRequestUtils.getLongParameter(request, "personId");
		Long personalLicenceId = ServletRequestUtils.getLongParameter(request, "personalLicenceId");
		Long procedureId = ServletRequestUtils.getLongParameter(request, "procedureId");

		Collection<ProjectLicence> elements = null;

		if(personId != null) {
			elements = projectLicenceService.fetchByLicenceHolder(personId, null);
		}
		else if(personalLicenceId != null && procedureId != null) {
			elements = projectLicenceService.fetchByPersonalLicenceAndProcedureId(personalLicenceId, procedureId, null);
		}
		else if(personalLicenceId != null) {
			elements = projectLicenceService.fetchByPersonalLicenceId(personalLicenceId, null);
		}
		else {
			Person user = RequestUtils.getUser(request);
			elements = projectLicenceService.fetchByLicenceHolder(user.getId(), null);
		}

		if(elements != null && procedureId != null) {
			attachDefaultProtocols(elements, procedureId);
		}

		return new ModelAndView(getViewName(), "model", elements);
	}

	private void attachDefaultProtocols(Collection<ProjectLicence> licences, Long protocolId) {
		for(ProjectLicence licence : licences) {
			Collection<Protocol> protocols = protocolService.fetchByProcedureAndProject(protocolId, licence.getId(), null);
			if(protocols.size() == 1) {
				Protocol protocol = protocols.iterator().next();
				licence.setProtocolElementData(
						LookupListUtil.format("protocolId", protocol.getId()) +
						LookupListUtil.format("protocolDisplayText", protocol.getDisplayText())
						);
			}
		}
	}
}
