/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.licensing.dao;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.licensing.ProjectLicence;

public class ProjectLicenceDaoSpringImpl extends AbstractDaoSpringImpl<ProjectLicence>
	implements ProjectLicenceDao {

	public Collection<ProjectLicence> fetchByPersonalLicenceId(Long personalLicenceId) {
		String sql =
			"select pj.* " +
			" from " +
			"  lic_project_licence pj, " +
			"  lic_project_2_personal_licence pj2pr, " +
			"  lic_personal_licence pr " +
			" where " +
			"  pj.project_licence_id = pj2pr.project_licence_id and " +
			"  pr.personal_licence_id = pj2pr.personal_licence_id and " +
			"  pr.personal_licence_id = ? " +
			" order by pj.licence_number ";

		Collection<ProjectLicence> licences = null;
		licences = getSimpleJdbcTemplate().query(sql, getRowMapper(), personalLicenceId);
		return (licences != null) ? licences : new ArrayList<ProjectLicence>();
	}

	public Collection<ProjectLicence> fetchByPersonalLicenceAndProcedureId(Long personalLicenceId, Long procedureId) {
		String sql =
			" select ppl.* " +
			" from " +
			"  lic_project_licence ppl, " +
			"  lic_project_2_personal_licence link1, " +
			"  lic_protocol_19b p19b, " +
			"  lic_procedure_2_protocol link2 " +
			" where " +
			"  ppl.project_licence_id = link1.project_licence_id and " +
			"  link1.personal_licence_id = ? and " +
			"  ppl.project_licence_id = p19b.project_licence_id and " +
			"  p19b.id = link2.protocol_id and " +
			"  link2.procedure_dict_id = ? " +
			" order by ppl.licence_number ";

		Collection<ProjectLicence> licences = null;
		licences = getSimpleJdbcTemplate().query(sql, getRowMapper(), personalLicenceId, procedureId);
		return (licences != null) ? licences : new ArrayList<ProjectLicence>();
	}

	public Collection<ProjectLicence> fetchByLicenceHolder(Long personId) {
		String sql =
			"select pj.* " +
			" from " +
			"  lic_project_licence pj, " +
			"  lic_project_2_personal_licence pj2pr, " +
			"  lic_personal_licence pr " +
			" where " +
			"  pj.project_licence_id = pj2pr.project_licence_id and " +
			"  pr.personal_licence_id = pj2pr.personal_licence_id and " +
			"  pr.person_id = ? " +
			" order by pj.licence_number ";

		Collection<ProjectLicence> licences = null;
		licences = getSimpleJdbcTemplate().query(sql, getRowMapper(), personId);
		return (licences != null) ? licences : new ArrayList<ProjectLicence>();
	}

	public Collection<ProjectLicence> fetchAll() {
		Collection<ProjectLicence> licences = null;
		String sql = " select * from lic_project_licence order by licence_number ";
		licences = getSimpleJdbcTemplate().query(sql, getRowMapper());
		return (licences != null) ? licences : new ArrayList<ProjectLicence>();
	}

	public Collection<ProjectLicence> fetchCurrent() {
		Collection<ProjectLicence> licences = null;
		String sql = " select * from lic_project_licence where (end_date >= sysdate or end_date is null) order by licence_number ";
		licences = getSimpleJdbcTemplate().query(sql, getRowMapper());
		return (licences != null) ? licences : new ArrayList<ProjectLicence>();
	}


	/**
	 * Returns the ProjectLicence object with the passed licence number. The licence number must not have
	 * an end_date to qualify.
	 *
	 * @param projectLicence - string such as '80/2163'.
	 * @return licence - the ProjectLicence which may be null if nothing was found.
	 */
	public ProjectLicence fetchByLicenceNumber(String licenceNumber) {
		String sql = "select * from lic_project_licence where licence_number = ?";
		return fetchOne(sql, licenceNumber);
	}


	public Collection<ProjectLicence> fetchForAddToProcedure(Long procedureDictId) {
	  String sql =
  	  "select l.* from " +
  	  "lic_project_licence l, " +
  	  "mts_procedure_dict pd " +
  	  "where pd.id = ? " +
  	  "and (not exists ( " +
  	  "  select null " +
  	  "  from lic_protocol_19b b, lic_procedure_2_protocol x " +
  	  "  where x.protocol_id = b.id and " +
  	  "  b.project_licence_id = l.project_licence_id and " +
  	  "  b.harmful_mutant = 0 and " +
  	  "  x.procedure_dict_id = pd.id " +
  	  " ) " +
  	  " or not exists ( " +
  	  "  select null " +
  	  "  from lic_protocol_19b b, lic_procedure_2_protocol x  " +
  	  "  where x.protocol_id = b.id and " +
  	  "  b.project_licence_id = l.project_licence_id and  " +
  	  "  b.harmful_mutant = 1 and " +
  	  "  x.procedure_dict_id = pd.id"  +
  	  " ) " +
  	  ")";

		Collection<ProjectLicence> licences = null;
		licences = getSimpleJdbcTemplate().query(sql, getRowMapper(), procedureDictId);
		return (licences != null) ? licences : new ArrayList<ProjectLicence>();
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, ProjectLicence projectLicence) {
		sql.addLongParam(projectLicence.getResponsiblePersonId(), "RESPONSIBLE_PERSON_ID");
		sql.addStringParam(projectLicence.getLicenceNumber(), "LICENCE_NUMBER");
		sql.addStringParam(projectLicence.getTitle(), "TITLE");
		sql.addDateParam(projectLicence.getStartDate(), "START_DATE");
		sql.addDateParam(projectLicence.getEndDate(), "END_DATE");
		sql.addLongParam(projectLicence.getDeputy1PersonId(), "DEPUTY1_PERSON_ID");
		sql.addLongParam(projectLicence.getDeputy2PersonId(), "DEPUTY2_PERSON_ID");
		sql.addLongParam(projectLicence.getDeputy3PersonId(), "DEPUTY3_PERSON_ID");
		sql.addLongParam(projectLicence.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(projectLicence.getCreatedDate(), "CREATED_DATE");
		sql.addStringParam(projectLicence.getEditedBy(), "EDITED_BY");
		sql.addDateParam(projectLicence.getEditDate(), "EDIT_DATE");
		sql.addLongParam(projectLicence.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(projectLicence.getId(), "PROJECT_LICENCE_ID");
	}
}
