/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.licensing.services;

import java.util.Collection;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.licensing.PersonalLicence;
import uk.ac.sanger.mig.licensing.ProjectLicence;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.phenotyping.datacapture.StdOperatingProcedure;

public interface PersonalLicenceService {

	/**
	 * Returns personalLicence for a given id that maps to primary key of a record in a database
	 * table.
	 *
	 * @param id
	 * @return
	 */
	public PersonalLicence fetchByPersonId(Long personId, ComponentMap componentMap);


	public PersonalLicence fetchById(Long id, ComponentMap componentMap);


	public Long store(PersonalLicence personalLicence, Person user);


	public int linkToPpl(Long personalLicenceId, Long projectLicenceId);


	public int clearLinksToPpls(Long personalLicenceId);


	public Collection<PersonalLicence> fetchCurrent(ComponentMap requiredComponents);


	public PersonalLicence fetchByPersonalLicenceNumber(String personalLicenceNumber, ComponentMap requiredComponents);


	/**
	 * Returns true if the person with the personal licence (PIL) and the project licence (PPL) can
	 * work on the passed standard operating procedure.
	 *
	 * @param pil -
	 *            the persons personal licence.
	 * @param ppl -
	 *            the project licence.
	 * @param sop -
	 *            the standard operating procedure associated with the procedure.
	 * @return true - if the pil and project are licenced to carry out the procedure, otherwise
	 *         false.
	 */
	public boolean isLicenced(PersonalLicence pil, ProjectLicence ppl, StdOperatingProcedure sop);

}
