/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.licensing.services;

import java.util.Collection;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.licensing.Protocol;
import uk.ac.sanger.mig.mousetracking.Mouse;
import uk.ac.sanger.mig.personnel.Person;

public interface ProtocolService {

	public Collection<Protocol> fetchByProjectLicenceId(Long projectLicenceId, ComponentMap requriedComponents);

	public Protocol fetchById(Long id, ComponentMap requiredComponents);

	public Protocol fetchByProcedureAndProject(Long procedureId, Long projectId, boolean isHarmfulMutant, ComponentMap requiredComponents);

	public Collection<Protocol> fetchByProcedureAndProject(Long procedureId, Long projectId, ComponentMap requiredComponents);

	public Collection<Protocol> fetchByProcedureId(Long procedureId, ComponentMap requriedComponents);

	public int linkToProcedure(Long procedureId, Long protocolId);

	public int unlinkFromProcedure(Long procedureId, Long protocolId);

	public Long store(Protocol protocol, Person user);

	/**
	 * This method evaluates whether a 19b is required for a mouse based on its embryonic stage and transgenic status.
	 * In order to evalute correctly, the mouse's Litter, Alleles and ChimericData objects should be attched.
	 * @param mouse the mouse to be evaluated
	 * @return true if the mouse should have an assoicated 19b.
	 */
	public boolean is19bRequired(Mouse mouse);
}
