/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.licensing.validators;

import org.springframework.validation.Errors;
import org.springframework.validation.ValidationUtils;

import uk.ac.sanger.mig.common.AbstractBindingValidator;
import uk.ac.sanger.mig.licensing.forms.ProtocolForm;

public class ProtocolFormValidator extends AbstractBindingValidator {

	private ProtocolValidator protocolValidator;

	public void setProtocolValidator(ProtocolValidator protocolValidator) {
		this.protocolValidator = protocolValidator;
	}

	@Override
	public boolean supports(Class clazz) {
		return ProtocolForm.class.equals(clazz);
	}

	@Override
	protected void validate(Object target, Errors errors, boolean hasBindingErrors) {
		ProtocolForm protocolForm = (ProtocolForm)target;
		try{
			errors.pushNestedPath("protocol");
			ValidationUtils.invokeValidator(protocolValidator, protocolForm.getProtocol(), errors);
		}
		finally {
			errors.popNestedPath();
		}
	}

}
