/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.login;

import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;


/**
 * A Utility class to allow passwords to be 1-way hashed for storage and comparison
 * in a database table.
 * 
 * @author dgm
 *
 */
public class PasswordHasher {

	private static final Log logger = LogFactory.getLog(PasswordHasher.class);
	private MessageDigest md;

	private static char int2hex[] = { '0', '1', '2', '3', '4', '5', '6', '7', '8',
		                              '9', 'a', 'b', 'c', 'd', 'e', 'f'};
	
	public PasswordHasher(String scheme) {
		try {
			md = MessageDigest.getInstance(scheme);
		} catch(NoSuchAlgorithmException e) {
			logger.fatal(e);
		}
	}
	
	private String byteToHexString(byte[] data){
		StringBuffer res = new StringBuffer();
		
		for(int i=0; i< data.length; i++) {
			int unib = (data[i] >> 4) & 0xF;
			int lnib = data[i] & 0xF;
			
			res.append(int2hex[unib]);
			res.append(int2hex[lnib]);
		}
		return new String(res);
	}

	/**
	 * Convert a supplied string into a repeatable 1-way hash. The typical use for this is to
	 * allow storage of a password in a non human-readable format that can later be used to
	 * verify that a password is correct.
	 * @param password
	 * @return
	 */
	public String doHash(String string) {
		// no null passwords
		
		if (null == string)
			return null;

		/*
		 * Get the digest of the clear text password. This is actually
		 * stored in the remote database.
		 */
		md.update(string.getBytes());
		String pwDigest = byteToHexString(md.digest());
		md.reset();
		
		return pwDigest;
	}
}