/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.microscopy;

import java.util.Collection;

import uk.ac.sanger.mig.annotation.Annotation;
import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.ComponentEnum;
import uk.ac.sanger.mig.common.DictionaryEntry;

/**
 * Writable extension to readonly MetaData object.
 *
 * @author ae1
 *
 */
public class MetaData extends AuthenticatedDataObject  {

	public enum Component implements ComponentEnum {
		ALL_COMPONENTS,
		READ_ONLY_META_DATA,
		ANNOTATIONS,
		CREATOR;
	}

    private Long readOnlyMetaDataId;
    private ReadOnlyMetaData readOnlyMetaData;
    private Boolean primaryForTissue;
    private Boolean qcPass;
    private Collection<Annotation> annotations;
    private Long tissueDictId;
    private DictionaryEntry tissueDict;
    private Long descriptionDictId;
    private DictionaryEntry descriptionDict;
    private String comments;
    private String convertedImagePath;
    private String imageUrl; //derived from convertedImagePath and service-injected root url dir
    private int imageWidth, imageHeight;

    //flat view only
    private String pipeline;
    private Long pipelineId;
    private String geneName;
    private Long geneId;
    private String alleleSuperscript;
    private Long alleleId;
    private String genotype;
    private Long genotypeId;
    private String gender;
    private Long genderDictId;
    private String ageAtDeath;
    private boolean genotypeLocked;

    //add stain type fields

	public boolean isGenotypeLocked() {
		return this.genotypeLocked;
	}

	public void setGenotypeLocked(boolean genotypeLocked) {
		this.genotypeLocked = genotypeLocked;
	}

	public Long getGenderDictId() {
		return this.genderDictId;
	}

	public void setGenderDictId(Long genderDictId) {
		this.genderDictId = genderDictId;
	}

	public String getAgeAtDeath() {
		return ageAtDeath;
	}

	public void setAgeAtDeath(String age) {
		this.ageAtDeath = age;
	}

	public String getGender() {
		return gender;
	}

	public void setGender(String gender) {
		this.gender = gender;
	}

	public String getAlleleSuperscript() {
		return this.alleleSuperscript;
	}

	public void setAlleleSuperscript(String alleleSuperscript) {
		this.alleleSuperscript = alleleSuperscript;
	}

	public Long getGeneId() {
		return this.geneId;
	}

	public void setGeneId(Long geneId) {
		this.geneId = geneId;
	}

	public String getGeneName() {
		return this.geneName;
	}

	public void setGeneName(String geneName) {
		this.geneName = geneName;
	}

	public String getGenotype() {
		return this.genotype;
	}

	public void setGenotype(String genotype) {
		this.genotype = genotype;
	}



	public Long getAlleleId() {
		return this.alleleId;
	}

	public void setAlleleId(Long alleleId) {
		this.alleleId = alleleId;
	}

	public Long getGenotypeId() {
		return this.genotypeId;
	}

	public void setGenotypeId(Long genotypeId) {
		this.genotypeId = genotypeId;
	}

	public String getPipeline() {
		return this.pipeline;
	}

	public void setPipeline(String pipeline) {
		this.pipeline = pipeline;
	}

	public Long getPipelineId() {
		return this.pipelineId;
	}

	public void setPipelineId(Long pipelineId) {
		this.pipelineId = pipelineId;
	}

	public int getImageHeight() {
		return this.imageHeight;
	}

	public void setImageHeight(int imageHeight) {
		this.imageHeight = imageHeight;
	}

	public int getImageWidth() {
		return this.imageWidth;
	}

	public void setImageWidth(int imageWidth) {
		this.imageWidth = imageWidth;
	}

	public String getImageUrl() {
		return this.imageUrl;
	}

	public void setImageUrl(String imageUrl) {
		this.imageUrl = imageUrl;
	}

	public Collection<Annotation> getAnnotations() {
		return this.annotations;
	}

	public void setAnnotations(Collection<Annotation> annotations) {
		this.annotations = annotations;
	}

	public ReadOnlyMetaData getReadOnlyMetaData() {
		return this.readOnlyMetaData;
	}

	public void setReadOnlyMetaData(ReadOnlyMetaData readOnlyMetaData) {
		this.readOnlyMetaData = readOnlyMetaData;
	}

	public Long getReadOnlyMetaDataId() {
		return this.readOnlyMetaDataId;
	}

	public void setReadOnlyMetaDataId(Long readOnlyMetaDataId) {
		this.readOnlyMetaDataId = readOnlyMetaDataId;
	}

	public String getConvertedImagePath() {
        return convertedImagePath;
    }

    public void setConvertedImagePath(String convertedImagePath) {
        this.convertedImagePath = convertedImagePath;
    }

    public Boolean getPrimaryForTissue() {
        return primaryForTissue;
    }

    public void setPrimaryForTissue(Boolean primaryForTissue) {
        this.primaryForTissue = primaryForTissue;
    }
    public Boolean getQcPass() {
        return qcPass;
    }

    public void setQcPass(Boolean qcPass) {
        this.qcPass = qcPass;
    }


	public DictionaryEntry getTissueDict() {
		return this.tissueDict;
	}

	public void setTissueDict(DictionaryEntry tissueDict) {
		this.tissueDict = tissueDict;
	}

	public Long getTissueDictId() {
		return this.tissueDictId;
	}

	public void setTissueDictId(Long tissueDictId) {
		this.tissueDictId = tissueDictId;
	}

	public String getComments() {
		return this.comments;
	}

	public void setComments(String comments) {
		this.comments = comments;
	}

	public DictionaryEntry getDescriptionDict() {
		return this.descriptionDict;
	}

	public void setDescriptionDict(DictionaryEntry descriptionDict) {
		this.descriptionDict = descriptionDict;
	}

	public Long getDescriptionDictId() {
		return this.descriptionDictId;
	}

	public void setDescriptionDictId(Long descriptionDictId) {
		this.descriptionDictId = descriptionDictId;
	}



}