/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.microscopy.controllers;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.alleles.Allele;
import uk.ac.sanger.mig.alleles.services.AlleleService;
import uk.ac.sanger.mig.common.AbstractSearchFormController;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.microscopy.MetaData;
import uk.ac.sanger.mig.microscopy.MetaDataSearchBean;
import uk.ac.sanger.mig.microscopy.services.MetaDataService;


public class ListMetaDataController extends AbstractSearchFormController {

	private MetaDataService metaDataService;
	private AlleleService alleleService;
	private DictionaryService dictionaryService;

	@Override
	protected ModelAndView onSearch(HttpServletRequest request, HttpServletResponse response,
			Object command, BindException errors) throws Exception {

		MetaDataSearchBean searchBean = (MetaDataSearchBean)command;
		Collection<MetaData> metas = null;
		if( searchBean.getAlleleId() != null ) {
			metas = metaDataService.searchGenotyped(searchBean);
		}
		Allele allele = alleleService.fetchById(searchBean.getAlleleId(), ComponentMap.of(Allele.Component.GENE ));
		DictionaryEntry pipeline = dictionaryService.fetchEntry(
				DictionaryEnum.MOUSE_COHORT_PIPELINE, searchBean.getPipelineId());
		Map<String, Object> map = referenceData(request);
		map.put("metas", metas);
		map.put("metasCount", (metas == null) ? 0 : metas.size() );
		map.put("pipeline", pipeline);
		map.put("allele", allele);
		return new ModelAndView(getSuccessView(), map);
	}

	@Override
	protected Map<String, Object> referenceData(HttpServletRequest request) throws Exception {
		Map<String, Object> map = new HashMap<String,Object>();
		Collection<DictionaryEntry> pipelines = dictionaryService.fetch(
				DictionaryEnum.MOUSE_COHORT_PIPELINE);
		map.put("pipelines", pipelines);
		return map;
	}

	public void setMetaDataService(MetaDataService metaDataService) {
		this.metaDataService = metaDataService;
	}

	public void setAlleleService(AlleleService alleleService) {
		this.alleleService = alleleService;
	}

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}


}