/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.microscopy.controllers;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.AbstractCancellableFormController;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.microscopy.MetaData;
import uk.ac.sanger.mig.microscopy.forms.MetaDataForm;
import uk.ac.sanger.mig.microscopy.services.MetaDataService;

public class MetaDataFormController extends AbstractCancellableFormController {

	private MetaDataService metaDataService;
	private DictionaryService dictionaryService;

	@Override
	protected ModelAndView onSubmit(
			HttpServletRequest request,
			HttpServletResponse response,
			Object command,
			BindException bindException) throws Exception {

		MetaDataForm annotationForm = (MetaDataForm)command;
		metaDataService.storeAnnotated(
							  annotationForm.getMetaData(),
							  annotationForm.getSelectedAnnotations(),
							  RequestUtils.getUser(request));

		return new ModelAndView( getSuccessView() );
	}

	@Override
	protected Object formBackingObject(HttpServletRequest request) throws Exception {
		MetaDataForm metaDataForm = (MetaDataForm)createCommand();
		Long id = ServletRequestUtils.getRequiredLongParameter(request, "id");
		MetaData metaData = metaDataService.fetchById(id, ComponentMap.of(MetaData.Component.ANNOTATIONS));
		if( metaData == null ) {
			throw new Exception("MetaData with ID " + id + " was not found!");
		}
		metaDataForm.setMetaData( metaData );
		return metaDataForm;
	}

	@Override
	protected Map referenceData(HttpServletRequest request, Object command, Errors errors)
					throws Exception {
		Collection<DictionaryEntry> tissues
			= dictionaryService.fetch(DictionaryEnum.MIC_TISSUE_DICT);
		Collection<DictionaryEntry> descriptions
			= dictionaryService.fetch(DictionaryEnum.MIC_DESCRIPTION_DICT);
		Map<String, Collection<DictionaryEntry>> map
			= new HashMap<String,Collection<DictionaryEntry>>();
		map.put("tissues",      tissues);
		map.put("descriptions", descriptions);
		return map;
	}

	public void setMetaDataService(MetaDataService metaDataService) {
		this.metaDataService = metaDataService;
	}

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}
}
