/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.microscopy.dao;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.LongRowMapper;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.microscopy.MetaData;
import uk.ac.sanger.mig.microscopy.MetaDataSearchBean;

/**
 * @author ae1
 *
 */
public class MetaDataDaoSpringImpl extends AbstractDaoSpringImpl<MetaData> implements MetaDataDao {

	private LongRowMapper longRowMapper;
	private String mimpRoMetaData;
	private String metaDataView;

	@Override
	public MetaData fetchById(Long id) {
		String sql = "SELECT * from "+metaDataView+" where id = ?";
		return fetchOne(sql, id);
	}


	public Collection<Long> fetchUnsweptMetaDataIds() {
		String sql ="(select romd.id from " +mimpRoMetaData+ " romd, "+
		"mts_mouse m where (m.NAME = romd.sample_name OR m.barcode = romd.sample_name) ) "+
		"minus (select read_only_meta_data_id from "+getTableName()+")";
		return getSimpleJdbcTemplate().query(sql, longRowMapper);
	}

	public Collection<MetaData> searchGenotyped(MetaDataSearchBean metaDataSearchBean) {

		String sql = "SELECT * from "+metaDataView + " where 1=1 ";

		Collection<Object> bindVariables = new ArrayList<Object>();

		sql += " and allele_id = ?";
		bindVariables.add(  metaDataSearchBean.getAlleleId()  );

		if(  metaDataSearchBean.getPipelineId() != null ) {

			bindVariables.add( metaDataSearchBean.getPipelineId()  );
			sql += " and pipeline_id  = ? ";

		} else {

		}

		return fetchCollection(sql, bindVariables.toArray());
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, MetaData metaData) {
		sql.addLongParam(metaData.getId(), "ID");
		sql.addLongParam(metaData.getReadOnlyMetaDataId(), "READ_ONLY_META_DATA_ID");
		sql.addStringParam(metaData.getConvertedImagePath(), "FILE_PATH");
		sql.addStringParam(metaData.getImageUrl(), "URL");
		sql.addBooleanParam(metaData.getPrimaryForTissue(), "IS_PRIMARY_FOR_TISSUE_TYPE");
		sql.addDateParam(metaData.getEditDate(), "EDIT_DATE");
		sql.addStringParam(metaData.getEditedBy(), "EDITED_BY");
		sql.addDateParam(metaData.getCreatedDate(), "CREATED_DATE");
		sql.addLongParam(metaData.getCreatorId(), "CREATOR_ID");
		sql.addLongParam(metaData.getCheckNumber(), "CHECK_NUMBER");
		sql.addBooleanParam(metaData.getQcPass(), "QC_PASS");
		sql.addLongParam(metaData.getTissueDictId(), "TISSUE_DICT_ID");
		sql.addLongParam(metaData.getDescriptionDictId(), "DESCRIPTION_DICT_ID");
		sql.addStringParam(metaData.getComments(), "COMMENTS");
		sql.addIntParam(metaData.getImageWidth(), "IMAGE_WIDTH");
		sql.addIntParam(metaData.getImageHeight(), "IMAGE_HEIGHT");
		sql.addLongParam(metaData.getId(), "ID");
	}

	public void setLongRowMapper(LongRowMapper longRowMapper) {
		this.longRowMapper = longRowMapper;
	}


	public void setMetaDataView(String metaDataView) {
		this.metaDataView = metaDataView;
	}


	public void setMimpRoMetaData(String mimpRoMetaData) {
		this.mimpRoMetaData = mimpRoMetaData;
	}





}

