/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.microscopy.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.microscopy.MetaData;

public class MetaDataRowMapper implements ParameterizedRowMapper<MetaData> {

	private DictionaryService dictionaryService;

	public MetaData mapRow(ResultSet rs, int rowNum) throws SQLException {
		MetaData metaData = new MetaData();
		metaData.setId(rs.getLong("ID"));
		metaData.setReadOnlyMetaDataId(rs.getLong("READ_ONLY_META_DATA_ID"));
		if(rs.wasNull()) {metaData.setReadOnlyMetaDataId(null);}
		metaData.setConvertedImagePath(rs.getString("FILE_PATH"));
		metaData.setImageUrl(rs.getString("URL"));
		metaData.setPrimaryForTissue(rs.getBoolean("IS_PRIMARY_FOR_TISSUE_TYPE"));
		if(rs.wasNull()) {metaData.setPrimaryForTissue(null);}
		metaData.setEditDate(rs.getTimestamp("EDIT_DATE"));
		metaData.setEditedBy(rs.getString("EDITED_BY"));
		metaData.setCreatedDate(rs.getTimestamp("CREATED_DATE"));
		metaData.setCreatorId(rs.getLong("CREATOR_ID"));
		if(rs.wasNull()) {metaData.setCreatorId(null);}
		metaData.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) {metaData.setCheckNumber(null);}
		metaData.setQcPass(rs.getBoolean("QC_PASS"));
		if(rs.wasNull()) {metaData.setQcPass(null);}
		metaData.setDescriptionDictId(rs.getLong("DESCRIPTION_DICT_ID"));
		if(rs.wasNull()) {metaData.setDescriptionDictId(null);}
		else {
			DictionaryEntry descriptionDict
				= dictionaryService.fetchEntry(DictionaryEnum.MIC_DESCRIPTION_DICT,
						metaData.getDescriptionDictId());
			metaData.setDescriptionDict(descriptionDict);
		}
		metaData.setImageWidth(rs.getInt("IMAGE_WIDTH"));
		metaData.setImageHeight(rs.getInt("IMAGE_HEIGHT"));
		metaData.setTissueDictId(rs.getLong("TISSUE_DICT_ID"));
		if(rs.wasNull()) {metaData.setTissueDictId(null);}
		else {
			DictionaryEntry tissueDict
				= dictionaryService.fetchEntry(DictionaryEnum.MIC_TISSUE_DICT,
						metaData.getTissueDictId());
			metaData.setTissueDict(tissueDict);
		}
		metaData.setPipeline(rs.getString("pipeline"));
		metaData.setPipelineId(rs.getLong("pipeline_id"));
		if(rs.wasNull()) {metaData.setPipelineId(null);}
		metaData.setGeneId(rs.getLong("gene_id"));
		if(rs.wasNull()) {metaData.setGeneId(null);}
		metaData.setGeneName(rs.getString("gene_name"));
		metaData.setAlleleId(rs.getLong("allele_id"));
		if(rs.wasNull()) {metaData.setAlleleId(null);}
		metaData.setAlleleSuperscript(rs.getString("allele_superscript"));
		metaData.setGenotypeId(rs.getLong("genotype_id"));
		if(rs.wasNull()) {metaData.setGenotypeId(null);}
		metaData.setGenotype(rs.getString("genotype"));
		metaData.setComments(rs.getString("comments"));

		metaData.setAgeAtDeath( rs.getString("age_at_death"));
		metaData.setGenderDictId(rs.getLong("gender_dict_id"));
		if(rs.wasNull()) {metaData.setGenderDictId(null);}
		metaData.setGender(rs.getString("gender"));

		return metaData;
	}

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}



}