/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.microscopy.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.microscopy.ReadOnlyMetaData;

public class ReadOnlyMetaDataRowMapper implements ParameterizedRowMapper<ReadOnlyMetaData> {

	public ReadOnlyMetaData mapRow(ResultSet rs, int rowNum) throws SQLException {
		ReadOnlyMetaData metaData = new ReadOnlyMetaData();
		metaData.setId( rs.getLong("id"));
		metaData.setSampleName(rs.getString("SAMPLE_NAME"));
		/*
		metaData.setMouseName(rs.getString("MOUSE_NAME"));
		metaData.setMouseBarcode(rs.getString("MOUSE_BARCODE"));
		metaData.setGender(rs.getString("GENDER"));
		metaData.setStrain(rs.getString("STRAIN"));
		metaData.setGenotype(rs.getString("GENOTYPE"));
		metaData.setEarmark(rs.getString("EARMARK"));
		metaData.setBirthDate(rs.getTimestamp("BIRTH_DATE"));
		metaData.setDeathDate(rs.getTimestamp("DEATH_DATE"));
		metaData.setAgeInWeeks(rs.getInt("AGE_IN_WEEKS"));
		metaData.setMouseComments(rs.getString("MOUSE_COMMENTS"));
		metaData.setCohorts(rs.getString("COHORTS"));
		metaData.setPipelines(rs.getString("PIPELINES"));
		*/
		metaData.setGroupDescription(rs.getString("GROUP_DESCRIPTION"));
		metaData.setCreatedBy(rs.getString("CREATED_BY"));
		metaData.setTissue(rs.getString("TISSUE"));
		metaData.setImageDescription(rs.getString("IMAGE_DESCRIPTION"));
		metaData.setAcquisitionDate(rs.getTimestamp("ACQUISITION_DATE"));
		metaData.setImgWme(rs.getInt("IMG_WME"));
		metaData.setImgFaxitron(rs.getInt("IMG_FAXITRON"));
		metaData.setImgSlitLamp(rs.getInt("IMG_SLIT_LAMP"));
		metaData.setImgSkinScreen(rs.getInt("IMG_SKIN_SCREEN"));
		metaData.setImgLacz(rs.getInt("IMG_LACZ"));
		metaData.setImgVideo(rs.getInt("IMG_VIDEO"));
		metaData.setImgMisc(rs.getInt("IMG_MISC"));
		metaData.setImageType(rs.getString("IMAGE_TYPE"));
		metaData.setWorkstation(rs.getString("WORKSTATION"));
		metaData.setMicModel(rs.getString("MIC_MODEL"));
		metaData.setCamera(rs.getString("CAMERA"));
		metaData.setMicAdapterMag(rs.getFloat("MIC_ADAPTER_MAG"));
		metaData.setMicIntermediate(rs.getFloat("MIC_INTERMEDIATE"));
		metaData.setMicIris(rs.getFloat("MIC_IRIS"));
		metaData.setMicObjective(rs.getFloat("MIC_OBJECTIVE"));
		metaData.setMicZpos(rs.getFloat("MIC_ZPOS"));
		metaData.setMicZoomFactor(rs.getFloat("MIC_ZOOM_FACTOR"));
		metaData.setXMicronsPerPixel(rs.getInt("X_MICRONS_PER_PIXEL"));
		metaData.setYMicronsPerPixel(rs.getInt("Y_MICRONS_PER_PIXEL"));
		metaData.setImagePath(rs.getString("IMAGE_PATH"));
		metaData.setImageFormat(rs.getString("IMAGE_FORMAT"));
		metaData.setImageWidth(rs.getInt("IMAGE_WIDTH"));
		metaData.setImageHeight(rs.getInt("IMAGE_HEIGHT"));
		metaData.setImageBitsPerPixel(rs.getInt("IMAGE_BITS_PER_PIXEL"));
		//metaDataView.setQcPass(rs.getInt("QC_PASS"));
		return metaData;

	}
}