/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.microscopy.services;

import java.util.ArrayList;
import java.util.Collection;

import org.springframework.transaction.annotation.Transactional;

import uk.ac.sanger.mig.annotation.Annotation;
import uk.ac.sanger.mig.annotation.services.AnnotationService;
import uk.ac.sanger.mig.common.AbstractServiceImpl2;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.database.TableMetadataEnum;
import uk.ac.sanger.mig.microscopy.MetaData;
import uk.ac.sanger.mig.microscopy.MetaDataSearchBean;
import uk.ac.sanger.mig.microscopy.ReadOnlyMetaData;
import uk.ac.sanger.mig.microscopy.dao.MetaDataDao;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.personnel.services.PersonService;

/**
 * @author ae1
 *
 */
public class MetaDataServiceImpl extends AbstractServiceImpl2<MetaData,MetaDataDao>  implements MetaDataService {

	private ReadOnlyMetaDataService readOnlyMetaDataService;
	private AnnotationService annotationService;
	private PersonService personService;

	@Transactional
	public Long storeAnnotated(MetaData metaData, Collection<Annotation> selected, Person user) {
		annotationService.updateAll(metaData.getAnnotations(),
				 selected, TableMetadataEnum.MIC_META_DATA, user);
		return store(metaData, user);
	}

	public Collection<Long> fetchUnsweptMetaDataIds() {

		return getPrimaryDao().fetchUnsweptMetaDataIds();
	}

	public Collection<MetaData> searchGenotyped(MetaDataSearchBean metaDataSearchBean) {

		return getPrimaryDao().searchGenotyped(metaDataSearchBean);
	}

	@Override
	protected void attachComponents(MetaData metaData, ComponentMap requiredComponents) {

		if(metaData == null) {
			throw new RuntimeException("Cannot attach components to null metaData");
		}

		boolean fetchAll = false;

		if(requiredComponents != null) {

			if(requiredComponents.containsKey(MetaData.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}

			if(fetchAll || requiredComponents.containsKey(MetaData.Component.READ_ONLY_META_DATA)) {

				metaData.setReadOnlyMetaData(
						fetchReadOnlyMetaDataById(metaData.getReadOnlyMetaDataId()));

			}

			if(fetchAll || requiredComponents.containsKey(MetaData.Component.ANNOTATIONS)) {

				metaData.setAnnotations(fetchAnnotationsByTableAndForeignKey(
						TableMetadataEnum.MIC_META_DATA,
						metaData.getId(),
						requiredComponents.get(MetaData.Component.ANNOTATIONS)));
			}

			if(fetchAll || requiredComponents.containsKey(MetaData.Component.CREATOR)) {
				metaData.setCreator(fetchCreatorById(
						metaData.getCreatorId(),
						requiredComponents.get(MetaData.Component.CREATOR)));
			}

		}

	}

	private Person fetchCreatorById(Long personId, ComponentMap requiredComponents) {
		return personService.fetchById(personId, requiredComponents);
	}

	private Collection<Annotation> fetchAnnotationsByTableAndForeignKey(TableMetadataEnum table, Long foreignKeyId, ComponentMap requiredComponents) {

		return annotationService.fetchByTableAndForeignKey(table, foreignKeyId, requiredComponents);

	}

	private ReadOnlyMetaData fetchReadOnlyMetaDataById(Long readOnlyId) {

		return readOnlyMetaDataService.fetchById( readOnlyId );
	}

	public void setAnnotationService(AnnotationService annotationService) {
		this.annotationService = annotationService;
	}

	public void setReadOnlyMetaDataService(
			ReadOnlyMetaDataService readOnlyMetaDataService) {
		this.readOnlyMetaDataService = readOnlyMetaDataService;
	}

	public void setPersonService(PersonService personService) {
		this.personService = personService;
	}





}
