/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.microscopy.services;

import java.util.ArrayList;
import java.util.Collection;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import uk.ac.sanger.mig.microscopy.ReadOnlyMetaData;
import uk.ac.sanger.mig.microscopy.Thumbnail;
import uk.ac.sanger.mig.microscopy.dao.ReadOnlyMetaDataDao;

/**
 * @author ae1
 *
 */
public class ReadOnlyMetaDataServiceImpl  implements ReadOnlyMetaDataService {

	protected Log logger = LogFactory.getLog(this.getClass());

	private ReadOnlyMetaDataDao readOnlyMetaDataDao;
	private MetaDataService metaDataService;
	private String defaultThumbMimeType;


	public void setMetaDataService(MetaDataService metaDataService) {
		this.metaDataService = metaDataService;
	}

	public Collection<ReadOnlyMetaData> fetchUnsweptMetaData() {

		Collection<Long> ids = metaDataService.fetchUnsweptMetaDataIds();
		Collection<ReadOnlyMetaData> metas
			= new ArrayList<ReadOnlyMetaData>( ids.size() );
		for(Long id : ids ) {
			ReadOnlyMetaData meta = fetchById( id );
			metas.add( meta );
		}

		logger.debug("ReadOnlyMetaData object found for sweep to MIG MetaData: " + metas.size());

		return metas;
	}

	public ReadOnlyMetaData fetchById(Long id) {

		return readOnlyMetaDataDao.fetchById(id);
	}

	public Thumbnail fetchThumbnail(Long id) {

		Thumbnail thumbnail = readOnlyMetaDataDao.fetchThumbnail( id );

		if( thumbnail != null ) {

			if( thumbnail.getContentType() == null ) {

				thumbnail.setContentType( getDefaultThumbMimeType() );
			}

		}

		return thumbnail;
	}





	public void setReadOnlyMetaDataDao(ReadOnlyMetaDataDao readOnlyMetaDataDao) {
		this.readOnlyMetaDataDao = readOnlyMetaDataDao;
	}



	public String getDefaultThumbMimeType() {
		return this.defaultThumbMimeType;
	}

	public void setDefaultThumbMimeType(String defaultThumbMimeType) {
		this.defaultThumbMimeType = defaultThumbMimeType;
	}

	public ReadOnlyMetaDataDao getReadOnlyMetaDataDao() {
		return this.readOnlyMetaDataDao;
	}








}
