/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.miprocessing;

import java.util.Date;

import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.ComponentEnum;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.mirequest.MiRequest;
import uk.ac.sanger.mig.personnel.Person;

public class MicroInjection extends AuthenticatedDataObject{
	
	public enum Component implements ComponentEnum {
		SCHEDULED_MICRO_INJECTION,
		EMBRYO_HARVEST,
		TECHNICIAN,
		ALL_COMPONENTS  //add additional component enums here as needed for this AuthenticatedDataObject		
	}

	private static final Long 	 DEFAULT_EMBRYO_STAGE_DICT_ID 			= 2L;//3.5 dpc
	private static final Integer DEFAULT_ES_CELLS_PER_EMBRYO_RANGE_FROM = 5;
	private static final Integer DEFAULT_ES_CELLS_PER_EMBRYO_RANGE_TO   = 40;
	
	private Long embryoHarvestId;
	private EmbryoHarvest embryoHarvest;
	private ScheduledMicroInjectionJob scheduledMicroInjection; //get EmbryoHarvest through parent ScheduledMicroInjection  
	private Long scheduledMicroInjectionId;	
    private Date dateCompleted;//do we even need, ie, have as creaded date and in smi task completed date??  
    private Long embryoStageDictId       = DEFAULT_EMBRYO_STAGE_DICT_ID;       
    private DictionaryEntry embryoStageDict; 
    private Integer injectedEmbryoCount;        
    private Integer esCellPerEmbryo;  
    private String comments;
    private Integer esCellsPerEmbryoFrom = DEFAULT_ES_CELLS_PER_EMBRYO_RANGE_FROM;
    private Integer esCellsPerEmbryoTo   = DEFAULT_ES_CELLS_PER_EMBRYO_RANGE_TO; 
    private Long technicianId;
    private Person technician;
    
    
    
   public String getRequiredHarvestCoatColour() {
	   return (scheduledMicroInjection != null) ? 
			   scheduledMicroInjection.getRequiredHarvestCoatColour() : null;
   }
    
   public Date getHarvestPlugCheckDate() {
	   return (embryoHarvest != null) ? embryoHarvest.getPlugCheckDate() : null;
   }
    
	//////////////////////////////////////////////////////////
	///////////////// bit bucket methods /////////////////////
	//////////////////////////////////////////////////////////	
  
    public Integer getEsCellsPerEmbryoFrom() {
		return esCellsPerEmbryoFrom;
	}

	public void setEsCellsPerEmbryoFrom(Integer esCellsPerEmbryoFrom) {
		this.esCellsPerEmbryoFrom = esCellsPerEmbryoFrom;
	}

	public Integer getEsCellsPerEmbryoTo() {
		return esCellsPerEmbryoTo;
	}

	public void setEsCellsPerEmbryoTo(Integer esCellsPerEmbryoTo) {
		this.esCellsPerEmbryoTo = esCellsPerEmbryoTo;
	}

	public MiRequest getMiRequest() {
    	return (scheduledMicroInjection != null) ?
    			scheduledMicroInjection.getMiRequest() : null;
    }
    
    public ScheduledMicroInjectionJob getScheduledMicroInjection() {
		return scheduledMicroInjection;
	}

	public void setScheduledMicroInjection(
			ScheduledMicroInjectionJob scheduledMicroInjection) {
		this.scheduledMicroInjection = scheduledMicroInjection;
	}

	public Long getScheduledMicroInjectionId() {
		return scheduledMicroInjectionId;
	}

	public void setScheduledMicroInjectionId(Long scheduledMicroInjectionId) {
		this.scheduledMicroInjectionId = scheduledMicroInjectionId;
	}
                                                                                                                                          
    public Long getEmbryoStageDictId() {
        return embryoStageDictId;
    }
    
    public void setEmbryoStageDictId(Long embryoStageDictId) {
        this.embryoStageDictId = embryoStageDictId;
    }                                                                                                                                            
    public Integer getInjectedEmbryoCount() {
        return injectedEmbryoCount;
    }
    
    public void setInjectedEmbryoCount(Integer embryoCount) {
        this.injectedEmbryoCount = embryoCount;
    }                                                                                                                                            
                                                                                                                                         
    public Integer getEsCellPerEmbryo() {
		return esCellPerEmbryo;
	}

	public void setEsCellPerEmbryo(Integer esCellPerEmbryo) {
		this.esCellPerEmbryo = esCellPerEmbryo;
	}

	public DictionaryEntry getEmbryoStageDict() {
		return embryoStageDict;
	}

	public void setEmbryoStageDict(DictionaryEntry embryoStageDict) {
		this.embryoStageDict = embryoStageDict;
	}


	public Date getDateCompleted() {
		return dateCompleted;
	}

	public void setDateCompleted(Date dateCompleted) {
		this.dateCompleted = dateCompleted;
	}

	public String getComments() {
		return comments;
	}

	public void setComments(String comments) {
		this.comments = comments;
	}

	public EmbryoHarvest getEmbryoHarvest() {
		return embryoHarvest;
	}

	public void setEmbryoHarvest(EmbryoHarvest embryoHarvest) {
		this.embryoHarvest = embryoHarvest;
	}

	public Long getEmbryoHarvestId() {
		return embryoHarvestId;
	}

	public void setEmbryoHarvestId(Long embryoHarvestId) {
		this.embryoHarvestId = embryoHarvestId;
	}

	public Person getTechnician() {
		return technician;
	}

	public void setTechnician(Person technician) {
		this.technician = technician;
	}

	public Long getTechnicianId() {
		return technicianId;
	}

	public void setTechnicianId(Long technicianId) {
		this.technicianId = technicianId;
	}                                                                                                                                            
                         

}
