/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.miprocessing;

import java.util.Date;

import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.common.Nullable;
import uk.ac.sanger.mig.miprocessing.workflow.Job;
import uk.ac.sanger.mig.miprocessing.workflow.Task;

public class ScheduledMiTask extends AuthenticatedDataObject implements Task, Nullable {
	
    private Job scheduledMicroInjection;
    private Long scheduledMicroInjectionId;
	private Date estimatedCompletionDate;        
    private Date actualCompletionDate;        
    private String description;        
    private int sequenceNumber;
    private String name;
    private boolean isMilestone;

    private DictionaryEntry taskGroupDict;
    private Long taskGroupDictId;   
    
    
    
    public DictionaryEntry getTaskGroupDict() {
		return this.taskGroupDict;
	}

	public void setTaskGroupDict(DictionaryEntry taskGroupDict) {
		this.taskGroupDict = taskGroupDict;
	}

	public Long getTaskGroupDictId() {
		return this.taskGroupDictId;
	}

	public void setTaskGroupDictId(Long taskGroupDictId) {
		this.taskGroupDictId = taskGroupDictId;
	}

	public boolean isBlank() {
		return false;
	}

	public boolean isComplete() {
    	return (actualCompletionDate != null);
    }

	public boolean isPastDue() {
    	return (!isComplete() && new Date().after( estimatedCompletionDate ));
    }
    
    public int compareTo(Task task) {
    	if(this.sequenceNumber > task.getSequenceNumber()) return 1;
    	if(this.sequenceNumber < task.getSequenceNumber()) return -1;
    	return 0;
    }
 
    
	//////////////////////////////////////////////////////////
	///////////////// bit bucket methods /////////////////////
	//////////////////////////////////////////////////////////	
  
	public Long getParentJobId() {
		return scheduledMicroInjectionId;
	}

	public void setParentJobId(Long jobId) {
		scheduledMicroInjectionId = jobId;		
	}
    
	public Job getParentJob() {
		return scheduledMicroInjection;
	}

	public void setParentJob(Job scheduledMicroInjection) {
		this.scheduledMicroInjection = scheduledMicroInjection;
	}
    
    public boolean isMilestone() {
		return isMilestone;
	}

	public void setMilestone(boolean isMilestone) {
		this.isMilestone = isMilestone;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public int getSequenceNumber() {
		return sequenceNumber;
	}

	public void setSequenceNumber(int sequenceNumber) {
		this.sequenceNumber = sequenceNumber;
	}

	public Date getEstimatedCompletionDate() {
        return estimatedCompletionDate;
    }
    
    public void setEstimatedCompletionDate(Date date) {
        this.estimatedCompletionDate = date;
    }                                                                                                                                            

    public Date getActualCompletionDate() {
        return actualCompletionDate;
    }

    public void setActualCompletionDate(Date date) {
        this.actualCompletionDate = date;
    }                                                                                                                                            

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }


                                                                                                                                           
                                                                                                                                         

}