/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.miprocessing.controllers;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.AbstractCancellableFormController;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.miprocessing.forms.BatchWildtypeRequestForm;
import uk.ac.sanger.mig.miprocessing.services.BatchWildtypeRequestService;

/**
 * @author ae1
 *
 */
public class BatchWildtypeRequestFormController extends AbstractCancellableFormController {

	private BatchWildtypeRequestService batchWildtypeRequestService;
	//private VelocityEngine velocityEngine;
	
	@Override
	protected Object formBackingObject(HttpServletRequest request) throws Exception {
		BatchWildtypeRequestForm form = (BatchWildtypeRequestForm)createCommand();
		form.setRequester(RequestUtils.getUser(request));
		return form;
	}
	
	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, 
			Object command, BindException errs) throws Exception {
				
		BatchWildtypeRequestForm form = (BatchWildtypeRequestForm)command;
		
		if( form.isAdd() ) {//may also add comments text
			
			if(form.getDateRequired() != null)
				form.addDailyRequests( RequestUtils.getUser(request) );
			
			return showForm( request, response, errs );
			
		} else if( form.isDelete() ) {
			form.removeDailyRequests();	
			return showForm( request, response, errs );
		
		} else {//process batch request
			Collection<String> emailRecipients = batchWildtypeRequestService.processWildtypeRequests( form );
			Map<String, Collection<String>> model = new HashMap<String, Collection<String>>();
			model.put("emailRecipients", emailRecipients );
		    return new ModelAndView( getSuccessView(),  model );
		}
	}
	
	@Override
	protected Map referenceData(HttpServletRequest request, Object command, Errors errs) throws Exception {
	
		BatchWildtypeRequestForm form = (BatchWildtypeRequestForm)command;
		
		Map<String,Object> velocityReportEmail = batchWildtypeRequestService.buildReport( form );
		
		//String velocityReportEmailStr = VelocityEngineUtils.mergeTemplateIntoString(velocityEngine, 
		//		BatchWildtypeRequestService.VELOCITY_REPORT_EMAIL + "_body.vm", velocityReportEmail);
		
		int[] mouseCount = new int[ BatchWildtypeRequestService.MICE_COUNT_CEILING ];
		for(int x = 0; x < mouseCount.length; x++) {
			mouseCount[x] = x;
		}
		
		Map<String,Object> metaData = new HashMap<String,Object>();
		//metaData.put("velocityReportEmailStr", velocityReportEmailStr);
		metaData.put("mouseCount", mouseCount);
		metaData.put("batchCount", form.getDailyRequestsCache().size());
		metaData.put("velocityReportEmail", velocityReportEmail);
		return metaData;
	}
	
	////////////////////////////////////////////////////////////////////////////////////////////////////
	/////////////////////////////////////// dependencies ///////////////////////////////////////////////
	////////////////////////////////////////////////////////////////////////////////////////////////////
	public void setBatchWildtypeRequestService(
			BatchWildtypeRequestService batchWildtypeRequestService) {
		this.batchWildtypeRequestService = batchWildtypeRequestService;
	}

	//public void setVelocityEngine(VelocityEngine velocityEngine) {
	//	this.velocityEngine = velocityEngine;
	//}

}
