/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.miprocessing.controllers;


import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.animalrequest.AnimalRequest;
import uk.ac.sanger.mig.common.AbstractCancellableFormController;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.miprocessing.ScheduledMicroInjectionJob;
import uk.ac.sanger.mig.miprocessing.forms.ScheduledMicroInjectionForm;
import uk.ac.sanger.mig.miprocessing.services.ScheduledMicroInjectionService;
import uk.ac.sanger.mig.mirequest.MiRequest;
import uk.ac.sanger.mig.mirequest.services.MiRequestService;

public class CreateScheduledMicroInjectionController extends AbstractCancellableFormController {
	
	private ScheduledMicroInjectionService scheduledMicroInjectionService;
	private MiRequestService miRequestService;
	
	@Override
	protected Object formBackingObject(HttpServletRequest request) throws Exception {
		
		ScheduledMicroInjectionForm form = (ScheduledMicroInjectionForm)createCommand();				    	
		Long miRequestId = ServletRequestUtils.getRequiredLongParameter(request, "miRequestId");
		
		MiRequest miRequest = miRequestService.fetchWithAllComponentsById(miRequestId);
		       	
		ScheduledMicroInjectionJob scheduledMicroInjection = new ScheduledMicroInjectionJob();	
		scheduledMicroInjection.setMiRequestId(miRequestId);
		scheduledMicroInjection.setMiRequest(miRequest);
		
		//derive job id
		scheduledMicroInjection.setJobId( scheduledMicroInjectionService.deriveJobId(miRequest) );
			
		return populateForm(form,  scheduledMicroInjection);
	}
	
	
	
	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, 
				Object command, BindException errors) throws Exception {
		
		ScheduledMicroInjectionForm form = (ScheduledMicroInjectionForm) command;

		ScheduledMicroInjectionJob scheduledMicroInjection = dePopulateForm( form );
			
		Long id = scheduledMicroInjectionService.schedule( scheduledMicroInjection, RequestUtils.getUser(request), 
				form.getNumberDonors(), form.getNumberRecipients() );
		
		logger.debug("Stored ScheduledMicroInjectionJob " + id);
		
		return new ModelAndView( getSuccessView() + "?id=" + 
				scheduledMicroInjection.getMiRequestId()); // return to MI Req detail view
	}
	
	@Override
	protected Map referenceData(HttpServletRequest request, Object command, Errors errs) throws Exception {
		Map<String, Object> metaData = new HashMap<String, Object>();	
		ScheduledMicroInjectionForm form = (ScheduledMicroInjectionForm) command;
		MiRequest miRequest = form.getMiRequest();
		metaData.put("miRequest", miRequest); //accesed by MiRequest summary jspf 
		metaData.put("hideMiRequestControls", "true"); //controld should be hidden in MiRequest summary jspf 
		return metaData;
	}
	
	////////////////////////////////////////////////////////////////////////////////////////////////////
	/////////////////////////////////////// dependencies ///////////////////////////////////////////////
	////////////////////////////////////////////////////////////////////////////////////////////////////
	public void setScheduledMicroInjectionService(ScheduledMicroInjectionService scheduledMicroInjectionService) {
		this.scheduledMicroInjectionService = scheduledMicroInjectionService;
	}

	public void setMiRequestService(MiRequestService miRequestService) {
		this.miRequestService = miRequestService;
	}

	
	////////////////////////////////////////////////////////////////////////////////////////////////////
	/////////////////////////////////////// privates ///////////////////////////////////////////////////
	////////////////////////////////////////////////////////////////////////////////////////////////////
	private ScheduledMicroInjectionForm populateForm(ScheduledMicroInjectionForm form, 
			ScheduledMicroInjectionJob scheduledMicroInjection) {
		
		MiRequest miRequest = scheduledMicroInjection.getMiRequest();
		form.setScheduledMicroInjection( scheduledMicroInjection );	
		form.setMiRequest( miRequest ); //need to expose cell line in form for edit
		form.setCellLineProviderId( miRequest.getCellLine().getCellLineProviderId() );
		form.setCellLineProviderName( miRequest.getCellLine().getCellLineProvider().getDisplayText() );
		form.setNumberDonors( AnimalRequest.DEFAULT_NUMBER_DONORS ); //default 
		form.setNumberRecipients( AnimalRequest.DEFAULT_NUMBER_RECIPIENTS ); //default 
		form.setDonorRequest( false );
		form.setRecipientRequest( false );
		return form;
	}
	
	private ScheduledMicroInjectionJob dePopulateForm(ScheduledMicroInjectionForm form) {
		
		ScheduledMicroInjectionJob scheduledMicroInjection = form.getScheduledMicroInjection();	
		scheduledMicroInjection.setCellLineProviderId( form.getCellLineProviderId() );		
		scheduledMicroInjection.setMiRequestId( form.getMiRequest().getId() );
				
		if( !form.isDonorRequest() ) 
			form.setNumberDonors( 0 );
		
		if( !form.isRecipientRequest() )
			form.setNumberRecipients( 0 );
		
		return scheduledMicroInjection;
	}
	
}