/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.miprocessing.controllers;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.AbstractCancellableFormController;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.miprocessing.forms.DeactivateScheduledMicroInjectionForm;
import uk.ac.sanger.mig.miprocessing.services.ScheduledMicroInjectionService;

/**
 * Deactivates ScheduledMicroInjection setting its status to either cancelled or failed.
 * @author ae1
 *
 */
public class DeactivateScheduledMicroInjectionController extends AbstractCancellableFormController {
	
	private ScheduledMicroInjectionService scheduledMicroInjectionService;
	
	@Override
	protected Object formBackingObject(HttpServletRequest httpServletRequest) throws Exception {
		
		DeactivateScheduledMicroInjectionForm deactivateSmiForm 
			= (DeactivateScheduledMicroInjectionForm)createCommand();				    
		
		Long id = ServletRequestUtils.getRequiredLongParameter(httpServletRequest, "id");	
		
		deactivateSmiForm.setScheduledMicroInjectionId( id );

		return deactivateSmiForm;
	}
		
	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, 
				Object command, BindException errors) throws Exception {
		
		DeactivateScheduledMicroInjectionForm deactivateSmiForm 
			= (DeactivateScheduledMicroInjectionForm) command;		
		
		Long jobId = null;
		
		if( deactivateSmiForm.getCancellation()  ) {
			
			jobId = scheduledMicroInjectionService.cancelJob(
					 deactivateSmiForm.getScheduledMicroInjectionId(), 
					RequestUtils.getUser(request), 
					deactivateSmiForm.getCancelOrFailReasons());
			
		} else if ( deactivateSmiForm.getFailure() ) {//failed is only other possibility
			
			jobId = scheduledMicroInjectionService.failJob(
					deactivateSmiForm.getScheduledMicroInjectionId(),
					RequestUtils.getUser(request), 
					deactivateSmiForm.getCancelOrFailReasons());			
		}  else {
			
			logger.warn("Invalid deactivation parameter! Must be either cancel or fail to deactivate.");
		}

		return new ModelAndView( getSuccessView() + "?customFilterId=1&retrieveFromSession=true&newQuery=true&bypassForm=true&currentRecordId=" + 
				jobId );
		
	}
	
	public void setScheduledMicroInjectionService(ScheduledMicroInjectionService scheduledMicroInjectionService) {
		this.scheduledMicroInjectionService = scheduledMicroInjectionService;
	}	
	
	
}