/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.miprocessing.controllers;

import java.util.Calendar;
import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.AbstractSearchFormController;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.miprocessing.ScheduledMicroInjectionSearchBean;
import uk.ac.sanger.mig.miprocessing.services.ScheduledMicroInjectionService;
import uk.ac.sanger.mig.miprocessing.views.ScheduledMicroInjectionListView;

public class SearchScheduledMicroInjectionController extends AbstractSearchFormController {
		
	private ScheduledMicroInjectionService scheduledMicroInjectionService;
	private DictionaryService dictionaryService;	
	
	private static final Integer DAY_OFFSET_FILTER_FROM = -7;
	private static final Integer DAY_OFFSET_FILTER_TO   = +7; 
	
	@Override
	protected ModelAndView onSearch(HttpServletRequest request, HttpServletResponse response, 
			Object command, BindException errors) throws Exception {
		
		ScheduledMicroInjectionSearchBean searchBean = (ScheduledMicroInjectionSearchBean)command;
		searchBean.setQueryName("searchSmi");
		
		if(request.getQueryString().contains("defaultDateRange")){
			setDayFilter(searchBean, DAY_OFFSET_FILTER_FROM, DAY_OFFSET_FILTER_TO);
		}
					
		Collection<ScheduledMicroInjectionListView> smiList 
			= scheduledMicroInjectionService.search(searchBean);
		
		Map<String, Object> model = referenceData(request);
		model.put("smiList", smiList);
		model.put("smiCount", (smiList != null) ? smiList.size() : 0);
		
		return showForm(request, response, errors, model);
	}

	@Override
	protected Map<String, Object> referenceData(HttpServletRequest request) throws Exception {
		Map<String, Object> model = new HashMap<String, Object>(); 	
		
		boolean viewOne = ServletRequestUtils.getBooleanParameter(request, "viewOne", false);
		
		Collection<DictionaryEntry> endpoints 
			= dictionaryService.fetch(DictionaryEnum.MIR_TARGET_ENDPOINT_DICT, false);	
		model.put("endpoints", endpoints);		
		model.put("viewOne", viewOne);	
		return model;
	}

	/////////////////////////////////////////////////////////////////////////////////////////////
	////////////////////////////////// dependencies /////////////////////////////////////////////
	/////////////////////////////////////////////////////////////////////////////////////////////	
	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	public void setScheduledMicroInjectionService(ScheduledMicroInjectionService scheduledMicroInjectionService) {
		this.scheduledMicroInjectionService = scheduledMicroInjectionService;
	}
	
	
	

	/////////////////////////////////////////////////////////////////////////////////////////////
	//////////////////////////////////// privates ///////////////////////////////////////////////
	/////////////////////////////////////////////////////////////////////////////////////////////
	private void setDayFilter(ScheduledMicroInjectionSearchBean searchBean, int from, int to) {
		Calendar calendar = Calendar.getInstance();
		calendar.add( Calendar.DAY_OF_YEAR, to );
		searchBean.setTargetScheduleDateTo( calendar.getTime() );
		calendar.add( Calendar.DAY_OF_YEAR, from - to );	
		searchBean.setTargetScheduleDateFrom( calendar.getTime() );		
	}
	
	
}
