/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.miprocessing.dao;

import java.util.ArrayList;
import java.util.Calendar;
import java.util.Collection;
import java.util.Date;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.common.PaginatedSearchUtils;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.miprocessing.EmbryoHarvest;
import uk.ac.sanger.mig.miprocessing.EmbryoHarvestSearchBean;

public class EmbryoHarvestDaoSpringImpl extends AbstractDaoSpringImpl<EmbryoHarvest> implements EmbryoHarvestDao {
	
	private PaginatedSearchUtils<EmbryoHarvest> paginator;
	private String listViewName;

	
	public Collection<EmbryoHarvest> fetchAll(EmbryoHarvestSearchBean searchBean) {
		Collection<Object> bindVariables = new ArrayList<Object>();
		String sql = " select * from " + listViewName + " eh where 1=1";
		if(searchBean!= null) {
			if(searchBean.getFlushDate()!=null){
				sql += " and trunc(eh.FLUSH_DATE) = ? ";
			    bindVariables.add(defaultDateFormat.format(searchBean.getFlushDate()));
			}
		}
		else {
			sql += " order by id desc";
		}
		
		if(searchBean.getOrderBy() != null && !searchBean.getOrderBy().equals("")) {
			sql += " order by " + searchBean.getOrderBy();
			if(searchBean.isOrderDesc()) {
				sql += " desc ";
			}
		}
		
		if(searchBean!=null)
			return paginator.fetchSearchResults(sql, bindVariables, searchBean, getRowMapper());
		else{
			Collection<EmbryoHarvest> harvest = getSimpleJdbcTemplate().query(sql, 
					getRowMapper());
			return (harvest == null) ? new ArrayList<EmbryoHarvest>() : harvest;			
		}
		
	}
	
	public Collection<EmbryoHarvest> fetchAvailableByDate(Date date, boolean incubateOvernight) {
		
		String sql = " select * from " + getTableName() 
		+ " where trunc(FLUSH_DATE) = ? AND OVERNIGHT_INCUBATION = 0 order by id desc";
		
		Collection<EmbryoHarvest> harvest = getSimpleJdbcTemplate().query(sql, 
				getRowMapper(), defaultDateFormat.format(date));
		
		if( incubateOvernight )
			harvest.addAll( fetchIncubatedDayBefore( date ) );
		
		return harvest;	
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, EmbryoHarvest embryoHarvest) {
		sql.addDateParam(embryoHarvest.getEditDate(), "EDITED_DATE");
		sql.addStringParam(embryoHarvest.getEditedBy(), "EDITED_BY");
		sql.addDateParam(embryoHarvest.getCreatedDate(), "CREATED_DATE");
		sql.addLongParam(embryoHarvest.getCreatorId(), "CREATOR_ID");
		sql.addLongParam(embryoHarvest.getCheckNumber(), "CHECK_NUMBER");
		sql.addDateParam(embryoHarvest.getPlugCheckDate(), "PLUG_CHECK_DATE");
		sql.addDateParam(embryoHarvest.getFlushDate(), "FLUSH_DATE");
		sql.addStringParam(embryoHarvest.getComments(), "COMMENTS");
		sql.addIntParam(embryoHarvest.getBlastocystCount(), "BLASTOCYST_COUNT");
		sql.addIntParam(embryoHarvest.getMoralaeCount(), "MORALAE_COUNT");
		sql.addIntParam(embryoHarvest.getEightCellCompCount(), "EIGHT_CELL_COMP_COUNT");
		sql.addIntParam(embryoHarvest.getEightCellNonCompCount(), "EIGHT_CELL_NON_COMP_COUNT");
		sql.addIntParam(embryoHarvest.getFourCellCount(), "FOUR_CELL_COUNT");
		sql.addIntParam(embryoHarvest.getHatchedCount(), "HATCHED_COUNT");
		sql.addIntParam(embryoHarvest.getDeadOrFragmentedCount(), "DEAD_OR_FRAGMENTED_COUNT");
		sql.addIntParam(embryoHarvest.getOtherEmbryoTypeCount(), "OTHER_EMBRYO_TYPE_COUNT");
		sql.addBooleanParam(embryoHarvest.isOvernightIncubation(), "OVERNIGHT_INCUBATION");		
		sql.addLongParam(embryoHarvest.getMotherStrainId(), "MOTHER_STRAIN_ID");
		sql.addLongParam(embryoHarvest.getFatherStrainId(), "FATHER_STRAIN_ID");	
		//sql.addLongParam(embryoHarvest.getMotherCoatColourDictId(), "MOTHER_COAT_COLOUR_DICT_ID");
		//sql.addLongParam(embryoHarvest.getFatherCoatColourDictId(), "FATHER_COAT_COLOUR_DICT_ID");	
		sql.addIntParam(embryoHarvest.getTotalDonors(), "TOTAL_DONORS");
		sql.addLongParam(embryoHarvest.getTechnicianId(), "TECHNICIAN_ID");
		sql.addBooleanParam(embryoHarvest.isUseBlastocysts(),"USE_BLASTOCYST");
		sql.addBooleanParam(embryoHarvest.isUseMoralae(),"USE_MORALAE");
		sql.addBooleanParam(embryoHarvest.isUseEightCells(),"USE_EIGHT_CELLS");
		sql.addBooleanParam(embryoHarvest.isUseEightCellNonComp(),"USE_EIGHT_CELLS_NON_COMP");
		sql.addBooleanParam(embryoHarvest.isUseFourCell(),"USE_FOUR_CELLS");
		sql.addBooleanParam(embryoHarvest.isUseHatched(),"USE_HATCHED");
		sql.addBooleanParam(embryoHarvest.isUseDeadOrFragmented(),"USE_DEAD_OR_FRAGMENTED");
		sql.addBooleanParam(embryoHarvest.isUseOther(),"USE_OTHER");
		sql.addLongParam(embryoHarvest.getId(), "ID");
	}
	
	
	private Collection<EmbryoHarvest> fetchIncubatedDayBefore(Date date) {
		Calendar cal = Calendar.getInstance();
		cal.setTime( date );
		cal.add(Calendar.DAY_OF_MONTH, -1);	//day befor	
		String sql = " select * from " + getTableName() + 
		" where trunc(FLUSH_DATE) = ? AND OVERNIGHT_INCUBATION = 1 order by id desc";
		Collection<EmbryoHarvest> harvest = getSimpleJdbcTemplate().query(sql, 
				getRowMapper(), defaultDateFormat.format( cal.getTime() ) );	
		return (harvest == null) ? new ArrayList<EmbryoHarvest>() : harvest;		
	}
	
	public String getListViewName() {
		return listViewName;
	}
	
	
	public void setListViewName(String listViewName) {
		this.listViewName = listViewName;
	}
	
	


	public void setPaginator(PaginatedSearchUtils<EmbryoHarvest> paginator) {
		this.paginator = paginator;
	}
	
}