/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.miprocessing.dao;

import java.util.ArrayList;
import java.util.Collection;

import org.springframework.dao.IncorrectResultSizeDataAccessException;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.miprocessing.EmbryoTransferProcedure;

public class EmbryoTransferProcedureDaoSpringImpl extends AbstractDaoSpringImpl<EmbryoTransferProcedure> implements EmbryoTransferProcedureDao {


	public Collection<EmbryoTransferProcedure> fetchBySmiJobId(Long smiId) {
		String sql = " select * from " + getTableName() + " where scheduled_micro_injection_id = ? ";
		Collection<EmbryoTransferProcedure> embryoTransfer = getSimpleJdbcTemplate().query(sql, getRowMapper(), smiId);
		return (embryoTransfer == null) ? new ArrayList<EmbryoTransferProcedure>() : embryoTransfer;
	}
	

	public Collection<EmbryoTransferProcedure> fetchByThawTestId(Long thawTestId) {
		String sql = "select * from " + getTableName() + " where thaw_test_id = ? ";
		Collection<EmbryoTransferProcedure> embryoTransfers =  getSimpleJdbcTemplate().query(sql, getRowMapper(), thawTestId);
		return (embryoTransfers == null) ? new ArrayList<EmbryoTransferProcedure>() : embryoTransfers;
	}

	public boolean isMouseInUse(Long mouseId, Long smiId) {
		String sql = "select * from " + getTableName() + " where mouse_id = ? and scheduled_micro_injection_id = ? ";
		EmbryoTransferProcedure embryoTransfer = null;
		try {
			embryoTransfer = getSimpleJdbcTemplate().queryForObject(sql,getRowMapper(),mouseId,smiId);
		}
		catch (IncorrectResultSizeDataAccessException e) {}	
		return (embryoTransfer == null ? false : true);
	}
	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, EmbryoTransferProcedure embryoTransferProcedure) {
		sql.addDateParam(embryoTransferProcedure.getCreatedDate(), "CREATED_DATE");
		sql.addLongParam(embryoTransferProcedure.getCreatorId(), "CREATOR_ID");
		sql.addStringParam(embryoTransferProcedure.getEditedBy(), "EDITED_BY");
		sql.addDateParam(embryoTransferProcedure.getEditDate(), "EDIT_DATE");
		sql.addLongParam(embryoTransferProcedure.getCheckNumber(), "CHECK_NUMBER");
		sql.addDoubleParam(embryoTransferProcedure.getRecipientWeight(), "MOUSE_WEIGHT");
		sql.addIntParam(embryoTransferProcedure.getNumberRight(), "NUMBER_RIGHT");
		sql.addIntParam(embryoTransferProcedure.getNumberLeft(), "NUMBER_LEFT");
		sql.addLongParam(embryoTransferProcedure.getAnaestheticDictId(), "ANAESTHETIC_DICT_ID");
		sql.addDoubleParam(embryoTransferProcedure.getDoseAnaesthetic(), "DOSE_ANESTHETIC");
		sql.addLongParam(embryoTransferProcedure.getAnalgesiaDictId(), "ANALGESIA_DICT_ID");
		sql.addDoubleParam(embryoTransferProcedure.getDoseAnalgesia(), "DOSE_ANALGESIA");
		sql.addLongParam(embryoTransferProcedure.getTransferTypeDictId(), "TRANSFER_TYPE_DICT_ID");
		sql.addLongParam(embryoTransferProcedure.getStufferStrainDictId(), "STUFFER_STRAIN_ID");
		sql.addIntParam(embryoTransferProcedure.getNumberRightStuffers(), "NUMBER_RIGHT_STUFFERS");
		sql.addIntParam(embryoTransferProcedure.getNumberLeftStuffers(), "NUMBER_LEFT_STUFFERS");
		sql.addStringParam(embryoTransferProcedure.getComments(), "COMMENTS");
		sql.addLongParam(embryoTransferProcedure.getScheduledMicroInjectionId(), "SCHEDULED_MICRO_INJECTION_ID");
		sql.addLongParam(embryoTransferProcedure.getMouseId(), "MOUSE_ID");
		sql.addLongParam(embryoTransferProcedure.getThawTestId(), "THAW_TEST_ID");
		sql.addStringParam(embryoTransferProcedure.getDaysFromPlug(), "DAYS_FROM_PLUG");
		sql.addLongParam(embryoTransferProcedure.getId(), "ID");
	}
	
}