/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.miprocessing.dao;

import org.springframework.dao.IncorrectResultSizeDataAccessException;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.miprocessing.MicroInjection;


public class MicroInjectionDaoSpringImpl extends AbstractDaoSpringImpl<MicroInjection> implements MicroInjectionDao {
	
	public MicroInjection fetchBySmiJobId(Long smiId) {
		String sql = " select * from " + getTableName() + " where scheduled_micro_injection_id = ? ";
		
		MicroInjection microInjection = null;
		
		try {
		
			microInjection = getSimpleJdbcTemplate().queryForObject(sql, getRowMapper(), smiId);	
		
		} catch(IncorrectResultSizeDataAccessException e) {}
		
		return microInjection;
	}
	
	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, MicroInjection microInjection) {
		sql.addDateParam(microInjection.getCreatedDate(), "CREATED_DATE");
		sql.addStringParam(microInjection.getEditedBy(), "EDITED_BY");
		sql.addDateParam(microInjection.getEditDate(), "EDIT_DATE");
		sql.addLongParam(microInjection.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(microInjection.getEmbryoStageDictId(), "EMBRYO_STAGE_DICT_ID");
		sql.addIntParam(microInjection.getInjectedEmbryoCount(), "EMBRYO_COUNT");
		//sql.addIntParam(microInjection.getEsCellPerEmbryo(), "ES_CELL_PER_EMBRYO");
		sql.addDateParam(microInjection.getDateCompleted(), "DATE_COMPLETED");
		sql.addStringParam(microInjection.getComments(), "COMMENTS");
		sql.addLongParam(microInjection.getCreatorId(), "CREATOR_ID");
		sql.addLongParam(microInjection.getTechnicianId(), "TECHNICIAN_ID");
		sql.addLongParam(microInjection.getScheduledMicroInjectionId(), "SCHEDULED_MICRO_INJECTION_ID");
		sql.addLongParam(microInjection.getEmbryoHarvestId(), "EMBRYO_HARVEST_ID");
		sql.addIntParam(microInjection.getEsCellsPerEmbryoFrom(), "ES_CELLS_PER_EMBRYO_FROM");
		sql.addIntParam(microInjection.getEsCellsPerEmbryoTo(), "ES_CELLS_PER_EMBRYO_TO");	
		sql.addLongParam(microInjection.getId(), "ID");
	}
	

	public MicroInjection fetchByEmbryoHarvestId(Long embryoHarvestId) {
		MicroInjection microInjection = null;
		String sql = " select * from " + getTableName() + " where EMBRYO_HARVEST_ID = ? ";
		try {
			microInjection = getSimpleJdbcTemplate().queryForObject(sql, getRowMapper(), embryoHarvestId);	
		}
		catch(IncorrectResultSizeDataAccessException e) {
			
		}
		
		return microInjection;
	}

	
	/*		
	public Collection<MicroInjection> search(MicroInjectionSearchBean microInjectionSearchBean) {
			// TODO Auto-generated method stub
		
		Collection<Object> bindVariables = new ArrayList<Object>();	
		
		String sql=" select m.* from mir_micro_injection m  where 1=1 ";
		
		// ID
		if(microInjectionSearchBean.getId() != null) {
			sql += " and m.id = ? ";
			bindVariables.add(microInjectionSearchBean.getId());
		}
		
		// CellLineId
		if(microInjectionSearchBean.getActualCellLineId() != null) {
			sql += " and m.cell_line_id = ? ";
			bindVariables.add(microInjectionSearchBean.getActualCellLineId());
		}
		
		//Date completed (from)
		if(microInjectionSearchBean.getFromDateCompleted() != null) {
			sql += " and m.date_completed >= ? ";
			bindVariables.add( microInjectionSearchBean.getFromDateCompleted() );				
		}
		
		//	Date completed (to)
		if(microInjectionSearchBean.getToDateCompleted() != null) {
			sql += " and m.date_completed <= ? ";
			bindVariables.add( microInjectionSearchBean.getToDateCompleted() );				
		}
	
		//Actual creatorId (technician)
		if(microInjectionSearchBean.getCreatorId() != null) {
			sql += " and m.creator_id = ? ";
			bindVariables.add(microInjectionSearchBean.getCreatorId());
		}
		
		//Scheduled Micro Injection id
		if(microInjectionSearchBean.getScheduledMicroInjectionId() != null) {
			sql += " and m.scheduled_micro_injection_id = ? ";
			bindVariables.add(microInjectionSearchBean.getScheduledMicroInjectionId());
		}
		
		//embryo stage dict id
		if(microInjectionSearchBean.getEmbryoStageDictId() != null) {
			sql += " and m.embryo_stage_id = ? ";
			bindVariables.add(microInjectionSearchBean.getEmbryoStageDictId());
		}
		
		//embryo count (from)
		if(microInjectionSearchBean.getFromEmbryoCount() != null) {
			sql += " and m.embryo_count >= ? ";
			bindVariables.add(microInjectionSearchBean.getFromEmbryoCount());
		}
		
		//embryo count (to)
		if(microInjectionSearchBean.getToEmbryoCount() != null) {
			sql += " and m.embryo_count <= ? ";
			bindVariables.add(microInjectionSearchBean.getToEmbryoCount());
		}
	
		//es cell per embryo (from)
		if(microInjectionSearchBean.getEsCellsPerEmbryoFrom() != null) {
			sql += " and m.ES_CELLS_PER_EMBRYO_FROM = ? ";
			bindVariables.add(microInjectionSearchBean.getEsCellsPerEmbryoFrom());
		}
	
		//es cell per embryo (to)
		if(microInjectionSearchBean.getEsCellsPerEmbryoTo()  != null) {
			sql += " and m.es_cell_per_embryo = ? ";
			bindVariables.add(microInjectionSearchBean.getEsCellsPerEmbryoTo() );
		}	
	
		//comments
		if(microInjectionSearchBean.getComments()!=null && !microInjectionSearchBean.getComments().equals("")){
			sql += " and lower(comments) like lower('%?%') ";
			bindVariables.add(microInjectionSearchBean.getComments());
		}
		//paginator 
		sql += " order by ";	
		if(microInjectionSearchBean.getOrderBy().equals("")) {
			sql += "id ";
		}
		else {
			sql += microInjectionSearchBean.getOrderBy();
		}
		
		if(microInjectionSearchBean.isOrderDesc()) {
			sql += " desc ";
		}
		
		logger.debug(sql);
		
		//return paginator.fetchSearchResults(sql, bindVariables, microInjectionSearchBean, getRowMapper());	
		return null;
	}
*/
	
}