/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.miprocessing.dao;

import java.util.ArrayList;
import java.util.List;

import org.springframework.dao.IncorrectResultSizeDataAccessException;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.miprocessing.ScheduledMiTask;
import uk.ac.sanger.mig.miprocessing.workflow.Task;


public class ScheduledMiTaskDaoSpringImpl extends AbstractDaoSpringImpl<ScheduledMiTask> implements ScheduledMiTaskDao {
		
	public List<Task> fetchSubsequentTasks(ScheduledMiTask scheduledMiTask) {
		String sql = " select * from " + getTableName() + 
		" where scheduled_micro_injection_id = ? and estimated_completion_date > ? ";
		List tasks = getSimpleJdbcTemplate().query(sql, getRowMapper(), 
				scheduledMiTask.getParentJobId(), 
				scheduledMiTask.getEstimatedCompletionDate());
		return (tasks == null) ? new ArrayList<Task>() : tasks;
	}


	public List<Task> fetchAllBySmiJobId(Long smiJobId) {
		String sql = " select * from " + getTableName() + " where scheduled_micro_injection_id = ? order by sequence_number ";
		List tasks = getSimpleJdbcTemplate().query(sql, getRowMapper(), smiJobId);
		//note: we only have smi id ref to parent not actual SMI obj ref	
		return (tasks == null) ? new ArrayList<Task>() : tasks;
		
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, ScheduledMiTask scheduledMiTask) {
		sql.addLongParam(scheduledMiTask.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(scheduledMiTask.getCreatedDate(), "CREATED_DATE");
		sql.addStringParam(scheduledMiTask.getEditedBy(), "EDITED_BY");
		sql.addDateParam(scheduledMiTask.getEditDate(), "EDITED_DATE");
		sql.addLongParam(scheduledMiTask.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(scheduledMiTask.getParentJobId(), "scheduled_micro_injection_id");
		sql.addDateParam(scheduledMiTask.getActualCompletionDate(), "actual_completion_date");
		sql.addDateParam(scheduledMiTask.getEstimatedCompletionDate(), "estimated_completion_date");
		sql.addIntParam(scheduledMiTask.getSequenceNumber(), "sequence_number");
		sql.addStringParam(scheduledMiTask.getDescription(), "description");
		sql.addStringParam(scheduledMiTask.getName(), "name");
		sql.addBooleanParam(scheduledMiTask.isMilestone(), "is_milestone");
		sql.addLongParam(scheduledMiTask.getTaskGroupDictId(), "task_group_id");
		sql.addLongParam(scheduledMiTask.getId(), "ID");
	}


	public ScheduledMiTask fetchBySmiIdAndTaskName(Long smiId, String taskName) {
		
		String sql = " select * from " + getTableName() + " where scheduled_micro_injection_id = ? and name = ?";
		ScheduledMiTask smiTask = null;
		try {
			smiTask = getSimpleJdbcTemplate().queryForObject(sql, getRowMapper(), smiId,taskName);
		} catch (IncorrectResultSizeDataAccessException e) {}
		
		return smiTask;
	}


	
}