/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.miprocessing.dao;

import java.util.Collection;

import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.database.TypedDao;
import uk.ac.sanger.mig.miprocessing.ScheduledMicroInjectionJob;
import uk.ac.sanger.mig.miprocessing.ScheduledMicroInjectionSearchBean;
import uk.ac.sanger.mig.miprocessing.views.ScheduledMicroInjectionListView;
																
	 
	public interface ScheduledMicroInjectionDao extends TypedDao<ScheduledMicroInjectionJob> {
	
		public Collection<ScheduledMicroInjectionListView> search(ScheduledMicroInjectionSearchBean 
				scheduledMicroInjectionSearchBean);
		
		/**
		 * Used by Quartz which needs all records and has no session ID, 
		 * which pagination requires.
		 * 
		 * @param scheduledMicroInjectionSearchBean
		 * @return
		 */
		public Collection<ScheduledMicroInjectionListView> searchAllNonPaginated(ScheduledMicroInjectionSearchBean 
				scheduledMicroInjectionSearchBean);
		
		
		public Collection<ScheduledMicroInjectionJob> fetchAllActive();
		
		public Collection<ScheduledMicroInjectionJob> fetchAllByMiRequestId(Long miRequestId);
	
		/**
		 * Given a particular ES cell line strain, returns the paternal
		 * Mouse strain required for future coat color testing when 
		 * generating blastocysts to be harvested for micro-injection.
		 * 
		 * Returns null if RequiredDonorStrain could not be found for a 
		 * given cell line strain.
		 * 
		 * Throws IllegalArgumentException if cellLineStrainDictId is null.
		 * 
		 * @param cellLineStrainDictId
		 * @return
		 */
		public DictionaryEntry fetchRequiredDonorStrain(Long cellLineStrainDictId);
}