/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.miprocessing.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.miprocessing.EmbryoHarvest;

public class EmbryoHarvestRowMapper implements ParameterizedRowMapper<EmbryoHarvest> {
	
	private DictionaryService dictionaryService;

	public void setDictionaryService (DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}
	
	public EmbryoHarvest mapRow(ResultSet rs, int rowNum) throws SQLException {
		
		EmbryoHarvest embryoHarvest = new EmbryoHarvest();
		
		embryoHarvest.setId(rs.getLong("ID"));
		embryoHarvest.setEditDate(rs.getDate("EDITED_DATE"));
		embryoHarvest.setEditedBy(rs.getString("EDITED_BY"));
		embryoHarvest.setCreatedDate(rs.getDate("CREATED_DATE"));
		embryoHarvest.setCreatorId(rs.getLong("CREATOR_ID"));	
		embryoHarvest.setTechnicianId(rs.getLong("TECHNICIAN_ID"));
		if(rs.wasNull()) embryoHarvest.setTechnicianId(null);
		embryoHarvest.setUseBlastocysts(rs.getBoolean("USE_BLASTOCYST"));
		embryoHarvest.setUseMoralae(rs.getBoolean("USE_MORALAE"));
		embryoHarvest.setUseEightCells(rs.getBoolean("USE_EIGHT_CELLS"));
		embryoHarvest.setUseEightCellNonComp(rs.getBoolean("USE_EIGHT_CELLS_NON_COMP"));
		embryoHarvest.setUseFourCell(rs.getBoolean("USE_FOUR_CELLS"));
		embryoHarvest.setUseHatched(rs.getBoolean("USE_HATCHED"));
		embryoHarvest.setUseDeadOrFragmented(rs.getBoolean("USE_DEAD_OR_FRAGMENTED"));
		embryoHarvest.setUseOther(rs.getBoolean("USE_OTHER"));
		
		
		embryoHarvest.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) embryoHarvest.setCheckNumber(null);	
		
		embryoHarvest.setComments(rs.getString("COMMENTS"));
		
		embryoHarvest.setBlastocystCount(rs.getInt("BLASTOCYST_COUNT"));
		if(rs.wasNull()) embryoHarvest.setBlastocystCount(null);		
		
		embryoHarvest.setMoralaeCount(rs.getInt("MORALAE_COUNT"));
		if(rs.wasNull()) embryoHarvest.setMoralaeCount(null);		
		
		embryoHarvest.setEightCellCompCount(rs.getInt("EIGHT_CELL_COMP_COUNT"));
		if(rs.wasNull()) embryoHarvest.setEightCellCompCount(null);		
		
		embryoHarvest.setEightCellNonCompCount(rs.getInt("EIGHT_CELL_NON_COMP_COUNT"));
		if(rs.wasNull()) embryoHarvest.setEightCellNonCompCount(null);		
		
		embryoHarvest.setFourCellCount(rs.getInt("FOUR_CELL_COUNT"));
		if(rs.wasNull()) embryoHarvest.setFourCellCount(null);		
		
		embryoHarvest.setHatchedCount(rs.getInt("HATCHED_COUNT"));
		if(rs.wasNull()) embryoHarvest.setHatchedCount(null);		
		
		embryoHarvest.setDeadOrFragmentedCount(rs.getInt("DEAD_OR_FRAGMENTED_COUNT"));
		if(rs.wasNull()) embryoHarvest.setDeadOrFragmentedCount(null);		
		
		embryoHarvest.setOtherEmbryoTypeCount(rs.getInt("OTHER_EMBRYO_TYPE_COUNT"));
		if(rs.wasNull()) embryoHarvest.setOtherEmbryoTypeCount(null);		
    
		embryoHarvest.setOvernightIncubation(rs.getBoolean("OVERNIGHT_INCUBATION"));	
		
		embryoHarvest.setPlugCheckDate(rs.getTimestamp("PLUG_CHECK_DATE"));
		embryoHarvest.setFlushDate(rs.getTimestamp("FLUSH_DATE"));			

		embryoHarvest.setTotalDonors(rs.getInt("TOTAL_DONORS"));
		if(rs.wasNull()) embryoHarvest.setTotalDonors(null);

		embryoHarvest.setMotherStrainId((rs.getLong("MOTHER_STRAIN_ID")));
		embryoHarvest.setFatherStrainId((rs.getLong("FATHER_STRAIN_ID")));
		//embryoHarvest.setMotherCoatColourDictId((rs.getLong("MOTHER_COAT_COLOUR_DICT_ID")));
		//embryoHarvest.setFatherCoatColourDictId((rs.getLong("FATHER_COAT_COLOUR_DICT_ID")));

		//populate dictionaries
		DictionaryEntry motherStrain = dictionaryService.fetchEntry(DictionaryEnum.MOUSE_STRAIN, 
				embryoHarvest.getMotherStrainId());
		embryoHarvest.setMotherStrain( motherStrain );		

		DictionaryEntry fatherStrain = dictionaryService.fetchEntry(DictionaryEnum.MOUSE_STRAIN, 
				embryoHarvest.getFatherStrainId());
		embryoHarvest.setFatherStrain( fatherStrain );
		
		//DictionaryEntry motherCoatColourDict = dictionaryService.fetchEntry(DictionaryEnum.MOUSE_COAT_COLOUR, 
		//		embryoHarvest.getMotherCoatColourDictId());
		//embryoHarvest.setMotherCoatColourDict( motherCoatColourDict );	
	
		//DictionaryEntry fatherCoatColourDict = dictionaryService.fetchEntry(DictionaryEnum.MOUSE_COAT_COLOUR, 
		//		embryoHarvest.getFatherCoatColourDictId());
		//embryoHarvest.setFatherCoatColourDict( fatherCoatColourDict );
		

		return embryoHarvest;
		
	}
}