/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.miprocessing.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.miprocessing.EmbryoTransferProcedure;

public class EmbryoTransferProcedureRowMapper implements ParameterizedRowMapper<EmbryoTransferProcedure> {
	
	private DictionaryService dictionaryService;

	public void setDictionaryService (DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	public EmbryoTransferProcedure mapRow(ResultSet rs, int rowNum) throws SQLException {
		
		EmbryoTransferProcedure embryoTransferProcedure = new EmbryoTransferProcedure();
		
		embryoTransferProcedure.setId(rs.getLong("ID"));

		embryoTransferProcedure.setCreatedDate(rs.getTimestamp("CREATED_DATE"));

		embryoTransferProcedure.setEditedBy(rs.getString("EDITED_BY"));

		embryoTransferProcedure.setEditDate(rs.getTimestamp("EDIT_DATE"));

		embryoTransferProcedure.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) embryoTransferProcedure.setCheckNumber(null);		

		embryoTransferProcedure.setRecipientWeight(rs.getDouble("MOUSE_WEIGHT"));
		if(rs.wasNull()) embryoTransferProcedure.setRecipientWeight(null);
		
		embryoTransferProcedure.setNumberRight(rs.getInt("NUMBER_RIGHT"));
		if(rs.wasNull()) embryoTransferProcedure.setNumberRight(null);
		
		embryoTransferProcedure.setNumberLeft(rs.getInt("NUMBER_LEFT"));
		if(rs.wasNull()) embryoTransferProcedure.setNumberLeft(null);

		embryoTransferProcedure.setAnaestheticDictId(rs.getLong("ANAESTHETIC_DICT_ID"));
		if(rs.wasNull()) embryoTransferProcedure.setAnaestheticDictId(null);		
		
		embryoTransferProcedure.setDoseAnaesthetic( rs.getDouble("DOSE_ANESTHETIC") );
		if(rs.wasNull()) embryoTransferProcedure.setDoseAnaesthetic(null);
		
		embryoTransferProcedure.setAnalgesiaDictId(rs.getLong("ANALGESIA_DICT_ID"));
		if(rs.wasNull()) embryoTransferProcedure.setAnalgesiaDictId(null);		

		embryoTransferProcedure.setDoseAnalgesia(rs.getDouble("DOSE_ANALGESIA"));
		if(rs.wasNull()) embryoTransferProcedure.setDoseAnalgesia(null);

		embryoTransferProcedure.setTransferTypeDictId(rs.getLong("TRANSFER_TYPE_DICT_ID"));
		if(rs.wasNull()) embryoTransferProcedure.setTransferTypeDictId(null);		

		embryoTransferProcedure.setStufferStrainDictId(rs.getLong("STUFFER_STRAIN_ID"));
		if(rs.wasNull()) embryoTransferProcedure.setStufferStrainDictId(null);		

		embryoTransferProcedure.setNumberRightStuffers(rs.getInt("NUMBER_RIGHT_STUFFERS"));
		if(rs.wasNull()) embryoTransferProcedure.setNumberRightStuffers(null);

		embryoTransferProcedure.setNumberLeftStuffers(rs.getInt("NUMBER_LEFT_STUFFERS"));
		if(rs.wasNull()) embryoTransferProcedure.setNumberLeftStuffers(null);

		embryoTransferProcedure.setCreatorId(rs.getLong("CREATOR_ID"));
		if(rs.wasNull()) embryoTransferProcedure.setCreatorId(null);	
		
		embryoTransferProcedure.setMouseId(rs.getLong("MOUSE_ID"));
		if(rs.wasNull()) embryoTransferProcedure.setMouseId(null);	
		
		embryoTransferProcedure.setComments(rs.getString("COMMENTS"));
		
		embryoTransferProcedure.setDaysFromPlug( rs.getString("DAYS_FROM_PLUG") );
		
		embryoTransferProcedure.setScheduledMicroInjectionId(rs.getLong("SCHEDULED_MICRO_INJECTION_ID"));
		if(rs.wasNull()) embryoTransferProcedure.setScheduledMicroInjectionId(null);	
		
		embryoTransferProcedure.setThawTestId(rs.getLong("THAW_TEST_ID"));
		if(rs.wasNull()) embryoTransferProcedure.setThawTestId(null);	
	
		//populate dictionaries
		DictionaryEntry anaesthetic = dictionaryService.fetchEntry(DictionaryEnum.MIR_ANAESTHETIC_DICT, 
					embryoTransferProcedure.getAnaestheticDictId());
		embryoTransferProcedure.setAnaestheticDict(  anaesthetic );

		DictionaryEntry analgesia = dictionaryService.fetchEntry(DictionaryEnum.MIR_ANALGESIA_DICT, 
				embryoTransferProcedure.getAnalgesiaDictId());
		embryoTransferProcedure.setAnalgesiaDict( analgesia );

		DictionaryEntry transferType = dictionaryService.fetchEntry(DictionaryEnum.MIR_TRANSFER_TYPE_DICT, 
				embryoTransferProcedure.getTransferTypeDictId());
		embryoTransferProcedure.setTransferTypeDict( transferType );
		
		DictionaryEntry stufferStrain = dictionaryService.fetchEntry(DictionaryEnum.MOUSE_STRAIN, 
				embryoTransferProcedure.getStufferStrainDictId());
		embryoTransferProcedure.setStufferStrainDict( stufferStrain );		
		
		return embryoTransferProcedure;
		
	}
}