/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.miprocessing.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.miprocessing.MicroInjection;

public class MicroInjectionRowMapper implements ParameterizedRowMapper<MicroInjection> {
	
	private DictionaryService dictionaryService;

	public void setDictionaryService (DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}
	
	public MicroInjection mapRow(ResultSet rs, int rowNum) throws SQLException {
		
		MicroInjection microInjection = new MicroInjection();
		
		microInjection.setId(rs.getLong("ID"));
		microInjection.setCreatedDate(rs.getDate("CREATED_DATE"));
		microInjection.setEditedBy(rs.getString("EDITED_BY"));
		microInjection.setEditDate(rs.getDate("EDIT_DATE"));
		microInjection.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) microInjection.setCheckNumber(null);	
		
		microInjection.setEmbryoStageDictId(rs.getLong("EMBRYO_STAGE_DICT_ID"));
		if(rs.wasNull()) microInjection.setEmbryoStageDictId(null);	
		
		microInjection.setEmbryoStageDict(dictionaryService.fetchEntry(DictionaryEnum.MIR_EMBRYO_STAGE_DICT, 
				microInjection.getEmbryoStageDictId()));	
		
		microInjection.setInjectedEmbryoCount(rs.getInt("EMBRYO_COUNT"));
		if(rs.wasNull()) microInjection.setInjectedEmbryoCount(null);		

		microInjection.setEsCellsPerEmbryoFrom(rs.getInt("ES_CELLS_PER_EMBRYO_FROM"));
		if(rs.wasNull()) microInjection.setEsCellsPerEmbryoFrom(null);		

		microInjection.setEsCellsPerEmbryoTo(rs.getInt("ES_CELLS_PER_EMBRYO_TO"));
		if(rs.wasNull()) microInjection.setEsCellsPerEmbryoTo(null);	
		
		microInjection.setDateCompleted(rs.getDate("DATE_COMPLETED"));
		microInjection.setComments(rs.getString("COMMENTS"));
		microInjection.setCreatorId(rs.getLong("CREATOR_ID"));
		if(rs.wasNull()) microInjection.setCreatorId(null);		
		microInjection.setScheduledMicroInjectionId(rs.getLong("SCHEDULED_MICRO_INJECTION_ID"));
		if(rs.wasNull()) microInjection.setScheduledMicroInjectionId(null);		
		
		microInjection.setEmbryoHarvestId(rs.getLong("EMBRYO_HARVEST_ID"));
		if(rs.wasNull()) microInjection.setEmbryoHarvestId(null);
		
		microInjection.setTechnicianId(rs.getLong("TECHNICIAN_ID"));
		if(rs.wasNull()) microInjection.setTechnicianId(null);
		
		return microInjection;
		
	}
}