/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.miprocessing.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.miprocessing.views.ScheduledMicroInjectionListView;


public class ScheduledMicroInjectionListViewRowMapper implements ParameterizedRowMapper<ScheduledMicroInjectionListView> {

	public ScheduledMicroInjectionListView mapRow(ResultSet rs, int rowNum) throws SQLException {	
		ScheduledMicroInjectionListView smiListView = new ScheduledMicroInjectionListView();	
		smiListView.setId(rs.getLong("id"));
		smiListView.setCellLineProviderNameNo(rs.getString("cell_line_provider_name_no"));
		smiListView.setDonorAnimalRequestId(rs.getLong("donor_animal_request_id"));
		if(rs.wasNull()) smiListView.setDonorAnimalRequestId(null);	
		smiListView.setRecipientAnimalRequestId(rs.getLong("recipient_animal_request_id"));
		if(rs.wasNull()) smiListView.setRecipientAnimalRequestId(null);
		smiListView.setSupplementalRecipientAnimalRequestId(rs.getLong("supplemental_recipient_req_id"));
		if(rs.wasNull()) smiListView.setSupplementalRecipientAnimalRequestId(null);
		smiListView.setInternalStatusId(rs.getLong("internal_status_id"));
		smiListView.setInternalStatusName(rs.getString("internal_status_name"));
		smiListView.setEndpointId(rs.getLong("endpoint_id"));
		smiListView.setEndpointName(rs.getString("endpoint_name"));
		smiListView.setTargetScheduleDate(rs.getDate("target_schedule_date"));
		smiListView.setMiRequestId(rs.getLong("micro_injection_request_id"));
		smiListView.setMiCompletionDate(rs.getDate("mi_actual_completion_date"));
		smiListView.setEmbryoTransferCompletionDate(rs.getDate("et_actual_completion_date"));
		smiListView.setF0CompletionDate(rs.getDate("f0_actual_completion_date"));
		smiListView.setF1CompletionDate(rs.getDate("f1_actual_completion_date"));

		smiListView.setRecipientMouseCount(rs.getInt("recipient_mouse_count"));
		smiListView.setDonorMouseCount(rs.getInt("donor_mouse_count"));
		smiListView.setSupplementalMouseCount(rs.getInt("supplemental_mouse_count"));
		smiListView.setRequesterName(rs.getString("requester_name"));
		smiListView.setMicroInjectionId(rs.getLong("micro_injection_id"));
	    smiListView.setCellLineName(rs.getString("cell_line_name"));
	    smiListView.setCellLineClone(rs.getString("cell_line_clone"));
	   	    
	    smiListView.setF0Status(rs.getString("F0_STATUS"));
	    smiListView.setF1Status(rs.getString("F1_STATUS"));
	    
	    smiListView.setJobId( rs.getString("job_id") );
	    
		return smiListView;
	}
}