/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.miprocessing.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.miprocessing.ScheduledMicroInjectionJob;

public class ScheduledMicroInjectionRowMapper implements ParameterizedRowMapper<ScheduledMicroInjectionJob> {
	
	
	private DictionaryService dictionaryService;

	public void setDictionaryService (DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}
	
	public ScheduledMicroInjectionJob mapRow(ResultSet rs, int rowNum) throws SQLException {
		
		ScheduledMicroInjectionJob scheduledMicroInjection = new ScheduledMicroInjectionJob();
		
		scheduledMicroInjection.setId(rs.getLong("ID"));
		scheduledMicroInjection.setCellLineProviderId(rs.getLong("CELL_LINE_PROVIDER_ID"));
		if(rs.wasNull()) scheduledMicroInjection.setCellLineProviderId(null);
		scheduledMicroInjection.setCreatorId(rs.getLong("CREATOR_ID"));
		if(rs.wasNull()) scheduledMicroInjection.setCreatorId(null);		
		scheduledMicroInjection.setCreatedDate(rs.getDate("CREATED_DATE"));
		scheduledMicroInjection.setEditedBy(rs.getString("EDITED_BY"));
		scheduledMicroInjection.setEditDate(rs.getDate("EDITED_DATE"));
		scheduledMicroInjection.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) scheduledMicroInjection.setCheckNumber(null);		
		
		scheduledMicroInjection.setScheduledMiStatusDictId(rs.getLong("INTERNAL_STATUS_DICT_ID"));		
		if(rs.wasNull()) scheduledMicroInjection.setScheduledMiStatusDictId(null);
				
		DictionaryEntry scheduledMiStatus = dictionaryService.fetchEntry(DictionaryEnum.MIR_INTERNAL_STATUS_DICT, 
				scheduledMicroInjection.getScheduledMiStatusDictId());
		
		scheduledMicroInjection.setScheduledMiStatusDict( scheduledMiStatus );					
		scheduledMicroInjection.setAnchorDate(rs.getDate("TARGET_SCHEDULE_DATE"));
	
		scheduledMicroInjection.setMicroInjectionRequestId(rs.getLong("MICRO_INJECTION_REQUEST_ID"));
		if(rs.wasNull()) scheduledMicroInjection.setMicroInjectionRequestId(null);		
		
		scheduledMicroInjection.setDonorAnimalRequestId(rs.getLong("DONOR_ANIMAL_REQUEST_ID"));
		if(rs.wasNull()) scheduledMicroInjection.setDonorAnimalRequestId(null);		
		
		scheduledMicroInjection.setRecipientAnimalRequestId(rs.getLong("RECIPIENT_ANIMAL_REQUEST_ID"));
		if(rs.wasNull()) scheduledMicroInjection.setRecipientAnimalRequestId(null);		
		
		scheduledMicroInjection.setSupplementalRecipientAnimalRequestId(rs.getLong("SUPPLEMENTAL_RECIPIENT_REQ_ID"));
		if(rs.wasNull()) scheduledMicroInjection.setSupplementalRecipientAnimalRequestId(null);	
		
		scheduledMicroInjection.setComments(rs.getString("COMMENTS"));	
		scheduledMicroInjection.setCancelOrFailReasons(rs.getString("CANCEL_OR_FAIL_REASONS"));
		
		scheduledMicroInjection.setJobId(rs.getString("JOB_ID"));
		
		return scheduledMicroInjection;
		
	}
}