/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.miprocessing.forms;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.SortedMap;
import java.util.TreeMap;

import uk.ac.sanger.mig.animalrequest.AnimalRequest;
import uk.ac.sanger.mig.animalrequest.NullAnimalRequest;
import uk.ac.sanger.mig.animalrequest.AnimalRequest.Group;
import uk.ac.sanger.mig.miprocessing.EmbryoHarvest;
import uk.ac.sanger.mig.personnel.Person;

/**
 * Form object that holds Set of DefaultAnimalRequests
 * @author ae1
 *
 */
public class BatchWildtypeRequestForm {

	private SortedMap<Date, List<AnimalRequest>> dailyRequestsCache 
		= new TreeMap<Date, List<AnimalRequest>> (); 	
	private Date dateRequired;
	private Integer albinoDonorCount, blackDonorCount, recipientCount;
	private String additionalEmailNotes;
	private static final Long TMP_PPL_ID = 98L;//temp under na5's PPL
	private boolean add, delete;
	private Person requester;

	
	
	
	public Person getRequester() {
		return this.requester;
	}

	public void setRequester(Person requester) {
		this.requester = requester;
	}

	public boolean isAdd() {
		return this.add;
	}

	public void setAdd(boolean add) {
		this.add = add;
	}

	public boolean isDelete() {
		return this.delete;
	}

	public void setDelete(boolean delete) {
		this.delete = delete;
	}

	public String getAdditionalEmailNotes() {
		return this.additionalEmailNotes;
	}

	public void setAdditionalEmailNotes(String additionalEmailNotes) {
		this.additionalEmailNotes = additionalEmailNotes;
	}

	public void addDailyRequests(Person user) {
		
		List<AnimalRequest> dailyRequestList = new ArrayList<AnimalRequest>();
		AnimalRequest albinoDonorRequest = null;
		AnimalRequest blackDonorRequest = null;
		AnimalRequest recipientRequest = null;
		
		if( albinoDonorCount != null && albinoDonorCount > 0) {
			albinoDonorRequest = AnimalRequest.createDefaultGroupRequest(Group.MICRO_INJECTION_EMBRYO_DONORS,
					dateRequired, user, TMP_PPL_ID);	
			albinoDonorRequest.setStrainId( EmbryoHarvest.getPaternalDonorStrainForAlbino() );	
			albinoDonorRequest.setNumFemalesNeeded( albinoDonorCount );		
		
		} else albinoDonorRequest = new NullAnimalRequest();
		
		if( blackDonorCount != null && blackDonorCount > 0) {
			blackDonorRequest = AnimalRequest.createDefaultGroupRequest(Group.MICRO_INJECTION_EMBRYO_DONORS,
					dateRequired, user, TMP_PPL_ID);	
			blackDonorRequest.setStrainId( EmbryoHarvest.getPaternalDonorStrainForBlack() );	
			blackDonorRequest.setNumFemalesNeeded( blackDonorCount );	
		
		} else blackDonorRequest = new NullAnimalRequest();
		
		if(  recipientCount != null && recipientCount > 0) {
			recipientRequest = AnimalRequest.createDefaultGroupRequest(Group.MICRO_INJECTION_EMBRYO_RECIPIENTS,
					dateRequired, user, TMP_PPL_ID );		
			recipientRequest.setNumFemalesNeeded( recipientCount );	
			
		} else recipientRequest = new NullAnimalRequest();
		
		dailyRequestList.add( albinoDonorRequest );
		dailyRequestList.add( blackDonorRequest );
		dailyRequestList.add( recipientRequest );
		dailyRequestsCache.put( getDateRequired(), dailyRequestList );
		clear();
	}
	
	public void removeDailyRequests() {
		dailyRequestsCache.remove( getDateRequired() );
		clear();
	}
	
	public Integer getAlbinoDonorCount() {
		return this.albinoDonorCount;
	}

	public void setAlbinoDonorCount(Integer albinoDonorCount) {
		this.albinoDonorCount = albinoDonorCount;
	}

	public Integer getBlackDonorCount() {
		return this.blackDonorCount;
	}

	public void setBlackDonorCount(Integer blackDonorCount) {
		this.blackDonorCount = blackDonorCount;
	}

	public Date getDateRequired() {
		return this.dateRequired;
	}

	public void setDateRequired(Date dateRequired) {
		this.dateRequired = dateRequired;
	}

	public Integer getRecipientCount() {
		return this.recipientCount;
	}

	public void setRecipientCount(Integer recipientCount) {
		this.recipientCount = recipientCount;
	}

	public SortedMap<Date, List<AnimalRequest>> getDailyRequestsCache() {
		return this.dailyRequestsCache;
	}
	
	private void clear() {
		this.add = false;
		this.delete = false;
		this.dateRequired = null;
		this.albinoDonorCount = null;
		this.blackDonorCount = null;
		this.recipientCount = null;		
	}
}
