/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.miprocessing.forms;


import java.util.Date;

import uk.ac.sanger.mig.miprocessing.EmbryoHarvest;

public class EmbryoHarvestForm {

	private EmbryoHarvest embryoHarvest;
	private String redirect;
	private Long smiId;
	private Long redirectId;
	private Date defaultMiDateCompleted;
	private Long embryoHarvestId;
	private Integer oldInjectableCount;

	public Integer getInjectableCount() {
		int injectableCount=0;
		if(this.embryoHarvest.isUseBlastocysts())
			injectableCount+=this.embryoHarvest.getBlastocystCount();
		if(this.embryoHarvest.isUseMoralae())
			injectableCount+=this.embryoHarvest.getMoralaeCount();
		if(this.embryoHarvest.isUseEightCells())
			injectableCount+=this.embryoHarvest.getEightCellCompCount();
		if(this.embryoHarvest.isUseEightCellNonComp())
			injectableCount+=this.embryoHarvest.getEightCellNonCompCount();
		if(this.embryoHarvest.isUseFourCell())
			injectableCount+=this.embryoHarvest.getFourCellCount();
		if(this.embryoHarvest.isUseHatched())
			injectableCount+=this.embryoHarvest.getHatchedCount();
		if(this.embryoHarvest.isUseDeadOrFragmented())
			injectableCount+=this.embryoHarvest.getDeadOrFragmentedCount();
		if(this.embryoHarvest.isUseOther())
			injectableCount+=this.embryoHarvest.getOtherEmbryoTypeCount();

		return injectableCount;
	}


	//////////////////////////////////////////////////////////
	///////////////// bit bucket methods /////////////////////
	//////////////////////////////////////////////////////////

	public Integer getOldInjectableCount() {
		return oldInjectableCount;
	}

	public void setOldInjectableCount(Integer oldInjectableCount) {
		this.oldInjectableCount = oldInjectableCount;
	}

	public EmbryoHarvest getEmbryoHarvest() {
		return embryoHarvest;
	}

	public void setEmbryoHarvest(EmbryoHarvest embryoHarvest) {
		this.embryoHarvest = embryoHarvest;
	}

	public String getRedirect() {
		return redirect;
	}

	public void setRedirect(String redirect) {
		this.redirect = redirect;
	}

	public Long getRedirectId() {
		return redirectId;
	}

	public void setRedirectId(Long redirectId) {
		this.redirectId = redirectId;
	}

	public Long getSmiId() {
		return smiId;
	}

	public void setSmiId(Long smiId) {
		this.smiId = smiId;
	}

	public Date getDefaultMiDateCompleted() {
		return this.defaultMiDateCompleted;
	}

	public void setDefaultMiDateCompleted(Date defaultMiDateCompleted) {
		this.defaultMiDateCompleted = defaultMiDateCompleted;
	}








}