/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.miprocessing.forms;

import java.util.Collection;
import java.util.Date;

import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.miprocessing.EmbryoTransferProcedure;
import uk.ac.sanger.mig.miprocessing.ScheduledMicroInjectionJob;

public class EmbryoTransferProcedureForm {

	private EmbryoTransferProcedure embryoTransferProcedure; 
	private Date dateCompleted;
	private String recipientsCageBarcode;
	private Long recipientsCageId;
	private Long earmarkId;
	private String embryoTransferBarcode;
	private String embryoTransferBarcodeDescription;
	private Long embryoTransferCageOrRackId;
	private String embryoTransferBarcodeType;
	private Long etCageIdFrom;
	private Collection<DictionaryEntry> earmarks;
	private boolean changeEarmarks;

	
	public Long getAnalgesiaDictId() {
		return (embryoTransferProcedure != null) ? embryoTransferProcedure.getAnalgesiaDictId() : null;
	}
	
	
	public ScheduledMicroInjectionJob getScheduledMicroInjection() {
		return (embryoTransferProcedure != null) ? 
				embryoTransferProcedure.getScheduledMicroInjection() : null;
	}
	
	public Long getScheduledMicroInjectionId() {
		return (embryoTransferProcedure != null) ? 
				embryoTransferProcedure.getScheduledMicroInjectionId() : null;
	}	

	
	
	//////////////////////////////////////////////////////////
	///////////////// bit bucket methods /////////////////////
	//////////////////////////////////////////////////////////	
		
	public boolean isChangeEarmarks() {
		return changeEarmarks;
	}

	public void setChangeEarmarks(boolean changeEarmarks) {
		this.changeEarmarks = changeEarmarks;
	}

	public Collection<DictionaryEntry> getEarmarks() {
		return earmarks;
	}

	public void setEarmarks(Collection<DictionaryEntry> earmarks) {
		this.earmarks = earmarks;
	}

	public Long getEtCageIdFrom() {
		return etCageIdFrom;
	}

	public void setEtCageIdFrom(Long etCageId) {
		this.etCageIdFrom = etCageId;
	}
	
	public Date getDateCompleted() {
		return dateCompleted;
	}

	public void setDateCompleted(Date dateCompleted) {
		this.dateCompleted = dateCompleted;
	}

	public EmbryoTransferProcedure getEmbryoTransferProcedure() {
		return embryoTransferProcedure;
	}
	

	public void setEmbryoTransferProcedure(EmbryoTransferProcedure embryoTransferProcedure) {
		this.embryoTransferProcedure = embryoTransferProcedure;
	}

	public Long getEarmarkId() {
		return earmarkId;
	}

	public void setEarmarkId(Long earmarkId) {
		this.earmarkId = earmarkId;
	}


	public String getRecipientsCageBarcode() {
		return recipientsCageBarcode;
	}

	public void setRecipientsCageBarcode(String recipientsCageBarcode) {
		this.recipientsCageBarcode = recipientsCageBarcode;
	}

	public Long getRecipientsCageId() {
		return recipientsCageId;
	}

	public void setRecipientsCageId(Long recipientsCageId) {
		this.recipientsCageId = recipientsCageId;
	}

	public String getEmbryoTransferBarcode() {
		return this.embryoTransferBarcode;
	}

	public void setEmbryoTransferBarcode(String embryoTransferBarcode) {
		this.embryoTransferBarcode = embryoTransferBarcode;
	}

	public String getEmbryoTransferBarcodeDescription() {
		return this.embryoTransferBarcodeDescription;
	}

	public void setEmbryoTransferBarcodeDescription(
			String embryoTransferBarcodeDescription) {
		this.embryoTransferBarcodeDescription = embryoTransferBarcodeDescription;
	}

	public String getEmbryoTransferBarcodeType() {
		return this.embryoTransferBarcodeType;
	}

	public void setEmbryoTransferBarcodeType(String embryoTransferBarcodeType) {
		this.embryoTransferBarcodeType = embryoTransferBarcodeType;
	}

	public Long getEmbryoTransferCageOrRackId() {
		return this.embryoTransferCageOrRackId;
	}

	public void setEmbryoTransferCageOrRackId(Long embryoTransferCageOrRackId) {
		this.embryoTransferCageOrRackId = embryoTransferCageOrRackId;
	}




}