/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.miprocessing.services;

import java.util.Collection;
import java.util.Map;

import uk.ac.sanger.mig.miprocessing.forms.BatchWildtypeRequestForm;

/**
 * @author ae1
 *
 */
public interface BatchWildtypeRequestService {

	public static final String VELOCITY_REPORT_EMAIL = "mi_batch_wildtype_request";
	public static final int MICE_COUNT_CEILING = 61;
	
	/**
	 * Stores all wildtype requests collected in the BatchWildtypeRequestForm object,
	 * generates a report of the batch requests, and emails it to end-users.
	 * Return s list of email recipients.
	 * @param batchWildypeRequestForm
	 * @return
	 */
	public Collection<String> processWildtypeRequests(BatchWildtypeRequestForm  batchWildypeRequestForm );
	

	/**
	 * Returns Map of AnimalRequest Lists per given day and date range
	 * for these requests
	 * @param form
	 * @return
	 */
	public Map<String, Object> buildReport(BatchWildtypeRequestForm form);
	
	
}
