/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.miprocessing.services;

import java.util.Collection;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.SortedMap;

import org.springframework.transaction.annotation.Transactional;

import uk.ac.sanger.mig.animalrequest.AnimalRequest;
import uk.ac.sanger.mig.common.MailHelper;
import uk.ac.sanger.mig.miprocessing.forms.BatchWildtypeRequestForm;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.personnel.dao.MailingListDao;

/**
 * @author ae1
 *
 */
public class BatchWildtypeRequestServiceImpl implements BatchWildtypeRequestService {
	
	private MailHelper mailHelper;
	private MailingListDao mailingListDao;
	private MirMouseTrackingBridgeService mirMouseTrackingBridgeService;
	
	@Transactional
	public Collection<String> processWildtypeRequests(BatchWildtypeRequestForm form ) {
		
		SortedMap<Date, List<AnimalRequest>> dailyRequestsCache = form.getDailyRequestsCache();
		
		storeBatchRequests( dailyRequestsCache, form.getRequester() );	
		
		Map<String, Object> report = buildReport( form );
		
		return emailBatchRequests( report, form.getRequester() ); 
	}
	
	public Map<String, Object> buildReport(BatchWildtypeRequestForm form) {
		Map<String, Object> model = new HashMap<String, Object>();
		if(form.getDailyRequestsCache().size() > 0) {		
			Date fromDate = form.getDailyRequestsCache().firstKey();
		    Date toDate =  form.getDailyRequestsCache().lastKey();
			model.put("dailyRequestsCache", form.getDailyRequestsCache());
			model.put("additionalEmailNotes", form.getAdditionalEmailNotes());
		    model.put("fromDate", fromDate);
		    model.put("toDate", toDate);
		    model.put("requester", form.getRequester());
		}
			
	    return model;
	}


	
	/////////////////////////////////////////////////////////////////////////////////////////////
	//////////////////////////////////// privates ///////////////////////////////////////////////
	/////////////////////////////////////////////////////////////////////////////////////////////	
	private void storeBatchRequests( SortedMap<Date, List<AnimalRequest>> requestCache, Person user ) {
		Set<Date> days = requestCache.keySet();
		for(Date day : days) {
			List<AnimalRequest> dailyRequests = requestCache.get( day );
			for(AnimalRequest request : dailyRequests) {
				if( !request.isBlank() )
					mirMouseTrackingBridgeService.storeAnimalRequest( request, user );
			}
		}
	}	

	private Collection<String> emailBatchRequests( Map<String,Object> report , Person user  ) {
	    Collection<String> recipients = mailingListDao.fetchRecipientEmailsByListId(
	    		MailingListDao.ANIMAL_REQUEST_MAILING_LIST);
	    recipients.add( user.getEmail() );   
	    mailHelper.sendMail(VELOCITY_REPORT_EMAIL, report, recipients.toArray(new String[]{}));		
	    return recipients;
	}
	
	/////////////////////////////////////////////////////////////////////////////////////////////
	////////////////////////////////// dependencies /////////////////////////////////////////////
	/////////////////////////////////////////////////////////////////////////////////////////////		
	public void setMailHelper(MailHelper mailHelper) {
		this.mailHelper = mailHelper;
	}

	public void setMailingListDao(MailingListDao mailingListDao) {
		this.mailingListDao = mailingListDao;
	}

	public void setMirMouseTrackingBridgeService(
			MirMouseTrackingBridgeService mirMouseTrackingBridgeService) {
		this.mirMouseTrackingBridgeService = mirMouseTrackingBridgeService;
	}
}
