/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.miprocessing.services;

import java.util.Collection;
import java.util.Date;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.miprocessing.EmbryoHarvest;
import uk.ac.sanger.mig.miprocessing.EmbryoHarvestSearchBean;
import uk.ac.sanger.mig.personnel.Person;


public interface EmbryoHarvestService {

	public static final Integer DEFAULT_PLUG_DAY_OFFSET = -3;  //3 days prior

	/**
	 * Fetch all Embryo Harvests flushed on a given day, and if incubatedOvernight == true
	 * also fetch those flushed the day prior selected for overnight incubation.
	 *
	 * @param date
	 * @param incubatedOvernight
	 * @param requiredComponents
	 * @return
	 */
	public Collection<EmbryoHarvest> fetchAvailableByDate(Date date,
			boolean incubatedOvernight, ComponentMap requiredComponents);

	/**
	 * Returns Embryo Harvest for a given id.
	 *
	 * @param id
	 * @return
	 */
	public EmbryoHarvest fetchById(Long id, ComponentMap componentMap);

	/**
	 * Returns Embryo Harvest with its full object graph.
	 *
	 * @param id
	 * @return
	 */
	public  EmbryoHarvest fetchWithAllComponentsById(Long id);

	/**
	 * Stores an EmbryoHarvest object.
	 *
	 * @param embryoHarvest
	 * @param person
	 * @return
	 */
	public Long store(EmbryoHarvest embryoHarvest, Person person);

	/**
	 * Returns all embryo harvests.
	 *
	 * @param requiredComponents
	 * @return
	 */
	public Collection<EmbryoHarvest> fetch(EmbryoHarvestSearchBean searchBean,
			ComponentMap requiredComponents);

	/**
	 * Returns default plug date based on a flush date (e.g., flush date -3 days).
	 *
	 * @param flushDate
	 * @return
	 */
	public Date getDefaultPlugDate(Date flushDate);

	/**
	 * Constructs a new Embryo Harvest setting technician
	 * field to user argument and with default setings such that
	 * getUseBlastocysts() and getUseMoralae()both return true.
	 *
	 * @param user
	 * @return
	 */
	public EmbryoHarvest buildDefaultEmbryoHarvest( Person user );


}