package uk.ac.sanger.mig.miprocessing.services;

import java.util.Collection;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.cryoprocessing.forms.ThawTestForm;
import uk.ac.sanger.mig.miprocessing.EmbryoTransferProcedure;
import uk.ac.sanger.mig.miprocessing.forms.EmbryoTransferProcedureForm;
import uk.ac.sanger.mig.personnel.Person;
																
public interface EmbryoTransferProcedureService {
	
	public final static Long EMBRYO_TRANSFER_PROCEDURE_DICT_ID = 19L; //embryo transfer;
	
	/**
	 * Returns a new (not-yet-persisted) EmbryoTrasnferProcedure object
	 * with default values.
	 * @param smiId
	 * @param user
	 * @return
	 */
	public EmbryoTransferProcedure buildDefaultEmbryoTransfer(Long smiId, Person user);
	public EmbryoTransferProcedure buildDefaultThawTestEmbryoTransfer(Person user);
	/**
	 * Returns full graph of EmbryoTrasnferProcedure object--with all of its 
	 * hierarchical sub-components based on  EmbryoTrasnferProcedure id.
	 * @param id
	 * @return
	 */
	public EmbryoTransferProcedure fetchWithAllComponentsById(Long id);
	
	/**
	 * Returns full graph of EmbryoTrasnferProcedure object--with all of its 
	 * hierarchical sub-components based on parent ScheduledMicroInjectionJob id
	 * of a given EmbryoTrasnferProcedure.
	 * @param smiId
	 * @return
	 */
	public Collection<EmbryoTransferProcedure> fetchWithAllComponentsByScheduledMicroinjection(Long smiId);
	public Collection<EmbryoTransferProcedure> fetchWithAllComponentsByThawTestId(Long thawTestId);
	/**
	 * Stores EmbryoTransferProcedure (including MouseProcedure component) 
	 * and moves Mouse to Recovery Cage (if newCage = true) or to new cage
	 * in Recovery Rack if newCage false
	 * @param embryoTransferProcedure
	 * @param newRecoveryCage
	 * @param recoveryLocationId -- either rackId (if newRecoveryCage true) or cageId  (if newRecoveryCage false) 
	 * @param person
	 * @return
	 */
	public Long store(EmbryoTransferProcedure embryoTransferProcedure, Person person);	
	
	public Long editEmbryoTransfer(EmbryoTransferProcedure embryoTransferProcedure, EmbryoTransferProcedureForm form,
			Person person);
			
	public Long storeThawTestEmbryoTransfer(EmbryoTransferProcedure embryoTransferProcedure, Person person);
	
	/**
	 * Returns embryoTransferProcedure for a given id that maps to primary key
	 * of a record in a database table.
	 * @param id
	 * @return
	 */
	public EmbryoTransferProcedure fetchById(Long id, ComponentMap componentMap);
	
	/**
	 * Returns the Collection of EmbryoTransferProcedures of a given ScheduledMicroInjection
	 * base on its id and ComponentMap for how deap to fetch each EmbryoTransferProcedure
	 * @param smiId
	 * @param componentMap
	 * @return
	 */
	public Collection<EmbryoTransferProcedure> fetchBySmiJobId(Long smiId, 
			ComponentMap componentMap);
	

	public Collection<EmbryoTransferProcedure> fetchByThawTestId(Long thawTestId, 
			ComponentMap componentMap);
	/**
	 * Deletes EmbryoTransferProcedure and returns number rows affected. Never be > 1.
	 * @param embryoTransferProcedureId
	 * @param user
	 * @return
	 */
	public int delete(Long embryoTransferProcedureId, Person user, Long recipientCageId);
	
	/**
	 * Instantiates and attaches any components that are null that are required (typically for Spring bind)
	 * @param embryoTransferProcedure
	
	public void inflateEmbryoTransferProcedure(EmbryoTransferProcedure embryoTransferProcedure );
	*/
	
	public EmbryoTransferProcedure createThawTestEmbryoTransfer(EmbryoTransferProcedure embryoTransferProcedure, ThawTestForm form);
 
}