package uk.ac.sanger.mig.miprocessing.services;

import java.util.Collection;
import java.util.Date;

import org.springframework.transaction.annotation.Transactional;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.cryoprocessing.ThawTest;
import uk.ac.sanger.mig.cryoprocessing.forms.ThawTestForm;
import uk.ac.sanger.mig.cryoprocessing.services.ThawTestService;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.database.TableMetadataEnum;
import uk.ac.sanger.mig.licensing.PersonalLicence;
import uk.ac.sanger.mig.licensing.ProjectLicence;
import uk.ac.sanger.mig.licensing.Protocol;
import uk.ac.sanger.mig.licensing.services.PersonalLicenceService;
import uk.ac.sanger.mig.licensing.services.ProtocolService;
import uk.ac.sanger.mig.miprocessing.EmbryoTransferProcedure;
import uk.ac.sanger.mig.miprocessing.ScheduledMicroInjectionJob;
import uk.ac.sanger.mig.miprocessing.dao.EmbryoTransferProcedureDao;
import uk.ac.sanger.mig.miprocessing.forms.EmbryoTransferProcedureForm;
import uk.ac.sanger.mig.mousetracking.Cage;
import uk.ac.sanger.mig.mousetracking.Mouse;
import uk.ac.sanger.mig.mousetracking.MouseProcedure;
import uk.ac.sanger.mig.mousetracking.MouseWeight;
import uk.ac.sanger.mig.mousetracking.services.MouseProcedureService;
import uk.ac.sanger.mig.mousetracking.services.MouseService;
import uk.ac.sanger.mig.mousetracking.views.MouseLocation;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.personnel.services.PersonService;

/**
 * @author wl1
 *
 */
public class EmbryoTransferProcedureServiceImpl extends AbstractServiceImpl<EmbryoTransferProcedure>
									implements EmbryoTransferProcedureService {

	private EmbryoTransferProcedureDao embryoTransferProcedureDao;
	private ScheduledMicroInjectionService scheduledMicroInjectionService;
	private MouseProcedureService mouseProcedureService;
	private MirMouseTrackingBridgeService mirMouseTrackingBridgeService;
	private ProtocolService protocolService;
	private PersonalLicenceService personalLicenceService;
	private DictionaryService dictionaryService;
	private ThawTestService thawTestService;
	private PersonService personService;

	private final static String OVERNIGHT_EMBRYO_AGE = "0.5";

	public void setPersonService(PersonService personService) {
		this.personService = personService;
	}

	public void setThawTestService(ThawTestService thawTestService) {
		this.thawTestService = thawTestService;
	}

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	public EmbryoTransferProcedure buildDefaultEmbryoTransfer(Long smiId, Person user) {
		EmbryoTransferProcedure embryoTransferProcedure=prepopulateEmbryoTransfer(user);
		embryoTransferProcedure.setScheduledMicroInjectionId( smiId );
		return embryoTransferProcedure;
	}

	public EmbryoTransferProcedure buildDefaultThawTestEmbryoTransfer(Person user) {
		EmbryoTransferProcedure embryoTransferProcedure=prepopulateEmbryoTransfer(user);
		embryoTransferProcedure.setDaysFromPlug(OVERNIGHT_EMBRYO_AGE);
		return embryoTransferProcedure;
	}


	@Transactional
	public Long editEmbryoTransfer(EmbryoTransferProcedure embryoTransferProcedure,
				EmbryoTransferProcedureForm form, Person user) {

		Long id = embryoTransferProcedure.getId();
		Long femaleId = null;
		Mouse female = null;

		if(id == null) {
			// 1) Store recepient mouse after ear clipped
			female = new Mouse();
			female.setGenderDictId( MouseService.MOUSE_GENDER_FEMALE );
			female.setStrainDictId( EmbryoTransferProcedure.getDefaultRecipientStrainId() );
			female.setCurrentOwnerId( embryoTransferProcedure.getMiRequesterId() );
			female.setCageId( form.getEmbryoTransferCageOrRackId() );
			female.setComments( "Auto-created by MI embryo transfer procedure.");
			female.setEarmarkDictId( embryoTransferProcedure.getEarmarkId() );

			// 2) store embryo transfer
			femaleId = mirMouseTrackingBridgeService.storeMouse(female, user);
			embryoTransferProcedure.setMouseId(femaleId);
			id = store(embryoTransferProcedure, user);

			// 3) Store MouseProcedure component w/fkRef to EmbryoTransfer ID
			embryoTransferProcedure.getMouseProcedure().setForeignKeyId( id );
			embryoTransferProcedure.getMouseProcedure().setMouseId(femaleId);

			//need protocol derived prom PPL/Procedure/PIL
			Protocol protocol = protocolService.fetchByProcedureAndProject(
					embryoTransferProcedure.getMouseProcedure().getProcedureDictId(),
					embryoTransferProcedure.getMouseProcedure().getProtocol().getProjectLicenceId(),
					false,
					null);

			embryoTransferProcedure.getMouseProcedure().setProtocolId(protocol.getId());

			mirMouseTrackingBridgeService.storeMouseProcedure(
					embryoTransferProcedure.getMouseProcedure(), user);
			mirMouseTrackingBridgeService.createBreedingAndLitter(embryoTransferProcedure.getId(),user);
		} else {
			// update existing mouse (earmark or location is all that will change on this form)
			femaleId = embryoTransferProcedure.getMouseId();
			female = mirMouseTrackingBridgeService.fetchMouseById(femaleId, null);
			female.setEarmarkDictId(embryoTransferProcedure.getEarmarkId());
			female.setCageId(form.getEmbryoTransferCageOrRackId());
			mirMouseTrackingBridgeService.storeMouse(female, user);

			//update protocol derived prom PPL/Procedure/PIL
			MouseProcedure updatedMouseProcedure
				= mirMouseTrackingBridgeService.fetchMouseProcedureByMouseId(femaleId);

			Protocol protocol = protocolService.fetchByProcedureAndProject(
					embryoTransferProcedure.getMouseProcedure().getProcedureDictId(),
					embryoTransferProcedure.getMouseProcedure().getProtocol().getProjectLicenceId(),
					false,
					null);

			updatedMouseProcedure.setPersonalLicenceId( embryoTransferProcedure.getMouseProcedure().getPersonalLicenceId() );
			updatedMouseProcedure.setProtocolId( protocol.getId() );

			mirMouseTrackingBridgeService.storeMouseProcedure(updatedMouseProcedure , user);

			//store trasnfer
			id = store(embryoTransferProcedure, user);
		}

		weighMouse(femaleId, form.getEmbryoTransferProcedure().getRecipientWeight(), form.getDateCompleted(), user);
		return id;
	}

	//to generate the embryo transfer for the thaw test
	//which contains the information for mouse and mouseprocedure for save later
	public EmbryoTransferProcedure createThawTestEmbryoTransfer(EmbryoTransferProcedure embryoTransferProcedure, ThawTestForm form){
		Mouse female = new Mouse();
		female.setLocation(new MouseLocation());
		female.setGenderDictId( MouseService.MOUSE_GENDER_FEMALE );
		female.setStrainDictId( EmbryoTransferProcedure.getDefaultRecipientStrainId() );
		female.setCurrentOwnerId( form.getCryoRequest().getRequesterId());
		female.setCageId( form.getEmbryoTransferCageOrRackId() );
		female.getLocation().setCageBarcode(form.getCageBarcode());
		female.setComments( "Auto-created by Thaw Test - Embryo Transfer Procedure.");
		female.setEarmarkDictId( embryoTransferProcedure.getEarmarkId());
		female.setEarmark(dictionaryService.fetchEntry(DictionaryEnum.MOUSE_EARMARK_DICT,
				embryoTransferProcedure.getEarmarkId()));
		embryoTransferProcedure.setMouse(female);
		//need protocol derived prom PPL/Procedure/PIL
		Protocol protocol = protocolService.fetchByProcedureAndProject(
				embryoTransferProcedure.getMouseProcedure().getProcedureDictId(),
				embryoTransferProcedure.getMouseProcedure().getProtocol().getProjectLicenceId(),
				false,
				ComponentMap.of(Protocol.Component.PROJECT_LICENCE, null));
		Person person = personService.fetchById(embryoTransferProcedure.getMouseProcedure().getPersonalLicence().getPersonId(), null);

		embryoTransferProcedure.getMouseProcedure().setProtocolId(protocol.getId());
		embryoTransferProcedure.getMouseProcedure().setProtocol(protocol);
		embryoTransferProcedure.getMouseProcedure().getPersonalLicence().setPerson(person);
		return embryoTransferProcedure;
	}

	//save embryotransfer for thawTest
	@Transactional
	public Long storeThawTestEmbryoTransfer(EmbryoTransferProcedure embryoTransferProcedure, Person user) {

		Long id = embryoTransferProcedure.getId();

		//1) Store the mouse information
		Long femaleId = mirMouseTrackingBridgeService.storeMouse(embryoTransferProcedure.getMouse(), user);
		if(id == null) {
			// 2) store embryo transfer
			embryoTransferProcedure.setMouseId(femaleId);
			id = store(embryoTransferProcedure, user);

			// 3) Store MouseProcedure component w/fkRef to EmbryoTransfer ID
			embryoTransferProcedure.getMouseProcedure().setForeignKeyId( id );
			embryoTransferProcedure.getMouseProcedure().setMouseId(femaleId);

			//protocol derived prom PPL/Procedure/PIL already assigned when first creat embryo transfer

			mirMouseTrackingBridgeService.storeMouseProcedure(
					embryoTransferProcedure.getMouseProcedure(), user);
			//4. Create new breeding and litter for F0
			mirMouseTrackingBridgeService.createBreedingAndLitter(id,user);
		} else {

			// 2) update protocol derived prom PPL/Procedure/PIL
			MouseProcedure updatedMouseProcedure
				= mirMouseTrackingBridgeService.fetchMouseProcedureByMouseId(femaleId);

			Protocol protocol = protocolService.fetchByProcedureAndProject(
					embryoTransferProcedure.getMouseProcedure().getProcedureDictId(),
					embryoTransferProcedure.getMouseProcedure().getProtocol().getProjectLicenceId(),
					false,
					null);

			updatedMouseProcedure.setPersonalLicenceId( embryoTransferProcedure.getMouseProcedure().getPersonalLicenceId() );
			updatedMouseProcedure.setProtocolId( protocol.getId() );

			mirMouseTrackingBridgeService.storeMouseProcedure(updatedMouseProcedure , user);


			// 3. update Embryo trasnfer
			id = store(embryoTransferProcedure, user);
		}

		weighMouse(femaleId, embryoTransferProcedure.getRecipientWeight(), new Date(), user);

		return id;
	}



	public Long store(EmbryoTransferProcedure embryoTransferProcedure, Person user) {
		return embryoTransferProcedureDao.store(embryoTransferProcedure, user);
	}

	public Collection<EmbryoTransferProcedure> fetchWithAllComponentsByScheduledMicroinjection(Long smiId) {
		return fetchBySmiJobId( smiId, getFullComponentMap() );
	}

	public EmbryoTransferProcedure fetchWithAllComponentsById(Long id) {
		return fetchById( id, getFullComponentMap() );
	}
	public Collection<EmbryoTransferProcedure> fetchWithAllComponentsByThawTestId(Long thawTestId) {

		return fetchByThawTestId(thawTestId, getFullComponentMap());
	}
	public EmbryoTransferProcedure fetchById(Long id, ComponentMap requiredComponents) {
		EmbryoTransferProcedure embryoTransferProcedure = embryoTransferProcedureDao.fetchById(id);

		if(embryoTransferProcedure != null)
			attachComponents(embryoTransferProcedure, requiredComponents);

		return embryoTransferProcedure;
	}

	public Collection<EmbryoTransferProcedure> fetchBySmiJobId(Long smiId,
			ComponentMap componentMap) {

		Collection<EmbryoTransferProcedure> embryoTrasnfer =
			embryoTransferProcedureDao.fetchBySmiJobId(smiId);

		if(embryoTrasnfer != null)
			attachComponents(embryoTrasnfer, componentMap);

		return embryoTrasnfer;
	}

public Collection<EmbryoTransferProcedure> fetchByThawTestId(Long thawTestId,
			ComponentMap componentMap) {
		Collection<EmbryoTransferProcedure> embryoTransfers = embryoTransferProcedureDao.fetchByThawTestId(thawTestId);

		if(embryoTransfers != null)
			attachComponents(embryoTransfers, componentMap);

		return embryoTransfers;
	}

	@Transactional
	public int delete(Long embryoTransferProcedureId, Person user, Long recipientCageId) {

		if(embryoTransferProcedureId == null)
			throw new IllegalArgumentException("Cannot delete a null embryoTransferProcedure");


		if( recipientCageId == null )
			throw new IllegalArgumentException("Recipient Cage Id must be provided.");

		ComponentMap componentMap = new ComponentMap();
		componentMap.put(EmbryoTransferProcedure.Component.MOUSE_PROCEDURE, null);
		componentMap.put(EmbryoTransferProcedure.Component.MOUSE,null);

		EmbryoTransferProcedure embryoTransferProcedure
			= this.fetchById(embryoTransferProcedureId, componentMap);


		Mouse mouse = embryoTransferProcedure.getMouse();
		mouse.setEarmarkDictId(null);
		mirMouseTrackingBridgeService.storeMouse(mouse,user);

		mirMouseTrackingBridgeService.deleteMouseProcedureByTableRef(
				TableMetadataEnum.MIR_EMBRYO_TRANSFER_PROCEDURE,
				embryoTransferProcedure.getMouseProcedure().getForeignKeyId(), user);

		return embryoTransferProcedureDao.delete(embryoTransferProcedure, user);
	}

	@Override
	protected void attachComponents(EmbryoTransferProcedure embryoTransferProcedure,
			ComponentMap requiredComponents) {

		if(embryoTransferProcedure == null) {
			throw new RuntimeException("Cannot attach components to null embryoTransferProcedure");
		}

		boolean fetchAll = false;

		if(requiredComponents != null) {

			if(requiredComponents.containsKey(EmbryoTransferProcedure.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}

			if(fetchAll || requiredComponents.containsKey(EmbryoTransferProcedure.Component.SCHEDULED_MICRO_INJECTION)) {
				embryoTransferProcedure.setScheduledMicroInjection(fetchSmiJobById(
						embryoTransferProcedure.getScheduledMicroInjectionId(),
						requiredComponents.get(EmbryoTransferProcedure.Component.SCHEDULED_MICRO_INJECTION)));
			}

			if(fetchAll || requiredComponents.containsKey(EmbryoTransferProcedure.Component.MOUSE_PROCEDURE)) {
				embryoTransferProcedure.setMouseProcedure(fetchMouseProcedureByTableRef(
						embryoTransferProcedure.getId(),
						requiredComponents.get(EmbryoTransferProcedure.Component.MOUSE_PROCEDURE)));
			}

			if(fetchAll || requiredComponents.containsKey(EmbryoTransferProcedure.Component.MOUSE)) {
				embryoTransferProcedure.setMouse(fetchMouseById(
						embryoTransferProcedure.getMouseId(),
						requiredComponents.get(EmbryoTransferProcedure.Component.MOUSE)));
			}

			if(fetchAll || requiredComponents.containsKey(EmbryoTransferProcedure.Component.THAW_TEST)) {
				embryoTransferProcedure.setThawTest(fetchThawTestById(
						embryoTransferProcedure.getThawTestId(),
						requiredComponents.get(EmbryoTransferProcedure.Component.THAW_TEST)));
			}

		}
	}




	/////////////////////////////////////////////////////////////////////////////////////////////
	////////////////////////////////// dependencies /////////////////////////////////////////////
	/////////////////////////////////////////////////////////////////////////////////////////////
	public void setMouseProcedureService(MouseProcedureService mouseProcedureService) {
		this.mouseProcedureService = mouseProcedureService;
	}

	public void setScheduledMicroInjectionService(
			ScheduledMicroInjectionService scheduledMicroInjectionService) {
		this.scheduledMicroInjectionService = scheduledMicroInjectionService;
	}

	public void setEmbryoTransferProcedureDao(EmbryoTransferProcedureDao embryoTransferProcedureDao) {
		this.embryoTransferProcedureDao = embryoTransferProcedureDao;
	}

	public void setMirMouseTrackingBridgeService(
			MirMouseTrackingBridgeService mirMouseTrackingBridgeService) {
		this.mirMouseTrackingBridgeService = mirMouseTrackingBridgeService;
	}
	public void setPersonalLicenceService(
			PersonalLicenceService personalLicenceService) {
		this.personalLicenceService = personalLicenceService;
	}

	public void setProtocolService(ProtocolService protocolService) {
		this.protocolService = protocolService;
	}
	/////////////////////////////////////////////////////////////////////////////////////////////
	////////////////////////////////////  privates //////////////////////////////////////////////
	/////////////////////////////////////////////////////////////////////////////////////////////

	private ThawTest fetchThawTestById(Long thawTestId,
			ComponentMap componentMap) {
		return (thawTestId != null) ?
				thawTestService.fetchById(thawTestId, componentMap) : null;

	}

	private Mouse fetchMouseById(Long mouseId, ComponentMap requiredComponents) {
		return (mouseId != null) ? mirMouseTrackingBridgeService.fetchMouseById( mouseId, requiredComponents ) : null;
	}

	private MouseProcedure fetchMouseProcedureByTableRef(Long fkId, ComponentMap requiredComponents) {
		return (fkId != null) ?
				mouseProcedureService.fetchByTableRef(TableMetadataEnum.MIR_EMBRYO_TRANSFER_PROCEDURE,
						fkId, requiredComponents) : null;
	}

	private ScheduledMicroInjectionJob fetchSmiJobById(Long smiJobId, ComponentMap requiredComponents) {
		if( smiJobId != null)
			return scheduledMicroInjectionService.fetchById(smiJobId, requiredComponents);
		return null;
	}

	private void weighMouse(Long mouseId, Double weight, Date sampleDate, Person user) {
		Mouse mouse = mirMouseTrackingBridgeService.fetchMouseById(mouseId, ComponentMap.of(Mouse.Component.CURRENT_WEIGHT));

		// if input weight is null, then do nothing.
		if(weight != null) {
			//if current mouse weight is empty or different from input weight then store new weight record
			if(mouse.getCurrentWeight() == null ||
					mouse.getCurrentWeight().getWeightValue().floatValue() != weight.floatValue()) {

				MouseWeight mouseWeight = new MouseWeight();
				mouseWeight.setMouseId(mouseId);
				mouseWeight.setWeightValue(weight.floatValue());
				mouseWeight.setSampleDate(sampleDate);
				mouseWeight.setWeightUnits("g");
				mirMouseTrackingBridgeService.storeMouseWeight(mouseWeight, user);
			}
		}
	}

	private ComponentMap getFullComponentMap() {

		ComponentMap mouseComponents = new ComponentMap();
		mouseComponents.put(Mouse.Component.LOCATION,null);
		mouseComponents.put(Mouse.Component.LITTER,null); //read only for plug check verify in form
		mouseComponents.put(Mouse.Component.CAGE,ComponentMap.of(Cage.Component.RACK));

		ComponentMap mouseProcedureComponents = new ComponentMap();
		mouseProcedureComponents.put(MouseProcedure.Component.PERSONAL_LICENCE,
				ComponentMap.of(PersonalLicence.Component.PERSON));

		mouseProcedureComponents.put(MouseProcedure.Component.PROTOCOL,
				ComponentMap.of(Protocol.Component.ALL_COMPONENTS) );

		ComponentMap embryoTransferComponents = new ComponentMap();
		embryoTransferComponents.put(EmbryoTransferProcedure.Component.MOUSE, mouseComponents);
		embryoTransferComponents.put(EmbryoTransferProcedure.Component.MOUSE_PROCEDURE,
				mouseProcedureComponents);

		return embryoTransferComponents;
	}

private EmbryoTransferProcedure prepopulateEmbryoTransfer(Person user) {

		EmbryoTransferProcedure embryoTransferProcedure = new EmbryoTransferProcedure();
		MouseProcedure mouseProcedure = new MouseProcedure();
		PersonalLicence pil
			= personalLicenceService.fetchByPersonId(user.getId(),
					ComponentMap.of(PersonalLicence.Component.PERSON));

		if( pil == null ) {
			pil = new PersonalLicence();
			pil.setPersonId( user.getId() );
			pil.setPerson( user );
		}

		Protocol protocol = new Protocol();
		protocol.setProjectLicence(new ProjectLicence());
		mouseProcedure.setPersonalLicence(pil);
		mouseProcedure.setProtocol(protocol);
		mouseProcedure.setProcedureDictId( EmbryoTransferProcedureService.EMBRYO_TRANSFER_PROCEDURE_DICT_ID );
		embryoTransferProcedure.setMouseProcedure(mouseProcedure);

		embryoTransferProcedure.setMouse(new Mouse());
		return embryoTransferProcedure;
	}

}
