/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.miprocessing.services;

import java.util.Date;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.miprocessing.MicroInjection;
import uk.ac.sanger.mig.personnel.Person;
																
public interface MicroInjectionService {
	
	
	/**
	 * Returns a new (not-yet-persisted) MicroInjection object
	 * with default values.
	 * @param simId
	 * @param defaultDate
	 * @param user
	 * @return
	 */
	public MicroInjection buildDefaultMicroInjection(Long simId, Date defaultDate, Person user);
	
	/**
	 * Stores MicroInjection as record in database and returns the record's primary key
	 * @param microInjection
	 * @return
	 */
	public Long store(MicroInjection microInjection, Person person);	
	
	/**
	 * Returns microInjection for a given id that maps to primary key
	 * of a record in a database table.
	 * @param id
	 * @return
	 */
	public MicroInjection fetchById(Long id, ComponentMap componentMap);
	
	/**
	 * Returns microInjection for given Scheduled MI id
	 * @param smiId
	 * @param componentMap
	 * @return
	 */
	public MicroInjection fetchBySmiJobId(Long smiId, ComponentMap componentMap);


}