/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.miprocessing.services;

import java.util.Collection;

import uk.ac.sanger.mig.animalrequest.AnimalRequest;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.database.TableMetadataEnum;
import uk.ac.sanger.mig.miprocessing.EmbryoTransferProcedure;
import uk.ac.sanger.mig.mousetracking.Cage;
import uk.ac.sanger.mig.mousetracking.Mouse;
import uk.ac.sanger.mig.mousetracking.MouseProcedure;
import uk.ac.sanger.mig.mousetracking.MouseWeight;
import uk.ac.sanger.mig.personnel.Person;

public interface MirMouseTrackingBridgeService {

	public Mouse fetchMouseById(Long mouseId, ComponentMap components);
	public Long createBreedingAndLitter(Long embryoTransferProcedureId,  Person user);
	public Long creatNewCageInRack(Long rackId, Person user);
	public Cage fetchCage(Long cageId);
	public Long storeMouseWeight(MouseWeight mouseWeight, Person user);

	public EmbryoTransferProcedure fetchEmbryoTransferById(Long embryoTransferId, ComponentMap requiredComponents);

	/**
	 * Creates new WT req for donor or recipient.
	 * @param animalRequest
	 * @param user
	 * @return
	 */
	public Long storeAnimalRequest( AnimalRequest animalRequest, Person user );


	public Long storeMouse(Mouse mouse, Person person);

	/**
	 *
	 * @param tableId
	 * @param fkRef
	 * @param user
	 * @return
	 */
	public int deleteMouseProcedureByTableRef(TableMetadataEnum foreignTableName, Long fkRef, Person user);

	public Long storeMouseProcedure(MouseProcedure mouseProcedure, Person user);

	public Collection<DictionaryEntry> getEarmarksByCageId(Long cageId);

	public MouseProcedure fetchMouseProcedureByMouseId(Long mouseId);

}
