/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.miprocessing.services;

import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.List;

import org.springframework.transaction.annotation.Transactional;

import uk.ac.sanger.mig.miprocessing.ScheduledMiTask;
import uk.ac.sanger.mig.miprocessing.ScheduledMicroInjectionJob.MilestoneEnum;
import uk.ac.sanger.mig.miprocessing.dao.ScheduledMiTaskDao;
import uk.ac.sanger.mig.miprocessing.workflow.Task;
import uk.ac.sanger.mig.personnel.Person;

public class ScheduledMiTaskServiceSpringImpl implements ScheduledMiTaskService {

	private ScheduledMiTaskDao scheduledMiTaskDao;
	
	public void setScheduledMiTaskDao(ScheduledMiTaskDao scheduledMiTaskDao) {
		this.scheduledMiTaskDao = scheduledMiTaskDao;
	}

	public List<Task> fetchAllBySmiJobId(Long smiJobId) {
		return scheduledMiTaskDao.fetchAllBySmiJobId(smiJobId);
	}

	public List<Task> fetchAllMilestonesBySmiJobId(Long smiJobId) {
		// TODO Auto-generated method stub
		return null;
	}

	@Transactional
	public Long store(ScheduledMiTask scheduledMiTask, Person person) {
		if(scheduledMiTask == null) {
			throw new RuntimeException("Cannot save a null scheduledMiTask");
		}
		return scheduledMiTaskDao.store(scheduledMiTask, person);
	}

	public Long updateTaskCompletion(Long smiId, 
			MilestoneEnum milestone, Date date, Person user) {
		
		if( date == null )
			throw new IllegalArgumentException("Milestone completion Date cannot be null!!!");
		
		ScheduledMiTask task 
			= scheduledMiTaskDao.fetchBySmiIdAndTaskName( smiId, milestone.getTaskName() );
		
		task.setActualCompletionDate( date );
		return scheduledMiTaskDao.store(task, user);
	}
	

	public void updateEstimatedCompletionDate(ScheduledMiTask scheduledMiTask, 
			boolean cascadeSubsequentDates, int daysAdjusted, Person user) {
	
		List<Task> tasksToUpdate = new ArrayList<Task>();
		tasksToUpdate.add( scheduledMiTask );
		
		if( cascadeSubsequentDates ) {
			List<Task> subsequentTasksToUpdate 
			 = scheduledMiTaskDao.fetchSubsequentTasks( scheduledMiTask );
			tasksToUpdate.addAll( subsequentTasksToUpdate );
		} 
			
		updateEstimatedCompletionDates(tasksToUpdate, daysAdjusted, user);
		
	}

	@Transactional
	private int updateEstimatedCompletionDates(List<Task> tasksToUpdate, int daysAdjusted, Person user) {
		
		Calendar cal = Calendar.getInstance(); 
		
		int count = 0;
		
		for(Task task : tasksToUpdate) {
			
			Date date = task.getEstimatedCompletionDate();			
			cal.setTime(date);
			cal.add(Calendar.DAY_OF_YEAR, daysAdjusted);
			task.setEstimatedCompletionDate(cal.getTime());
			scheduledMiTaskDao.store((ScheduledMiTask)task, user);
			count++;
		}
		
		return count;
		
		
	}
	
}
