/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.miprocessing.services;

import uk.ac.sanger.mig.miprocessing.ScheduledMicroInjectionJob;
import uk.ac.sanger.mig.personnel.Person;

/**
 * @author ae1
 *
 */
public interface SchedulerService {
	
	/**
	 * Schedules a SMI by setting its status to Scheduled and assigning it a 
	 * task list.
	 * 
	 * Optionally, if either numberDonors or numberRecipients is > 0,
	 * an AnimalRequest will be generated for either or both, setting 
	 * the AnimalRequests' "date required" field to the SMI target date, 
	 * and assigning AnimalRequest IDs to SMI, accordingly.
	 * 
	 * .
	 * 
	 * IllegalStateException is thrown if the ScheduledMicroInjectionJob 
	 * has a null MiRequest ID or target (anchor) date.
	 * 
	 * RuntimeException is thrown if MiRequest does not exist.
	 * 
	 * @param newSmiJob
	 * @param user
	 * @param numberDonors
	 * @param numberRecipients
	 * @return Returns the ScheduledMicroInjectionJob ID
	 * @Throws IllegalArgumentException if there is a null or negative value in the argument list.
	 * @Throws IllegalStateException if the ScheduledMicroInjectionJob has a null MiRequest ID or target (anchor) date
	 * @Throws RuntimeException if MiRequest does not exist
	 */
	public Long schedule(ScheduledMicroInjectionJob newSmiJob, Person user, 
			int numberDonors, int numberRecipients);
	
}
