/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.miprocessing.validators;

import java.util.HashSet;
import java.util.Set;

import org.springframework.validation.Errors;

import uk.ac.sanger.mig.common.AbstractBindingValidator;
import uk.ac.sanger.mig.common.AllowedFormField;
import uk.ac.sanger.mig.miprocessing.forms.BatchWildtypeRequestForm;

public class BatchWildtypeRequestFormValidator extends AbstractBindingValidator {
			
	@Override
	public Set<AllowedFormField> defineAllowedFields() {
		
		Set<AllowedFormField> formFields = new HashSet<AllowedFormField>();	
		formFields.add(new AllowedFormField("dateRequired", "Date Required", false) );
		formFields.add(new AllowedFormField("albinoDonorCount", "Albino B6 Donor Count", false) );
		formFields.add(new AllowedFormField("blackDonorCount", "Black B6 Donor Count", false) );
		formFields.add(new AllowedFormField("recipientCount", "Recipient Count", false) );
		formFields.add(new AllowedFormField("additionalEmailNotes", "Additional Email Notes", false) );
		formFields.add(new AllowedFormField("add", "Add Daily Requests", false) );
		formFields.add(new AllowedFormField("delete", "Remove Daily Requests", false) );
		return formFields;
	}

	public boolean supports(Class clazz) {
		return BatchWildtypeRequestForm.class.equals(clazz);
	}

	@Override
	protected void validate(Object command, Errors errors, boolean hasBindingErrors) {
		
		if( !hasBindingErrors ) {
			
			BatchWildtypeRequestForm form = (BatchWildtypeRequestForm)command;
			
			if( form.isAdd() &&
			    form.getAlbinoDonorCount() == 0 &&
			    form.getBlackDonorCount()  == 0 &&
			    form.getRecipientCount()   == 0) {
				   
				if( form.getDateRequired() == null &&
						form.getAdditionalEmailNotes() == null)
					errors.reject(null,"Please enter a date and select the number of mice for one, some or all of the request categories.");
				
				if(form.getDateRequired() != null)
					errors.reject(null,"Please select the number of mice for one, some or all of the request categories.");
			}
			
			if( form.isAdd() &&
				    (form.getAlbinoDonorCount() != 0 ||
				    form.getBlackDonorCount()   != 0 ||
				    form.getRecipientCount()    != 0 ) &&
				    form.getDateRequired() == null ) {
				errors.reject(null,"Please enter a date.");
			}
		}	
	}
	
}