/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.miprocessing.validators;

import java.util.HashSet;
import java.util.Set;

import org.springframework.validation.Errors;
import org.springframework.validation.ValidationUtils;

import uk.ac.sanger.mig.common.AbstractBindingValidator;
import uk.ac.sanger.mig.common.AllowedFormField;
import uk.ac.sanger.mig.miprocessing.EmbryoHarvest;
import uk.ac.sanger.mig.miprocessing.forms.EmbryoHarvestForm;

public class EmbryoHarvestFormValidator extends AbstractBindingValidator  {

	private EmbryoHarvestValidator embryoHarvestValidator;	
	private static final String NESTED_PATH = "embryoHarvest";

	@Override
	public Set<AllowedFormField> defineAllowedFields() {
		Set<AllowedFormField> formFields = new HashSet<AllowedFormField>();		
		formFields.add(new AllowedFormField("redirect", "Redirect Mode", false) );	
		formFields.add(new AllowedFormField("smiId", "Redirect Scheduled Microinjection ID", false) );	
		formFields.add(new AllowedFormField("redirectId", "Redirect Microinjection ID", false) );
		return formFields;
	}

	@Override
	public void validate(Object command, Errors errors, boolean hasBindingErrors) {	
		
		EmbryoHarvestForm embryoHarvestForm = (EmbryoHarvestForm)command; 
		
		//Validate sub-objects, if any
		try {  	
	        errors.pushNestedPath( NESTED_PATH );
	  			        
	        ValidationUtils.invokeValidator(
	        		  embryoHarvestValidator,  
	        		  embryoHarvestForm.getEmbryoHarvest(), 
	        		  errors);
	     } finally {
	          errors.popNestedPath();
	     }		
	}

	/**
	 * This Validator validates EmbryoHarvestForm instances, and 
	 * any subclasses of EmbryoHarvestForm too
	 */ 
	public boolean supports(Class clazz) {
	    return EmbryoHarvestForm.class.isAssignableFrom(clazz);
	}
	
	@Override
	public Set<String> getAllowedFields() {
		//get nested FormFields (from EmbryoHarvestValidator, merge and return 
		Set<String> allowedFieldNames = embryoHarvestValidator.getAllowedFields( NESTED_PATH );	
		allowedFieldNames.addAll( super.getAllowedFields() ); //need super otherwise infinite recursion
		return allowedFieldNames;
	}
	
	@Override
	public Set<String> getRequiredFields() {
		//get nested FormFields (from EmbryoHarvestValidator, merge and return 
		Set<String> requiredFieldNames = embryoHarvestValidator.getRequiredFields( NESTED_PATH );	
		requiredFieldNames.addAll( super.getRequiredFields() ); //need super otherwise infinite recursion
		return requiredFieldNames;
	}
	 
	public EmbryoHarvestValidator getEmbryoHarvestValidator() {
		return embryoHarvestValidator;
	}

	public void setEmbryoHarvestValidator(
			EmbryoHarvestValidator embryoHarvestValidator) {

	    if (! embryoHarvestValidator.supports(EmbryoHarvest.class)) {
	          throw new IllegalArgumentException(
	            "The supplied Validator, EmbryoHarvestValidator, must support the validation of an EmbryoHarvest instance.");
	    }
		
		this.embryoHarvestValidator = embryoHarvestValidator;
		

		
	}

	
}