/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.miprocessing.validators;


import java.util.HashSet;
import java.util.Set;

import org.springframework.validation.Errors;

import uk.ac.sanger.mig.common.AbstractBindingValidator;
import uk.ac.sanger.mig.common.AllowedFormField;
import uk.ac.sanger.mig.miprocessing.EmbryoHarvest;


public class EmbryoHarvestValidator extends AbstractBindingValidator {
		
	
	@Override
	public Set<AllowedFormField> defineAllowedFields() {
		
		Set<AllowedFormField> formFields = new HashSet<AllowedFormField>();		
		formFields.add(new AllowedFormField("flushDate", "Flush Date", true) );
		formFields.add(new AllowedFormField("plugCheckDate", "Plug Check Date", true) );
		formFields.add(new AllowedFormField("blastocystCount", "Blastocyst Count", true) );
		formFields.add(new AllowedFormField("moralaeCount", "Moralae Count", true) );
		formFields.add(new AllowedFormField("eightCellCompCount", "Eight-Cell Comp. Count", true) );
		formFields.add(new AllowedFormField("eightCellNonCompCount", "Eight-Cell Non-Comp. Count", true) );
		formFields.add(new AllowedFormField("fourCellCount", "Four-Cell Count", true) );
		formFields.add(new AllowedFormField("hatchedCount", "Hatched Count", true) );
		formFields.add(new AllowedFormField("deadOrFragmentedCount", "Dead/Fragmented Count", true) );
		formFields.add(new AllowedFormField("otherEmbryoTypeCount", "Other Embryo Type Count", true) );			
		formFields.add(new AllowedFormField("motherStrainId", "Maternal Strain", true) );
		formFields.add(new AllowedFormField("fatherStrainId", "Paternal Strain", true) );			
		formFields.add(new AllowedFormField("totalDonors", "Number Females Flushed", true) );
		formFields.add(new AllowedFormField("technicianId", "Technician", true) );
		
		//allowed, but optional
		formFields.add(new AllowedFormField("useBlastocysts", "Blastocyst Count", false) );
		formFields.add(new AllowedFormField("useMoralae", "Morulae Count", false) );
		formFields.add(new AllowedFormField("useEightCells", "Eight-Cell Comp. Count", false) );
		formFields.add(new AllowedFormField("useEightCellNonComp", "Eight-Cell Non-Comp. Count", false) );
		formFields.add(new AllowedFormField("useFourCell", "Four-Cell Count", false) );
		formFields.add(new AllowedFormField("useHatched", "Hatched Count", false) );
		formFields.add(new AllowedFormField("useDeadOrFragmented", "Dead/Freagmented", false) );
		formFields.add(new AllowedFormField("useOther", "Other Count", false) );
		formFields.add(new AllowedFormField("comments", "Comments", false) );	
		formFields.add(new AllowedFormField("overnightIncubation", "Overnight Incubation", false) );
		return formFields;
	}

	@Override
	protected void validate(Object object, Errors errors, boolean hasBindingErrors) {
		
		if( !hasBindingErrors ) {
		
			EmbryoHarvest embryoHarvest = (EmbryoHarvest)object;
		
			if( !embryoHarvest.getPlugCheckDate().before( embryoHarvest.getFlushDate() ) ) {
				errors.reject(null, "Plug check date must precede flush date.");
			}	
	
		}
	}

	public boolean supports(Class clazz) {
		return EmbryoHarvest.class.equals(clazz);
	}
	
	
}