/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.miprocessing.views;

import java.util.Date;
import java.util.Set;
import java.util.TreeMap;

import uk.ac.sanger.mig.miprocessing.ScheduledMicroInjectionJob.InternalStatus;
import uk.ac.sanger.mig.miprocessing.ScheduledMicroInjectionJob.MilestoneEnum;
import uk.ac.sanger.mig.mirequest.MiRequest.EndpointEnum;

public class ScheduledMicroInjectionListView {

	private Long id;
	private Long internalStatusId;
	private String internalStatusName;
	private Long  endpointId;
	private String endpointName;
	private Date targetScheduleDate;
	private Long miRequestId;
	private Long donorAnimalRequestId, recipientAnimalRequestId, supplementalRecipientAnimalRequestId;	
	
	//enums hashed in order of declaration by default 
	private TreeMap<MilestoneEnum, Date> milestones = new TreeMap<MilestoneEnum, Date>(); //ordered hash
	private int donorMouseCount, recipientMouseCount, supplementalMouseCount;

	private String requesterName;
	private Long microInjectionId; //need for eh redirect back to this page
	private String cellLineProviderNameNo; //from smi field   
    private String cellLineName; //from cell line
    private String cellLineClone; //from cell line

    private String jobId;

    private String f0Status;
    private String f1Status;
  
	public String getF0MilestoneStatus() {
		return this.f0Status;
	}

	public void setF0Status(String milestoneStatus) {
		this.f0Status = milestoneStatus;
	}

	public String getF1Status() {
		return this.f1Status;
	}

	public void setF1Status(String status) {
		this.f1Status = status;
	}

	public String getF0Status() {
		return this.f0Status;
	}

	public String getJobId() {
		return this.jobId;
	}

	public void setJobId(String jobId) {
		this.jobId = jobId;
	}

	public String getCellLineClone() {
		return (this.cellLineClone != null) ? this.cellLineClone : "none";
	}

	public void setCellLineClone(String cellLineClone) {
		this.cellLineClone = cellLineClone;
	}


	public String getCellLineName() {
		return this.cellLineName;
	}


	public void setCellLineName(String cellLineName) {
		this.cellLineName = cellLineName;
	}  

	/**
	 * helper method for jsp to query if next task to do is MI
	 * @return
	 */
	public boolean isMicroinjectionNextTaskToComplete() {
		return MilestoneEnum.MICRO_INJECTION_TASK_COMPLETED .equals( getNextMilestoneToComplete() );
	}
	
	/**
	 * helper method for jsp to determin if next task to do is ET
	 * @return
	 */
	public boolean isEmbryoTransfertNextTaskToComplete() {
		return MilestoneEnum.EMBRYO_TRANSFER_TASK_COMPLETED.equals( getNextMilestoneToComplete() );
	}
	
	/**
	 * helper method for jsp to determin if next task to do is F0 weaning
	 * @return
	 */
	public boolean isF0WeanNextTaskToComplete() {
		return MilestoneEnum.F0_WEANED_TASK_COMPLETED.equals( getNextMilestoneToComplete() );
	}
	
	/**
	 * helper method for jsp to determin if next task to do is F! genotyping
	 * @return
	 */
	public boolean isF1GenotypeNextTaskToComplete() {
		return MilestoneEnum.F1_GENOTYPING_TASK_COMPLETED.equals( getNextMilestoneToComplete() );
	}
	
	/**
	 * helper method for jsp to determin if endpoint is EC
	 * @return
	 */
	public boolean isEmbryonicChimeraEndpoint() {
		return (endpointId == EndpointEnum.EMBRYONIC_CHIMERAS.getId());
	}
	
	/**
	 * helper method for jsp to determin  endpoint is F0 weaned
	 * @return
	 */
	public boolean isF0Endpoint() {
		return (endpointId == EndpointEnum.F0.getId());
	}
	
	/**
	 * helper method for jsp to determin if next task to do is F! genotyping
	 * @return
	 */
	public boolean isF1Endpoint() {
		return (endpointId ==  EndpointEnum.F1.getId());
	}
	
	public Date getMiCompletionDate() {
		return this.milestones.get( MilestoneEnum.MICRO_INJECTION_TASK_COMPLETED );
	}
	
	public void setMiCompletionDate(Date miCompletionDate) {	
		this.milestones.put( MilestoneEnum.MICRO_INJECTION_TASK_COMPLETED, miCompletionDate );
	}
	
	public Date getEmbryoTransferCompletionDate() {
		return this.milestones.get( MilestoneEnum.EMBRYO_TRANSFER_TASK_COMPLETED );
	}
	
	public void setEmbryoTransferCompletionDate(Date embryoTransferCompletionDate) {			
		this.milestones.put(  
				MilestoneEnum.EMBRYO_TRANSFER_TASK_COMPLETED, 
					embryoTransferCompletionDate);
	}

	public Date getF0CompletionDate() {
		return this.milestones.get(MilestoneEnum.F0_WEANED_TASK_COMPLETED);
	}
	
	/**
	 * Relavent date for F0 and F1 endpoints
	 * @param completionDate
	 */
	public void setF0CompletionDate(Date completionDate) {
		if(endpointId == EndpointEnum.F0.getId() || endpointId == EndpointEnum.F1.getId())
			this.milestones.put(MilestoneEnum.F0_WEANED_TASK_COMPLETED,completionDate);
	}
	
	public Date getF1CompletionDate() {
			return this.milestones.get(MilestoneEnum.F1_GENOTYPING_TASK_COMPLETED);
	}
	
	public Date getChimeraEmbryoHarvestCompletionDate() {
		return this.milestones.get(MilestoneEnum.CHIMERA_EMBRYO_HARVEST_TASK_COMPLETED);
	}
	
	public void setChimeraEmbryoHarvestCompletionDate(Date completionDate) {
		if(endpointId == EndpointEnum.EMBRYONIC_CHIMERAS.getId()) {
			this.milestones.put(MilestoneEnum.CHIMERA_EMBRYO_HARVEST_TASK_COMPLETED,completionDate);
		}
	}
	
	public void setF1CompletionDate(Date completionDate) {
		if(endpointId == EndpointEnum.F1.getId()) {//only want to set if endpoint extends to this stage
			this.milestones.put(MilestoneEnum.F1_GENOTYPING_TASK_COMPLETED,completionDate);
		}
	}
	
	/**
	 * Tells whether this SMI is active
	 * @return true if active, false otherwise
	 */
	public boolean isActive() {
		return !(internalStatusId == InternalStatus.CANCELLED.getId() ||
				internalStatusId == InternalStatus.FAILED.getId() ||
				internalStatusId ==InternalStatus.COMPLETED.getId()
				);
	}
	
	public boolean isEndpointReached() {		
	    	
		return ( (EndpointEnum.F1.getId().equals( endpointId  ) && getF1CompletionDate() != null )
				|| ( EndpointEnum.F0.getId().equals( endpointId  ) && getF0CompletionDate() != null )
				|| ( EndpointEnum.EMBRYONIC_CHIMERAS.getId().equals( endpointId  ) 
						&& getChimeraEmbryoHarvestCompletionDate() != null) 			
		);
		     
	}  
	
	public String getCellLineProviderNameNo() {
			return cellLineProviderNameNo;
	}
		 		 
	public void setCellLineProviderNameNo(String cellLineProviderName) {
			this.cellLineProviderNameNo = cellLineProviderName;
	}
	
	public Long getMicroInjectionId() {
		return microInjectionId;
	}

	public void setMicroInjectionId(Long microInjectionId) {
		this.microInjectionId = microInjectionId;
	}

	public String getRequesterName() {
		return requesterName;
	}

	public void setRequesterName(String requesterName) {
		this.requesterName = requesterName;
	}
	
	public Long getEndpointId() {
		return endpointId;
	}
	public void setEndpointId(Long endpointId) {
		this.endpointId = endpointId;
	}
	public Long getInternalStatusId() {
		return internalStatusId;
	}
	public void setInternalStatusId(Long internalStatusId) {
		this.internalStatusId = internalStatusId;
	}
	public Long getDonorAnimalRequestId() {
		return donorAnimalRequestId;
	}
	public void setDonorAnimalRequestId(Long donorAnimalRequestId) {
		this.donorAnimalRequestId = donorAnimalRequestId;
	}

	
	public String getEndpointName() {
		return endpointName;
	}
	public void setEndpointName(String endpointName) {
		this.endpointName = endpointName;
	}
	
	public Long getId() {
		return id;
	}
	public void setId(Long id) {
		this.id = id;
	}
	public String getInternalStatusName() {
		return internalStatusName;
	}
	public void setInternalStatusName(String internalStatusName) {
		this.internalStatusName = internalStatusName;
	}

	public Long getMiRequestId() {
		return miRequestId;
	}
	public void setMiRequestId(Long miRequestId) {
		this.miRequestId = miRequestId;
	}
	public Long getRecipientAnimalRequestId() {
		return recipientAnimalRequestId;
	}
	public void setRecipientAnimalRequestId(Long recipientAnimalRequestId) {
		this.recipientAnimalRequestId = recipientAnimalRequestId;
	}
	public Long getSupplementalRecipientAnimalRequestId() {
		return supplementalRecipientAnimalRequestId;
	}
	public void setSupplementalRecipientAnimalRequestId(
			Long supplementalRecipientAnimalRequestId) {
		this.supplementalRecipientAnimalRequestId = supplementalRecipientAnimalRequestId;
	}
	public Date getTargetScheduleDate() {
		return targetScheduleDate;
	}
	public void setTargetScheduleDate(Date targetScheduleDate) {
		this.targetScheduleDate = targetScheduleDate;
	}

	public int getDonorMouseCount() {
		return donorMouseCount;
	}

	public void setDonorMouseCount(int donorMouseCount) {
		this.donorMouseCount = donorMouseCount;
	}

	public int getRecipientMouseCount() {
		return recipientMouseCount;
	}

	public void setRecipientMouseCount(int recipientMouseCount) {
		this.recipientMouseCount = recipientMouseCount;
	}

	public int getSupplementalMouseCount() {
		return supplementalMouseCount;
	}

	public void setSupplementalMouseCount(int supplementalMouseCount) {
		this.supplementalMouseCount = supplementalMouseCount;
	}

	private MilestoneEnum getNextMilestoneToComplete() {
		Set<MilestoneEnum> keys = milestones.keySet();	
		for(MilestoneEnum milestone : keys) {
			if(milestones.get(milestone) == null) {
					return milestone;
			} 
		}
		return null;
	}
	
}
