/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.miprocessing.workflow;

import java.util.List;

import uk.ac.sanger.mig.mirequest.MiRequest;


public interface TaskDao {

	/**
	 * Returns a List of TaskTemplates belonging to a particular Task Group. 

	   The Task Group is determined by 3 pieces of information in the MiRequest: 
	   
	   1.) End-point
	   2.) Cell Line Strain
	   3.) Chimera Mate Strain (for F1 End-point)

	 * Rules:
	 * 
	 * If end-point is F0 embryo, Tasks in the default "F0 Embryo" Task Group are returned.
	 * 
	 * If end-point is F0 adult, Tasks in the default "F0 Adult" Task Group are returned.
	 * 
	 * If end-point is F1, a suitable Task Group is searched for the MiRequest's 
	 * Cell Line Strain and Chimera Mate Strain.  If one cannot be found, 
	 * Tasks in the default "F1 B6" Task Group are returned.
	 * 		 
	 * IllegalArgumentException is thrown if MiRequest is null.
	 * 
	 * RuntimeException thrown if:
	 * 
	 * 1. The MiRequest has null end-point id.
	 * 2. If end-point is F1 and chimera mate strain or  cell-line strain id is null.
	   3. A  List of TaskTemplates cannot be found for the MiRequest despite valid 
	      parameters in 1 and 2.

	 * @param miRequest
	 * @return
	 */
	public List<TaskTemplate> fetchTaskTemplates(MiRequest miRequest);
	
	
}
