/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.miprocessing.workflow;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import uk.ac.sanger.mig.miprocessing.ScheduledMiTask;
import uk.ac.sanger.mig.mirequest.MiRequest;



public class TaskServiceImpl implements TaskService {

	private TaskDao taskDao;
		
	public void setTaskDao(TaskDao taskDao) {
		this.taskDao = taskDao;
	}

	public List<Task> generateTaskList(final Date anchorDate, MiRequest miRequest) {
		
		validate( anchorDate, miRequest );
		
		List<TaskTemplate> taskTemplates = taskDao.fetchTaskTemplates( miRequest );
		
		List<Task> tasks = new ArrayList<Task>();
				
		long anchorMillisecs = anchorDate.getTime();//so we can calculate fractional days
		
		for(TaskTemplate taskTemplate : taskTemplates ) {

			Task task = new ScheduledMiTask();;
	
			Double offset = taskTemplate.getDaysOffset(); //assume days default	
			task.setEstimatedCompletionDate( new Date((long) ( (offset * 24 * 60 * 60 * 1000) + anchorMillisecs ) ) );
			task.setDescription( taskTemplate.getDescription() );
			task.setName( taskTemplate.getName() );
			task.setMilestone( taskTemplate.isMilestone() );
			task.setSequenceNumber( taskTemplate.getSequenceNumber() );						
			task.setTaskGroupDictId( taskTemplate.getTaskGroupDictId() );
			
			tasks.add( task );
	
		}
		
		return tasks;
	}
	



	private void validate(Date anchorDate, MiRequest miRequest) {

		if( miRequest == null )
			throw new IllegalArgumentException("MiRequest cannot be null.");		

		if( anchorDate == null )
			throw new IllegalArgumentException("anchorDate cannot be null.");	
		
		if( miRequest.getEndpointDictId() == null )
			throw new RuntimeException("miRequest endpoint id cannot be null.");
		
		if( miRequest.isEndpointF1() &&
				(miRequest.getChimeraMateStrainDictId() == null ||
						miRequest.getCellLineStrainId() == null )) {	
			throw new RuntimeException("miRequest cell line strain and chimera mate strain " +
					"cannot be null if the miRequest endpoint is F1.");
		}
		
	}

	


	
}
