/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mirequest;

import java.util.Date;

import uk.ac.sanger.mig.alleles.Allele;
import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.ComponentEnum;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.common.LookupListElement;
import uk.ac.sanger.mig.common.LookupListUtil;
import uk.ac.sanger.mig.personnel.Person;

public class CellLine extends AuthenticatedDataObject implements LookupListElement  {

	public enum Component implements ComponentEnum {
		ALL_COMPONENTS,
		ALLELE,
		DEFAULT_CELL_LINE_PROVIDER,
		PERSON;
	}

    private String cellLineName;
    private DictionaryEntry cellLineSource;
    private Long cellLineSourceDictId;
    private DictionaryEntry cellLineStrain;
    private Long cellLineStrainDictId;
    private DictionaryEntry expectedCoatColor;
    private Long expectedCoatColorDictId;
    private int team87RefId;
    private String cloneName;
    private Allele modifiedAllele;
    private Long modifiedAlleleId;
    private Date createdDate;
    private Person creator;
    private Long creatorId;
    private DictionaryEntry genotype;
    private Long genotypeDictId;
    private Long cellLineProviderId;
    private Person cellLineProvider;

    private Long fundingDictId;
    private DictionaryEntry fundingDict;

    private String comments;


    public Long getFundingDictId() {
		return this.fundingDictId;
	}

	public void setFundingDictId(Long fundingDictId) {
		this.fundingDictId = fundingDictId;
	}

	public DictionaryEntry getFundingDict() {
		return this.fundingDict;
	}

	public void setFundingDict(DictionaryEntry fundingDict) {
		this.fundingDict = fundingDict;
	}

	public Long getCellLineProviderId() {
		return cellLineProviderId;
	}

	public void setCellLineProviderId(Long cellProviderId) {
		this.cellLineProviderId = cellProviderId;
	}

	public String getDisplayText() {
		return cellLineName +  ( (cloneName != null) ? " ("+cloneName+")" : "" );
	}

	public String getElementData() {
		return LookupListUtil.format("cellLineId", getId()) +
		LookupListUtil.format("cellLineName", cellLineName) +
		LookupListUtil.format("cloneName", cloneName);
	}

	public void setDisplayText(String displayText) {
		// TODO Auto-generated method stub

	}

	public void setElementData(String elementData) {
		// TODO Auto-generated method stub

	}

	public DictionaryEntry getGenotype() {
		return genotype;
	}

	public void setGenotype(DictionaryEntry genotype) {
		this.genotype = genotype;
	}

	public Long getGenotypeDictId() {
		return genotypeDictId;
	}

	public void setGenotypeDictId(Long genotypeDictId) {
		this.genotypeDictId = genotypeDictId;
	}

	public String getCellLineName() {
        return cellLineName;
    }

    public void setCellLineName(String cellLineName) {
        this.cellLineName = cellLineName;
    }


    public DictionaryEntry getCellLineSource() {
		return cellLineSource;
	}

	public void setCellLineSource(DictionaryEntry cellLineSource) {
		this.cellLineSource = cellLineSource;
	}

	public Long getCellLineSourceDictId() {
		return cellLineSourceDictId;
	}

	public void setCellLineSourceDictId(Long cellLineSourceDictId) {
		this.cellLineSourceDictId = cellLineSourceDictId;
	}

	public DictionaryEntry getCellLineStrain() {
        return cellLineStrain;
    }

    public void setCellLineStrain(DictionaryEntry cellLineStrain) {
        this.cellLineStrain = cellLineStrain;
    }
    public int getTeam87RefId() {
        return team87RefId;
    }

    public void setTeam87RefId(int team87RefId) {
        this.team87RefId = team87RefId;
    }
    public String getCloneName() {
        return cloneName;
    }

    public void setCloneName(String cloneName) {
        this.cloneName = cloneName;
    }
    public Allele getModifiedAllele() {
        return modifiedAllele;
    }

    public void setModifiedAllele(Allele modifiedAllele) {
        this.modifiedAllele = modifiedAllele;
    }
    public Date getCreatedDate() {
        return createdDate;
    }

    public void setCreatedDate(Date createdDate) {
        this.createdDate = createdDate;
    }

	public Person getCreator() {
		return creator;
	}

    public void setCreator(Person creator) {
        this.creator = creator;
    }

    public DictionaryEntry getExpectedCoatColor() {
        return expectedCoatColor;
    }

    public void setExpectedCoatColor(DictionaryEntry expectedCoatColor) {
        this.expectedCoatColor = expectedCoatColor;
    }


	public Long getCreatorId() {
		return creatorId;
	}

	public void setCreatorId(Long creatorId) {
		this.creatorId = creatorId;
	}

	public Long getModifiedAlleleId() {
		return modifiedAlleleId;
	}

	public void setModifiedAlleleId(Long modifiedAlleleId) {
		this.modifiedAlleleId = modifiedAlleleId;
	}

	public Long getCellLineStrainDictId() {
		return cellLineStrainDictId;
	}

	public void setCellLineStrainDictId(Long cellLineStrainDictId) {
		this.cellLineStrainDictId = cellLineStrainDictId;
	}

	public Long getExpectedCoatColorDictId() {
		return expectedCoatColorDictId;
	}

	public void setExpectedCoatColorDictId(Long expectedCoatColorDictId) {
		this.expectedCoatColorDictId = expectedCoatColorDictId;
	}

	public Person getCellLineProvider() {
		return cellLineProvider;
	}

	public void setCellLineProvider(Person cellLineProvider) {
		this.cellLineProvider = cellLineProvider;
	}

	public String getComments() {
		return this.comments;
	}

	public void setComments(String comments) {
		this.comments = comments;
	}




}