/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mirequest.controllers;

import java.util.Collection;
import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.AbstractSearchFormController;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.mirequest.CellLineSearchBean;
import uk.ac.sanger.mig.mirequest.services.CellLineService;
import uk.ac.sanger.mig.mirequest.view.CellLineListViewBean;

public class CellLineListController extends AbstractSearchFormController {

	private CellLineService cellLineService;
	private DictionaryService dictionaryService;

	@Override
	protected Map<String, Object> referenceData(HttpServletRequest request) throws Exception {

		Collection<DictionaryEntry> cellLineStrains = dictionaryService.fetch(DictionaryEnum.MIR_CELL_LINE_STRAIN);
		Collection<DictionaryEntry> chimeraMateStrains = dictionaryService.fetch(DictionaryEnum.MIR_CHIMERA_MATE_STRAIN_DICT);
		Collection<DictionaryEntry> coatColors = dictionaryService.fetch(DictionaryEnum.MOUSE_COAT_COLOUR);
		Collection<DictionaryEntry> genotypes =  dictionaryService.fetch(DictionaryEnum.MOUSE_GENOTYPE);
		Collection<DictionaryEntry> cellLineSources =  dictionaryService.fetch(DictionaryEnum.MIR_CELL_LINE_SOURCE);
		Collection<DictionaryEntry> fundings =  dictionaryService.fetch(DictionaryEnum.APP_FUNDING_SOURCE);

		Map<String, String> searchByColumns = new LinkedHashMap<String, String>();
		searchByColumns.put("GENE_NAME", "Gene Name");
		searchByColumns.put("ALLELE_NAME", "Allele Name");
		searchByColumns.put("CELL_LINE_NAME", "Cell Line Name");
		searchByColumns.put("CLONE_NAME", "Clone Name");
		searchByColumns.put("CELL_LINE_PROVIDER_NAME_NO", "Provider");

		Map<String, Object> model = new HashMap<String, Object>();
		model.put("chimeraMateStrains",chimeraMateStrains);
		model.put("cellLineStrains",cellLineStrains);
		model.put("genotypes", genotypes);
		model.put("fundings", fundings);
		model.put("cellLineSources", cellLineSources);
		model.put("coatColors",coatColors);
		model.put("searchByColumns", searchByColumns);
		return model;
	}

	@Override
	protected ModelAndView onSearch(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {

		CellLineSearchBean searchBean = (CellLineSearchBean)command;
		searchBean.setQueryName("listESCellLines");

		Collection<CellLineListViewBean> cellLines = cellLineService.search(searchBean);

		Map<String, Object> model = referenceData(request);
		model.put("cellLines", cellLines);

		return new ModelAndView(getSuccessView(),model);
	}

	////////////////////////////////////////////////////////////////////////////////////////////////////
	/////////////////////////////////////// dependencies ///////////////////////////////////////////////
	////////////////////////////////////////////////////////////////////////////////////////////////////
	public void setCellLineService(CellLineService cellLineService) {
		this.cellLineService = cellLineService;
	}

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}
}

