/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mirequest.controllers;

import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.ParameterizableViewController;

import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.mirequest.MiRequest;
import uk.ac.sanger.mig.mirequest.services.MiRequestService;


public class ChangeMiRequestStatusController extends ParameterizableViewController {

	private MiRequestService miRequestService;

	@Override
	protected ModelAndView handleRequestInternal(HttpServletRequest request, HttpServletResponse response) throws Exception {

		Long id= ServletRequestUtils.getRequiredLongParameter(request,"id");
		String newStatus = ServletRequestUtils.getRequiredStringParameter(request,"newStatus");
			
		MiRequest miRequest = miRequestService.fetchWithAllComponentsById(id);
		
		switch( Enum.valueOf(MiRequest.ExternalStatusEnum.class, newStatus) ) {
		
			case CANCELLED:  
				miRequestService.cancelRequest(miRequest, RequestUtils.getUser(request));
				break;
				
			case COMPLETED:  
				miRequestService.completeRequest(miRequest, RequestUtils.getUser(request));;
				break;
			
			case AWAITING_MAP_TEST:  
				miRequestService.awaitMapTest(miRequest, RequestUtils.getUser(request));
				break;
			
			case DELAYED:
				miRequestService.delayRequest(miRequest, RequestUtils.getUser(request));
				break;

			case REQUESTED:
				miRequestService.reRequest(miRequest, RequestUtils.getUser(request));
				break;
				
			default: logger.error("Invalid status parameter in query string! param: " + newStatus);

		}

		Map<String, MiRequest> model = new HashMap<String, MiRequest> ();
		model.put("miRequest", miRequest);
		return new ModelAndView(getViewName(),model);
	}

	////////////////////////////////////////////////////////////////////////////////////////////////////
	/////////////////////////////////////// dependencies ///////////////////////////////////////////////
	////////////////////////////////////////////////////////////////////////////////////////////////////
	public void setMiRequestService(MiRequestService miRequestService) {
		this.miRequestService = miRequestService;
	}





}