/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mirequest.controllers;
import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.AbstractSearchFormController;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.mirequest.MiRequestSearchBean;
import uk.ac.sanger.mig.mirequest.services.MiRequestService;
import uk.ac.sanger.mig.mirequest.view.MiRequestListViewBean;


public class MiRequestListController extends AbstractSearchFormController {

	private MiRequestService miRequestService;
	private DictionaryService dictionaryService; 
	private String excelView;
	
	@Override
	protected ModelAndView onSearch(HttpServletRequest request, HttpServletResponse response, 
			Object command, BindException errors) throws Exception {

		MiRequestSearchBean searchBean = (MiRequestSearchBean)command;
		searchBean.setQueryName("listMicroInjectionRequests");
			
		Collection<MiRequestListViewBean> results = miRequestService.search(searchBean);
		
		Map<String, Object> model = referenceData(request);	
		model.put("results", results);
		return new ModelAndView(getSuccessView(),model);

	}
	
	@Override
	protected Map<String, Object> referenceData(HttpServletRequest request) throws Exception {
			
		Collection<DictionaryEntry> mirStages = 
			dictionaryService.fetch(DictionaryEnum.MIR_EMBRYO_STAGE_DICT);
		Collection<DictionaryEntry> mirStatus = 
			dictionaryService.fetch(DictionaryEnum.MIR_EXTERNAL_STATUS_DICT);
		Collection<DictionaryEntry> mirEndpoints = 
			dictionaryService.fetch(DictionaryEnum.MIR_TARGET_ENDPOINT_DICT);
		Collection<DictionaryEntry> donorCellLineStrains = 
			dictionaryService.fetch(DictionaryEnum.CELL_LINE_STRAIN);
		Collection<DictionaryEntry> chimeraMateStrains = 
			dictionaryService.fetch(DictionaryEnum.MIR_CHIMERA_MATE_STRAIN_DICT);	
		Collection<DictionaryEntry> mirWorkflows = 
			dictionaryService.fetch(DictionaryEnum.APP_WORKFLOW_PIPELINE_DICT);
		
		Map<String, Object> model = new HashMap<String, Object>();
		model.put("mirStages",mirStages);
		model.put("mirStatus",mirStatus);
		model.put("mirEndpoints",mirEndpoints);
		model.put("donorCellLineStrains",donorCellLineStrains);	
		model.put("chimeraMateStrains",chimeraMateStrains);
		model.put("mirWorkflows",mirWorkflows);
		return model;
	}
		
	////////////////////////////////////////////////////////////////////////////////////////////////////
	/////////////////////////////////////// dependencies ///////////////////////////////////////////////
	////////////////////////////////////////////////////////////////////////////////////////////////////
	public void setMiRequestService(MiRequestService miRequestService) {
		this.miRequestService = miRequestService;
	}
	
	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}
	
	public String getExcelView() {
		return excelView;
	}
	
	public void setExcelView(String excelView) {
		this.excelView = excelView;
	}	
}
	