/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mirequest.controllers;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.ParameterizableViewController;

import uk.ac.sanger.mig.charting.ChartData;
import uk.ac.sanger.mig.mirequest.services.MiRequestService;
import ChartDirector.Chart;
import ChartDirector.PieChart;
import ChartDirector.TextBox;

public class MiRequestStatusController extends
		ParameterizableViewController {
	
	private MiRequestService miRequestService;
	private SimpleDateFormat dateFormat = new SimpleDateFormat("EEEEEE, d MMM yyyy");
	


	@Override
	protected ModelAndView handleRequestInternal(HttpServletRequest request, HttpServletResponse response) throws Exception {
		ChartData chartData =  miRequestService.fetchNonCancelledStatusChartData();				
		Map<String,Object> model = new HashMap<String, Object>();	
		
		int total = 0;
		for(double data : chartData.getData(0)) {
			total += data;
		}		
		
		//Pie formatting
		String titleText = "Microinjection Request Processing as of " + dateFormat.format(new Date()) + " - TOTAL = " + total;
		PieChart chart = new PieChart(1200, 600, 0xE9EDF1, 0x000000, 1);
		chart.setPieSize(600, 370, 200);
		chart.set3D(20);
		chart.setLabelLayout(Chart.SideLayout);
		chart.setRoundedFrame();
		chart.setLineColor(Chart.SameAsMainColor, 0x000000);
		chart.setStartAngle(0, false);
		
		//Title
		TextBox title = chart.addTitle(titleText, "Arial Bold", 15);
		title.setBackground(0xCBDCED, 0x000000, Chart.glassEffect());
		TextBox titleBottom = chart.addTitle2(2, "Click a label or pie slice to view microinjection requests for that status", "", 8);
		titleBottom.setMargin(10);
		
		//Label formatting
		TextBox labels = chart.setLabelStyle();
		chart.setLabelFormat("{label} ({value})<*br*>{percent|1}%");
		//labels.setBackground(Chart.SameAsMainColor, Chart.Transparent, Chart.ReducedGlare);
		labels.setBackground(Chart.SameAsMainColor, Chart.Transparent, Chart.glassEffect());
		labels.setRoundedCorners(5);
		labels.setMaxWidth(300);
		
		//Generate chart
		chart.setData(chartData.getData(0), chartData.getLabels());
		chart.addExtraField(chartData.getExtraFields());		
		String imageId = "miStatusPiechart" + new Date().getTime();
		chart.makeSession(request, imageId);		
		model.put("imageId", imageId);
		model.put("imageMap", chart.getHTMLImageMap("list_mi_requests.do","bypassForm=true&newQuery=true&orderBy=id&amp;orderDesc=true&miRequest.externalStatusDictId={field0}", "title='Click to show list of microinjection requests with status {label}'"));
		
		return new ModelAndView(getViewName(),model);		
	}



	public void setMiRequestService(MiRequestService miRequestService) {
		this.miRequestService = miRequestService;
	}
	
}