/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mirequest.dao;

import java.util.Collection;

import uk.ac.sanger.mig.charting.ChartData;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.common.LookupListElement;
import uk.ac.sanger.mig.mirequest.CellLine;
import uk.ac.sanger.mig.mirequest.CellLineSearchBean;
import uk.ac.sanger.mig.mirequest.view.CellLineListViewBean;
import uk.ac.sanger.mig.personnel.Person;

public interface CellLineDao {



	public Long store(CellLine cellLine, Person person);
	public CellLine fetchById(Long id);
	public Collection<CellLineListViewBean> search(CellLineSearchBean cellLineSearchBean);
	public Collection<LookupListElement> lookup(String cellLineName);
	public DictionaryEntry fetchMouseStrainByCellLineDictId(Long cellLineDictId);
	public ChartData fetchStrainChartData();
	public Collection<CellLine> fetchCellLinesInMouseFamilyTree(Long mouseId);


	public DictionaryEntry fetchStrainByTeam87Name(String startsWith);

	public CellLine fetchByEpdId(String epdId);

	/**
	 * Case-insensitive check to see if a CellLine of given EPD ID exists.
	 *
	 *
	 * @param epdId
	 * @return
	 */
	public boolean isValidEpdId(String epdId);

	/**
	 * Case-insensitive check to see if a CellLine of given name and clone.
	 *
	 * @param cellLineName
	 * @param cloneName
	 * @return
	 */
	public boolean existsByCellLineAndCloneName(String cellLineName, String cloneName);

	/**
	 * Fetch all cell lines that can be linked to a colony, via a microinjection request
	 *
	 * @param colonyInfoId
	 * @return cell lines
	 */
	public Collection<CellLine> fetchCellLinesForColony(Long colonyInfoId);


}
