/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mirequest.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.mirequest.view.CellLineListViewBean;

public class CellLineListViewRowMapper implements ParameterizedRowMapper<CellLineListViewBean> {

	public CellLineListViewBean mapRow(ResultSet rs, int rowNum) throws SQLException {

		CellLineListViewBean cellLineListViewBean = new CellLineListViewBean();			
		cellLineListViewBean.setId(rs.getLong("ID"));
		
		cellLineListViewBean.setCreatorId(rs.getLong("CREATOR_ID"));
		cellLineListViewBean.setCreatedBy(rs.getString("CREATED_BY"));
		cellLineListViewBean.setCreatedDate(rs.getDate("CREATED_DATE"));
		cellLineListViewBean.setCellLineName(rs.getString("CELL_LINE_NAME"));
		cellLineListViewBean.setCloneName(rs.getString("CLONE_NAME"));
		
		cellLineListViewBean.setGeneId(rs.getLong("GENE_ID"));
		cellLineListViewBean.setGeneName(rs.getString("GENE_NAME"));
		cellLineListViewBean.setAlleleName(rs.getString("ALLELE_NAME"));
		cellLineListViewBean.setModifiedAlleleId(rs.getLong("MODIFIED_ALLELE_ID"));
		
		cellLineListViewBean.setCellLineSourceName(rs.getString("cell_line_source"));
		cellLineListViewBean.setCellLineSourceId(rs.getLong("cell_line_source_id"));
		
		
		cellLineListViewBean.setFunding((rs.getString("funding")));
		cellLineListViewBean.setFundingId(rs.getLong("funding_id"));
		
		cellLineListViewBean.setCellLineProviderNameNo(rs.getString("cell_line_provider_name_no"));
		
		cellLineListViewBean.setCoatColorName(rs.getString("COAT_COLOR_NAME"));
		cellLineListViewBean.setCoatColorId(rs.getLong("COAT_COLOR_ID"));
		cellLineListViewBean.setStrainName(rs.getString("STRAIN_NAME"));
		cellLineListViewBean.setStrainId(rs.getLong("STRAIN_ID"));
		cellLineListViewBean.setWildtypePrimerForward(rs.getString("WILDTYPE_PRIMER_FORWARD"));
		cellLineListViewBean.setWildtypePrimerReverse(rs.getString("WILDTYPE_PRIMER_REVERSE"));
		cellLineListViewBean.setWildtypeExpectedSize(rs.getInt("WILDTYPE_EXPECTED_SIZE"));
		cellLineListViewBean.setAllelePrimerForward(rs.getString("ALLELE_PRIMER_FORWARD"));
		cellLineListViewBean.setAllelePrimerReverse(rs.getString("ALLELE_PRIMER_REVERSE"));
		cellLineListViewBean.setAlleleExpectedSize(rs.getInt("ALLELE_EXPECTED_SIZE"));
		cellLineListViewBean.setEditedDate(rs.getString("EDIT_DATE"));
		cellLineListViewBean.setEditedBy(rs.getString("EDITED_BY"));
		cellLineListViewBean.setGenotype(rs.getString("genotype"));
		cellLineListViewBean.setGenotypeId(rs.getLong("genotype_id"));
		
		
		return cellLineListViewBean;
	
		
		
	}
}