/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mirequest.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.mirequest.CellLine;

public class CellLineRowMapper implements ParameterizedRowMapper<CellLine> {

	private DictionaryService dictionaryService;

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	public CellLine mapRow(ResultSet rs, int rowNum) throws SQLException {

		CellLine cellLine = new CellLine();

		cellLine.setId(rs.getLong("ID"));
		cellLine.setCellLineName(rs.getString("CELL_LINE_NAME"));
		cellLine.setTeam87RefId(rs.getInt("TEAM_87_REF_ID"));
		cellLine.setCloneName(rs.getString("CLONE_NAME"));
		cellLine.setComments(rs.getString("COMMENTS"));
		cellLine.setCreatedDate(rs.getDate("CREATED_DATE"));
		cellLine.setEditDate(rs.getDate("EDIT_DATE"));
		cellLine.setEditedBy(rs.getString("EDITED_BY"));
		cellLine.setCheckNumber(rs.getLong("CHECK_NUMBER"));

		cellLine.setCellLineStrainDictId(rs.getLong("CELL_LINE_STRAIN_DICT_ID"));if(rs.wasNull()) cellLine.setCellLineStrainDictId(null);
		cellLine.setExpectedCoatColorDictId(rs.getLong("EXPECTED_COAT_COLOR_DICT_ID"));if(rs.wasNull()) cellLine.setExpectedCoatColorDictId(null);
		cellLine.setModifiedAlleleId(rs.getLong("MODIFIED_ALLELE_ID"));if(rs.wasNull()) cellLine.setModifiedAlleleId(null);
		cellLine.setCreatorId(rs.getLong("CREATOR_ID"));if(rs.wasNull()) cellLine.setCreatorId(null);
		cellLine.setGenotypeDictId(rs.getLong("GENOTYPE_DICT_ID"));if(rs.wasNull()) cellLine.setGenotypeDictId(null);
		cellLine.setCellLineSourceDictId(rs.getLong("CELL_LINE_SOURCE_DICT_ID"));if(rs.wasNull()) cellLine.setCellLineSourceDictId(null);

		cellLine.setFundingDictId(rs.getLong("CELL_LINE_FUNDING_DICT_ID"));if(rs.wasNull()) cellLine.setFundingDictId(null);

		cellLine.setCellLineProviderId(rs.getLong("CELL_LINE_PROVIDER_ID"));if(rs.wasNull()) cellLine.setCellLineProviderId(null);
		//set dictionary entries
		cellLine.setCellLineStrain(dictionaryService.fetchEntry(DictionaryEnum.CELL_LINE_STRAIN, cellLine.getCellLineStrainDictId()));
		cellLine.setExpectedCoatColor(dictionaryService.fetchEntry(DictionaryEnum.MOUSE_COAT_COLOUR, cellLine.getExpectedCoatColorDictId()));
		cellLine.setGenotype(dictionaryService.fetchEntry(DictionaryEnum.MOUSE_GENOTYPE, cellLine.getGenotypeDictId()));
		cellLine.setCellLineSource(dictionaryService.fetchEntry(DictionaryEnum.MIR_CELL_LINE_SOURCE, cellLine.getCellLineSourceDictId()));

		cellLine.setFundingDict(dictionaryService.fetchEntry(DictionaryEnum.APP_FUNDING_SOURCE, cellLine.getFundingDictId()));


		return cellLine;
	}
}
