/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mirequest.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.mirequest.view.MiRequestListViewBean;

public class MiRequestListViewRowMapper implements ParameterizedRowMapper<MiRequestListViewBean> {

	public MiRequestListViewBean mapRow(ResultSet rs, int rowNum) throws SQLException {

		MiRequestListViewBean miRequestListViewBean = new MiRequestListViewBean();

		miRequestListViewBean.setId(rs.getLong("ID"));
		miRequestListViewBean.setWorkflowPipeline(rs.getString("WORKFLOW_PIPELINE"));
		miRequestListViewBean.setRequesterName(rs.getString("REQUESTER_NAME"));
		miRequestListViewBean.setTeamNumber(rs.getLong("TEAM_NUMBER"));
		miRequestListViewBean.setDonorCellLineStrainName(rs.getString("STRAIN_NAME")); //refers to ES_CELL_LINE strain dict (not typ_strain)
		miRequestListViewBean.setCellLineName(rs.getString("CELL_LINE_NAME"));
		miRequestListViewBean.setCellLineId(rs.getLong("cell_line_id"));
		miRequestListViewBean.setCloneName(rs.getString("CLONE_NAME"));
		miRequestListViewBean.setEndpointName(rs.getString("ENDPOINT_NAME"));
		miRequestListViewBean.setEmbryoName(rs.getString("EMBRYO_STAGE_NAME"));
		miRequestListViewBean.setProjectLicence(rs.getString("PROJECT_LICENCE"));
		miRequestListViewBean.setRequesterId(rs.getLong("REQUESTER_ID"));
		miRequestListViewBean.setCreatedDate(rs.getDate("CREATED_DATE"));
		miRequestListViewBean.setEditDate(rs.getDate("EDIT_DATE"));
		miRequestListViewBean.setChimeraMateStrainName(rs.getString("CHIMERA_MATE_STRAIN_NAME"));
		miRequestListViewBean.setExternalStatusDictId(rs.getLong("EXTERNAL_STATUS_DICT_ID"));
		miRequestListViewBean.setExternalStatusDictName(rs.getString("EXTERNAL_STATUS_NAME"));
		miRequestListViewBean.setSmiCount(rs.getInt("SMI_COUNT"));
		miRequestListViewBean.setColonyInfoId(rs.getLong("COLONY_INFO_ID"));
		miRequestListViewBean.setColonyName(rs.getString("COLONY_NAME"));
		miRequestListViewBean.setColonyPrefix(rs.getString("COLONY_PREFIX"));
		miRequestListViewBean.setGeneName(rs.getString("GENE_NAME"));

		return miRequestListViewBean;

	}
}