/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mirequest.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.mirequest.MiRequest;

public class MiRequestRowMapper implements ParameterizedRowMapper<MiRequest> {
	
	private DictionaryService dictionaryService;
	
	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	public MiRequest mapRow(ResultSet rs, int rowNum) throws SQLException {
		
		MiRequest miRequest = new MiRequest();		
		
		miRequest.setId(rs.getLong("id"));
		miRequest.setEditDate(rs.getDate("EDIT_DATE"));
		miRequest.setEditedBy(rs.getString("EDITED_BY"));
		miRequest.setCreatedDate(rs.getDate("CREATED_DATE"));
		miRequest.setRequesterId(rs.getLong("REQUESTER_ID"));if(rs.wasNull()) miRequest.setRequesterId(null);
		miRequest.setDonorPlugCount(rs.getLong("DONOR_PLUG_COUNT"));
		miRequest.setChimeraMateStrainDictId(rs.getLong("CHIMERA_MATE_STRAIN_DICT_ID"));if(rs.wasNull()) miRequest.setChimeraMateStrainDictId(null);
		miRequest.setGenotypingRequired(rs.getBoolean("GENOTYPING_REQUIRED"));
		miRequest.setDonorEmbryoStageDictId(rs.getLong("DONOR_EMBRYO_STAGE_DICT_ID"));if(rs.wasNull()) miRequest.setDonorEmbryoStageDictId(null);
		miRequest.setExternalStatusDictId(rs.getLong("EXTERNAL_STATUS_DICT_ID"));if(rs.wasNull()) miRequest.setExternalStatusDictId(null);
		miRequest.setEndpointDictId(rs.getLong("ENDPOINT_DICT_ID"));if(rs.wasNull()) miRequest.setEndpointDictId(null);
		miRequest.setCellLineId(rs.getLong("CELL_LINE_ID"));if(rs.wasNull()) miRequest.setCellLineId(null);
		miRequest.setProjectLicenceId(rs.getLong("PROJECT_LICENCE_ID"));if(rs.wasNull()) miRequest.setProjectLicenceId(null);
		miRequest.setWorkflowPipelineDictId(rs.getLong("WORKFLOW_PIPELINE_DICT_ID"));if(rs.wasNull()) miRequest.setWorkflowPipelineDictId(null);
		miRequest.setFundingSource(rs.getString("FUNDING_SOURCE"));
		miRequest.setRequesterProvidedGenotyping(rs.getBoolean("REQUESTER_PROVIDED_GENOTYPING"));
		miRequest.setColonyInfoId(rs.getLong("COLONY_INFO_ID"));if(rs.wasNull()) miRequest.setColonyInfoId(null);
		
		miRequest.setDonorEmbryoStageDict(dictionaryService.fetchEntry(DictionaryEnum.MIR_EMBRYO_STAGE_DICT, miRequest.getDonorEmbryoStageDictId()));
		miRequest.setExternalStatusDict(dictionaryService.fetchEntry(DictionaryEnum.MIR_EXTERNAL_STATUS_DICT, miRequest.getExternalStatusDictId()));
		miRequest.setEndpointDict(dictionaryService.fetchEntry(DictionaryEnum.MIR_TARGET_ENDPOINT_DICT, miRequest.getEndpointDictId()));
		miRequest.setChimeraMateStrainDict(dictionaryService.fetchEntry(DictionaryEnum.MIR_CHIMERA_MATE_STRAIN_DICT, miRequest.getChimeraMateStrainDictId()));
		miRequest.setWorkflowPipelineDict(dictionaryService.fetchEntry(DictionaryEnum.APP_WORKFLOW_PIPELINE_DICT, miRequest.getWorkflowPipelineDictId()));

		return miRequest;
	}	
}
