/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mirequest.view;

import java.util.Date;

import uk.ac.sanger.mig.mirequest.MiRequest.ExternalStatusEnum;

public class MiRequestListViewBean   {

	private Long id;
    private String requesterName;
    private Long teamNumber;
    private String donorCellLineStrainName;
    private Long donorCellLineStrainId;
    private String workflowPipeline;
    private String cellLineName;
    private Long cellLineId;
    private String cloneName;
    private String endpointName;
    private String embryoName;
    private String projectLicence;
    private Date editDate;
    private Date createdDate;
    private Long requesterId;
    private String chimeraMateStrainName;
    private Long chimeraMateStrainId;
    private String externalStatusDictName;
    private Long externalStatusDictId;
    private Integer smiCount;
    private Long colonyInfoId;
    private String colonyName;
    private String colonyPrefix;
    private String geneName;


	public String getGeneName() {
		return geneName;
	}

	public void setGeneName(String geneName) {
		this.geneName = geneName;
	}

	/**
	 * Returns true if this Request is active--ie, not complete and not cancelled.
	 * @return
	 */
	public boolean isActive() {
    	return (
    			!(
    				externalStatusDictId.equals( ExternalStatusEnum.COMPLETED.getId() )
    				||  externalStatusDictId.equals( ExternalStatusEnum.CANCELLED.getId() )
    			)
    		);
	}

	public Integer getSmiCount() {
		return this.smiCount;
	}

	public boolean isRequested() {
		return externalStatusDictId.equals(ExternalStatusEnum.REQUESTED.getId());
	}

	public void setSmiCount(Integer activeSmiCount) {
		this.smiCount = activeSmiCount;
	}

	public Long getExternalStatusDictId() {
		return externalStatusDictId;
	}
	public void setExternalStatusDictId(Long externalStatusDictId) {
		this.externalStatusDictId = externalStatusDictId;
	}
	public String getExternalStatusDictName() {
		return externalStatusDictName;
	}
	public void setExternalStatusDictName(String externalStatusDictName) {
		this.externalStatusDictName = externalStatusDictName;
	}

	public Long getRequesterId() {
		return requesterId;
	}
	public String getChimeraMateStrainName() {
		return chimeraMateStrainName;
	}
	public void setChimeraMateStrainName(String chimeraMateStrainName) {
		this.chimeraMateStrainName = chimeraMateStrainName;
	}
	public void setRequesterId(Long requesterId) {
		this.requesterId = requesterId;
	}
	public String getCellLineName() {
		return cellLineName;
	}
	public void setCellLineName(String cellLineName) {
		this.cellLineName = cellLineName;
	}
	public String getCloneName() {
		return cloneName;
	}
	public void setCloneName(String cloneName) {
		this.cloneName = cloneName;
	}
	public Date getCreatedDate() {
		return createdDate;
	}
	public void setCreatedDate(Date createdDate) {
		this.createdDate = createdDate;
	}
	public Date getEditDate() {
		return editDate;
	}
	public void setEditDate(Date editDate) {
		this.editDate = editDate;
	}
	public String getEmbryoName() {
		return embryoName;
	}
	public void setEmbryoName(String embryoName) {
		this.embryoName = embryoName;
	}
	public String getEndpointName() {
		return endpointName;
	}
	public void setEndpointName(String endpointName) {
		this.endpointName = endpointName;
	}
	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}
	public String getProjectLicence() {
		return projectLicence;
	}
	public void setProjectLicence(String projectLicence) {
		this.projectLicence = projectLicence;
	}
	public String getRequesterName() {
		return requesterName;
	}
	public void setRequesterName(String requesterName) {
		this.requesterName = requesterName;
	}
	public Long getDonorCellLineStrainId() {
		return donorCellLineStrainId;
	}
	public void setDonorCellLineStrainId(Long donorCellLineStrainId) {
		this.donorCellLineStrainId = donorCellLineStrainId;
	}
	public String getDonorCellLineStrainName() {
		return donorCellLineStrainName;
	}
	public void setDonorCellLineStrainName(String donorCellLineStrainName) {
		this.donorCellLineStrainName = donorCellLineStrainName;
	}
	public Long getTeamNumber() {
		return teamNumber;
	}
	public void setTeamNumber(Long teamNumber) {
		this.teamNumber = teamNumber;
	}
	public String getWorkflowPipeline() {
		return workflowPipeline;
	}
	public void setWorkflowPipeline(String workflowPipeline) {
		this.workflowPipeline = workflowPipeline;
	}
	public Long getCellLineId() {
		return cellLineId;
	}
	public void setCellLineId(Long cellLineId) {
		this.cellLineId = cellLineId;
	}
	public Long getChimeraMateStrainId() {
		return chimeraMateStrainId;
	}
	public void setChimeraMateStrainId(Long chimeraMateStrainId) {
		this.chimeraMateStrainId = chimeraMateStrainId;
	}

	public Long getColonyInfoId() {
		return colonyInfoId;
	}

	public void setColonyInfoId(Long colonyInfoId) {
		this.colonyInfoId = colonyInfoId;
	}

	public String getColonyName() {
		return colonyName;
	}

	public void setColonyName(String colonyName) {
		this.colonyName = colonyName;
	}

	public String getColonyPrefix() {
		return colonyPrefix;
	}

	public void setColonyPrefix(String colonyPrefix) {
		this.colonyPrefix = colonyPrefix;
	}
}