/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mirequest.view;

import java.util.Date;

import uk.ac.sanger.mig.mirequest.CellLine;


/**
 * wrapper around CellLine to flatten data structure for view/jsp
 * @author ae1
 *
 */
public class ViewOneCellLineBean {

	private CellLine cellLine;

	public ViewOneCellLineBean(CellLine cellLine) {
		this.cellLine = cellLine;
	}

	public String getFunding() {

		return ( cellLine.getFundingDict() != null ) ?
				cellLine.getFundingDict().getName() : "";

	}

	public String getComments() {
		return cellLine.getComments();
	}

	public Long getId() {
		return cellLine.getId();
	}

	public String getCellLineName() {
		return cellLine.getCellLineName();
	}

	public String getCellLineStrainName() {
		return (cellLine.getCellLineStrain() != null) ? cellLine.getCellLineStrain().getName() : "";
	}

	public String getCloneName() {
		return cellLine.getCloneName();
	}

	public Date getCreatedDate() {
		return cellLine.getCreatedDate();
	}

	public String getCreatorName() {
		return (cellLine.getCreator() != null) ? cellLine.getCreator().getFullName() : "";
	}

	public String getExpectedCoatColor() {
		return (cellLine.getExpectedCoatColor() != null) ? cellLine.getExpectedCoatColor().getName() : "";
	}

	public String getGenotype() {
		return (cellLine.getGenotype() != null) ? cellLine.getGenotype().getName() : "";
	}

	public String getCellLineSourceName() {
		return ( cellLine.getCellLineSource() != null ) ? cellLine.getCellLineSource().getName() : "";
	}

	public String getTeam87RefId() {
		return (cellLine.getTeam87RefId() > 0) ? ""+cellLine.getTeam87RefId() : "None Assigned";
	}

	public String getModifiedAllelePrimaryGeneName() {
		return (cellLine.getModifiedAllele() != null
				&& cellLine.getModifiedAllele().getMigGene() != null) ?
						cellLine.getModifiedAllele().getMigGene().getPrimaryName() : "";
	}

	public String getAlleleName() {
		return (cellLine.getModifiedAllele() != null) ?
				cellLine.getModifiedAllele().getOfficialNameSuperscript() : "";
	}

	public Long getModifiedAlleleId() {//use for hyperlink to modified allele detailed view
		return cellLine.getModifiedAlleleId();
	}

	public String getEditedBy() {
		return cellLine.getEditedBy();
	}

	public Date getEditDate() {
		return cellLine.getEditDate();
	}

	//add getter methods
}
