/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking;

import java.util.Date;

import uk.ac.sanger.mig.common.PaginatedSearchBean;

public class BreedingSearchBean extends PaginatedSearchBean {

	private String breedingName;
	private Date startDateFrom;
	private Date startDateTo;
	private Date endDateFrom;
	private Date endDateTo;
	private boolean endDateNull;
	private String mouseBarcodeDescription;
	private String mouseBarcode;
	private String status;
	private String litterExpression;
	private Long litterNumber;
	private String roomNumber;
	private Long roomId;
	private Long embryoTransferId;
	private Long microinjectionId;
	private String offspringColonyName;
	private String offspringColonyPrefix;
	private Long offspringColonyId;
	private String parentBarcodeDescription;
	private String parentBarcode;
	private Long parentId;
	private String parentName;
	private String parentCageDescription;
	private String parentCageBarcode;
	private Long parentCageId;
	private Long femaleCageId;
	private Boolean timed;
	private Date timedHarvestDate;
	private Long breedingCategoryDictId;

	public String getParentBarcode() {
		return parentBarcode;
	}

	public void setParentBarcode(String parentBarcode) {
		this.parentBarcode = parentBarcode;
	}

	public String getParentBarcodeDescription() {
		return parentBarcodeDescription;
	}

	public void setParentBarcodeDescription(String parentBarcodeDescription) {
		this.parentBarcodeDescription = parentBarcodeDescription;
	}

	public String getParentCageBarcode() {
		return parentCageBarcode;
	}

	public void setParentCageBarcode(String parentCageBarcode) {
		this.parentCageBarcode = parentCageBarcode;
	}

	public String getParentCageDescription() {
		return parentCageDescription;
	}

	public void setParentCageDescription(String parentCageDescription) {
		this.parentCageDescription = parentCageDescription;
	}

	public Long getParentCageId() {
		return parentCageId;
	}

	public void setParentCageId(Long parentCageId) {
		this.parentCageId = parentCageId;
	}

	public String getOffspringColonyName() {
		return offspringColonyName;
	}

	public void setOffspringColonyName(String parentColony) {
		this.offspringColonyName = parentColony;
	}

	public Long getOffspringColonyId() {
		return offspringColonyId;
	}

	public void setOffspringColonyId(Long parentColonyId) {
		this.offspringColonyId = parentColonyId;
	}

	public Long getParentId() {
		return parentId;
	}

	public void setParentId(Long parentId) {
		this.parentId = parentId;
	}

	public String getParentName() {
		return parentName;
	}

	public void setParentName(String parentName) {
		this.parentName = parentName;
	}

	public String getBreedingName() {
		return breedingName;
	}

	public void setBreedingName(String breedingName) {
		this.breedingName = breedingName;
	}

	public String getLitterExpression() {
		return this.litterExpression;
	}

	public void setLitterExpression(String litterExpression) {
		this.litterExpression = litterExpression;
	}

	public Long getLitterNumber() {
		return this.litterNumber;
	}

	public void setLitterNumber(Long litterNumber) {
		this.litterNumber = litterNumber;
	}

	public Long getRoomId() {
		return this.roomId;
	}

	public void setRoomId(Long roomId) {
		this.roomId = roomId;
	}

	public String getRoomNumber() {
		return this.roomNumber;
	}

	public void setRoomNumber(String roomNumber) {
		this.roomNumber = roomNumber;
	}

	public String getStatus() {
		return this.status;
	}

	public void setStatus(String status) {
		this.status = status;
	}

	public Date getStartDateFrom() {
		return startDateFrom;
	}

	public void setStartDateFrom(Date eventStartFrom) {
		this.startDateFrom = eventStartFrom;
	}

	public Date getStartDateTo() {
		return startDateTo;
	}

	public void setStartDateTo(Date eventStartTo) {
		this.startDateTo = eventStartTo;
	}

	public Date getEndDateFrom() {
		return endDateFrom;
	}

	public void setEndDateFrom(Date eventEndFrom) {
		this.endDateFrom = eventEndFrom;
	}

	public boolean isEndDateNull() {
		return endDateNull;
	}

	public void setEndDateNull(boolean eventEndNull) {
		this.endDateNull = eventEndNull;
	}

	public Date getEndDateTo() {
		return endDateTo;
	}

	public void setEndDateTo(Date eventEndTo) {
		this.endDateTo = eventEndTo;
	}

	public String getMouseBarcode() {
		return mouseBarcode;
	}

	public void setMouseBarcode(String mouseBarcode) {
		this.mouseBarcode = mouseBarcode;
	}

	public String getMouseBarcodeDescription() {
		return mouseBarcodeDescription;
	}

	public void setMouseBarcodeDescription(String mouseBarcodeDescription) {
		this.mouseBarcodeDescription = mouseBarcodeDescription;
	}

	public Long getEmbryoTransferId() {
		return embryoTransferId;
	}

	public void setEmbryoTransferId(Long embryoTransferId) {
		this.embryoTransferId = embryoTransferId;
	}

	public boolean isMinimumOneFieldSet() {

		return (
				(breedingName != null && breedingName.length() > 0) ||
				startDateFrom != null ||
				startDateTo != null ||
				endDateFrom != null ||
				endDateTo != null ||
				endDateNull != false ||
				(status != null && status.length() > 0) ||
				litterNumber != null ||
				roomId != null	||
				embryoTransferId != null ||
				microinjectionId != null ||
				offspringColonyId != null ||
				parentId != null ||
				(parentName != null && parentName.length() > 0) ||
				parentCageId != null ||
				femaleCageId != null ||
				timed != null ||
				timedHarvestDate != null ||
				breedingCategoryDictId != null
		);
	}

	public Long getMicroinjectionId() {
		return microinjectionId;
	}

	public void setMicroinjectionId(Long microinjectionId) {
		this.microinjectionId = microinjectionId;
	}

	public Long getFemaleCageId() {
		return femaleCageId;
	}

	public void setFemaleCageId(Long femaleCageId) {
		this.femaleCageId = femaleCageId;
	}

	public String getOffspringColonyPrefix() {
		return offspringColonyPrefix;
	}

	public void setOffspringColonyPrefix(String offspringColonyPrefix) {
		this.offspringColonyPrefix = offspringColonyPrefix;
	}

	public Boolean getTimed() {
		return timed;
	}

	public void setTimed(Boolean timed) {
		this.timed = timed;
	}

	public Date getTimedHarvestDate() {
		return timedHarvestDate;
	}

	public void setTimedHarvestDate(Date timedHarvestDate) {
		this.timedHarvestDate = timedHarvestDate;
	}

	public Long getBreedingCategoryDictId() {
		return breedingCategoryDictId;
	}

	public void setBreedingCategoryDictId(Long breedingCategoryDictId) {
		this.breedingCategoryDictId = breedingCategoryDictId;
	}

}
