/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking;

import java.util.Collection;
import java.util.Date;

import org.apache.commons.lang.StringUtils;

import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.ComponentEnum;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.common.LookupListElement;
import uk.ac.sanger.mig.common.LookupListUtil;

/**
 * A group of mice.
 *
 * Different purposes of grouping are indicated by the type code.
 *
 * 'End date' is intially intended as a necropsy date for histology batches,
 * but interpretation depends on the type of cohort.
 *
 */
public class Cohort extends AuthenticatedDataObject implements LookupListElement, BarcodedObject {

	public enum Component implements ComponentEnum {
		ALL_COMPONENTS,
		MICE
	}

	private String cohortName;
	private String comments;
	private String reason;

	// Mice booked for this reservation.
	private Collection<Mouse> mice;

	private DictionaryEntry cohortType;
	private Long cohortTypeDictId;
	private Date endDate;
	private Long cohortPipelineDictId;
	private DictionaryEntry cohortPipeline;

	public Long getCohortPipelineDictId() {
		return cohortPipelineDictId;
	}

	public void setCohortPipelineDictId(Long cohortPipelineDictId) {
		this.cohortPipelineDictId = cohortPipelineDictId;
	}

	public DictionaryEntry getCohortPipeline() {
		return cohortPipeline;
	}

	public void setCohortPipeline(DictionaryEntry cohortPipeline) {
		this.cohortPipeline = cohortPipeline;
	}

	public Long getCohortTypeDictId() {
		return cohortTypeDictId;
	}

	public void setCohortTypeDictId(Long cohortTypeDictId) {
		this.cohortTypeDictId = cohortTypeDictId;
	}

	public DictionaryEntry getCohortType() {
		return cohortType;
	}

	public void setCohortType(DictionaryEntry cohortType) {
		this.cohortType = cohortType;
	}

	public String getReason() {
		return this.reason;
	}

	public void setReason(String reason) {
		this.reason = reason;
	}

	public Collection<Mouse> getMice() {
		return this.mice;
	}

	public void setMice(Collection<Mouse> mice) {
		this.mice = mice;
	}

	public String getComments() {
		return comments;
	}

	public void setComments(String comments) {
		this.comments = comments;
	}

	public String getCohortName() {
		return cohortName;
	}

	public void setCohortName(String cohortName) {
		this.cohortName = cohortName;
	}

	public String getDisplayText() {
		String displayText = "";

		if(StringUtils.isEmpty(cohortName)) {
			displayText += "(no name)";
		}
		else {
			displayText += cohortName;
		}
		if(!StringUtils.isEmpty(reason)) {
			displayText += " - " + reason;
		}

		return displayText;
	}

	public String getElementData() {
		return
		LookupListUtil.format("cohortId", getId()) +
		LookupListUtil.format("cohortName", getCohortName());
	}

	public void setDisplayText(String displayText) {
		// not required
	}

	public void setElementData(String elementData) {
		// not required
	}

	public String getBarcode() {
		return getCohortName();
	}

	public String getBarcodeDescription() {
		return getCohortName();
	}

	public BarcodeType getBarcodeType() {
		return BarcodeType.COHORT;
	}

	public Date getEndDate() {
		return endDate;
	}

	public void setEndDate(Date endDate) {
		this.endDate = endDate;
	}

	public void generateBarcode() {
		// implementation is not applicable (cohorts don't really have barcodes)
	}

}