/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.Set;

public class FamilyTreeImpl implements FamilyTree {

	Map<Integer, Collection<FamilyTreeMember>> generations = new HashMap<Integer, Collection<FamilyTreeMember>>();

	public FamilyTreeImpl(Collection animals) {

		Iterator i = animals.iterator();
		while(i.hasNext()) {
			FamilyTreeMember member = (FamilyTreeMember)i.next();
			Integer generationNumber = new Integer(member.getFamilyTreeGeneration());

			if(!generations.containsKey(generationNumber)) {
				Collection<FamilyTreeMember> newGeneration = new ArrayList<FamilyTreeMember>();
				generations.put(generationNumber,newGeneration);
			}

			Collection<FamilyTreeMember> generation = generations.get(generationNumber);
			generation.add(member);
		}
	}

	public Collection getParents(FamilyTreeMember member) {
		Collection<FamilyTreeMember> parents = new ArrayList<FamilyTreeMember>();
		Integer parentGenerationKey = new Integer(member.getFamilyTreeGeneration()-1);

		if(generations.containsKey(parentGenerationKey)) {
			Collection parentGeneration = (Collection)generations.get(parentGenerationKey);
			Iterator i = parentGeneration.iterator();
			while(i.hasNext()) {
				FamilyTreeMember parent = (FamilyTreeMember)i.next();
				if(parent.getFamilyTreeChild() == member.getId()) {
					parents.add(parent);
				}
			}
		}

		return parents;
	}

	public Collection getGeneration(int generationNumber) {
		Collection<FamilyTreeMember> generation = new ArrayList<FamilyTreeMember>();

		if(generations.containsKey(new Integer(generationNumber))) {
			generation = generations.get(new Integer(generationNumber));
		}

		return generation;
	}

	public Integer getMinGeneration() {
		Set<Integer> s = generations.keySet();
		Integer i  = Collections.min((Collection<Integer>)s);
		return i;
	}

	public Integer getMaxGeneration() {
		Set<Integer> s = generations.keySet();
		Integer i  = Collections.max((Collection<Integer>)s);
		return i;
	}
}