/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking;

import java.util.Date;

import uk.ac.sanger.mig.common.PaginatedSearchBean;


public class LitterSearchBean extends PaginatedSearchBean  {

	// parent
	private String parentBarcodeDescription;
	private String parentBarcode;
	private Long parentId;
	private String parentName;
	private String colonyPrefix;
	private String colonyName;
	private Long colonyInfoId;

	//litter birth date
	private Date birthDateFrom;
	private Date birthDateTo;

	//litter plug date
	private Date plugDateFrom;
	private Date plugDateTo;

	//litter name
	private String litterName;

	private Long roomId;
	private String status;

	public boolean isMinimumOneFieldSet() {
		return (
				(litterName != null && litterName.length() >0) ||
				parentId != null 		||
				colonyInfoId != null 		||
			    birthDateFrom != null	||
				birthDateTo != null		||
			    plugDateFrom != null	||
				plugDateTo != null		||
				(status != null && status.length() > 0) ||
				roomId != null
		);
	}

	public Date getBirthDateFrom() {
		return birthDateFrom;
	}

	public void setBirthDateFrom(Date birthDateFrom) {
		this.birthDateFrom = birthDateFrom;
	}

	public Date getBirthDateTo() {
		return birthDateTo;
	}

	public void setBirthDateTo(Date birthDateTo) {
		this.birthDateTo = birthDateTo;
	}

	public String getStatus() {
		return status;
	}

	public void setStatus(String status) {
		this.status = status;
	}

	public String getLitterName() {
		return litterName;
	}

	public void setLitterName(String litterName) {
		this.litterName = litterName;
	}

	public String getParentBarcodeDescription() {
		return parentBarcodeDescription;
	}

	public void setParentBarcodeDescription(String parentBarcodeDescription) {
		this.parentBarcodeDescription = parentBarcodeDescription;
	}

	public String getParentBarcode() {
		return parentBarcode;
	}

	public void setParentBarcode(String parentBarcode) {
		this.parentBarcode = parentBarcode;
	}

	public Long getParentId() {
		return parentId;
	}

	public void setParentId(Long parentId) {
		this.parentId = parentId;
	}

	public String getParentName() {
		return parentName;
	}

	public void setParentName(String parentName) {
		this.parentName = parentName;
	}

	public String getColonyName() {
		return colonyName;
	}

	public void setColonyName(String colony) {
		this.colonyName = colony;
	}

	public Long getColonyInfoId() {
		return colonyInfoId;
	}

	public void setColonyInfoId(Long colonyId) {
		this.colonyInfoId = colonyId;
	}

	public Date getPlugDateFrom() {
		return plugDateFrom;
	}

	public void setPlugDateFrom(Date plugDateFrom) {
		this.plugDateFrom = plugDateFrom;
	}

	public Date getPlugDateTo() {
		return plugDateTo;
	}

	public void setPlugDateTo(Date plugDateTo) {
		this.plugDateTo = plugDateTo;
	}

	public String getColonyPrefix() {
		return colonyPrefix;
	}

	public void setColonyPrefix(String colonyPrefix) {
		this.colonyPrefix = colonyPrefix;
	}

	public void setRoomId(Long roomId) {
		this.roomId = roomId;
	}

	public Long getRoomId() {
		return roomId;
	}
}