/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking;

import java.util.Date;

import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.ComponentEnum;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.database.TableMetadataEnum;
import uk.ac.sanger.mig.licensing.PersonalLicence;
import uk.ac.sanger.mig.licensing.Protocol;

public class MouseProcedure extends AuthenticatedDataObject implements Cloneable {

	public enum Component implements ComponentEnum {
		ALL_COMPONENTS,
		MOUSE,
		PERSONAL_LICENCE,
		PROTOCOL
	}

    private Long mouseId;
    private Mouse mouse;
    private Long protocolId;
    private Protocol protocol;
    private Long personalLicenceId;
    private PersonalLicence personalLicence;
    private Date startDate;
    private Date endDate;
    private TableMetadataEnum foreignTableName;
    private Long foreignKeyId;
    private DictionaryEntry procedure;
    private Long procedureDictId;
    private boolean licencedProcedure;

    public boolean isLicencedProcedure() {
		return licencedProcedure;
	}

	public void setLicencedProcedure(boolean licencedProcedure) {
		this.licencedProcedure = licencedProcedure;
	}

	public Mouse getMouse() {
		return mouse;
	}

	public void setMouse(Mouse mouse) {
		this.mouse = mouse;
	}

	public PersonalLicence getPersonalLicence() {
		return personalLicence;
	}

	public void setPersonalLicence(PersonalLicence personalLicence) {
		this.personalLicence = personalLicence;
	}

	public Protocol getProtocol() {
		return protocol;
	}

	public void setProtocol(Protocol protocol) {
		this.protocol = protocol;
	}

	public Long getMouseId() {
        return mouseId;
    }

    public void setMouseId(Long mouseId) {
        this.mouseId = mouseId;
    }
    public Long getProtocolId() {
        return protocolId;
    }

    public void setProtocolId(Long protocolId) {
        this.protocolId = protocolId;
    }
    public Long getPersonalLicenceId() {
        return personalLicenceId;
    }

    public void setPersonalLicenceId(Long personalLicenceId) {
        this.personalLicenceId = personalLicenceId;
    }
    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }
    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }
    public TableMetadataEnum getForeignTableName() {
        return foreignTableName;
    }

    public void setForeignTableName(TableMetadataEnum foreignTableName) {
        this.foreignTableName = foreignTableName;
    }
    public Long getForeignKeyId() {
        return foreignKeyId;
    }

    public void setForeignKeyId(Long foreignKeyId) {
        this.foreignKeyId = foreignKeyId;
    }

	public DictionaryEntry getProcedure() {
		return procedure;
	}

	public void setProcedure(DictionaryEntry procedure) {
		this.procedure = procedure;
	}

	public Long getProcedureDictId() {
		return procedureDictId;
	}

	public void setProcedureDictId(Long procedureDictId) {
		this.procedureDictId = procedureDictId;
	}

	/**
	 * Creates a copy of the object without setting mouse id or id fields.
	 */
	@Override
	public MouseProcedure clone() {
		MouseProcedure mouseProcedure = new MouseProcedure();
		if(getStartDate()!= null) {
			mouseProcedure.setStartDate((Date)getStartDate().clone());
		}
		mouseProcedure.setProcedureDictId(getProcedureDictId());
		mouseProcedure.setPersonalLicenceId(getPersonalLicenceId());
		mouseProcedure.setProtocolId(getProtocolId());
		return mouseProcedure;
	}
}