/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking;
import java.util.Collection;

import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.BarcodeUtils;
import uk.ac.sanger.mig.common.ComponentEnum;
import uk.ac.sanger.mig.common.LookupListElement;
import uk.ac.sanger.mig.common.LookupListUtil;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.tecniplast.AirHandlingUnit;

public class Rack extends AuthenticatedDataObject implements LookupListElement, BarcodedObject {

	public enum Component implements ComponentEnum {
		ALL_COMPONENTS,
		CAGES,
		CAGE_COUNT,
		AIR_HANDLING_UNIT,
		ROOM
	}

	private String technoplastName;
	private String name;
	private String status;
	private String barcode;
	private String barcodeDescription;
	private String displayText;

	private Collection<Cage> cages;
	private Collection<Person> users;
	private Integer cageCount;

	private Room room;
	private Long roomId;

	private AirHandlingUnit airHandlingUnit;
	private Long airHandlingUnitId;

	private int maxCapacity;
	private int totalCages;


	/**
	 * @return the totalCages
	 */
	public int getTotalCages() {
		return this.totalCages;
	}

	/**
	 * @param totalCages the totalCages to set
	 */
	public void setTotalCages(int totalCages) {
		this.totalCages = totalCages;
	}

	public int getMaxCapacity() {
		return maxCapacity;
	}

	public void setMaxCapacity(int maxCapacity) {
		this.maxCapacity = maxCapacity;
	}

	public String getDisplayText() {
		if(displayText == null && name != null) {
			displayText = "Rack " + name;
		}
		return displayText;
	}

	public String getElementData() {
		return
		LookupListUtil.format("rackId", getId()) +
		LookupListUtil.format("rackName", getName());
	}

	public void setDisplayText(String displayText) {
		this.displayText = displayText;
	}
	public void setElementData(String elementData) {
		// TODO Auto-generated method stub
	}

	public Collection<Cage> getCages() {
		return cages;
	}
	public void setCages(Collection<Cage> cages) {
		this.cages = cages;
	}
	public String getName() {
		return name;
	}
	public void setName(String name) {
		this.name = name;
	}
	public Room getRoom() {
		return room;
	}
	public void setRoom(Room room) {
		this.room = room;
	}
	public String getTechnoplastName() {
		return technoplastName;
	}
	public void setTechnoplastName(String technoplastName) {
		this.technoplastName = technoplastName;
	}
	public Collection<Person> getUsers() {
		return users;
	}
	public void setUsers(Collection<Person> users) {
		this.users = users;
	}
	public AirHandlingUnit getAirHandlingUnit() {
		return airHandlingUnit;
	}
	public void setAirHandlingUnit(AirHandlingUnit airHandlingUnit) {
		this.airHandlingUnit = airHandlingUnit;
	}
	public String getStatus() {
		return status;
	}
	public void setStatus(String status) {
		this.status = status;
	}
	public Long getAirHandlingUnitId() {
		return airHandlingUnitId;
	}
	public void setAirHandlingUnitId(Long airHandlingUnitId) {
		this.airHandlingUnitId = airHandlingUnitId;
	}
	public Long getRoomId() {
		return roomId;
	}
	public void setRoomId(Long roomId) {
		this.roomId = roomId;
	}
	public String getBarcode() {
		return barcode;
	}
	public void setBarcode(String barcode) {
		this.barcode = barcode;
	}

	public String getBarcodeDescription() {
		if(barcodeDescription == null) {
			if(getName() != null) {
				barcodeDescription = "Rack " + getName();
			}

			if(room != null) {
				barcodeDescription += " " + room.getRoomNumber();
			}
		}
		return barcodeDescription;
	}
	public void setBarcodeDescription(String barcodeDescription) {
		this.barcodeDescription = barcodeDescription;
	}

	public void inflate() {

		if(this.room == null){
			this.room = new Room();
		}

		if(this.airHandlingUnit == null) {
			this.airHandlingUnit = new AirHandlingUnit();
		}

	}

	public BarcodedObject.BarcodeType getBarcodeType() {
		return BarcodedObject.BarcodeType.RACK;
	}

	public void generateBarcode() {
		this.barcode = BarcodeUtils.generateBarcode(getBarcodeType(), getId());
	}

	public Integer getCageCount() {
		return cageCount;
	}

	public void setCageCount(Integer cageCount) {
		this.cageCount = cageCount;
	}

}
