/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.mousetracking;

import java.util.Calendar;
import java.util.Date;

import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.ComponentEnum;
import uk.ac.sanger.mig.personnel.Person;


public class StudBreeding extends AuthenticatedDataObject {

	public enum Component implements ComponentEnum {
		ALL_COMPONENTS,
		MALE,
		FEMALE,
		SETUP_PERSON,
		CHECK_PERSON
	}

	private Long maleId;
	private Mouse male;
	private Long femaleId;
	private Mouse female;
	private Date startDateTime;
	private Date endDate;
	private Date plugDateTime;
	private Long checkPersonId;
	private Person checkPerson;
	private Long setupPersonId;
	private Person setupPerson;
	private boolean pseudoBreeding;
	private Float timedEmbryoAge;

    public boolean isPlugged() {
        return (plugDateTime == null) ? false : true;
    }

	public Date getEndDate() {
		return endDate;
	}

	public void setEndDate(Date endDate) {
		this.endDate = endDate;
	}

	public Long getFemaleId() {
		return femaleId;
	}

	public void setFemaleId(Long femaleId) {
		this.femaleId = femaleId;
	}

	public Long getMaleId() {
		return maleId;
	}

	public void setMaleId(Long maleId) {
		this.maleId = maleId;
	}

	public Date getPlugDateTime() {
		return plugDateTime;
	}

	public void setPlugDateTime(Date plugDate) {
		this.plugDateTime = plugDate;
	}

	public Date getStartDateTime() {
		return startDateTime;
	}

	public void setStartDateTime(Date startDate) {
		this.startDateTime = startDate;
	}

	public Mouse getFemale() {
		return female;
	}

	public void setFemale(Mouse female) {
		this.female = female;
	}

	public Mouse getMale() {
		return male;
	}

	public void setMale(Mouse male) {
		this.male = male;
	}

	public Person getCheckPerson() {
		return checkPerson;
	}

	public void setCheckPerson(Person checkPerson) {
		this.checkPerson = checkPerson;
	}

	public Long getCheckPersonId() {
		return checkPersonId;
	}

	public void setCheckPersonId(Long checkPersonId) {
		this.checkPersonId = checkPersonId;
	}

	public Person getSetupPerson() {
		return setupPerson;
	}

	public void setSetupPerson(Person setupPerson) {
		this.setupPerson = setupPerson;
	}

	public Long getSetupPersonId() {
		return setupPersonId;
	}

	public void setSetupPersonId(Long setupPersonId) {
		this.setupPersonId = setupPersonId;
	}

	public String getStatus() {
		String status = "";

		if(isPlugged()) {
			status = "Plugged";
		}
		else {
			if(endDate == null) {
				status = "Mating";
			}
			else {
				status = "Failed";
			}
		}

		return status;
	}

	public boolean isPseudoBreeding() {
		return pseudoBreeding;
	}

	public void setPseudoBreeding(boolean pseudoBreeding) {
		this.pseudoBreeding = pseudoBreeding;
	}

	public Float getTimedEmbryoAge() {
		return timedEmbryoAge;
	}

	public void setTimedEmbryoAge(Float timedEmbryoAge) {
		this.timedEmbryoAge = timedEmbryoAge;
	}

	public Date getReadyDate() {
		if(timedEmbryoAge == null || plugDateTime == null) {
			return null;
		}
		else {
			Calendar c = Calendar.getInstance();
			c.setTime(getPlugDateTime());
			c.add(Calendar.DAY_OF_MONTH, timedEmbryoAge.intValue());
			return c.getTime();
		}
	}
}