package uk.ac.sanger.mig.mousetracking.controllers;

import java.text.SimpleDateFormat;
import java.util.Collection;
import java.util.Date;
import java.util.List;
import java.util.Set;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.propertyeditors.CustomDateEditor;
import org.springframework.validation.BindException;
import org.springframework.web.bind.ServletRequestDataBinder;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.common.controllers.AbstractFormChangeController;
import uk.ac.sanger.mig.common.services.ComponentMapService;
import uk.ac.sanger.mig.mousetracking.Cage;
import uk.ac.sanger.mig.mousetracking.Cohort;
import uk.ac.sanger.mig.mousetracking.Mouse;
import uk.ac.sanger.mig.mousetracking.MousePool;
import uk.ac.sanger.mig.mousetracking.forms.AddStudBreedingForm;
import uk.ac.sanger.mig.mousetracking.forms.BarcodeForm;
import uk.ac.sanger.mig.mousetracking.services.CageService;
import uk.ac.sanger.mig.mousetracking.services.CohortService;
import uk.ac.sanger.mig.mousetracking.services.MousePoolService;
import uk.ac.sanger.mig.mousetracking.services.StudBreedingService;
import uk.ac.sanger.mig.personnel.Person;

public class AddStudBreedingFormController extends AbstractFormChangeController {

	private MousePoolService mousePoolService;
	private ComponentMapService componentMapService;
	private StudBreedingService studBreedingService;
	private CohortService cohortService;
	private CageService cageService;

	public void setComponentMapService(ComponentMapService componentMapService) {
		this.componentMapService = componentMapService;
	}

	public void setMousePoolService(MousePoolService mousePoolService) {
		this.mousePoolService = mousePoolService;
	}

	public void setStudBreedingService(StudBreedingService studBreedingService) {
		this.studBreedingService = studBreedingService;
	}

	public void setCohortService(CohortService cohortService) {
		this.cohortService = cohortService;
	}

	public void setCageService(CageService cageService) {
		this.cageService = cageService;
	}

	@Override
	protected void initBinder(HttpServletRequest request, ServletRequestDataBinder binder) throws Exception {
		super.initBinder(request, binder);
		binder.registerCustomEditor(Date.class, new CustomDateEditor(new SimpleDateFormat("dd-MMM-yyyy HH:mm"), true));
	}


	@Override
	protected void onFormChange(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		AddStudBreedingForm form = (AddStudBreedingForm)command;
		String changeRequest = form.getChangeForm();

		if(changeRequest.equals("addPoolCage")) {
			addPool(form, errors);
			form.setPoolCage(new BarcodeForm());
		}
		else if(changeRequest.equals("removePool")) {
			removePool(form, errors);
		}
		else if(changeRequest.equals("addStudCohort")) {
			addStudCohort(form);
		}
		else if(changeRequest.equals("addStudCage")) {
			addStudCage(form);
			form.setStudCage(new BarcodeForm());
		}

		// reset form change fields
		form.setChangeForm(null);
		form.setChangeFormValue(null);
	}

	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		AddStudBreedingForm form = (AddStudBreedingForm)command;
		Person user = RequestUtils.getUser(request);

		Set<Long> studCageids = studBreedingService.addBreedings(form, user);

		String cageIdString = "";
		for(Long cageId : studCageids) {
			cageIdString +=cageId + ",";
		}

		return new ModelAndView(getSuccessView(), "cageIds", cageIdString);
	}

	@Override
	protected Object formBackingObject(HttpServletRequest request) throws Exception {
		RequestUtils.setLastReferer(request);
		AddStudBreedingForm form = (AddStudBreedingForm)createCommand();
		return form;
	}

	@Override
	protected ModelAndView handleInvalidSubmit(HttpServletRequest request, HttpServletResponse response) throws Exception {
		return new ModelAndView("errors/handle_invalid_submit");
	}

	private void addPool(AddStudBreedingForm form, BindException errors) {
		ComponentMap poolComponents = componentMapService.getComponentMap("viewOnePool");
		MousePool pool = mousePoolService.fetchByBarcode(form.getPoolCage().getBarcode(), poolComponents);

		if(pool == null && errors != null) {
			errors.reject(null, "No Pool found with barcode " + form.getPoolCage().getBarcode());
		}
		else if(!form.getPools().contains(pool)) {
			form.getPools().add(pool);
			form.getFemalesToUse().add(null);
		}
	}

	private void removePool(AddStudBreedingForm form, BindException errors) {
		try {
			int index = new Integer(form.getChangeFormValue());
			List<MousePool> pools = form.getPools();
			pools.remove(index);
			List<Long> femalesToUse = form.getFemalesToUse();
			femalesToUse.remove(index);
		}
		catch(NumberFormatException e) {
			errors.reject(null, "Invalid row index supplied" + form.getChangeFormValue());
		}
	}

	private void addStudCage(AddStudBreedingForm form) {
		if(form.getStudCage().getId() != null) {
			ComponentMap cageComponents = componentMapService.getComponentMap("addStudCage");
			Cage studCage = cageService.fetchById(form.getStudCage().getId(), cageComponents);
			if(studCage != null && studCage.getContents() != null) {
				addStudsToForm(form, studCage.getContents());
			}
		}
	}

	private void addStudCohort(AddStudBreedingForm form) {
		if(form.getStudCohortId() != null) {
			ComponentMap cohortComponents = componentMapService.getComponentMap("manageCohort");
			Cohort studCohort = cohortService.fetchById(form.getStudCohortId(), cohortComponents);
			if(studCohort != null && studCohort.getMice() != null) {
				addStudsToForm(form, studCohort.getMice());
			}
		}
	}

	private void addStudsToForm(AddStudBreedingForm form, Collection<Mouse> mice) {
		for(Mouse mouse : mice) {
			if(mouse.isStud() && mouse.isAlive() && !form.getStuds().contains(mouse)) {
				form.getStuds().add(mouse);
				form.getStudsToUse().add(null); //default checkbox to unchecked
			}
		}
	}
}
