/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.controllers;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Date;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.licensing.PersonalLicence;
import uk.ac.sanger.mig.mousetracking.Mouse;
import uk.ac.sanger.mig.mousetracking.TissueSample;
import uk.ac.sanger.mig.mousetracking.forms.BloodSampleForm;
import uk.ac.sanger.mig.mousetracking.services.TissueSampleService;
import uk.ac.sanger.mig.personnel.Person;

public class BloodSampleController extends CohortProcedureFormController {
	
	private TissueSampleService tissueSampleService;

	public void setTissueSampleService(TissueSampleService mouseWeightService) {
		this.tissueSampleService = mouseWeightService;
	}

	@Override
	protected void changeForm(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) {
		BloodSampleForm form = (BloodSampleForm)command;
		Collection<TissueSample> tissueSamples = new ArrayList<TissueSample>();
		for(Mouse mouse : form.getMice()) {
			TissueSample sample = new TissueSample();
			sample.setMouseId(mouse.getId());
			sample.setSampleType("Blood");
			sample.setSampleDate(new Date());
			sample.setReusable(true);
			tissueSamples.add(sample);
			
			// set the project for the mouse. will be the same for all in the cage.
			if(mouse.getCurrentLicencedProcedure() != null && form.getProjectLicenceId() == null) {
				form.setProjectLicenceDescription(mouse.getCurrentLicencedProcedure().getProtocol().getProjectLicence().getDisplayText());
				form.setProjectLicenceId(mouse.getCurrentLicencedProcedure().getProtocol().getProjectLicenceId());
			}
		}
		form.setBloodSamples(tissueSamples);		
	}

	@Override
	protected void customiseFormBackingObject(HttpServletRequest request, Object command) throws Exception {
		BloodSampleForm form = (BloodSampleForm)command;
		PersonalLicence licence = RequestUtils.getUser(request).getPersonalLicence();
		form.setPersonalLicence(licence);
	}

	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		BloodSampleForm form = (BloodSampleForm)command;
		Person user = RequestUtils.getUser(request);		
		
		tissueSampleService.storeWithProcedure(form.getBloodSamples(), user, form.getProjectLicenceId(), form.getPersonalLicence().getId());
		
		return new ModelAndView(getSuccessView(),"id",form.getCohort().getId());
	}
}
