/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.controllers;

import java.util.Collection;
import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang.StringUtils;
import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.AbstractCancellableFormController;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.mousetracking.forms.BulkUpdateMiceForm;
import uk.ac.sanger.mig.mousetracking.services.MouseService;
import uk.ac.sanger.mig.personnel.Person;


public class BulkUpdateMiceFormController extends AbstractCancellableFormController {

	private MouseService mouseService;

	public void setMouseService(MouseService mouseService) {
		this.mouseService = mouseService;
	}

	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		BulkUpdateMiceForm updateForm = (BulkUpdateMiceForm)command;
		Person user = RequestUtils.getUser(request);

		int recordsUpdated = mouseService.bulkUpdate(updateForm, user);

		return new ModelAndView(getSuccessView(), "updated", recordsUpdated);
	}

	@Override
	protected Map referenceData(HttpServletRequest request, Object command, Errors errors) throws Exception {
		Map<String,Object> referenceData = new HashMap<String,Object>();

		//  Yes/No list
		Map<Boolean, String> yesNo = new LinkedHashMap<Boolean, String>();
		yesNo.put(false, "No");
		yesNo.put(true, "Yes");
		referenceData.put("yesNo", yesNo);

		return referenceData;
	}

	@Override
	protected Object formBackingObject(HttpServletRequest request) throws Exception {
		BulkUpdateMiceForm form = (BulkUpdateMiceForm)createCommand();

		if(!StringUtils.contains(request.getHeader("referer"), "bulk_update_mice.do")) {
			RequestUtils.setLastReferer(request);
		}

		String sessionId = RequestUtils.getSessionId(request);
		String queryName = ServletRequestUtils.getStringParameter(request, "queryName", MouseService.MOUSE_SEARCH_QUERY);

		Collection<Long> selectedMouseIds = mouseService.fetchLastSelectionIds(sessionId, queryName);
		form.getMouseIds().addAll(selectedMouseIds);

		return form;
	}

}
