/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.controllers;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang.StringUtils;
import org.springframework.validation.BindException;
import org.springframework.web.bind.ServletRequestUtils;

import uk.ac.sanger.mig.common.AbstractCancellableFormController;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.mousetracking.Cage;
import uk.ac.sanger.mig.mousetracking.Cohort;
import uk.ac.sanger.mig.mousetracking.Mouse;
import uk.ac.sanger.mig.mousetracking.forms.CohortForm;
import uk.ac.sanger.mig.mousetracking.services.CageService;
import uk.ac.sanger.mig.mousetracking.services.CohortService;

public abstract class CohortProcedureFormController extends	AbstractCancellableFormController {

	private CohortService cohortService;
	private CageService cageService;

	public void setCohortService(CohortService cohortService) {
		this.cohortService = cohortService;
	}

	public void setCageService(CageService cageService) {
		this.cageService = cageService;
	}

	@Override
	protected boolean isFormChangeRequest(HttpServletRequest request) {
		String changeRequest = ServletRequestUtils.getStringParameter(request, "changeForm", "");

		return (StringUtils.isNotEmpty(changeRequest));
	}

	protected abstract void customiseFormBackingObject(HttpServletRequest request, Object command) throws Exception;

	@Override
	protected final Object formBackingObject(HttpServletRequest request) throws Exception {
		RequestUtils.setLastReferer(request);
		CohortForm form = (CohortForm)createCommand();
		form.setCage(new Cage());
		form.setCohort(new Cohort());
		customiseFormBackingObject(request, form);
		return form;
	}

	@Override
	protected final void onFormChange(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		CohortForm form = (CohortForm)command;
		String changeRequest = ServletRequestUtils.getRequiredStringParameter(request, "changeForm");
		String changeRequestValue = ServletRequestUtils.getRequiredStringParameter(request, "changeFormValue");

		if((changeRequest.indexOf("fetch") != -1) && changeRequestValue != null && changeRequestValue.length() > 0) {

			if(changeRequest.equals("fetchCOHORT")) {
				ComponentMap cohortComponents = new ComponentMap(Cohort.Component.MICE, ComponentMap.of(Mouse.Component.CURRENT_WEIGHT, Mouse.Component.LOCATION));

				Cohort cohort = null;
				cohort = cohortService.fetchById(new Long(changeRequestValue), cohortComponents);
				form.setCohort(cohort);
			}
			else if(changeRequest.equals("fetchCAGE")) {
				ComponentMap cageComponents = new ComponentMap(Cage.Component.CONTENTS, ComponentMap.of(Mouse.Component.CURRENT_WEIGHT, Mouse.Component.LOCATION));

				Cage cage = null;
				cage = cageService.fetchById(new Long(changeRequestValue), cageComponents);
				if(cage != null) {
					form.setCage(cage);
				}
			}

			changeForm(request, response, form, errors);

		}
	}

	protected abstract void changeForm(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors);
}
