package uk.ac.sanger.mig.mousetracking.controllers;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.bind.ServletRequestBindingException;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.alleles.Allele;
import uk.ac.sanger.mig.common.AbstractCancellableFormController;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.common.services.ComponentMapService;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.gene.MigGene;
import uk.ac.sanger.mig.mousetracking.Cohort;
import uk.ac.sanger.mig.mousetracking.CohortSet;
import uk.ac.sanger.mig.mousetracking.CohortSetElement;
import uk.ac.sanger.mig.mousetracking.CohortSetMouseListComparator;
import uk.ac.sanger.mig.mousetracking.CohortSetWTDictionary;
import uk.ac.sanger.mig.mousetracking.GenotypeDictionary;
import uk.ac.sanger.mig.mousetracking.MouseSearchBean;
import uk.ac.sanger.mig.mousetracking.forms.EditCohortSetForm;
import uk.ac.sanger.mig.mousetracking.services.CohortService;
import uk.ac.sanger.mig.mousetracking.services.CohortSetElementService;
import uk.ac.sanger.mig.mousetracking.services.CohortSetService;
import uk.ac.sanger.mig.mousetracking.services.MouseService;
import uk.ac.sanger.mig.mousetracking.views.CohortListView;
import uk.ac.sanger.mig.mousetracking.views.CohortSetElementListView;
import uk.ac.sanger.mig.mousetracking.views.MouseListView;

public class EditCohortSetFormController extends AbstractCancellableFormController {

	private DictionaryService dictionaryService;
	private CohortSetService cohortSetService;
	private CohortService cohortService;
	private ComponentMapService componentMapService;
	private CohortSetElementService cohortSetElementService;
	private MouseService mouseService;

	@Override
	protected Object formBackingObject(HttpServletRequest request) throws Exception {

		EditCohortSetForm form = (EditCohortSetForm)createCommand();
		Long cohortSetId = ServletRequestUtils.getLongParameter(request, "id");
		CohortSet cohortSet = null;

		if(cohortSetId != null){
			ComponentMap cohortSetComponents = componentMapService.getComponentMap("editCohortSet");
			cohortSet = cohortSetService.fetchById(cohortSetId,cohortSetComponents);
			if(cohortSet != null && cohortSet.getAllele()!= null){
				form.setCohortSet(cohortSet);
				form.setAllele(cohortSet.getAllele());
			}else{
				throw new RuntimeException("Cohort Set Id or Allele Id is not valid !");
			}
			form.setPipelineCohortsElements(cohortSetService.getPipelineCohortsHash(cohortSetId));
			form.setMiceList(cohortSetService.getMiceListView(form.getCohortSet().getCohortSetElements(),request.getSession().getId()));

		}else{
			form.setMiceList(new HashMap<String,Collection<MouseListView>>());
			form.setCohortSet(new CohortSet());
			form.getCohortSet().setCohortSetTypeDictId(CohortSetService.COHORT_SET_TYPE_INTERNAL_DICT_ID);
		}
		initializeForm(form);
		return form;
	}

	@Override
	protected Map referenceData(HttpServletRequest httpServletRequest, Object command, Errors errors) throws Exception {

		Collection<DictionaryEntry> cohrotSetTypes =
			dictionaryService.fetch(DictionaryEnum.MOUSE_COHORT_SET_TYPE_DICT, true);
		Collection<DictionaryEntry> pipelineDicts =
			dictionaryService.fetch(DictionaryEnum.MOUSE_COHORT_PIPELINE, true);
		Collection<DictionaryEntry> wtOnlys =
			dictionaryService.fetch(DictionaryEnum.MOUSE_COHORT_SET_WT_DICT,true);

		HashMap<String, Long> pipelineTypes = new HashMap<String, Long>();
		for(DictionaryEntry pipeline: pipelineDicts){
			pipelineTypes.put(pipeline.getName(), pipeline.getId());
		}

		Map<String,Object> metaData = new HashMap<String,Object>();
		metaData.put("cohrotSetTypes", cohrotSetTypes);//for QC drop down list
		metaData.put("pipelineDicts", pipelineDicts);//for sorted pipeline entry
		metaData.put("cohrotPipelines", pipelineTypes);//fetch the pipelineID
		metaData.put("wtOnlys",wtOnlys);

		return metaData;
	}

	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response,
			Object command, BindException errors) throws Exception {

		EditCohortSetForm  form = (EditCohortSetForm) command;
		CohortSet cohortSet = form.getCohortSet();
		Collection<CohortSetElementListView> newCohorts = new ArrayList<CohortSetElementListView>();
		for(String key:form.getNewCohortsElements().keySet()){
			newCohorts.addAll(form.getNewCohortsElements().get(key));
		}

		Long cohortSetId = cohortSetService.editCohortSet(cohortSet, form.getAllele(),form.getDeleteCohortElements(),newCohorts, RequestUtils.getUser(request));

		return new ModelAndView(getSuccessView()+"?id="+cohortSetId);
	}

	@Override
	protected boolean isFormChangeRequest(HttpServletRequest request) {

		String changeRequest = null;

		try{
			changeRequest = ServletRequestUtils.getStringParameter(request, "changeForm");
		}
		catch(ServletRequestBindingException e) {

		}
		if(changeRequest != null && changeRequest.length() >0) {
			return true;
		}
		else {
			return false;
		}
	}

	@Override
	protected boolean suppressValidation(HttpServletRequest request,Object object) {
		boolean onFormChange = ServletRequestUtils.getBooleanParameter(request, "changeForm", false);

		if(onFormChange)
			return false;
		return super.suppressValidation(request, object);
	}

	@Override
	protected void onFormChange(HttpServletRequest request, HttpServletResponse response,
			Object command, BindException bindEx) throws Exception {

		EditCohortSetForm form = (EditCohortSetForm)command;

		String changeRequest = ServletRequestUtils.getStringParameter(request, "changeForm");
		Long changeFormValue = ServletRequestUtils.getLongParameter(request, "changeFormValue");
		String pipeline = form.getCurrentPipeline();

		form.getAlleleWarningMessage().put(pipeline, null);
		form.getStrainWarningMessage().put(pipeline, null);

		if(changeRequest.equals("add")){
			addNewCohort(form,pipeline, request.getSession().getId());
		}else if(changeRequest.equals("deleteExistingCohort")){
			deleteCohort(form,changeFormValue, pipeline, request.getSession().getId(),true);
		}else if(changeRequest.equals("deleteNewCohort")){
			deleteCohort(form,changeFormValue,pipeline,request.getSession().getId(),false);
		}
		changeRequest = null;
		changeFormValue = null;
	}

/////////////////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////privates methods///////////////////////////////////////////
/////////////////////////////////////////////////////////////////////////////////////////////
	private void addNewCohort(EditCohortSetForm form, String key, String sessionId) {
		Long cohortId = form.getNewCohort().get(key).getId();
		CohortListView cohortListView = cohortService.fetchListViewById(cohortId);

		if(cohortListView.getCohortStrain() == null){
			// some legacy cohorts contain no mice or mice with no strain. Give warning in this case.
			form.getStrainWarningMessage().put(form.getCurrentPipeline(),"The cohort "+cohortListView.getCohortName()
					+" contains no mice! Please add mice to this cohort if you want to add it to this cohort set!");
		}else{
			CohortSetElementListView newCohort = deleteCohort(form, cohortId, key, sessionId, null);
			if(newCohort == null){
				newCohort =  new CohortSetElementListView();
				newCohort.setCohortId(cohortId);
				newCohort.setReason(cohortListView.getReason());
				newCohort.setCohortAlleleId(cohortListView.getCohortAlleleId());
				newCohort.setCohortStrain(cohortListView.getCohortStrain());
				newCohort.setCohortName(cohortListView.getCohortName());
				newCohort.setPipeline(cohortListView.getPipeline());
				newCohort.setCreatedDate(cohortListView.getCreatedDate());
			}

			if(form.getWtDictId().get(key) != null){
				newCohort.setWtOnlyDictId(form.getWtDictId().get(key));
				newCohort.setWtOnlyName(
						dictionaryService.fetchEntry(DictionaryEnum.MOUSE_COHORT_SET_WT_DICT, form.getWtDictId().get(key)).getName());
			}
			//give warning if the new cohort has the mutant mice from another allele. Use the WT mice only
			if(newCohort.getCohortAlleleId() != null
					&& ! newCohort.getCohortAlleleId().contains(form.getAllele().getId().toString())
					&&  newCohort.getWtOnlyDictId() == null){
				newCohort.setWtOnlyDictId(CohortSetWTDictionary.WILDTYPE_BOTH_GENDER);
				newCohort.setWtOnlyName(
						dictionaryService.fetchEntry(DictionaryEnum.MOUSE_COHORT_SET_WT_DICT, CohortSetWTDictionary.WILDTYPE_BOTH_GENDER).getName());
				form.getAlleleWarningMessage().put(key, "The cohort "+newCohort.getCohortName()+" contains the mutants from different allele! Only the WT mice(if there are any) in this cohort will be used. ");
			}
			//give warning if the cohort strain is different from the existing ones.
			Collection<CohortSetElementListView> cohorts = new ArrayList<CohortSetElementListView>(form.getNewCohortsElements().get(key));
			cohorts.addAll(form.getPipelineCohortsElements().get(key));
			strainNeedWarn(newCohort,cohorts,form);

			//Only add the cohort if the
			if(getSearchBeanMice(cohortId,sessionId,newCohort).size()>0){
				form.getMiceList().get(key).addAll(getSearchBeanMice(cohortId,sessionId,newCohort));
				form.getNewCohortsElements().get(key).add(newCohort);

			}else{
				form.getStrainWarningMessage().put(key," There are no mice of the required type in this cohort!");
			}
			Collections.sort((List<MouseListView>) form.getMiceList().get(key),new CohortSetMouseListComparator());

		}
		form.getNewCohort().put(key, new Cohort());
		form.getWtDictId().put(key,null);

	}

	private void strainNeedWarn(CohortSetElementListView newCohort, Collection<CohortSetElementListView> cohortSetElements,EditCohortSetForm form) {
		// if the cohort is the first cohort to be added, then no need to check the strain
		if(cohortSetElements.size()>0){
			Set<String> strains = new HashSet<String>();
			for(CohortSetElementListView cohort: cohortSetElements){
				String[] temp = cohort.getCohortStrain().split(",");
				for(int i = 0;i< temp.length;i++){
					strains.add(temp[i]);
				}
			}
			String[] newCohortStrain = newCohort.getCohortStrain().split(",");
			for(int i=0;i<newCohortStrain.length;i++){
				// if we cant find the new cohort strain in the exsiting cohorts strains, then we need warn the users!
				if(!strains.contains(newCohortStrain[i])){
					form.getStrainWarningMessage().put(form.getCurrentPipeline(), "The cohort "+newCohort.getCohortName()
							+" contains mice from different genetic background!");
				}
			}
		}
	}

	private CohortSetElementListView deleteCohort(EditCohortSetForm form,Long cohortId, String key, String sessionId,Boolean exists) {

		CohortSetElementListView editElement = null;
		if(exists == null || exists.booleanValue() == true){
			CohortSetElement cohortElement =
				cohortSetElementService.fetchByCohortAndSetId(cohortId, form.getCohortSet().getId());
			for(CohortSetElementListView listElement : form.getPipelineCohortsElements().get(key)){
				if(listElement.getCohortId().equals(cohortId)){
					form.getDeleteCohortElements().add(cohortElement);
					form.getPipelineCohortsElements().get(key).remove(listElement);
					form.getMiceList().get(key).removeAll(getSearchBeanMice(cohortId,sessionId,listElement));
					editElement = listElement;
					break;
				}
			}
		}

		if(exists == null || exists.booleanValue() == false){
			for(CohortSetElementListView newElement: form.getNewCohortsElements().get(key)){
				if(newElement.getCohortId().equals(cohortId)){
					form.getNewCohortsElements().get(key).remove(newElement);
					form.getMiceList().get(key).removeAll(getSearchBeanMice(cohortId,sessionId,newElement));
					editElement = newElement;
					break;
				}
			}
		}
		return editElement;
	}

	private Collection<MouseListView> getSearchBeanMice(Long cohortId, String sessionId, CohortSetElementListView newCohort){
		MouseSearchBean bean = new MouseSearchBean();
		bean.setCohortId(cohortId);
		bean.setSessionId(sessionId);
		bean.setQueryName("cohortSetMiceList");
		bean.setPaginated(false);
		if(newCohort.getWtOnlyDictId()!= null){
			bean.setGenotypeDictId(GenotypeDictionary.WILDTYPE);
			if(newCohort.getWtOnlyDictId().equals(CohortSetWTDictionary.MALE_ONLY)){
				bean.setGenderDictId(MouseService.MOUSE_GENDER_MALE);
			}else if(newCohort.getWtOnlyDictId().equals(CohortSetWTDictionary.FEMALE_ONLY)){
				bean.setGenderDictId(MouseService.MOUSE_GENDER_FEMALE);
			}
		}
		return mouseService.search(bean);
	}

	private void initializeForm(EditCohortSetForm form) {

		HashMap<String,Collection<CohortSetElementListView>> newCohorts =  new HashMap<String,Collection<CohortSetElementListView>>();
		HashMap<String,Collection<CohortSetElementListView>> pipelineHash =  new HashMap<String,Collection<CohortSetElementListView>>();
		HashMap<String, Cohort> newCohort = new HashMap<String, Cohort>();
		HashMap<String, String> stringMap1 = new HashMap<String, String>();
		HashMap<String, String> stringMap2 = new HashMap<String, String>();
		HashMap<String, Long> wtOnly = new HashMap<String, Long>();
		HashMap<String, Collection<MouseListView>> miceHash = form.getMiceList();

		Collection<DictionaryEntry> pipelines =
			dictionaryService.fetch(DictionaryEnum.MOUSE_COHORT_PIPELINE);

		for(DictionaryEntry pipeline : pipelines){
			newCohorts.put(pipeline.getName(),new ArrayList<CohortSetElementListView>());
			pipelineHash.put(pipeline.getName(),new ArrayList<CohortSetElementListView>());
			newCohort.put(pipeline.getName(), new Cohort());
			wtOnly.put(pipeline.getName(), null);
			if(miceHash.get(pipeline.getName())==null){
				miceHash.put(pipeline.getName(), new ArrayList<MouseListView>());
			}
			stringMap1.put(pipeline.getName(), null);
			stringMap2.put(pipeline.getName(), null);
		}
		if(form.getAllele()==null){
			Allele allele = new Allele();
			allele.setMigGene(new MigGene());
			form.setAllele(allele);
		}
		if(form.getPipelineCohortsElements()==null){
			form.setPipelineCohortsElements(pipelineHash);
		}
		form.setNewCohortsElements(newCohorts);
		form.setNewCohort(newCohort);
		form.setWtDictId(wtOnly);
		form.setDeleteCohortElements(new ArrayList<CohortSetElement>());
		form.setMiceList(miceHash);
		form.setAlleleWarningMessage(stringMap1);
		form.setStrainWarningMessage(stringMap2);
	}

/////////////////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////dependencies /////////////////////////////////////////////
/////////////////////////////////////////////////////////////////////////////////////////////

	public void setCohortService(CohortService cohortService) {
		this.cohortService = cohortService;
	}
	public void setCohortSetService(CohortSetService cohortSetService) {
		this.cohortSetService = cohortSetService;
	}
	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}
	public void setComponentMapService(ComponentMapService componentMapService) {
		this.componentMapService = componentMapService;
	}
	public MouseService getMouseService() {
		return mouseService;
	}

	public void setMouseService(MouseService mouseService) {
		this.mouseService = mouseService;
	}

	public void setCohortSetElementService(CohortSetElementService cohortSetElementService) {
		this.cohortSetElementService = cohortSetElementService;
	}

}