/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.controllers;

import java.text.SimpleDateFormat;
import java.util.Date;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.propertyeditors.CustomDateEditor;
import org.springframework.validation.BindException;
import org.springframework.web.bind.ServletRequestDataBinder;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.SimpleFormController;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.database.TableMetadataEnum;
import uk.ac.sanger.mig.mousetracking.EnvironmentReport;
import uk.ac.sanger.mig.mousetracking.forms.EnvironmentReportForm;
import uk.ac.sanger.mig.mousetracking.services.EnvironmentReportService;
import uk.ac.sanger.mig.personnel.Person;

public class EditEnvironmentReportFormController extends SimpleFormController {

	private EnvironmentReportService environmentReportService;

	public void setEnvironmentReportService(EnvironmentReportService environmentReportService) {
		this.environmentReportService = environmentReportService;
	}

	@Override
	protected void initBinder(HttpServletRequest request, ServletRequestDataBinder binder) throws Exception {
		binder.registerCustomEditor(Date.class, new CustomDateEditor(new SimpleDateFormat("dd-MMM-yyyy"), true));
	}



	@Override
	protected Object formBackingObject(HttpServletRequest httpServletRequest) throws Exception {
		EnvironmentReportForm environmentReportForm = (EnvironmentReportForm)createCommand();
		Long id = ServletRequestUtils.getLongParameter(httpServletRequest, "id");

		EnvironmentReport environmentReport = null;

		if(id == null) {
			environmentReport = buildNewEnvironmentReport();
		}
		else {
			environmentReport = environmentReportService.fetchById(id,ComponentMap.of(EnvironmentReport.Component.ALL_COMPONENTS));
			String reportType = null;
			TableMetadataEnum foreignTableName = environmentReport.getForeignTableName();

			if(TableMetadataEnum.MTS_ROOM == foreignTableName) {
				reportType = "Room";
			}
			else if(TableMetadataEnum.MTS_RACK == foreignTableName){
				reportType = "Rack";
			}
			else if(TableMetadataEnum.MTS_CAGE == foreignTableName){
				reportType = "Cage";
			}
			else if(TableMetadataEnum.MTS_AIR_HANDLING_UNIT == foreignTableName){
				reportType = "Air Handling Unit";
			}
			environmentReportForm.setReportType(reportType);
		}

		environmentReportForm.setEnvironmentReport(environmentReport);
		environmentReportForm.setForeignKeyId(environmentReport.getForeignKeyId());

		return environmentReportForm;
	}


	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response,
			Object command, BindException errors) throws Exception {
		EnvironmentReportForm form = (EnvironmentReportForm) command;
		EnvironmentReport environmentReport = form.getEnvironmentReport();

		if(form.getForeignKeyId() != null) {
			environmentReport.setForeignKeyId(form.getForeignKeyId());
		}

		String tableMetaName = form.getReportType();
		if(tableMetaName.equals("room")) {
			environmentReport.setForeignTableName(TableMetadataEnum.MTS_ROOM);
		}
		else if(tableMetaName.equals("rack")){
			environmentReport.setForeignTableName(TableMetadataEnum.MTS_RACK);
		}
		else if(tableMetaName.equals("cage")) {
			environmentReport.setForeignTableName(TableMetadataEnum.MTS_CAGE);
		}
		else if(tableMetaName.equals("ahu")){
			environmentReport.setForeignTableName(TableMetadataEnum.MTS_AIR_HANDLING_UNIT);
		}

		if(environmentReport.getReportedDate() == null || environmentReport.getReportedDate().equals("")) {
			environmentReport.setReportedDate(new Date());
		}

		Long reportId = environmentReportService.storeAuthenticated(environmentReport, RequestUtils.getUser(request));
		logger.debug("Object " + environmentReport + " successfully stored.");

		return new ModelAndView(getSuccessView(),"id", reportId); // show list view
	}

	private EnvironmentReport buildNewEnvironmentReport() {
		EnvironmentReport environmentReport = new EnvironmentReport();

		environmentReport.setReporter(new Person());

		return environmentReport;
	}
}