/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.controllers;

import java.util.Collection;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.AbstractCancellableFormController;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.common.services.ComponentMapService;
import uk.ac.sanger.mig.mousetracking.Mouse;
import uk.ac.sanger.mig.mousetracking.MouseHealth;
import uk.ac.sanger.mig.mousetracking.forms.MouseHealthForm;
import uk.ac.sanger.mig.mousetracking.services.MouseHealthService;
import uk.ac.sanger.mig.mousetracking.services.MouseService;
import uk.ac.sanger.mig.personnel.Person;

public class EditMouseHealthFormController extends AbstractCancellableFormController {

	private ComponentMapService componentMapService;
	private MouseHealthService mouseHealthService;
	private MouseService mouseService;

	public void setMouseService(MouseService mouseService) {
		this.mouseService = mouseService;
	}

	public void setMouseHealthService(MouseHealthService mouseHealthService) {
		this.mouseHealthService = mouseHealthService;
	}

	public void setComponentMapService(ComponentMapService componentMapService) {
		this.componentMapService = componentMapService;
	}

	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		MouseHealthForm form = (MouseHealthForm)command;

		Person user = RequestUtils.getUser(request);

		MouseHealth mouseHealth = form.getMouseHealth();

		mouseHealth.setMouseId(mouseHealth.getMouseId());

		// If released, set the end date for the health concern.
		if(mouseHealth.getStatus().equals("Released")) {
			mouseHealth.setEndDate(new Date());
		}

		mouseHealthService.store(mouseHealth,user);

		if(form.isCullMouse()) {
			Mouse mouse = mouseService.fetchById(mouseHealth.getMouseId(), null);

			// set mouse to deceased.
			mouse.setCauseOfDeathDictId(MouseService.CAUSE_OF_DEATH_CULLED_SICK);
			mouse.setDeathDate(new Date());
			mouseService.store(mouse, user);
		}

		return new ModelAndView(getSuccessView(),"id",mouseHealth.getId());

	}

	@Override
	protected Object formBackingObject(HttpServletRequest request) throws Exception {
		MouseHealthForm form = (MouseHealthForm)createCommand();

		Long id = ServletRequestUtils.getLongParameter(request, "id");
		Long mouseId = ServletRequestUtils.getLongParameter(request, "mouseId");

		MouseHealth mouseHealth = null;

		if(id == null) {
			mouseHealth = new MouseHealth();
			mouseHealth.setMouseId(mouseId);
		}
		else {
			mouseHealth = mouseHealthService.fetchById(id, ComponentMap.of(MouseHealth.Component.ALL_COMPONENTS));
		}

		mouseHealth.setMouse(fetchMouse(mouseHealth.getMouseId()));
		form.setMouseHealth(mouseHealth);
		mouseHealthService.inflateMouseHealthComponents(mouseHealth);

		return form;
	}

	private Mouse fetchMouse(Long mouseId) {
		ComponentMap mouseComponents = componentMapService.getComponentMap("mouseForHealthConcern");
		return mouseService.fetchById(mouseId, mouseComponents);
	}

	@Override
	protected Map referenceData(HttpServletRequest request, Object command, Errors errors) throws Exception {
		MouseHealthForm form = (MouseHealthForm)command;
		Map<String,Object> referenceData = new HashMap<String,Object>();

		// Previous health concerns.
		Collection<MouseHealth> mouseHealthList = mouseHealthService.fetchByMouseId(form.getMouseHealth().getMouseId(), null);
		referenceData.put("concerns", mouseHealthList);

		// Status
		String[] status  = new String[3];
		status[0] = "Released";
		status[1] = "Green";
		status[2] = "Red";
		referenceData.put("concernStatus",status);

		return referenceData;
	}
}
