/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.controllers;

import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.propertyeditors.CustomNumberEditor;
import org.springframework.validation.BindException;
import org.springframework.web.bind.ServletRequestDataBinder;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.CancellableFormController;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.mousetracking.Rack;
import uk.ac.sanger.mig.mousetracking.forms.RackForm;
import uk.ac.sanger.mig.mousetracking.services.RackService;
import uk.ac.sanger.mig.mousetracking.services.RoomService;
import uk.ac.sanger.mig.personnel.Person;

public class EditRackFormController extends CancellableFormController {
	
	private RackService rackService;
	private RoomService roomService;

	public void setRoomService(RoomService roomService) {
		this.roomService = roomService;
	}

	public void setRackService(RackService rackService) {
		this.rackService = rackService;
	}

	@Override
	protected void initBinder(HttpServletRequest httpServletRequest, ServletRequestDataBinder binder) {	
	
		// Create and register Long binder for Long values which also allows null values
		CustomNumberEditor customLongEditor = new CustomNumberEditor(Long.class, true);
		binder.registerCustomEditor(Long.class, customLongEditor);
		
	
	}
		
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		RackForm form = (RackForm)command;
		
		Rack rack = form.getRack();
		rack.setRoomId(form.getRoomId());
		rack.setAirHandlingUnitId(form.getAirHandlingUnitId());
		rack.setStatus("In Use");
		Person user = RequestUtils.getUser(request);
		Long rackId = rackService.store(rack, user);		
		
		Map<String, Object> model = new HashMap<String, Object>();
		model.put("id", form.getRoomId());
		model.put("currentRecordId", rackId);		
		
		return new ModelAndView(getSuccessView(), model);
	
	}
	
	@Override
	protected Object formBackingObject(HttpServletRequest request) throws Exception {
		RackForm rackForm = (RackForm)createCommand();	
		
		Long id = ServletRequestUtils.getLongParameter(request, "id");	
		Long roomId = ServletRequestUtils.getLongParameter(request, "roomId");
		
		Rack rack = null; 
				
		if(id != null) {
			ComponentMap components = new ComponentMap();
			components.put(Rack.Component.ROOM, null);
			components.put(Rack.Component.AIR_HANDLING_UNIT,null);
			rack = rackService.fetchById(id, components);

		}else if(roomId != null){
			rack = new Rack();
			rack.setRoom(roomService.fetchById(roomId, null));
			rack.setRoomId(roomId);
		}
		
		if(rack == null) {	
			rack = new Rack();
		}
		
		rack.inflate();
		
		rackForm.setRack(rack);	
		return rackForm;
	}

	

}