package uk.ac.sanger.mig.mousetracking.controllers;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.propertyeditors.CustomDateEditor;
import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.bind.ServletRequestDataBinder;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.AbstractCancellableFormController;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.mousetracking.Cage;
import uk.ac.sanger.mig.mousetracking.StudBreeding;
import uk.ac.sanger.mig.mousetracking.forms.BarcodeForm;
import uk.ac.sanger.mig.mousetracking.forms.StudBreedingForm;
import uk.ac.sanger.mig.mousetracking.forms.StudBreedingForm.FemaleOption;
import uk.ac.sanger.mig.mousetracking.forms.StudBreedingForm.MaleOption;
import uk.ac.sanger.mig.mousetracking.services.StudBreedingService;
import uk.ac.sanger.mig.personnel.Person;

public class EditStudBreedingFormController extends AbstractCancellableFormController {

	private StudBreedingService studBreedingService;

	public void setStudBreedingService(StudBreedingService studBreedingService) {
		this.studBreedingService = studBreedingService;
	}

	@Override
	protected void initBinder(HttpServletRequest request, ServletRequestDataBinder binder) throws Exception {
		super.initBinder(request, binder);
		binder.registerCustomEditor(Date.class, new CustomDateEditor(new SimpleDateFormat("dd-MMM-yyyy HH:mm"), true));
	}

	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		StudBreedingForm form = (StudBreedingForm)command;
		Person user = RequestUtils.getUser(request);

		Long breedingId = studBreedingService.editBreeding(form, user);

		return new ModelAndView(getSuccessView(), "id", breedingId);
	}

	@Override
	protected Object formBackingObject(HttpServletRequest request) throws Exception {
		StudBreedingForm form = (StudBreedingForm)createCommand();
		Long id = ServletRequestUtils.getRequiredLongParameter(request, "id");
		StudBreeding breeding = studBreedingService.fetchById(id, ComponentMap.of(StudBreeding.Component.FEMALE, StudBreeding.Component.MALE));
		form.setBreeding(breeding);
		form.setFemaleLocation(new BarcodeForm());

		return form;
	}

	@Override
	protected Map referenceData(HttpServletRequest request, Object command, Errors errors) throws Exception {
		StudBreedingForm form = (StudBreedingForm)command;
		Map<String, Object> referenceData = new HashMap<String, Object>();
		Cage cage = studBreedingService.fetchForCageView(form.getBreeding().getId());
		referenceData.put("cage", cage);

		FemaleOption[] femaleOptions = StudBreedingForm.FemaleOption.values();
		referenceData.put("femaleOptions", femaleOptions);

		MaleOption[] maleOptions = StudBreedingForm.MaleOption.values();
		referenceData.put("maleOptions", maleOptions);

		referenceData.put("embryoAgeOptions", new Float[]{2.5f,3.5f,17.5f});

		return referenceData;
	}

}
