package uk.ac.sanger.mig.mousetracking.controllers;

import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.AbstractCancellableFormController;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.mousetracking.Cage;
import uk.ac.sanger.mig.mousetracking.EditStudBreedingsForm;
import uk.ac.sanger.mig.mousetracking.StudBreeding;
import uk.ac.sanger.mig.mousetracking.StudBreedingSearchBean;
import uk.ac.sanger.mig.mousetracking.services.CageService;
import uk.ac.sanger.mig.mousetracking.services.StudBreedingService;
import uk.ac.sanger.mig.personnel.Person;

public class EditStudBreedingsFormController extends AbstractCancellableFormController {

	private CageService cageService;
	private StudBreedingService studBreedingService;
	private DictionaryService dictionaryService;

	public void setCageService(CageService cageService) {
		this.cageService = cageService;
	}

	public void setStudBreedingService(StudBreedingService studBreedingService) {
		this.studBreedingService = studBreedingService;
	}

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		EditStudBreedingsForm form = (EditStudBreedingsForm)command;
		Person user = RequestUtils.getUser(request);

		Collection<StudBreeding> studBreedings = processForm(form);

		studBreedingService.storeCollection(studBreedings, user);

		String cageIdString = "";
		for(Cage cage : form.getCages()) {
			cageIdString += cage.getId() + ",";
		}

		return new ModelAndView(getSuccessView(), "cageIds", cageIdString);
	}

	private Collection<StudBreeding> processForm(EditStudBreedingsForm form) {
		Collection<StudBreeding> studBreedings = new ArrayList<StudBreeding>();
		StudBreedingSearchBean searchBean = new StudBreedingSearchBean();

		for(Cage cage : form.getCages()) {
			searchBean.setCageId(cage.getId());
			studBreedings.addAll(studBreedingService.fetch(searchBean, null));
		}

		for(StudBreeding breeding : studBreedings) {
			if(form.getDefaultValues().getTimedEmbryoAge() != null) {
				breeding.setTimedEmbryoAge(form.getDefaultValues().getTimedEmbryoAge());
			}
		}

		return studBreedings;
	}

	@Override
	protected Map referenceData(HttpServletRequest request, Object command, Errors errors) throws Exception {
		Map<String, Object> referenceData = new HashMap<String, Object>();

		Collection<DictionaryEntry> embryoAgeOptions = dictionaryService.fetch(DictionaryEnum.MOUSE_STUD_BREEDING_EMBRYO_AGE);
		referenceData.put("embryoAgeOptions", embryoAgeOptions);

		return referenceData;
	}

	@Override
	protected Object formBackingObject(HttpServletRequest request) throws Exception {
		EditStudBreedingsForm form = (EditStudBreedingsForm)createCommand();
		form.setDefaultValues(new StudBreeding());
		Collection<Cage> cages = new ArrayList<Cage>();
		ComponentMap requiredComponents = null;

		Long cageId = ServletRequestUtils.getLongParameter(request, "cageId");

		if(cageId != null) {
			cages.add(cageService.fetchById(cageId, requiredComponents));
		}
		else {
			String sessionId = RequestUtils.getSessionId(request);
			String queryName = ServletRequestUtils.getStringParameter(request, "queryName");
			cages = cageService.fetchLastSelection(sessionId, queryName, requiredComponents);
		}
		form.setCages(cages);

		return form;
	}
}
