/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.controllers;
import java.util.Collection;
import java.util.HashMap;
import java.util.Map;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.servlet.ModelAndView;


import uk.ac.sanger.mig.common.AbstractSearchFormController;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.mousetracking.CohortSetListViewSearchBean;
import uk.ac.sanger.mig.mousetracking.services.CohortSetService;
import uk.ac.sanger.mig.mousetracking.views.CohortSetListView;


public class SearchCohortSetController extends AbstractSearchFormController {

	private CohortSetService cohortSetService;
	private DictionaryService dictionaryService;


	public void setCohortSetService(CohortSetService cohortSetService) {
		this.cohortSetService = cohortSetService;
	}


	@Override
	protected ModelAndView onSearch(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		CohortSetListViewSearchBean searchBean = (CohortSetListViewSearchBean)command;
		searchBean.setQueryName("searchCohortSet");
		Map<String, Object> model = new HashMap<String, Object>();
		Collection<CohortSetListView> cohortSetListView = cohortSetService.search(searchBean);
		model.put("cohortSets", cohortSetListView);

		return showForm(request, errors, getSuccessView(), model);
	}

	@Override
	protected Map referenceData(HttpServletRequest request, Object command, Errors error) throws Exception {
		Map<String, Object> referenceData = new HashMap<String, Object>();

		Collection<DictionaryEntry> pipelines = dictionaryService.fetch(DictionaryEnum.MOUSE_COHORT_PIPELINE);

		referenceData.put("pipelines", pipelines);

		return referenceData;
	}


	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}
}
