/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.controllers;

import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.AbstractSearchFormController;
import uk.ac.sanger.mig.mousetracking.LitterSearchBean;
import uk.ac.sanger.mig.mousetracking.Room;
import uk.ac.sanger.mig.mousetracking.services.LitterService;
import uk.ac.sanger.mig.mousetracking.services.RoomService;
import uk.ac.sanger.mig.mousetracking.views.LitterListView;

public class SearchLitterController extends AbstractSearchFormController {

	private LitterService litterService;
	private RoomService roomService;

	public void setLitterService(LitterService litterService) {
		this.litterService = litterService;
	}
	public void setRoomService(RoomService roomService) {
		this.roomService = roomService;
	}

	@Override
	protected ModelAndView onSearch(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		LitterSearchBean searchBean = (LitterSearchBean)command;
		searchBean.setQueryName("searchLitter");
		Map<String, Object> model = new HashMap<String, Object>();
		Collection<LitterListView> litterViews = litterService.search(searchBean);

		if(litterViews.size() == 1) {
			LitterListView litter = litterViews.iterator().next();
			return new ModelAndView("redirect:view_one_litter.do?id=" + litter.getId());
		}

		model.put("litterViews", litterViews);
		return new ModelAndView(getSuccessView(), model);
	}

	@Override
	protected Map referenceData(HttpServletRequest request, Object command, Errors errors) throws Exception {
		Map<String, Object> referenceData = new HashMap<String, Object>();
		Collection<Room> rooms = roomService.fetchCurrent(null);
		referenceData.put("rooms",rooms);

		Collection<String> statuses = new ArrayList<String>();
		statuses.add(LitterService.LITTER_STATUS_UNBORN);
		statuses.add(LitterService.LITTER_STATUS_HARVESTED);
		statuses.add(LitterService.LITTER_STATUS_PREWEAN);
		statuses.add(LitterService.LITTER_STATUS_WEANED);
		statuses.add(LitterService.LITTER_STATUS_NOT_PREGNANT);
		referenceData.put("statuses",statuses);

		return referenceData;
	}
}
