/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.controllers;

import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

import javax.servlet.http.HttpServletRequest;

import org.springframework.validation.Errors;

import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.mousetracking.MouseSearchBean;

public class SearchMouseController extends SimpleSearchMouseController {

	private DictionaryService dictionaryService;

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	@Override
	protected Map referenceData(HttpServletRequest request, Object command, Errors errors) throws Exception {
		Map<String, Object> referenceData = new HashMap<String, Object>();

		referenceData.put("causeOfDeath", dictionaryService.fetch(DictionaryEnum.MOUSE_CAUSE_OF_DEATH));
		referenceData.put("coatColour", dictionaryService.fetch(DictionaryEnum.MOUSE_COAT_COLOUR));
		referenceData.put("earmark", dictionaryService.fetch(DictionaryEnum.MOUSE_EARMARK_DICT));
		referenceData.put("eyeColour", dictionaryService.fetch(DictionaryEnum.MOUSE_EYE_COLOUR_DICT));
		referenceData.put("gender", dictionaryService.fetch(DictionaryEnum.MOUSE_GENDER_DICT));
		referenceData.put("genotype", dictionaryService.fetch(DictionaryEnum.MOUSE_GENOTYPE));
		referenceData.put("reservationCategory",dictionaryService.fetch(DictionaryEnum.RESERVATION_CATEGORY));

		//Yes/No list
		Map<Boolean, String> yesNo = new HashMap<Boolean, String>();
		yesNo.put(false,"No");
		yesNo.put(true,"Yes");
		referenceData.put("yesNo",yesNo);

		//Genotype status
		Set<String> genotypeStatus = new HashSet<String>();
		genotypeStatus.add("Confirmed");
		genotypeStatus.add("Uncertain");
		referenceData.put("genotypeStatus",genotypeStatus);

		// Mouse status
		String[] statuses  = new String[2];
		statuses[0] = "Alive";
		statuses[1] = "Deceased";
		referenceData.put("statuses", statuses);

		// Mouse reservation options
		String[] reservationOptions = new String[4];
		reservationOptions[0] = "Not Reserved";
		reservationOptions[1] = "Mating";
		reservationOptions[2] = "Procedure";
		reservationOptions[3] = "Anything";
		referenceData.put("reservationOptions", reservationOptions);

		referenceData.put("histologyProgressOptions",
				MouseSearchBean.HistologyWorkProgress.values() );

		return referenceData;
	}
}
