package uk.ac.sanger.mig.mousetracking.controllers;

import java.text.SimpleDateFormat;
import java.util.Collection;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.propertyeditors.CustomDateEditor;
import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.bind.ServletRequestDataBinder;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.common.controllers.AbstractFormChangeController;
import uk.ac.sanger.mig.common.services.ComponentMapService;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.mousetracking.StudBreeding;
import uk.ac.sanger.mig.mousetracking.StudBreedingSearchBean;
import uk.ac.sanger.mig.mousetracking.forms.BarcodeForm;
import uk.ac.sanger.mig.mousetracking.forms.SeparateStudBreedingsForm;
import uk.ac.sanger.mig.mousetracking.forms.SeparateStudBreedingsForm.PlugStates;
import uk.ac.sanger.mig.mousetracking.services.StudBreedingService;
import uk.ac.sanger.mig.personnel.Person;

public class SeparateStudBreedingsFormController extends AbstractFormChangeController {

	private ComponentMapService componentMapService;
	private StudBreedingService studBreedingService;
	private DictionaryService dictionaryService;

	public void setStudBreedingService(StudBreedingService studBreedingService) {
		this.studBreedingService = studBreedingService;
	}

	public void setComponentMapService(ComponentMapService componentMapService) {
		this.componentMapService = componentMapService;
	}

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	@Override
	protected void initBinder(HttpServletRequest request, ServletRequestDataBinder binder) throws Exception {
		super.initBinder(request, binder);
		binder.registerCustomEditor(Date.class, new CustomDateEditor(new SimpleDateFormat("dd-MMM-yyyy HH:mm"), true));
	}

	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		SeparateStudBreedingsForm form = (SeparateStudBreedingsForm)command;
		Person user = RequestUtils.getUser(request);

		Map<String, Object> model = studBreedingService.separateBreedings(form, user);

		request.getSession().setAttribute("viewSeparatedStudBreedingsModel", model);

		return new ModelAndView(getSuccessView());
	}

	@Override
	protected void onFormChange(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		SeparateStudBreedingsForm form = (SeparateStudBreedingsForm)command;
		String changeRequest = form.getChangeForm();

		if(changeRequest.equals("addStudCohort")) {
			addStudCohort(form, errors);
		}
		else if(changeRequest.equals("addStudCage")) {
			addStudCage(form, errors);
		}

		// reset form change fields
		form.setChangeForm(null);
		form.setChangeFormValue(null);
	}

	@Override
	protected Object formBackingObject(HttpServletRequest request) throws Exception {
		RequestUtils.setLastReferer(request);
		SeparateStudBreedingsForm form = (SeparateStudBreedingsForm)createCommand();
		return form;
	}

	@Override
	protected Map referenceData(HttpServletRequest request, Object command, Errors errors) throws Exception {
		Map<String, Object> referenceData = new HashMap<String, Object>();

		referenceData.put("plugState_plugged", PlugStates.PLUGGED);
		referenceData.put("plugState_not_plugged", PlugStates.NOT_PLUGGED);
		referenceData.put("plugState_cull", PlugStates.CULL);
		referenceData.put("plugState_ignore", PlugStates.IGNORE);
		referenceData.put("plugState_default", PlugStates.DEFAULT);

		Collection<DictionaryEntry> embryoAgeOptions = dictionaryService.fetch(DictionaryEnum.MOUSE_STUD_BREEDING_EMBRYO_AGE);
		referenceData.put("embryoAgeOptions", embryoAgeOptions);

		return referenceData;
	}

	@Override
	protected ModelAndView handleInvalidSubmit(HttpServletRequest request, HttpServletResponse response) throws Exception {
		return new ModelAndView("errors/handle_invalid_submit");
	}

	private void addStudCage(SeparateStudBreedingsForm form, BindException errors) {
		if(form.getStudCage().getId() != null) {
			StudBreedingSearchBean searchBean = new StudBreedingSearchBean();
			searchBean.setCageId(form.getStudCage().getId());
			boolean breedingsFound = addBreedingsToForm(form, searchBean);
			if(!breedingsFound) {
				errors.reject(null, "No Stud Matings found for cage barcode '" + form.getStudCage().getBarcode() + "'");
			}
			form.setStudCage(new BarcodeForm()); //reset cage barcode field
		}
	}

	private void addStudCohort(SeparateStudBreedingsForm form, BindException errors) {
		if(form.getStudCohortId() != null) {
			StudBreedingSearchBean searchBean = new StudBreedingSearchBean();
			searchBean.setCohortId(form.getStudCohortId());
			boolean breedingsFound = addBreedingsToForm(form, searchBean);
			if(!breedingsFound) {
				errors.reject(null, "No Stud Matings found for cohort '" + form.getStudCohortName() + "'");
			}
		}
	}

	private boolean addBreedingsToForm(SeparateStudBreedingsForm form, StudBreedingSearchBean searchBean) {
		ComponentMap cohortComponents = componentMapService.getComponentMap("viewStudBreeding");
		searchBean.setNullEndDate(true);
		Collection<StudBreeding> breedings = studBreedingService.fetch(searchBean, cohortComponents);

		for(StudBreeding breeding : breedings) {
			if(!form.getStudBreedings().contains(breeding)) {
				form.getStudBreedings().add(breeding);
				form.getStudBreedingPlugs().add(PlugStates.DEFAULT);
			}
		}
		return (breedings.isEmpty()) ? false : true;
	}

}
