/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.controllers;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.AbstractSearchFormController;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.mousetracking.MouseSearchBean;
import uk.ac.sanger.mig.mousetracking.services.MouseService;
import uk.ac.sanger.mig.mousetracking.views.MouseListView;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.personnel.services.PersonColumnPrefService;
import uk.ac.sanger.mig.personnel.views.PersonColumnPrefListView;

public class SimpleSearchMouseController extends AbstractSearchFormController {

	private MouseService mouseService;
	private PersonColumnPrefService personColumnPrefService;

	public void setMouseService(MouseService mouseService) {
		this.mouseService = mouseService;
	}

	public void setPersonColumnPrefService(
			PersonColumnPrefService personColumnPrefService) {
		this.personColumnPrefService = personColumnPrefService;
	}

	@Override
	protected ModelAndView onSearch(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		MouseSearchBean searchBean = (MouseSearchBean)command;
		searchBean.setQueryName(MouseService.MOUSE_SEARCH_QUERY);

		Map<String, Object> model = new HashMap<String, Object>();
		Collection<MouseListView> mice = mouseService.search(searchBean);

		if(mice.size() == 1) {
			MouseListView mouse = mice.iterator().next();
			if(mouse.getCageId() == null) {
				return new ModelAndView("redirect:view_one_mouse.do?id=" + mouse.getId());
			}
			else {
				return new ModelAndView("redirect:view_one_cage.do?id=" + mouse.getCageId());
			}

		}

		model.put("mice", mice);

		Person user = RequestUtils.getUser(request);
		Collection<PersonColumnPrefListView> columnPrefs = personColumnPrefService.fetchCurrent("mts_mouse_list_vw", user.getId());
		model.put("columnPrefs", columnPrefs);

		return new ModelAndView(getSuccessView(), model);
	}

	@Override
	protected Map referenceData(HttpServletRequest request, Object command, Errors errors) throws Exception {
		Map<String, Object> referenceData = new HashMap<String, Object>();

		String[] statuses  = new String[2];
		statuses[0] = "Alive";
		statuses[1] = "Deceased";

		referenceData.put("statuses", statuses);

		return referenceData;
	}
}
