/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.controllers;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.ParameterizableViewController;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.genotyping.services.AssayPlateService;
import uk.ac.sanger.mig.histology.Block;
import uk.ac.sanger.mig.histology.services.BlockService;
import uk.ac.sanger.mig.mousetracking.BarcodedObject;
import uk.ac.sanger.mig.mousetracking.Cage;
import uk.ac.sanger.mig.mousetracking.Mouse;
import uk.ac.sanger.mig.mousetracking.Rack;
import uk.ac.sanger.mig.mousetracking.services.CageService;
import uk.ac.sanger.mig.mousetracking.services.CohortService;
import uk.ac.sanger.mig.mousetracking.services.LitterService;
import uk.ac.sanger.mig.mousetracking.services.MouseService;
import uk.ac.sanger.mig.mousetracking.services.RackService;
import uk.ac.sanger.mig.mousetracking.services.RoomService;
import uk.ac.sanger.mig.mousetracking.services.TissueSampleService;
import uk.ac.sanger.mig.tecniplast.services.AirHandlingUnitService;

public class ValidateBarcodeController extends ParameterizableViewController {

	private CohortService cohortService;
	private CageService cageService;
	private RackService rackService;
	private RoomService roomService;
	private AirHandlingUnitService airHandlingUnitService;
	private MouseService mouseService;
	private TissueSampleService tissueSampleService;
	private LitterService litterService;
	private BlockService blockService;
	private AssayPlateService plateService;

	public void setLitterService(LitterService litterService) {
		this.litterService = litterService;
	}

	public void setTissueSampleService(TissueSampleService tissueSampleService) {
		this.tissueSampleService = tissueSampleService;
	}

	public void setAirHandlingUnitService(
			AirHandlingUnitService airHandlingUnitService) {
		this.airHandlingUnitService = airHandlingUnitService;
	}

	public void setRoomService(RoomService roomService) {
		this.roomService = roomService;
	}

	public void setCageService(CageService cageService) {
		this.cageService = cageService;
	}

	public void setRackService(RackService rackService) {
		this.rackService = rackService;
	}

	public void setMouseService(MouseService mouseService) {
		this.mouseService = mouseService;
	}

	public void setCohortService(CohortService cohortService) {
		this.cohortService = cohortService;
	}

	public void setPlateService(AssayPlateService plateService) {
		this.plateService = plateService;
	}

	@Override
	protected ModelAndView handleRequestInternal(HttpServletRequest request, HttpServletResponse response) throws Exception {
		String barcode = ServletRequestUtils.getRequiredStringParameter(request, "barcode");
		barcode = barcode.trim();
		boolean invalidType = false;

		String type = ServletRequestUtils.getRequiredStringParameter(request, "type");

		Map<String, Object> model = new HashMap<String, Object>();
		BarcodedObject barcodedObject = null;

		// cage (or mouse)
		if(type.equalsIgnoreCase("cage")) {
			barcodedObject = cageService.fetchByBarcode(barcode, ComponentMap.of(Cage.Component.RACK));
			if(barcodedObject == null) {
				Mouse mouse = mouseService.fetchByBarcode(barcode, ComponentMap.of(Mouse.Component.CAGE));
				if(mouse != null && mouse.getCage() != null) {
					barcodedObject = mouse.getCage();
				}
			}
		}
		// rack
		else if(type.equalsIgnoreCase("rack")) {
			barcodedObject = rackService.fetchByBarcode(barcode, ComponentMap.of(Rack.Component.ROOM));
		}
		// mouse (or cage)
		else if(type.equalsIgnoreCase("mouse")) {
			barcodedObject = mouseService.fetchByBarcode(barcode, null);
			if(barcodedObject == null) {
				Cage cage = cageService.fetchByBarcode(barcode, ComponentMap.of(Cage.Component.CONTENTS));
				if(cage != null) {
					if(cage.getContents() != null && cage.getContents().size() == 1) {
						barcodedObject = cage.getContents().iterator().next();
					}
					else {
						barcodedObject = cage;
					}
				}
			}
		}
		// cage or rack (or mouse)
		else if(type.equalsIgnoreCase("cage or rack")) {
			barcodedObject = cageService.fetchByBarcode(barcode, ComponentMap.of(Cage.Component.RACK));
			if(barcodedObject == null) {
				barcodedObject = rackService.fetchByBarcode(barcode, ComponentMap.of(Rack.Component.ROOM));

				if(barcodedObject == null) {
					Mouse mouse = mouseService.fetchByBarcode(barcode, ComponentMap.of(Mouse.Component.CAGE));
					if(mouse != null) {
						if(mouse.getCage() == null) {
							barcodedObject = mouse;
						}
						else {
							barcodedObject = mouse.getCage();
						}
					}
				}
			}
		}
		else if(type.equalsIgnoreCase("cage or mouse")) {
			barcodedObject = cageService.fetchByBarcode(barcode, ComponentMap.of(Cage.Component.RACK));
			if(barcodedObject == null) {
				barcodedObject = mouseService.fetchByBarcode(barcode, ComponentMap.of(Mouse.Component.CAGE));
			}
		}
		else if(type.equalsIgnoreCase("cage or mouse or litter")) {
			barcodedObject = cageService.fetchByBarcode(barcode, ComponentMap.of(Cage.Component.RACK));
			if(barcodedObject == null) {
				barcodedObject = mouseService.fetchByBarcode(barcode, ComponentMap.of(Mouse.Component.CAGE));
			}
			if (barcodedObject == null) {
				barcodedObject = litterService.fetchByName(barcode.toUpperCase(), null);
			}
		}
		else if(type.equalsIgnoreCase("mouse or block")){
			barcodedObject = mouseService.fetchByBarcode(barcode, ComponentMap.of(Mouse.Component.ALL_COMPONENTS));
			if(barcodedObject == null) {
				barcodedObject = blockService.fetchByBarcode(barcode, ComponentMap.of(Block.Component.ALL_COMPONENTS));
			}
		}
		// ahu (air handling unit)
		else if(type.equalsIgnoreCase("ahu")) {
			barcodedObject = airHandlingUnitService.fetchByBarcode(barcode, null);
		}
		// room
		else if(type.equalsIgnoreCase("room")) {
			barcodedObject = roomService.fetchByBarcode(barcode, null);
		}
		// cohort or cage
		else if(type.equalsIgnoreCase("cohort or cage")) {
			barcodedObject = cohortService.fetchByName(barcode, null);
			if(barcodedObject == null) {
				barcodedObject = cageService.fetchByBarcode(barcode, ComponentMap.of(Cage.Component.RACK));
			}
		}
		// tissue sample blood barcode
		else if(type.equalsIgnoreCase("blood")) {
			barcodedObject = tissueSampleService.fetchByBarcode(barcode, null);

		}
		// genotyping sheet or plate.
		else if(type.equalsIgnoreCase("sheet or plate")) {
			barcodedObject = plateService.fetchByBarcode(barcode, null);
		}
		else {
			invalidType = true;
			model.put("errorText", "Invalid barcode type '" + type + "'");
		}

		model.put("object", barcodedObject);

		if(!invalidType) {
			if(barcodedObject == null) {
				model.put("errorText", "No " + type.toLowerCase() + " found corresponding to '" + barcode + "'");
			}
			else {
				model.put("errorText", "OK");
			}
		}

		return new ModelAndView(getViewName(), model);
	}

	public void setBlockService(BlockService blockService) {
		this.blockService = blockService;
	}
}
