/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.controllers;

import java.util.Collection;
import java.util.Date;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.SimpleFormController;

import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.mousetracking.Mouse;
import uk.ac.sanger.mig.mousetracking.MouseSearchBean;
import uk.ac.sanger.mig.mousetracking.forms.CullListForm;
import uk.ac.sanger.mig.mousetracking.services.MouseService;
import uk.ac.sanger.mig.mousetracking.views.MouseListView;
import uk.ac.sanger.mig.personnel.Person;

public class ViewCullMouseController extends SimpleFormController {
	
	
	public MouseService mouseService;
	

	/**
	 * @param mouseService the mouseService to set
	 */
	public void setMouseService(MouseService mouseService) {
		this.mouseService = mouseService;
	}

	
	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		CullListForm form = (CullListForm)command;
		
		Person user = RequestUtils.getUser(request);
				
		for(MouseListView mice : form.getMice()) {
			Mouse mouse = mouseService.fetchById(mice.getId(), null);
			mouse.setDeathDate(new Date());  // Assign a death date.
			mouse.setCageId(null);     // remove mouse from cage.
			mouseService.store(mouse, user);
		}
	
		return new ModelAndView(getSuccessView());
	}


	/* (non-Javadoc)
	 * @see org.springframework.web.servlet.mvc.AbstractFormController#formBackingObject(javax.servlet.http.HttpServletRequest)
	 */
	@Override
	protected Object formBackingObject(HttpServletRequest request) throws Exception {
		CullListForm form = (CullListForm)createCommand();
		
		Long roomId = ServletRequestUtils.getRequiredLongParameter(request, "id");
		String roomNumber = ServletRequestUtils.getRequiredStringParameter(request, "roomNumber");
		
		MouseSearchBean searchBean = new MouseSearchBean();
		searchBean.setSessionId(request.getSession().getId());
		searchBean.setRoomId(roomId);
		searchBean.setNullDeathDate(true);
		searchBean.setCauseOfDeathDictId(-1L);
		searchBean.setQueryName("mouseCullList");
		searchBean.setPaginated(false);
		Collection<MouseListView> miceList = mouseService.search(searchBean);
		
		form.setMice(miceList);
		form.setRoomNumber(roomNumber);
		
		return form;
	}
	
}