/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.controllers;


import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.charting.ChartData;
import uk.ac.sanger.mig.common.AbstractSearchFormController;
import uk.ac.sanger.mig.mousetracking.Room;
import uk.ac.sanger.mig.mousetracking.services.RoomService;
import uk.ac.sanger.mig.tecniplast.AhuMeasurementSearchBean;
import uk.ac.sanger.mig.tecniplast.AirHandlingUnit;
import uk.ac.sanger.mig.tecniplast.services.AhuMeasurementService;
import uk.ac.sanger.mig.tecniplast.services.AirHandlingUnitService;
import uk.ac.sanger.mig.tecniplast.views.AHUChart;

public class ViewOneAirHandlingUnitFormController extends AbstractSearchFormController  {

	private AirHandlingUnitService airHandlingUnitService;
	private AhuMeasurementService ahuMeasurementService;
	private RoomService roomService;


	/**
	 * @param roomService the roomService to set
	 */
	public void setRoomService(RoomService roomService) {
		this.roomService = roomService;
	}

	/**
	 * @param airHandlingUnitService the airHandlingUnitService to set
	 */
	public void setAirHandlingUnitService(
			AirHandlingUnitService airHandlingUnitService) {
		this.airHandlingUnitService = airHandlingUnitService;
	}



	/**
	 * @param ahuMeasurementService the ahuMeasurementService to set
	 */
	public void setAhuMeasurementService(AhuMeasurementService ahuMeasurementService) {
		this.ahuMeasurementService = ahuMeasurementService;
	}

	@Override
	protected ModelAndView onSearch(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		AhuMeasurementSearchBean searchBean = (AhuMeasurementSearchBean)command;
		searchBean.setPaginated(false);

		Long airHandlingUnitId = ServletRequestUtils.getLongParameter(request, "id");	
		AirHandlingUnit airUnit = airHandlingUnitService.fetchById(airHandlingUnitId, null);
		searchBean.setAirHandlingUnitId(airHandlingUnitId);

		Room room = roomService.fetchById(airUnit.getRoomId(), null);

		Map<String, Object> model = new HashMap<String, Object>();		

		searchBean.setQueryName(AhuMeasurementService.AHU_MEASUREMENT_SEARCH_QUERY);

		// check if user has clicked on a point of interest and reset searchBean for that Day.
		String selectedDate = ServletRequestUtils.getStringParameter(request, "selectedDate");
		if(selectedDate != null){
			DateFormat df = new SimpleDateFormat();
			Date d = df.parse(selectedDate);
			searchBean.setMeasurementDateFrom(d);
			searchBean.setMeasurementDateTo(d);
		}

		ChartData data = ahuMeasurementService.fetchChartData(searchBean);

		if(data != null ) {

			AHUChart test = new AHUChart(1000,600, data);
			test.setTitle(new SimpleDateFormat().format(searchBean.getMeasurementDateFrom()),
					new SimpleDateFormat().format(searchBean.getMeasurementDateTo()));

			test.makeSession(request, "xychart");

			// Include tool tip for the chart
			String imageMap1 = test.getHTMLImageMap("view_one_air_unit.do?id="+airHandlingUnitId, "selectedDate={xLabel}",
			"title='{dataSetName} : {value} '");

			model.put("imageMap1", imageMap1);

		}else{
			model.put("errors", "No Data Available.");
		}

		model.put("airUnit", airUnit);
		model.put("room", room);

		return showForm(request, response, errors, model);
	}




	@Override
	protected Map referenceData(HttpServletRequest request, Object command, Errors errors) throws Exception {
		Long id = ServletRequestUtils.getLongParameter(request, "id");		
		Map<String, Object> referenceData = new HashMap<String, Object>();

		AirHandlingUnit unit = airHandlingUnitService.fetchById(id, null);
		Room room = roomService.fetchById(unit.getRoomId(), null);	

		AhuMeasurementSearchBean searchBean = (AhuMeasurementSearchBean)command;
		searchBean.setPaginated(false);
		searchBean.setAirHandlingUnitId(unit.getId());
		searchBean.setQueryName(AhuMeasurementService.AHU_MEASUREMENT_SEARCH_QUERY);
		ChartData data = null;

		// check if user has clicked on a point of interest and reset searchBean for that Day.
		String selectedDate = ServletRequestUtils.getStringParameter(request, "selectedDate");
		if(selectedDate != null){
			DateFormat df = new SimpleDateFormat("MMM dd, yyyy hh:mm:ss");
			Date d = df.parse(selectedDate);
			searchBean.setMeasurementDateFrom(d);
			searchBean.setMeasurementDateTo(d);

			data = ahuMeasurementService.fetchChartData(searchBean);

			if(data != null) {
				AHUChart test = new AHUChart(1000,600, data);
				test.setTitle(new SimpleDateFormat().format(searchBean.getMeasurementDateFrom()),
						new SimpleDateFormat().format(searchBean.getMeasurementDateTo()));


				test.makeSession(request, "xychart");

				// Include tool tip for the chart
				String imageMap1 = test.getHTMLImageMap("", "",
				"title='{dataSetName} : {value} '");

				referenceData.put("imageMap1", imageMap1);
			}else{
				referenceData.put("errors", "No Data Available.");
			}

		}

		referenceData.put("airUnit", unit);
		referenceData.put("room", room);

		return referenceData;
	}

}