/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.controllers;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.ParameterizableViewController;

import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.mousetracking.Breeding;
import uk.ac.sanger.mig.mousetracking.Cage;
import uk.ac.sanger.mig.mousetracking.services.BreedingService;
import uk.ac.sanger.mig.mousetracking.services.CageService;
import uk.ac.sanger.mig.personnel.Person;

public class ViewOneCageController extends ParameterizableViewController {

	private BreedingService breedingService;
	private CageService cageService;

	public void setCageService(CageService cageService) {
		this.cageService = cageService;
	}

	public void setBreedingService(BreedingService breedingService) {
		this.breedingService = breedingService;
	}

	protected BreedingService getBreedingService() {
		return breedingService;
	}

	protected CageService getCageService() {
		return cageService;
	}

	protected final ModelAndView handleRequestInternal(HttpServletRequest request, HttpServletResponse response) throws Exception {
		Long objectId = ServletRequestUtils.getRequiredLongParameter(request, "id");
		Person user = RequestUtils.getUser(request);

		Map<String, Object> model = makeModel(objectId, user);
		Cage cage = (Cage)model.get("cage");

		if(cage.getCurrentBreedings() != null && cage.getCurrentBreedings().size()>0) {
			Breeding breeding = cage.getCurrentBreedings().iterator().next();
			Collection<Breeding> colonyBreedings = breedingService.fetchColonyBreedingsByBreedingId(breeding.getId(), null);
			model.put("colonyBreedings", colonyBreedings);
		}

		return new ModelAndView(getViewName(), model);
	}

	protected Map<String, Object> makeModel(Long objectId, Person user) {
		Map<String, Object> model = new HashMap<String, Object>();
		Cage cage = cageService.fetchForViewById(objectId);
		model.put("cage",cage);
		return model;
	}
}
