/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.controllers;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.services.ComponentMapService;
import uk.ac.sanger.mig.customquery.CustomQuery;
import uk.ac.sanger.mig.customquery.forms.CustomQueryFilterEnum;
import uk.ac.sanger.mig.customquery.forms.CustomQueryForm;
import uk.ac.sanger.mig.customquery.forms.CustomQueryFormFilter;
import uk.ac.sanger.mig.customquery.forms.CustomQueryFormSort;
import uk.ac.sanger.mig.customquery.services.CustomQueryService;
import uk.ac.sanger.mig.mousetracking.Cage;
import uk.ac.sanger.mig.mousetracking.Litter;
import uk.ac.sanger.mig.mousetracking.services.CageService;
import uk.ac.sanger.mig.mousetracking.services.LitterService;
import uk.ac.sanger.mig.personnel.Person;

public class ViewOneLitterController extends ViewOneCageController {

	private ComponentMapService componentMapService;
	private LitterService litterService;
	private CustomQueryService customQueryService;
	private CageService cageService;

	public void setLitterService(LitterService litterService) {
		this.litterService = litterService;
	}

	public void setComponentMapService(ComponentMapService componentMapService) {
		this.componentMapService = componentMapService;
	}

	public void setCustomQueryService(CustomQueryService customQueryService) {
		this.customQueryService = customQueryService;
	}

	public void setCageService(CageService cageService) {
		this.cageService = cageService;
	}

	@Override
	protected Map<String, Object> makeModel(Long litterId, Person user) {
		Litter litter = litterService.fetchById(litterId, null );

		Cage breedingCage = getBreedingService().fetchForCageView(litter.getBreedingId());

		ComponentMap cageComponents = componentMapService.getComponentMap("viewLitterCages");
		Collection<Cage> litterCages = cageService.fetchByLitterId(litterId, cageComponents);
		breedingCage.getPreviousCages().addAll(litterCages);

		Map<String, Object> model = new HashMap<String, Object>();
		model.put("litter", litter);
		model.put("cage", breedingCage);
		model.put("currentRecordId", litterId);

		model.putAll(fetchPups(user, litter.getId()));

		return model;
	}

	private Map<String, Object> fetchPups(Person user, Long litterId) {
		CustomQuery cq = customQueryService.fetchByUniqueName("litterDetail", user.getId(), null);

		CustomQueryForm queryForm = new CustomQueryForm(cq.getId(), user.getId(), "litterDetail");
		CustomQueryFormFilter filter = customQueryService.constructFormFilter(cq.getId(), "litter_id", false, CustomQueryFilterEnum.EQUALS, litterId);
		queryForm.addFilter(filter);

		CustomQueryFormSort sort = new CustomQueryFormSort("mouse_name", false, false);
		queryForm.addSort(sort);

		return customQueryService.fetchCustomQueryModel(queryForm);
	}
}
