/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.controllers;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.ParameterizableViewController;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.common.services.ComponentMapService;
import uk.ac.sanger.mig.customquery.CustomQuery;
import uk.ac.sanger.mig.customquery.forms.CustomQueryFilterEnum;
import uk.ac.sanger.mig.customquery.forms.CustomQueryForm;
import uk.ac.sanger.mig.customquery.forms.CustomQueryFormFilter;
import uk.ac.sanger.mig.customquery.forms.CustomQueryFormSort;
import uk.ac.sanger.mig.customquery.services.CustomQueryService;
import uk.ac.sanger.mig.mousetracking.Breeding;
import uk.ac.sanger.mig.mousetracking.BreedingSearchBean;
import uk.ac.sanger.mig.mousetracking.Cohort;
import uk.ac.sanger.mig.mousetracking.ExperimentData;
import uk.ac.sanger.mig.mousetracking.Mouse;
import uk.ac.sanger.mig.mousetracking.MouseAllele;
import uk.ac.sanger.mig.mousetracking.StudBreeding;
import uk.ac.sanger.mig.mousetracking.services.BreedingService;
import uk.ac.sanger.mig.mousetracking.services.CohortService;
import uk.ac.sanger.mig.mousetracking.services.ExperimentDataService;
import uk.ac.sanger.mig.mousetracking.services.MouseAlleleService;
import uk.ac.sanger.mig.mousetracking.services.MouseService;
import uk.ac.sanger.mig.mousetracking.services.StudBreedingService;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.reservations.Reservation;
import uk.ac.sanger.mig.reservations.services.ReservationService;

public class ViewOneMouseController extends ParameterizableViewController {

	private MouseService mouseService;
	private BreedingService breedingService;
	private ExperimentDataService experimentDataService;
	private ComponentMapService componentMapService;
	private CohortService cohortService;
	private ReservationService reservationService;
	private StudBreedingService studBreedingService;
	private MouseAlleleService mouseAlleleService;
	private CustomQueryService customQueryService;

	public void setMouseAlleleService(MouseAlleleService mouseAlleleService) {
		this.mouseAlleleService = mouseAlleleService;
	}

	public void setReservationService(ReservationService reservationService) {
		this.reservationService = reservationService;
	}

	public void setMouseService(MouseService mouseService) {
		this.mouseService = mouseService;
	}

	public void setBreedingService(BreedingService breedingService) {
		this.breedingService = breedingService;
	}

	public void setExperimentDataService(ExperimentDataService experimentDataService) {
		this.experimentDataService = experimentDataService;
	}

	public void setComponentMapService(ComponentMapService componentMapService) {
		this.componentMapService = componentMapService;
	}

	public void setCohortService(CohortService cohortService) {
		this.cohortService = cohortService;
	}

	public void setStudBreedingService(StudBreedingService studBreedingService) {
		this.studBreedingService = studBreedingService;
	}

	public void setCustomQueryService(CustomQueryService customQueryService) {
		this.customQueryService = customQueryService;
	}

	@Override
	protected ModelAndView handleRequestInternal(HttpServletRequest request, HttpServletResponse response) throws Exception {
		Person user = RequestUtils.getUser(request);
		Long mouseId = ServletRequestUtils.getRequiredLongParameter(request, "id");

		Mouse mouse = mouseService.fetchById(mouseId, ComponentMap.of(Mouse.Component.ALL_COMPONENTS));

		Map<String, Object> model = new HashMap<String, Object>();

		BreedingSearchBean breedingSearch = new BreedingSearchBean();
		breedingSearch.setPaginated(false);
		breedingSearch.setParentId(mouse.getId());
		breedingSearch.setOrderBy("start_date");

		Collection<Breeding> breedings = breedingService.search(breedingSearch, componentMapService.getComponentMap("viewOneMouseBreedings"));

		ExperimentData experimentData = experimentDataService.fetchByMouseId(mouseId, componentMapService.getComponentMap("viewOneMouseExperimentData"));

		Collection<Cohort> cohorts = cohortService.fetchByMouseId(mouseId, null);

		Reservation reservation = reservationService.fetchByMouseId(mouseId, componentMapService.getComponentMap("viewOneMouseReservation"));

		Collection<StudBreeding> studBredings = studBreedingService.fetchByMouseId(mouseId, null);

		Collection<MouseAllele> mouseAlleles = mouseAlleleService.fetchByMouseId(mouseId, componentMapService.getComponentMap("viewOneMouseAlleles"));

		model.put("mouse", mouse);
		model.putAll(fetchCurrentHealthRecords(user, mouseId));
		model.put("breedings", breedings);
		model.put("experimentData", experimentData);
		model.put("cohorts", cohorts);
		model.put("reservation", reservation);
		model.put("studBreedings", studBredings);
		model.put("mouseAlleles",mouseAlleles);

		return new ModelAndView(getViewName(), model);
	}

	private Map<String, Object> fetchCurrentHealthRecords(Person user, Long mouseId) {
		CustomQuery tempCq = customQueryService.fetchByUniqueName("mouseHealthMini", user.getId(), null);

		CustomQueryForm queryForm = new CustomQueryForm(tempCq.getId(), user.getId(), "currentHealthRecords");
		CustomQueryFormFilter filter1 = customQueryService.constructFormFilter(tempCq.getId(), "mouse_id", false, CustomQueryFilterEnum.EQUALS, mouseId);
		queryForm.addFilter(filter1);
		CustomQueryFormFilter filter2 = customQueryService.constructFormFilter(tempCq.getId(), "end_date", false, CustomQueryFilterEnum.NULL, null);
		queryForm.addFilter(filter2);

		CustomQueryFormSort sort = new CustomQueryFormSort("start_date", true, false);
		queryForm.addSort(sort);

		return customQueryService.fetchCustomQueryModel(queryForm);
	}
}
