/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.controllers;


import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.ParameterizableViewController;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.mousetracking.Cage;
import uk.ac.sanger.mig.mousetracking.Rack;
import uk.ac.sanger.mig.mousetracking.services.RackService;

public class ViewOneRackController extends ParameterizableViewController {

	private RackService rackService;
	private String errorView;

	/**
	 * @return the rackService
	 */
	public RackService getRackService() {
		return this.rackService;
	}

	/**
	 * @param rackService the rackService to set
	 */
	public void setRackService(RackService rackService) {
		this.rackService = rackService;
	}

	public void setErrorView(String errorView) {
		this.errorView = errorView;
	}


	protected ModelAndView handleRequestInternal(HttpServletRequest request, HttpServletResponse response) throws Exception {

		Long rackId = ServletRequestUtils.getRequiredLongParameter(request, "id");

		Map<String, Object> model = new HashMap<String, Object>();

		ComponentMap cageComponents = new ComponentMap();
		cageComponents.put(Cage.Component.CONTENTS,null);
		cageComponents.put(Cage.Component.CAGE_TYPE,null);

		ComponentMap rackComponents = new ComponentMap();
		rackComponents.put(Rack.Component.ALL_COMPONENTS, null);
		rackComponents.put(Rack.Component.CAGES, cageComponents);

		Rack rack = rackService.fetchById(rackId, rackComponents);

		int totalMice = 0;
		for (Cage cage : rack.getCages()) {
			totalMice += cage.getContents().size();
		}

		model.put("totalMice", totalMice);

		if(rack == null) {
			return new ModelAndView(errorView, "rackId", rackId);
		} else {
			model.put("rack", rack);
			return new ModelAndView(getViewName(), model);
		}
	}
}
