/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.controllers;

import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.ParameterizableViewController;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.common.services.ComponentMapService;
import uk.ac.sanger.mig.customquery.forms.CustomQueryFilterEnum;
import uk.ac.sanger.mig.customquery.forms.CustomQueryForm;
import uk.ac.sanger.mig.customquery.forms.CustomQueryFormFilter;
import uk.ac.sanger.mig.customquery.forms.CustomQueryFormSort;
import uk.ac.sanger.mig.customquery.services.CustomQueryService;
import uk.ac.sanger.mig.mousetracking.Room;
import uk.ac.sanger.mig.mousetracking.services.RoomService;
import uk.ac.sanger.mig.personnel.Person;

public class ViewOneRoomController extends ParameterizableViewController {

	private RoomService roomService;
	private ComponentMapService componentMapService;
	private CustomQueryService customQueryService;

	public void setRoomService(RoomService roomService) {
		this.roomService = roomService;
	}

	public void setComponentMapService(ComponentMapService componentMapService) {
		this.componentMapService = componentMapService;
	}

	public void setCustomQueryService(CustomQueryService customQueryService) {
		this.customQueryService = customQueryService;
	}

	@Override
	protected ModelAndView handleRequestInternal(HttpServletRequest request, HttpServletResponse response) throws Exception{

		Person user = RequestUtils.getUser(request);

		Long roomId = ServletRequestUtils.getRequiredLongParameter(request, "id");

		Map<String, Object> model = new HashMap<String, Object>();
		ComponentMap requiredComponents = componentMapService.getComponentMap("viewOneRoom");
		Room room = roomService.fetchById(roomId, requiredComponents);
		model.put("room", room);

		model.putAll(fetchMatingsByRoom(user, roomId));
		model.putAll(fetchPreweanLittersByRoom(user, roomId));
		model.putAll(fetchColoniesByRoom(user, roomId));

		return new ModelAndView(getViewName(), model);
	}

	private Map<String, Object> fetchColoniesByRoom(Person user, Long roomId) {
		CustomQueryForm queryForm = new CustomQueryForm(3L, user.getId(), "coloniesByRoom");
		CustomQueryFormFilter filter = customQueryService.constructFormFilter(3L, "room_id", false, CustomQueryFilterEnum.EQUALS, roomId);
		queryForm.addFilter(filter);

		CustomQueryFormSort sort = new CustomQueryFormSort("colony_prefix", false, false);
		queryForm.addSort(sort);

		return customQueryService.fetchCustomQueryModel(queryForm);
	}

	private Map<String, Object> fetchMatingsByRoom(Person user, Long roomId) {
		CustomQueryForm queryForm = new CustomQueryForm(4L, user.getId(), "matingsByRoom");
		CustomQueryFormFilter filter = customQueryService.constructFormFilter(4L, "room_id", false, CustomQueryFilterEnum.EQUALS, roomId);
		queryForm.addFilter(filter);

		CustomQueryFormSort sort = new CustomQueryFormSort("start_date", true, false);
		queryForm.addSort(sort);

		return customQueryService.fetchCustomQueryModel(queryForm);
	}

	private Map<String, Object> fetchPreweanLittersByRoom(Person user, Long roomId) {
		CustomQueryForm queryForm = new CustomQueryForm(5L, user.getId(), "preweanLittersByRoom");
		CustomQueryFormFilter filter = customQueryService.constructFormFilter(5L, "room_id", false, CustomQueryFilterEnum.EQUALS, roomId);
		queryForm.addFilter(filter);

		CustomQueryFormSort sort = new CustomQueryFormSort("birth_date", true, false);
		queryForm.addSort(sort);

		return customQueryService.fetchCustomQueryModel(queryForm);
	}

}