/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.controllers;


import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.propertyeditors.CustomNumberEditor;
import org.springframework.validation.BindException;
import org.springframework.web.bind.ServletRequestDataBinder;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.SimpleFormController;

import uk.ac.sanger.mig.mousetracking.CageRackSearchBean;



public class ViewUserHomeController extends SimpleFormController {

	private String cageSuccess;
	private String rackSuccess;
	private String mouseSuccess;

	public void setCageSuccess(String cageSuccess) {
		this.cageSuccess = cageSuccess;
	}

	public void setRackSuccess(String rackSuccess) {
		this.rackSuccess = rackSuccess;
	}

	public void setMouseSuccess(String mouseSuccess) {
		this.mouseSuccess = mouseSuccess;
	}

	@Override
	protected void initBinder(HttpServletRequest httpServletRequest, ServletRequestDataBinder binder) {

		// Create and register Long binder for Long values which also allows null values
		CustomNumberEditor customLongEditor = new CustomNumberEditor(Long.class, true);
		binder.registerCustomEditor(Long.class, customLongEditor);
	}

	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		CageRackSearchBean form = (CageRackSearchBean)command;

		String successView;

		if(form.getBarcodeType().equalsIgnoreCase("rack")){
			successView = rackSuccess + form.getCageOrRackId();
		}
		else if(form.getBarcodeType().equalsIgnoreCase("cage")){
			successView = cageSuccess + form.getCageOrRackId();
		}
		else {
			successView = mouseSuccess + form.getCageOrRackId();
		}

		return new ModelAndView(successView);
	}
}
