/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.controllers;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Date;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.propertyeditors.CustomDateEditor;
import org.springframework.validation.BindException;
import org.springframework.web.bind.ServletRequestDataBinder;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.mousetracking.Mouse;
import uk.ac.sanger.mig.mousetracking.MouseWeight;
import uk.ac.sanger.mig.mousetracking.forms.WeighMiceForm;
import uk.ac.sanger.mig.mousetracking.services.MouseWeightService;
import uk.ac.sanger.mig.personnel.Person;

public class WeighMiceController extends CohortProcedureFormController {

	private MouseWeightService mouseWeightService;

	public void setMouseWeightService(MouseWeightService mouseWeightService) {
		this.mouseWeightService = mouseWeightService;
	}

	@Override
	protected void initBinder(HttpServletRequest request, ServletRequestDataBinder binder) throws Exception {
		super.initBinder(request, binder);

		binder.registerCustomEditor(Date.class, "sampleDate", new CustomDateEditor(new SimpleDateFormat("dd-MMM-yyyy HH:mm"),true));
	}

	@Override
	protected void changeForm(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) {
		WeighMiceForm form = (WeighMiceForm)command;
		Collection<MouseWeight> weights = new ArrayList<MouseWeight>();
		for(Mouse mouse : form.getMice()) {
			MouseWeight mouseWeight = new MouseWeight();
			mouseWeight.setMouseId(mouse.getId());
			mouseWeight.setWeightUnits("g");
			weights.add(mouseWeight);
		}
		form.setWeights(weights);
	}

	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		WeighMiceForm form = (WeighMiceForm)command;
		Person user = RequestUtils.getUser(request);

		// copy the sample date into all the weights
		if(form.getWeights() != null) {
			for(MouseWeight mouseWeight : form.getWeights()) {
				mouseWeight.setSampleDate(form.getSampleDate());
			}
		}

		mouseWeightService.storeCollection(form.getWeights(), user);

		return new ModelAndView(getSuccessView(),"id",form.getCohort().getId());
	}

	@Override
	protected ModelAndView handleInvalidSubmit(HttpServletRequest request, HttpServletResponse response) throws Exception {
		return new ModelAndView("errors/handle_invalid_submit");
	}

	@Override
	protected void customiseFormBackingObject(HttpServletRequest request, Object command) throws Exception {
		// no customisation needed at the moment
	}

}
