/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.mousetracking.dao;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.common.PaginatedSearchUtils;
import uk.ac.sanger.mig.database.LongRowMapper;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.mousetracking.CohortSet;
import uk.ac.sanger.mig.mousetracking.CohortSetListViewSearchBean;
import uk.ac.sanger.mig.mousetracking.dao.rowmappers.CohortSetListViewRowMapper;
import uk.ac.sanger.mig.mousetracking.views.CohortSetListView;

public class CohortSetDaoSpringImpl extends AbstractDaoSpringImpl<CohortSet> implements CohortSetDao {
	private PaginatedSearchUtils<CohortSetListView> listPaginator;
	private CohortSetListViewRowMapper cohortSetListViewRowMapper;

	public void setCohortSetListViewRowMapper(CohortSetListViewRowMapper cohortSetListViewRowMapper) {
		this.cohortSetListViewRowMapper = cohortSetListViewRowMapper;
	}


	public void setListPaginator(PaginatedSearchUtils<CohortSetListView> listPaginator) {
		this.listPaginator = listPaginator;
	}

	public Collection<Long> fetchExsitingAlleleID() {
		String sql = "select distinct s.ALLELE_ID  from mts_cohort_set s ";
		Collection<Long> records = getSimpleJdbcTemplate().query(sql, new LongRowMapper());
		return (records == null) ? new ArrayList<Long>() : records;
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, CohortSet cohortSet) {
		sql.addDateParam(cohortSet.getCreatedDate(), "CREATED_DATE");
		sql.addLongParam(cohortSet.getCreatorId(), "CREATOR_ID");
		sql.addLongParam(cohortSet.getCheckNumber(), "CHECK_NUMBER");
		sql.addStringParam(cohortSet.getEditedBy(), "EDITED_BY");
		sql.addDateParam(cohortSet.getEditDate(), "EDIT_DATE");
		sql.addLongParam(cohortSet.getAlleleId(), "ALLELE_ID");
		sql.addLongParam(cohortSet.getCohortSetTypeDictId(), "COHORT_SET_TYPE_DICT_ID");
		sql.addLongParam(cohortSet.getId(), "ID");
	}

	public Collection<CohortSet> fetchByAlleleId(Long alleleId) {
		String sql = "select s.* from mts_cohort_set s where s.ALLELE_ID = ? ";
		return fetchCollection(sql, alleleId);
	}


	public Collection<CohortSetListView> search(CohortSetListViewSearchBean bean) {

		Collection<Object> bindVariables = new ArrayList<Object>();
		String sql = constructSearchSql(bean, bindVariables, "mts_cohort_set_list_vw");
		return listPaginator.fetchSearchResults(sql, bindVariables, bean, cohortSetListViewRowMapper);
	}


	private String constructSearchSql(CohortSetListViewSearchBean bean, Collection<Object> bindVariables, String tableName) {

		String selectSql  = " select m.* ";
		String fromSql = " from " + tableName + " m ";
		String whereSql = " where 1=1 ";

		if(bean.getGeneAlleleName() != null) {
			whereSql += " and lower(m.gene_name) = lower(?) or lower(m.short_allele_symbol)=lower(?) or lower(m.allele_superscript)=lower(?) ";
			bindVariables.add(bean.getGeneAlleleName());
			bindVariables.add(bean.getGeneAlleleName());
			bindVariables.add(bean.getGeneAlleleName());
		}

		if(bean.getCohortSetTypeDictId() != null) {
			whereSql += " and m.cohort_set_type_dict_id = ? ";
			bindVariables.add(bean.getCohortSetTypeDictId());
		}


		String orderBySql = "";

		if(bean.getOrderBy() != null && bean.getOrderBy().length() > 0) {
			orderBySql += " order by " + bean.getOrderBy();
			if(bean.isOrderDesc()) {
				orderBySql += " desc ";
			}
		}

		String sql = selectSql + fromSql + whereSql + orderBySql;

		logger.debug(sql);

		return sql;

	}



}