/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.mousetracking.dao;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.mousetracking.CohortSetElement;
import uk.ac.sanger.mig.mousetracking.dao.rowmappers.CohortSetElementListViewRowMapper;
import uk.ac.sanger.mig.mousetracking.views.CohortSetElementListView;

public class CohortSetElementDaoSpringImpl extends AbstractDaoSpringImpl<CohortSetElement> implements CohortSetElementDao {

	private CohortSetElementListViewRowMapper cohortSetElementListViewRowMapper;

	public void setCohortSetElementListViewRowMapper(CohortSetElementListViewRowMapper cohortSetElementListViewRowMapper) {
		this.cohortSetElementListViewRowMapper = cohortSetElementListViewRowMapper;
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, CohortSetElement cohortSetElement) {
		sql.addLongParam(cohortSetElement.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(cohortSetElement.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(cohortSetElement.getCreatedDate(), "CREATED_DATE");
		sql.addStringParam(cohortSetElement.getEditedBy(), "EDITED_BY");
		sql.addDateParam(cohortSetElement.getEditDate(), "EDIT_DATE");
		sql.addLongParam(cohortSetElement.getCohortId(), "COHORT_ID");
		sql.addLongParam(cohortSetElement.getSetId(), "SET_ID");
		sql.addLongParam(cohortSetElement.getWtDictId(), "WT_DICT_ID");
		sql.addLongParam(cohortSetElement.getId(), "ID");
	}

	public Collection<CohortSetElementListView> fetchByCohortSetId(Long cohortSetId) {
		String sql = " select s.* from mts_cohort_set_element_list_vw s where s.set_id = ? ";
		Collection<CohortSetElementListView> elementList =
			getSimpleJdbcTemplate().query(sql, this.cohortSetElementListViewRowMapper, cohortSetId);
		return (elementList != null) ? elementList:new ArrayList<CohortSetElementListView>();
	}

	public CohortSetElement fetchByCohortAndSetId(Long cohortId, Long setId){
		String sql = "select s.* from mts_cohort_set_element s where s.cohort_id = ? and s.set_id = ?";
		return fetchOne(sql, cohortId, setId);
	}

}