/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.dao;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.common.PaginatedSearchUtils;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.database.TableMetadataEnum;
import uk.ac.sanger.mig.mousetracking.EnvironmentReport;
import uk.ac.sanger.mig.mousetracking.EnvironmentReportSearchBean;



public class EnvironmentReportDaoSpringImpl extends AbstractDaoSpringImpl<EnvironmentReport> implements EnvironmentReportDao {

	private PaginatedSearchUtils<EnvironmentReport> paginator;
	
	public void setPaginator(PaginatedSearchUtils<EnvironmentReport> paginator) {
		this.paginator = paginator;
	}
	
	public Collection<EnvironmentReport> fetchPreviousReports(Long id, Long currentId) {
		
		String sql = "select m.* from mts_environment_report m where FOREIGN_KEY_ID = ? and id != ?";
		
		Collection<EnvironmentReport> previous = getSimpleJdbcTemplate().query(sql, getRowMapper(), id, currentId); 
		
		return (previous != null) ? previous : new ArrayList<EnvironmentReport>();
	}
	
	
	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, EnvironmentReport environmentReport) {
		sql.addStringParam(environmentReport.getDescription(), "DESCRIPTION");
		sql.addDateParam(environmentReport.getReportedDate(), "REPORTED_DATE");
		sql.addDateParam(environmentReport.getResolvedDate(), "RESOLVED_DATE");
		sql.addLongParam(environmentReport.getForeignKeyId(), "FOREIGN_KEY_ID");
		sql.addEnumParam(environmentReport.getForeignTableName(), "FOREIGN_TABLE_NAME");
		sql.addDateParam(environmentReport.getCreatedDate(), "CREATED_DATE");
		sql.addLongParam(environmentReport.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(environmentReport.getEditDate(), "EDIT_DATE");
		sql.addStringParam(environmentReport.getEditedBy(), "EDITED_BY");
		sql.addLongParam(environmentReport.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(environmentReport.getId(), "ID");

	
	}

	
	public Collection<EnvironmentReport> search(EnvironmentReportSearchBean bean) {
		
		Collection<Object> bindVariables = new ArrayList<Object>();	
		
		String sql  = " select m.* from mts_environment_report m where 1=1 ";
		
		// Report ID
		if(bean.getReportId() != null) {
			sql += " and m.id = ? ";
			bindVariables.add(bean.getReportId());
		}
		
		// reported date (from)
		if(bean.getReportedDateFrom() != null) {
			sql += " and m.reported_date >= ? ";
			bindVariables.add(bean.getReportedDateFrom());
		}
		
		// reported date (to)
		if(bean.getReportedDateTo() != null) {
			sql += " and m.reported_date <= ? ";
			bindVariables.add(bean.getReportedDateTo());
		}
		
		// resolved date (from)
		if(bean.getResolvedDateFrom() != null) {
			sql += " and m.resolved_date >= ? ";
			bindVariables.add(bean.getResolvedDateFrom());
		}
		
		// reported date (to)
		if(bean.getResolvedDateTo() != null) {
			sql += " and m.resolved_date <= ? ";
			bindVariables.add(bean.getResolvedDateTo());
		}
		
		// currently unresolved
		if(bean.isAllOpenReports() == true) {
			sql += " and m.reported_date is not null and m.resolved_date is null ";
		}
		
		// reported by
		if(bean.getCurrentOwnerId() != null) {
			sql += " and m.creator_id = ? ";
			bindVariables.add(bean.getCurrentOwnerId());
		}
		
		// report entity id.
		if(bean.getForeignKeyId() != null) {
			sql += " and m.foreign_key_id = ? ";
			bindVariables.add(bean.getForeignKeyId());
			
			sql += " and m.foreign_table_name = ? ";
			TableMetadataEnum tableName = null;
			if(bean.getReportType().equals("room")) {
				tableName = TableMetadataEnum.MTS_ROOM;
			}else if(bean.getReportType().equals("rack")) {
				tableName = TableMetadataEnum.MTS_RACK;
			}else if(bean.getReportType().equals("cage")) {
				tableName = TableMetadataEnum.MTS_CAGE;
			}else{
				tableName = TableMetadataEnum.MTS_AIR_HANDLING_UNIT;
			}
			bindVariables.add(tableName.name());
		}
		
		sql += " order by ";	
		if(bean.getOrderBy() == null || bean.getOrderBy().equals("")) {
			sql += "id ";
		}
		else {
			sql += bean.getOrderBy();
		}
		
		if(bean.isOrderDesc()) {
			sql += " desc ";
		}
		
		logger.debug(sql);
		
		return paginator.fetchSearchResults(sql, bindVariables, bean, getRowMapper());
		
	}
	
}