/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.mousetracking.dao;

import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.mousetracking.GenotypeHistory;

public class GenotypeHistoryDaoSpringImpl extends AbstractDaoSpringImpl<GenotypeHistory> implements GenotypeHistoryDao {

	public Collection<GenotypeHistory> fetchByMouseAlleleId(Long mouseAlleleId) {
		String sql = " select * from mts_genotype_history where mouse_allele_id = ? order by assignment_date desc";
		return fetchCollection(sql, mouseAlleleId);
	}

	public GenotypeHistory fetchLatestByMouseAlleleId(Long mouseAlleleId) {
		String sql = " select * from (select * from mts_genotype_history where mouse_allele_id = ? order by assignment_date desc, id) where rownum = 1 ";
		return fetchOne(sql, mouseAlleleId);
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, GenotypeHistory genotypeHistory) {
		sql.addLongParam(genotypeHistory.getMouseAlleleId(), "MOUSE_ALLELE_ID");
		sql.addDateParam(genotypeHistory.getAssignmentDate(), "ASSIGNMENT_DATE");
		sql.addLongParam(genotypeHistory.getGenotypeDictId(), "GENOTYPE_DICT_ID");
		sql.addLongParam(genotypeHistory.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(genotypeHistory.getCreatedDate(), "CREATED_DATE");
		sql.addStringParam(genotypeHistory.getEditedBy(), "EDITED_BY");
		sql.addDateParam(genotypeHistory.getEditDate(), "EDIT_DATE");
		sql.addLongParam(genotypeHistory.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(genotypeHistory.getSourceDictId(), "SOURCE_DICT_ID");
		sql.addStringParam(genotypeHistory.getComments(), "COMMENTS");
		sql.addLongParam(genotypeHistory.getId(), "ID");
	}

}