/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.dao;

import java.sql.Types;
import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.sql.DataSource;

import org.springframework.jdbc.core.SqlParameter;
import org.springframework.jdbc.object.StoredProcedure;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.mousetracking.MouseAllele;
import uk.ac.sanger.mig.personnel.Person;

public class MouseAlleleDaoSpringImpl extends AbstractDaoSpringImpl<MouseAllele> implements MouseAlleleDao {

	public Collection<MouseAllele> fetchByMouseId(Long mouseId) {
		String sql = " select * from mts_mouse_allele where mouse_id = ? ";
		return fetchCollection(sql, mouseId);

	}


	public void deleteMouseAllele(MouseAllele mouseAllele, Person user) {
		DeleteMouseAlleleStoredProcedure deleteMouseAllele = new DeleteMouseAlleleStoredProcedure(getDataSource());
		deleteMouseAllele.delete(mouseAllele.getId());
	}


	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, MouseAllele mouseAllele) {
		sql.addLongParam(mouseAllele.getMouseId(), "MOUSE_ID");
		sql.addLongParam(mouseAllele.getAlleleId(), "ALLELE_ID");
		sql.addLongParam(mouseAllele.getGenotypeDictId(), "GENOTYPE_DICT_ID");
		sql.addLongParam(mouseAllele.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(mouseAllele.getCreatedDate(), "CREATED_DATE");
		sql.addStringParam(mouseAllele.getEditedBy(), "EDITED_BY");
		sql.addDateParam(mouseAllele.getEditDate(), "EDIT_DATE");
		sql.addLongParam(mouseAllele.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(mouseAllele.getId(), "ID");
		sql.addBooleanParam(mouseAllele.isLockedForUpdate(), "IS_QC_LOCKED");
	}

}

class DeleteMouseAlleleStoredProcedure extends StoredProcedure {

	public DeleteMouseAlleleStoredProcedure(DataSource dataSource) {
		setDataSource(dataSource);
		setSql("mts_delete_mouse_allele");

		declareParameter(new SqlParameter("in_mouse_allele_id", Types.NUMERIC));

		compile();
	}


	public void delete(Long mouseAlleleId) {
		Map<String, Object> inputParameters = new HashMap<String, Object>();
		inputParameters.put("in_mouse_allele_id", mouseAlleleId);
		execute(inputParameters);
	}
}