/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.dao;

import java.util.Collection;

import uk.ac.sanger.mig.database.TypedDao;
import uk.ac.sanger.mig.mousetracking.Mouse;
import uk.ac.sanger.mig.mousetracking.MouseSearchBean;
import uk.ac.sanger.mig.mousetracking.views.MouseFaxView;
import uk.ac.sanger.mig.mousetracking.views.MouseListView;
import uk.ac.sanger.mig.personnel.Person;

public interface MouseDao extends TypedDao<Mouse>{


	/**
	 * Fetch a single mouse record from the database using the barcode field.
	 * If a record is not found, null is returned.
	 *
	 * @param barcode - barcode of the mouse to be fetched
	 * @return mouse record or null if not found.
	 */
	public Mouse fetchByBarcode(String barcode);

	/**
	 * Fetch a single mouse record from the database using the name field.
	 * If a record is not found, null is returned.
	 *
	 * @param name - name of the mouse to be fetched
	 * @return mouse record or null if not found.
	 */
	public Mouse fetchByName(String mouseName);

	public Collection<MouseListView> search(MouseSearchBean bean);

	public Collection<Mouse> fetchByCageId(Long cageId);

	public Collection<Mouse> fetchByLitterId(Long litterId);

	public Collection<Mouse> fetchByCohortId(Long cohortId);

	/**
	 * checks if any mouse that isn't the input mouse is alive with the same rfid tag
	 * @param mouse
	 * @return
	 */
	public boolean rfidTagInUse(Mouse mouse);

	public Collection<Mouse> fetchParentsById(Long mouseId);

	public Collection<Mouse> fetch(MouseSearchBean searchBean);

	public Collection<Mouse> fetchHistoricByCageId(Long cageId);

	public Mouse fetchMouseByTissueSampleId(Long tissueSampleId);

	public void deleteMouse(Mouse mouse, Person user);

	public MouseFaxView fetchFaxMouseByBarcode(String barcode);

	public Collection<Mouse> fetchByRfidTag(String barcode) ;
}
