/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.dao;


import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.common.LookupListDao;
import uk.ac.sanger.mig.common.LookupListElement;
import uk.ac.sanger.mig.database.ParameterizedSqlQuery;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.mousetracking.MouseHealth;

public class MouseHealthDaoSpringImpl extends AbstractDaoSpringImpl<MouseHealth> implements MouseHealthDao {

	private LookupListDao lookupListDao;

	public void setLookupListDao(LookupListDao lookupListDao) {
		this.lookupListDao = lookupListDao;
	}

	public Collection<MouseHealth> fetchByMouseId(Long mouseId) {
		String sql = " select * from mts_mouse_health where mouse_id = ? order by start_date ";
		return fetchCollection(sql, mouseId);
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, MouseHealth mouseHealth) {

		sql.addLongParam(mouseHealth.getMouseId(),"MOUSE_ID");
		sql.addDateParam(mouseHealth.getStartDate(),"START_DATE");
		sql.addDateParam(mouseHealth.getEndDate(),"END_DATE");
		sql.addDateParam(mouseHealth.getEditDate(),"EDIT_DATE");
		sql.addStringParam(mouseHealth.getEditedBy(),"EDITED_BY");
		sql.addLongParam(mouseHealth.getCreatorId(),"CREATOR_ID");
		sql.addDateParam(mouseHealth.getCreatedDate(),"CREATED_DATE");
		sql.addLongParam(mouseHealth.getCheckNumber(),"CHECK_NUMBER");
		sql.addStringParam(mouseHealth.getComments(),"COMMENTS");
		sql.addStringParam(mouseHealth.getStatus(),"STATUS");
		sql.addLongParam(mouseHealth.getBodySubsystemDictId(),"BODY_SUBSYSTEM_DICT_ID");
		sql.addLongParam(mouseHealth.getBodySystemDictId(),"BODY_SYSTEM_DICT_ID");
		sql.addLongParam(mouseHealth.getHealthConcernDictId(),"HEALTH_CONCERN_DICT_ID");
		sql.addLongParam(mouseHealth.getId(),"ID");
	}

	public Collection<LookupListElement> lookup() {
		ParameterizedSqlQuery variables = new ParameterizedSqlQuery();
		String sql = " select ";
		sql += " d1.name||' > '||d2.name||' > '||d3.name display_text, ";
		sql += " d1.id body_system_dict_id, ";
		sql += " d1.name body_system, ";
		sql += " d2.id body_subsystem_dict_id, ";
		sql += " d2.name body_subsystem, ";
		sql += " d3.id health_concern_dict_id, ";
		sql += " d3.name health_concern ";
		sql += " from ";
		sql += " mts_body_system_dict d1, ";
		sql += " mts_body_subsystem_dict d2, ";
		sql += " mts_health_concern_dict d3 ";
		sql += " where ";
		sql += " d3.body_subsystem_dict_id = d2.id and ";
		sql += " d2.body_system_dict_id = d1.id ";
		sql += " order by d1.name,d2.name,d3.name ";

		return lookupListDao.fetchListElements(sql, variables);
	}

}