/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.mousetracking.dao;

import java.util.Date;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.mousetracking.MousePool;


public class MousePoolDaoSpringImpl extends AbstractDaoSpringImpl<MousePool> implements MousePoolDao {

	public MousePool fetchPool(Long colonyId, Date poolDate) {
		String sql = "select * from mts_mouse_pool where colony_info_id = ? and pool_date = ? ";
		return fetchOne(sql, colonyId, poolDate);
	}

	public MousePool fetchByCageId(Long cageId) {
		String sql = " select * from mts_mouse_pool where cage_id = ?  ";
		return fetchOne(sql, cageId);
	}

	public MousePool fetchByBarcode(String barcode) {
		String sql = "select * from mts_mouse_pool p, mts_cage c where c.id = p.cage_id and c.barcode = upper(?) ";
		return fetchOne(sql, barcode);
	}


	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, MousePool mousePool) {
		sql.addLongParam(mousePool.getCageId(), "CAGE_ID");
		sql.addLongParam(mousePool.getColonyId(), "COLONY_INFO_ID");
		sql.addDateParam(mousePool.getPoolDate(), "POOL_DATE");
		sql.addDateParam(mousePool.getCreatedDate(), "CREATED_DATE");
		sql.addLongParam(mousePool.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(mousePool.getEditDate(), "EDIT_DATE");
		sql.addStringParam(mousePool.getEditedBy(), "EDITED_BY");
		sql.addLongParam(mousePool.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(mousePool.getId(), "ID");
	}

}