/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.dao;

import java.util.Collection;

import uk.ac.sanger.mig.database.TableMetadataEnum;
import uk.ac.sanger.mig.database.TypedDao;
import uk.ac.sanger.mig.mousetracking.MouseProcedure;
import uk.ac.sanger.mig.personnel.Person;

public interface MouseProcedureDao extends TypedDao<MouseProcedure> {
	/**
	 * Returns MouseProcedure whose foreign key id maps to a unique row (PK) in a procedure table
	 *
	 * @param table
	 * @param fkRef
	 * @return
	 */
	public MouseProcedure fetchByTableRef(TableMetadataEnum tableName, Long fkRef);


	/**
	 * Deletes MouseProcedure record with tableId and fkRef param
	 *
	 * @param tableId
	 * @param fkRef
	 * @param user
	 * @return
	 */
	public int deleteByTableRef(TableMetadataEnum tableName, Long fkRef, Person user);


	/**
	 * Returns a collection of MouseProcedure records by mouse id sorted by date
	 *
	 * @param mouseId
	 * @return
	 */
	public Collection<MouseProcedure> fetchByMouseId(Long mouseId);


	/**
	 * Return the latest licenced procedure for a given mouse id
	 *
	 * @param mouseId
	 * @return
	 */
	public MouseProcedure fetchCurrentLicencedByMouseId(Long mouseId);


	public MouseProcedure fetchByTableRefAndMouseId(TableMetadataEnum tableName, Long mouseId);


	/**
	 * Find all mouse procedures for a mouse with the passed procedure and returns them as a
	 * collection.
	 *
	 * @param procedureDictId -
	 *            the id of the procedure to lookup.
	 * @param mouseId -
	 *            the id of the mouse to lookup.
	 * @return collection of MouseProcedure objects.
	 */
	public Collection<MouseProcedure> fetchByProcedureDictIdAndMouseId(Long procedureDictId, Long mouseId);


	public boolean doesProcedureExist(MouseProcedure mouseProcedure);


	public boolean isLicencedProcedure(Long procedureDictId);


	public boolean isTerminalProcedure(Long procedureDictId);

	/**
	 *
	 * @param procedureDictId
	 * @return boolean whether this procedure can be applied to a mouse after its death.
	 */
	public boolean isAllowablePostMortem(Long procedureDictId);
}