/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.dao;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.mousetracking.Rack;
import uk.ac.sanger.mig.mousetracking.RackSearchBean;

public class RackDaoSpringImpl extends AbstractDaoSpringImpl<Rack> implements RackDao {

	public static final String AUDIT_RACK_NAME = "Audit";

	public Collection<Rack> fetch(RackSearchBean bean) {
		Collection<Object> bindVariables = new ArrayList<Object>();

		String sql = " select r.* from mts_rack r where 1=1 ";

		Collection<Rack> racks =
			getSimpleJdbcTemplate().query(
					sql,
					getRowMapper(),
					bindVariables.toArray());

		return (racks == null) ? new ArrayList<Rack>() : racks;
	}

	public Rack fetchByBarcode(String barcode) {
		String sql = "select * from mts_rack where barcode = upper(?) and status = 'In Use' ";
		return fetchOne(sql, barcode);
	}

	public Rack fetchAuditRack(Long roomId) {
		String sql = " select * from mts_rack where room_id = ? and name = ? ";
		return fetchOne(sql, roomId, AUDIT_RACK_NAME);
	}

	public int getMaxCapacity(Long rackId) {
		Rack rack = null;
		//i know we're fetching all cols, but this is cheap and the
		//alternative would be to create another row mapper just to
		//complete this rinky-dink task.
		String sql = "select * from mts_rack where id = ?";
		rack = getSimpleJdbcTemplate().queryForObject(sql, getRowMapper(), rackId);
		return rack.getMaxCapacity();
	}

	public Rack fetchByName(String rackName) {
		String sql = "select * from mts_rack where name = ?";
		return fetchOne(sql, rackName);
	}

	public Collection<Rack> fetchByAHUId(Long ahuId) {
		String sql = "select * from mts_rack where air_handling_unit_id = ? and status = 'In Use' order by name ";
		return fetchCollection(sql, ahuId);
	}

	public Collection<Rack> fetchByRoomId(Long roomId) {
		String sql = "select * from mts_rack where room_id = ? and status = 'In Use' order by name ";
		return fetchCollection(sql, roomId);
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, Rack rack) {
		sql.addStringParam(rack.getBarcode(), "BARCODE");
		sql.addStringParam(rack.getName(), "NAME");
		sql.addLongParam(rack.getAirHandlingUnitId(), "AIR_HANDLING_UNIT_ID");
		sql.addLongParam(rack.getRoomId(), "ROOM_ID");
		sql.addStringParam(rack.getStatus(), "STATUS");
		sql.addStringParam(rack.getTechnoplastName(), "TECHNOPLAST_NAME");
		sql.addLongParam(rack.getCheckNumber(), "CHECK_NUMBER");
		sql.addStringParam(rack.getEditedBy(), "EDITED_BY");
		sql.addDateParam(rack.getEditDate(), "EDIT_DATE");
		sql.addLongParam(rack.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(rack.getCreatedDate(), "CREATED_DATE");
		sql.addLongParam(rack.getId(), "ID");
	}

	public int getTotalRacksByRoomId(Long roomId) {
		String sql = "select count(*) from mts_rack where room_id = ? and status = 'In Use'";
		return getSimpleJdbcTemplate().queryForInt(sql, roomId);
	}
}
