/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.dao;

import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.mousetracking.Room;


public class RoomDaoSpringImpl extends AbstractDaoSpringImpl<Room> implements RoomDao {

	public Collection<Room> fetchAll() {
		String sql = "SELECT * FROM MTS_ROOM ORDER BY ROOM_NUMBER";
		return fetchCollection(sql, new Object[0]);
	}

	public Collection<Room> fetchCurrent() {
		String sql = "select * from mts_room  where active=1 order by room_number";
		return fetchCollection(sql, new Object[0]);
	}

	public Room fetchByBarcode(String barcode) {
		String sql = " select * from mts_room where upper(official_room_number) = upper(?) ";
		return fetchOne(sql, barcode);
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, Room room) {
		sql.addStringParam(room.getRoomNumber(), "ROOM_NUMBER");
		sql.addStringParam(room.getBuildingName(), "BUILDING_NAME");
		sql.addStringParam(room.getCorridor(), "CORRIDOR");
		sql.addStringParam(room.getDescription(), "DESCRIPTION");
		sql.addStringParam(room.getOfficialRoomNumber(), "OFFICIAL_ROOM_NUMBER");
		sql.addBooleanParam(room.isActive(), "ACTIVE");
		sql.addLongParam(room.getId(), "ID");
	}
}

