/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.mousetracking.dao;

import java.util.ArrayList;
import java.util.Collection;

import org.apache.commons.lang.StringUtils;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.mousetracking.StudBreeding;
import uk.ac.sanger.mig.mousetracking.StudBreedingSearchBean;

public class StudBreedingDaoSpringImpl extends AbstractDaoSpringImpl<StudBreeding> implements StudBreedingDao {

	public Collection<StudBreeding> fetchByMouseId(Long mouseId) {
		String sql = " select * from mts_stud_breeding where male_id = ? or female_id = ? order by start_date ";
		return fetchCollection(sql, mouseId, mouseId);
	}

	public Collection<StudBreeding> fetchByCageId(Long cageId) {
		String sql = " select s.* from mts_stud_breeding s, mts_mouse m where m.id = s.male_id and m.cage_id = ? order by s.start_date ";
		return fetchCollection(sql, cageId);
	}

	public StudBreeding fetchLatestForMouse(Long mouseId) {
		String sql = "select * from mts_stud_breeding where id in (select breeding_id from mts_latest_stud_breeding_vw where mouse_id = ?) ";
		return fetchOne(sql, mouseId);
	}

	public Collection<StudBreeding> fetch(StudBreedingSearchBean searchBean) {
		String sqlSelect = " select s.* ";
		String sqlFrom = " from mts_stud_breeding s ";
		String sqlWhere = " where 1=1 ";
		String sqlOrderBy = "";
		Collection<Object> bindVariables = new ArrayList<Object>();

		if(searchBean.getStartDate() != null) {
			sqlWhere += " and s.start_date = ? ";
			bindVariables.add(searchBean.getStartDate());
		}

		if(searchBean.getCohortId() != null) {
			sqlFrom += " ,mts_mouse m, mts_cohort_mouse c ";
			sqlWhere += " and m.id = s.male_id and m.id = c.mouse_id and c.cohort_id = ? ";
			bindVariables.add(searchBean.getCohortId());
			sqlOrderBy += " m.gender_dict_id desc, decode(m.cage_id,null,m.id,m.cage_id), m.earmark_dict_id ";
		}

		if(searchBean.getCageId() != null) {
			sqlFrom += " ,mts_mouse m2";
			sqlWhere += " and (m2.id = s.male_id or m2.id = s.female_id) and m2.cage_id = ? ";
			bindVariables.add(searchBean.getCageId());
		}

		if(Boolean.TRUE.equals(searchBean.getNullEndDate())) {
			sqlWhere += " and s.end_date is null ";
		}

		if(StringUtils.isEmpty(sqlOrderBy)) {
			sqlOrderBy = " order by s.male_id ";
		}
		else {
			sqlOrderBy = " order by " + sqlOrderBy;
		}

		String sql = sqlSelect + sqlFrom + sqlWhere + sqlOrderBy;
		return fetchCollection(sql, bindVariables.toArray());
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, StudBreeding studBreeding) {
		sql.addLongParam(studBreeding.getMaleId(), "MALE_ID");
		sql.addLongParam(studBreeding.getFemaleId(), "FEMALE_ID");
		sql.addDateParam(studBreeding.getStartDateTime(), "START_DATE");
		sql.addDateParam(studBreeding.getPlugDateTime(), "PLUG_DATE");
		sql.addDateParam(studBreeding.getEndDate(), "END_DATE");
		sql.addLongParam(studBreeding.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(studBreeding.getCreatedDate(), "CREATED_DATE");
		sql.addStringParam(studBreeding.getEditedBy(), "EDITED_BY");
		sql.addDateParam(studBreeding.getEditDate(), "EDIT_DATE");
		sql.addLongParam(studBreeding.getCheckNumber(), "CHECK_NUMBER");
		sql.addBooleanParam(studBreeding.isPseudoBreeding(), "PSEUDO_BREEDING");
		sql.addLongParam(studBreeding.getSetupPersonId(),"SETUP_PERSON_ID");
		sql.addLongParam(studBreeding.getCheckPersonId(),"CHECK_PERSON_ID");
		sql.addFloatParam(studBreeding.getTimedEmbryoAge(), "TIMED_MATING_EMBRYO_AGE");
		sql.addLongParam(studBreeding.getId(), "ID");
	}

}