/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.dao;

import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.mousetracking.TissueSample;
import uk.ac.sanger.mig.mousetracking.dao.rowmappers.BarcodeRowMapper;

public class TissueSampleDaoSpringImpl extends AbstractDaoSpringImpl<TissueSample> implements TissueSampleDao {

  private BarcodeRowMapper barcodeRowMapper;

	public TissueSample fetchByBarcode(String barcode) {
		String sql = " select * from mts_tissue_sample where barcode = ? ";
		return fetchOne(sql, barcode);
	}

	public Collection<TissueSample> fetchByMouseId(Long mouseId) {
		String sql = " select * from mts_tissue_sample where mouse_id = ? order by id ";
		return fetchCollection(sql, mouseId);
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, TissueSample tissueSample) {

		sql.addStringParam(tissueSample.getSampleType(),"SAMPLE_TYPE");
		sql.addDateParam(tissueSample.getSampleDate(),"SAMPLE_DATE");
		sql.addLongParam(tissueSample.getMouseId(), "MOUSE_ID");
		sql.addBooleanParam(tissueSample.isReusable(),"REUSABLE");
		sql.addStringParam(tissueSample.getBarcode(),"BARCODE");
		sql.addLongParam(tissueSample.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(tissueSample.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(tissueSample.getCreatedDate(), "CREATED_DATE");
		sql.addStringParam(tissueSample.getEditedBy(), "EDITED_BY");
		sql.addDateParam(tissueSample.getEditDate(), "EDIT_DATE");
		sql.addLongParam(tissueSample.getId(), "ID");
	}

  public Long generateBarcode() {
    String sql = "select app_barcode_seq.nextval as BARCODE from DUAL";

    Long barcode = getSimpleJdbcTemplate().queryForObject(sql, barcodeRowMapper);

    return barcode;
  }

  public void setBarcodeRowMapper(BarcodeRowMapper barcodeRowMapper) {
    this.barcodeRowMapper = barcodeRowMapper;
  }





}