/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.mousetracking.Breeding;

public class BreedingRowMapper implements ParameterizedRowMapper<Breeding> {

	private DictionaryService dictionaryService;

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	public Breeding mapRow(ResultSet rs, int rowNum) throws SQLException {

		Breeding breeding = new Breeding();

		breeding.setId(rs.getLong("ID"));
		breeding.setStartDate(rs.getDate("START_DATE"));
		breeding.setEndDate(rs.getDate("END_DATE"));
		breeding.setCheckNumber(rs.getLong("CHECK_NUMBER")); if(rs.wasNull()) {breeding.setCheckNumber(null);}
		breeding.setEditedBy(rs.getString("EDITED_BY"));
		breeding.setEditDate(rs.getDate("EDIT_DATE"));
		breeding.setComments(rs.getString("COMMENTS"));
		breeding.setCreatorId(rs.getLong("CREATOR_ID")); if(rs.wasNull()) {breeding.setCreatorId(null);}
		breeding.setCreatedDate(rs.getDate("CREATED_DATE"));
		breeding.setMaleId(rs.getLong("MALE_ID")); if(rs.wasNull()) {breeding.setMaleId(null);}
		breeding.setFemaleId(rs.getLong("FEMALE_ID")); if(rs.wasNull()) {breeding.setFemaleId(null);}
		breeding.setBreedingNumber(rs.getInt("BREEDING_NUMBER"));
		breeding.setNamePrefix(rs.getString("NAME_PREFIX"));
		breeding.setOffspringColonyId(rs.getLong("OFFSPRING_COLONY_ID")); if(rs.wasNull()) {breeding.setOffspringColonyId(null);}
		breeding.setOffspringGeneration(rs.getString("OFFSPRING_GENERATION"));
		breeding.setPseudoBreeding(rs.getBoolean("PSEUDO_BREEDING"));
		breeding.setEmbryoTransferId(rs.getLong("EMBRYO_TRANSFER_ID")); if(rs.wasNull()) {breeding.setEmbryoTransferId(null);}
		breeding.setTimed(rs.getBoolean("TIMED_MATING"));
		breeding.setTimedEmbryoAge(rs.getFloat("TIMED_MATING_EMBRYO_AGE")); if(rs.wasNull()) {breeding.setTimedEmbryoAge(null);}
		breeding.setBreedingCategoryDictId(rs.getLong("BREEDING_CATEGORY_DICT_ID")); if(rs.wasNull()) {breeding.setBreedingCategoryDictId(null);}

		breeding.setBreedingCategory(dictionaryService.fetchEntry(DictionaryEnum.MOUSE_BREEDING_CATEGORY, breeding.getBreedingCategoryDictId()));

		return breeding;
	}
}
