/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.mousetracking.ChimericMouseData;

public class ChimericMouseDataRowMapper implements ParameterizedRowMapper<ChimericMouseData> {

	private DictionaryService dictionaryService;

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	public ChimericMouseData mapRow(ResultSet rs, int rowNum) throws SQLException {

		ChimericMouseData chimericMouseData = new ChimericMouseData();

		chimericMouseData.setId(rs.getLong("ID"));
		chimericMouseData.setMouseId(rs.getLong("MOUSE_ID"));
		if(rs.wasNull()) chimericMouseData.setMouseId(null);
		chimericMouseData.setPercentChimeric(rs.getInt("PERCENT_CHIMERIC"));
		if(rs.wasNull()) chimericMouseData.setPercentChimeric(null);
		chimericMouseData.setCreatorId(rs.getLong("CREATOR_ID"));
		if(rs.wasNull()) chimericMouseData.setCreatorId(null);
		chimericMouseData.setCreatedDate(rs.getDate("CREATED_DATE"));
		chimericMouseData.setEditedBy(rs.getString("EDITED_BY"));
		chimericMouseData.setEditDate(rs.getDate("EDIT_DATE"));
		chimericMouseData.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) chimericMouseData.setCheckNumber(null);
		chimericMouseData.setCellLineId(rs.getLong("CELL_LINE_ID"));
		if(rs.wasNull()) chimericMouseData.setCellLineId(null);
		chimericMouseData.setCellLineStrainDictId(rs.getLong("CELL_LINE_STRAIN_DICT_ID"));
		if(rs.wasNull()) chimericMouseData.setCellLineStrainDictId(null);
		chimericMouseData.setExpectedCoatColourDictId(rs.getLong("EXPECTED_COAT_COLOUR_DICT_ID"));
		if(rs.wasNull()) chimericMouseData.setExpectedCoatColourDictId(null);

		chimericMouseData.setCellLineStrain(dictionaryService.fetchEntry(DictionaryEnum.CELL_LINE_STRAIN, chimericMouseData.getCellLineStrainDictId()));
		chimericMouseData.setExpectedCoatColour(dictionaryService.fetchEntry(DictionaryEnum.MOUSE_COAT_COLOUR, chimericMouseData.getExpectedCoatColourDictId()));

		return chimericMouseData;
	}
}