/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.mousetracking.views.CohortListView;

public class CohortListViewRowMapper implements ParameterizedRowMapper<CohortListView> {

	public CohortListView mapRow(ResultSet rs, int rowNum) throws SQLException {
		CohortListView cohortListView = new CohortListView();

		cohortListView.setId(rs.getLong("ID"));
		cohortListView.setCohortName(rs.getString("COHORT_NAME"));
		cohortListView.setReason(rs.getString("REASON"));
		cohortListView.setTotalMice(rs.getInt("TOTAL_MICE"));
		cohortListView.setLiveMice(rs.getInt("LIVE_MICE"));
		cohortListView.setDeadMice(rs.getInt("DEAD_MICE"));
		cohortListView.setCreatorId(rs.getLong("CREATOR_ID"));
		if(rs.wasNull()) cohortListView.setCreatorId(null);
		cohortListView.setCreatedDate(rs.getTimestamp("CREATED_DATE"));
		cohortListView.setEditedBy(rs.getString("EDITED_BY"));
		cohortListView.setEditDate(rs.getTimestamp("EDIT_DATE"));
		cohortListView.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) cohortListView.setCheckNumber(null);
		cohortListView.setCreatorName(rs.getString("CREATOR_NAME"));
		cohortListView.setCohortTypeId(rs.getLong("COHORT_TYPE_ID"));
		cohortListView.setEndDate(rs.getDate("END_DATE"));
		if (rs.wasNull()) {
			cohortListView.setEndDate(null);
		}
		cohortListView.setPipeline(rs.getString("PIPELINE"));

		cohortListView.setCohortStrain(rs.getString("COHORT_STRAIN"));
		cohortListView.setCohortAlleleId(rs.getString("COHORT_ALLELE_ID"));

		return cohortListView;

	}
}