/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.mousetracking.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.mousetracking.CohortSet;

public class CohortSetRowMapper implements ParameterizedRowMapper<CohortSet> {

	private DictionaryService dictionaryService;

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	public CohortSet mapRow(ResultSet rs, int rowNum) throws SQLException {

		CohortSet cohortSet = new CohortSet();

		cohortSet.setId(rs.getLong("ID"));
		cohortSet.setAlleleId(rs.getLong("ALLELE_ID"));
		if(rs.wasNull()) cohortSet.setAlleleId(null);

		cohortSet.setCohortSetTypeDictId(rs.getLong("COHORT_SET_TYPE_DICT_ID"));
		if(rs.wasNull()) cohortSet.setCohortSetTypeDictId(null);

		cohortSet.setCreatedDate(rs.getDate("CREATED_DATE"));
		cohortSet.setCreatorId(rs.getLong("CREATOR_ID")); if(rs.wasNull()) cohortSet.setCreatorId(null);
		cohortSet.setEditDate(rs.getDate("EDIT_DATE"));
		cohortSet.setEditedBy(rs.getString("EDITED_BY"));

		cohortSet.setCohortSetTypeDict(
				dictionaryService.fetchEntry(DictionaryEnum.MOUSE_COHORT_SET_TYPE_DICT, cohortSet.getCohortSetTypeDictId()));

		return cohortSet;

	}
}