/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.mousetracking.views.LitterListView;

public class LitterListViewRowMapper implements ParameterizedRowMapper<LitterListView> {

	public LitterListView mapRow(ResultSet rs, int rowNum) throws SQLException {
		LitterListView view = new LitterListView();

		view.setId(rs.getLong("ID"));
		view.setLitterName(rs.getString("LITTER_NAME"));

		view.setFatherId(rs.getLong("FATHER_ID")); if(rs.wasNull()) view.setFatherId(null);
		view.setFatherName(rs.getString("FATHER_NAME"));
		view.setMotherId(rs.getLong("MOTHER_ID")); if(rs.wasNull()) view.setMotherId(null);
		view.setMotherName(rs.getString("MOTHER_NAME"));
		view.setMicroInjectionRequestId(rs.getLong("MICRO_INJECTION_REQUEST_ID")); if(rs.wasNull()) view.setMicroInjectionRequestId(null);
		view.setPlugDate(rs.getDate("PLUG_DATE"));
		view.setBirthDate(rs.getDate("BIRTH_DATE"));
		view.setNotPregnant(rs.getBoolean("NOT_PREGNANT"));
		view.setNumberPups(rs.getInt("NUMBER_PUPS"));	if(rs.wasNull()) view.setNumberPups(null);
		view.setNumberBorn(rs.getInt("NUMBER_BORN"));	if(rs.wasNull()) view.setNumberBorn(null);
		view.setNumberWeaned(rs.getInt("NUMBER_WEANED"));	if(rs.wasNull()) view.setNumberWeaned(null);
		view.setNumberWeanedFemale(rs.getInt("NUMBER_WEANED_FEMALE"));	if(rs.wasNull()) view.setNumberWeanedFemale(null);
		view.setNumberWeanedMale(rs.getInt("NUMBER_WEANED_MALE"));	if(rs.wasNull()) view.setNumberWeanedMale(null);
		view.setNumberEmbryos(rs.getInt("NUMBER_EMBRYOS")); if(rs.wasNull()) view.setNumberEmbryos(null);
		view.setNumberUsedOrDied(rs.getInt("NUMBER_USED")); if(rs.wasNull()) view.setNumberUsedOrDied(null);
		view.setComments(rs.getString("COMMENTS"));

		return view;
	}

}
