/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.dao.rowmappers;
import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.mousetracking.Litter;

public class LitterRowMapper implements ParameterizedRowMapper<Litter> {

	public Litter mapRow(ResultSet rs, int rowNum) throws SQLException {

		Litter litter = new Litter();

		litter.setId(rs.getLong("ID"));
		litter.setBreedingId(rs.getLong("BREEDING_ID")); if(rs.wasNull()) litter.setBreedingId(null);
		litter.setBirthDate(rs.getDate("BIRTH_DATE"));
		litter.setDueDate(rs.getDate("DUE_DATE"));
		litter.setComments(rs.getString("COMMENTS"));
		litter.setNumberBorn(rs.getInt("NUMBER_BORN")); if(rs.wasNull()) litter.setNumberBorn(null);
		litter.setNumberHarvested(rs.getInt("NUMBER_HARVESTED")); if(rs.wasNull()) litter.setNumberHarvested(null);
		litter.setCheckNumber(rs.getLong("CHECK_NUMBER")); if(rs.wasNull()) litter.setCheckNumber(null);
		litter.setEditedBy(rs.getString("EDITED_BY"));
		litter.setEditDate(rs.getDate("EDIT_DATE"));
		litter.setPlugDate(rs.getDate("PLUG_CHECK_DATE"));
		litter.setNamePrefix(rs.getString("NAME_PREFIX"));
		litter.setLitterNumber(rs.getInt("LITTER_NUMBER"));
		litter.setNotPregnant(rs.getBoolean("NOT_PREGNANT"));
		litter.setCreatedDate(rs.getDate("CREATED_DATE"));
		litter.setCreatorId(rs.getLong("CREATOR_ID"));

		return litter;

	}
}