/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.mousetracking.MouseHealth;

public class MouseHealthRowMapper implements ParameterizedRowMapper<MouseHealth> {

	DictionaryService dictionaryService;

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	public MouseHealth mapRow(ResultSet rs, int rowNum) throws SQLException {

		MouseHealth mouseHealth = new MouseHealth();

		mouseHealth.setId(rs.getLong("ID"));
		mouseHealth.setMouseId(rs.getLong("MOUSE_ID"));
		if(rs.wasNull()) mouseHealth.setMouseId(null);
		mouseHealth.setStartDate(rs.getDate("START_DATE"));
		mouseHealth.setEndDate(rs.getDate("END_DATE"));
		mouseHealth.setEditDate(rs.getDate("EDIT_DATE"));
		mouseHealth.setEditedBy(rs.getString("EDITED_BY"));
		mouseHealth.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		mouseHealth.setCreatorId(rs.getLong("CREATOR_ID"));
		if(rs.wasNull()) mouseHealth.setCreatorId(null);
		mouseHealth.setCreatedDate(rs.getDate("CREATED_DATE"));
		mouseHealth.setComments(rs.getString("COMMENTS"));
		mouseHealth.setStatus(rs.getString("STATUS"));
		mouseHealth.setBodySubsystemDictId(rs.getLong("BODY_SUBSYSTEM_DICT_ID"));
		if(rs.wasNull()) mouseHealth.setBodySubsystemDictId(null);
		mouseHealth.setBodySystemDictId(rs.getLong("BODY_SYSTEM_DICT_ID"));
		if(rs.wasNull()) mouseHealth.setBodySystemDictId(null);
		mouseHealth.setHealthConcernDictId(rs.getLong("HEALTH_CONCERN_DICT_ID"));
		if(rs.wasNull()) mouseHealth.setHealthConcernDictId(null);

		mouseHealth.setBodySubsystem(dictionaryService.fetchEntry(DictionaryEnum.MOUSE_BODY_SUBSYSTEM, mouseHealth.getBodySubsystemDictId()));
		mouseHealth.setBodySystem(dictionaryService.fetchEntry(DictionaryEnum.MOUSE_BODY_SYSTEM, mouseHealth.getBodySystemDictId()));
		mouseHealth.setHealthConcern(dictionaryService.fetchEntry(DictionaryEnum.MOUSE_HEALTH_CONCERN_DICT, mouseHealth.getHealthConcernDictId()));

		return mouseHealth;
	}
}