/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.mousetracking.views.MouseListView;

public class MouseListViewRowMapper implements ParameterizedRowMapper<MouseListView> {

	public MouseListView mapRow(ResultSet rs, int rowNum) throws SQLException {

		MouseListView mouseListView = new MouseListView();

		mouseListView.setId(rs.getLong("ID"));
		mouseListView.setLitterId(rs.getLong("LITTER_ID"));
		if(rs.wasNull()) mouseListView.setLitterId(null);
		mouseListView.setRfidTag(rs.getString("RFID_TAG"));
		mouseListView.setName(rs.getString("NAME"));
		mouseListView.setEditDate(rs.getDate("EDIT_DATE"));
		mouseListView.setCoatColourDictId(rs.getLong("COAT_COLOUR_DICT_ID"));
		if(rs.wasNull()) mouseListView.setCoatColourDictId(null);
		mouseListView.setCoatColour(rs.getString("COAT_COLOUR"));
		mouseListView.setEyeColourDictId(rs.getLong("EYE_COLOUR_DICT_ID"));
		if(rs.wasNull()) mouseListView.setEyeColourDictId(null);
		mouseListView.setEyeColour(rs.getString("EYE_COLOUR"));
		mouseListView.setEarmarkDictId(rs.getLong("EARMARK_DICT_ID"));
		if(rs.wasNull()) mouseListView.setEarmarkDictId(null);
		mouseListView.setEarmark(rs.getString("EARMARK"));
		mouseListView.setBirthDate(rs.getDate("BIRTH_DATE"));
		mouseListView.setDeathDate(rs.getDate("DEATH_DATE"));
		mouseListView.setCauseOfDeathDictId(rs.getLong("CAUSE_OF_DEATH_DICT_ID"));
		if(rs.wasNull()) mouseListView.setCauseOfDeathDictId(null);
		mouseListView.setCauseOfDeath(rs.getString("CAUSE_OF_DEATH"));
		mouseListView.setEditedBy(rs.getString("EDITED_BY"));
		mouseListView.setWeanDate(rs.getDate("WEAN_DATE"));
		mouseListView.setCageId(rs.getLong("CAGE_ID"));
		if(rs.wasNull()) mouseListView.setCageId(null);
		mouseListView.setCageName(rs.getString("CAGE_NAME"));
		mouseListView.setRackId(rs.getLong("RACK_ID"));
		if(rs.wasNull()) mouseListView.setRackId(null);
		mouseListView.setRackName(rs.getString("RACK_NAME"));
		mouseListView.setRoomId(rs.getLong("ROOM_ID"));
		if(rs.wasNull()) mouseListView.setRoomId(null);
		mouseListView.setRoomName(rs.getString("ROOM_NAME"));
		mouseListView.setCurrentOwnerId(rs.getLong("CURRENT_OWNER_ID"));
		if(rs.wasNull()) mouseListView.setCurrentOwnerId(null);
		mouseListView.setCurrentOwner(rs.getString("CURRENT_OWNER"));
		mouseListView.setCurrentProjectLicenceId(rs.getLong("CURRENT_PROJECT_LICENCE_ID"));
		if(rs.wasNull()) mouseListView.setCurrentProjectLicenceId(null);
		mouseListView.setCurrentProjectLicence(rs.getString("CURRENT_PROJECT_LICENCE"));
		mouseListView.setCurrentProtocolId(rs.getLong("CURRENT_PROTOCOL_ID"));
		if(rs.wasNull()) mouseListView.setCurrentProtocolId(null);
		mouseListView.setCurrentProtocolCode(rs.getString("CURRENT_PROTOCOL_CODE"));
		mouseListView.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) mouseListView.setCheckNumber(null);
		mouseListView.setGenderDictId(rs.getLong("GENDER_DICT_ID"));
		if(rs.wasNull()) mouseListView.setGenderDictId(null);
		mouseListView.setGender(rs.getString("GENDER"));
		mouseListView.setMouseStrainDictId(rs.getLong("MOUSE_STRAIN_DICT_ID"));
		if(rs.wasNull()) mouseListView.setMouseStrainDictId(null);
		mouseListView.setStrain(rs.getString("STRAIN"));
		mouseListView.setStatus(rs.getString("STATUS"));
		mouseListView.setCreatorId(rs.getLong("CREATOR_ID"));
		if(rs.wasNull()) mouseListView.setCreatorId(null);
		mouseListView.setCreatedDate(rs.getDate("CREATED_DATE"));
		mouseListView.setBarcode(rs.getString("BARCODE"));
		mouseListView.setComments(rs.getString("COMMENTS"));
		mouseListView.setNonBreeder(rs.getBoolean("IS_NON_BREEDER"));
		mouseListView.setSentinel(rs.getBoolean("IS_SENTINEL"));
		mouseListView.setGeneration(rs.getString("GENERATION"));
		mouseListView.setColonyInfoId(rs.getLong("COLONY_INFO_ID"));
		if(rs.wasNull()) mouseListView.setColonyInfoId(null);
		mouseListView.setColonyName(rs.getString("COLONY_NAME"));
		mouseListView.setColonyPrefix(rs.getString("COLONY_PREFIX"));
		mouseListView.setArrivalDate(rs.getDate("ARRIVAL_DATE"));
		mouseListView.setAgeInWeeks(rs.getFloat("AGE_IN_WEEKS"));
		if(rs.wasNull()) mouseListView.setAgeInWeeks(null);
		mouseListView.setAgeAtDeath(rs.getFloat("AGE_AT_DEATH"));
		if(rs.wasNull()) mouseListView.setAgeAtDeath(null);
		mouseListView.setCageBarcode(rs.getString("CAGE_BARCODE"));
		mouseListView.setBreedingName(rs.getString("BREEDING_NAME"));
		mouseListView.setGenotype(rs.getString("GENOTYPE"));
		mouseListView.setFatherName(rs.getString("FATHER_NAME"));
		mouseListView.setFatherGenotype(rs.getString("FATHER_GENOTYPE"));
		mouseListView.setMotherName(rs.getString("MOTHER_NAME"));
		mouseListView.setMotherGenotype(rs.getString("MOTHER_GENOTYPE"));

    mouseListView.setReservation(rs.getString("RESERVATION"));
    if (rs.wasNull()) mouseListView.setReservation(null);

		// used for multi-page record selection,
		//so these fields are not always present in the record set
		try {
			mouseListView.setRecordNumber(rs.getLong("RECORD_NUMBER"));
			mouseListView.setSelected(rs.getString("SELECTED"));
			//mouseListView.setSelectedValue(rs.getLong("SELECTED_VALUE"));
		}
		catch(SQLException e) {

		}

		return mouseListView;
	}
}