/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.mousetracking.Mouse;

public class MouseRowMapper implements ParameterizedRowMapper<Mouse> {

	private DictionaryService dictionaryService;

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	public Mouse mapRow(ResultSet rs, int rowNum) throws SQLException {

		Mouse mouse = new Mouse();

		// Primitive fields
		mouse.setId(rs.getLong("ID")); if(rs.wasNull()) mouse.setId(null);
		mouse.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		mouse.setName(rs.getString("NAME"));
		mouse.setRfidTag(rs.getString("RFID_TAG"));
		mouse.setBarcode(rs.getString("BARCODE"));
		mouse.setComments(rs.getString("COMMENTS"));
		mouse.setNonBreeder(rs.getBoolean("IS_NON_BREEDER"));
		mouse.setSentinel(rs.getBoolean("IS_SENTINEL"));
		mouse.setSterile(rs.getBoolean("IS_STERILE"));
		mouse.setGeneration(rs.getString("GENERATION"));
		mouse.setPooled(rs.getBoolean("IS_POOLED"));
		mouse.setStud(rs.getBoolean("IS_STUD"));
		mouse.setProvenStud(rs.getBoolean("IS_PROVEN_STUD"));

		// Dates
		mouse.setEditedBy(rs.getString("EDITED_BY"));
		mouse.setEditDate(rs.getDate("EDIT_DATE"));
		mouse.setWeanDate(rs.getDate("WEAN_DATE"));
		mouse.setBirthDate(rs.getDate("BIRTH_DATE"));
		mouse.setDeathDate(rs.getDate("DEATH_DATE"));
		mouse.setArrivalDate(rs.getDate("ARRIVAL_DATE"));
		mouse.setCreatedDate(rs.getDate("CREATED_DATE"));

		// Foreign Key IDs
		mouse.setCageId(rs.getLong("CAGE_ID")); if(rs.wasNull()) mouse.setCageId(null);
		mouse.setLitterId(rs.getLong("LITTER_ID"));	if(rs.wasNull()) mouse.setLitterId(null);
		mouse.setCurrentOwnerId(rs.getLong("CURRENT_OWNER_ID")); if(rs.wasNull()) mouse.setCurrentOwnerId(null);
		mouse.setColonyInfoId(rs.getLong("COLONY_INFO_ID")); if(rs.wasNull()) mouse.setColonyInfoId(null);
		mouse.setCreatorId(rs.getLong("CREATOR_ID")); if(rs.wasNull()) mouse.setCreatorId(null);

        // Dictionary IDs
		mouse.setCoatColourDictId(rs.getLong("COAT_COLOUR_DICT_ID")); if(rs.wasNull()) mouse.setCoatColourDictId(null);
		mouse.setEyeColourDictId(rs.getLong("EYE_COLOUR_DICT_ID")); if(rs.wasNull()) mouse.setEyeColourDictId(null);
		mouse.setEarmarkDictId(rs.getLong("EARMARK_DICT_ID")); if(rs.wasNull()) mouse.setEarmarkDictId(null);
		mouse.setCauseOfDeathDictId(rs.getLong("CAUSE_OF_DEATH_DICT_ID")); if(rs.wasNull()) mouse.setCauseOfDeathDictId(null);
		mouse.setGenderDictId(rs.getLong("GENDER_DICT_ID")); if(rs.wasNull()) mouse.setGenderDictId(null);
		mouse.setStrainDictId(rs.getLong("MOUSE_STRAIN_DICT_ID")); if(rs.wasNull()) mouse.setStrainDictId(null);

		// Dictionary Values
		mouse.setCoatColour(dictionaryService.fetchEntry(DictionaryEnum.MOUSE_COAT_COLOUR, mouse.getCoatColourDictId()));
		mouse.setEyeColour(dictionaryService.fetchEntry(DictionaryEnum.MOUSE_EYE_COLOUR_DICT, mouse.getEyeColourDictId()));
		mouse.setEarmark(dictionaryService.fetchEntry(DictionaryEnum.MOUSE_EARMARK_DICT, mouse.getEarmarkDictId()));
		mouse.setCauseOfDeath(dictionaryService.fetchEntry(DictionaryEnum.MOUSE_CAUSE_OF_DEATH, mouse.getCauseOfDeathDictId()));
		mouse.setGender(dictionaryService.fetchEntry(DictionaryEnum.MOUSE_GENDER_DICT, mouse.getGenderDictId()));
		mouse.setStrain(dictionaryService.fetchEntry(DictionaryEnum.MOUSE_STRAIN, mouse.getStrainDictId()));

		return mouse;
	}

}
