/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.mousetracking.MouseWeight;

public class MouseWeightRowMapper implements ParameterizedRowMapper<MouseWeight> {

	public MouseWeight mapRow(ResultSet rs, int rowNum) throws SQLException {

		MouseWeight mouseWeight = new MouseWeight();

		mouseWeight.setId(rs.getLong("ID"));
		mouseWeight.setMouseId(rs.getLong("MOUSE_ID"));
		if(rs.wasNull()) mouseWeight.setMouseId(null);
		mouseWeight.setWeightValue(rs.getFloat("WEIGHT_VALUE"));
		if(rs.wasNull()) mouseWeight.setWeightValue(null);
		mouseWeight.setWeightUnits(rs.getString("WEIGHT_UNITS"));
		mouseWeight.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) mouseWeight.setCheckNumber(null);
		mouseWeight.setCreatorId(rs.getLong("CREATOR_ID"));
		mouseWeight.setCreatedDate(rs.getTimestamp("CREATED_DATE"));
		mouseWeight.setEditedBy(rs.getString("EDITED_BY"));
		mouseWeight.setEditDate(rs.getTimestamp("EDIT_DATE"));
		mouseWeight.setSampleDate(rs.getDate("SAMPLE_DATE"));

		return mouseWeight;
	}
}