/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.mousetracking.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.mousetracking.StudBreeding;

public class StudBreedingRowMapper implements ParameterizedRowMapper<StudBreeding> {

	public StudBreeding mapRow(ResultSet rs, int rowNum) throws SQLException {

		StudBreeding studBreeding = new StudBreeding();

		studBreeding.setId(rs.getLong("ID"));
		studBreeding.setStartDateTime(rs.getTimestamp("START_DATE"));
		studBreeding.setPlugDateTime(rs.getTimestamp("PLUG_DATE"));
		studBreeding.setEndDate(rs.getDate("END_DATE"));
		studBreeding.setMaleId(rs.getLong("MALE_ID")); if(rs.wasNull()) {studBreeding.setMaleId(null);}
		studBreeding.setFemaleId(rs.getLong("FEMALE_ID")); if(rs.wasNull()) {studBreeding.setFemaleId(null);}
		studBreeding.setCreatorId(rs.getLong("CREATOR_ID")); if(rs.wasNull()) {studBreeding.setCreatorId(null);}
		studBreeding.setCreatedDate(rs.getDate("CREATED_DATE"));
		studBreeding.setEditedBy(rs.getString("EDITED_BY"));
		studBreeding.setEditDate(rs.getDate("EDIT_DATE"));
		studBreeding.setCheckNumber(rs.getLong("CHECK_NUMBER")); if(rs.wasNull()) {studBreeding.setCheckNumber(null);}
		studBreeding.setPseudoBreeding(rs.getBoolean("PSEUDO_BREEDING"));
		studBreeding.setSetupPersonId(rs.getLong("SETUP_PERSON_ID")); if(rs.wasNull()) {studBreeding.setSetupPersonId(null);}
		studBreeding.setCheckPersonId(rs.getLong("CHECK_PERSON_ID")); if(rs.wasNull()) {studBreeding.setCheckPersonId(null);}
		studBreeding.setTimedEmbryoAge(rs.getFloat("TIMED_MATING_EMBRYO_AGE")); if(rs.wasNull()) {studBreeding.setTimedEmbryoAge(null);}
		return studBreeding;
	}
}