/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.forms;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Date;

import org.apache.commons.collections15.FactoryUtils;
import org.apache.commons.collections15.ListUtils;

import uk.ac.sanger.mig.mousetracking.Mouse;

public class AddBreedingForm {

	private Mouse male;
	private Collection<Mouse> females;
	private String comments;
	private Long offspringColonyId;
	private String offspringColonyName;
	private String offspringColonyPrefix;
	private String offspringGeneration;
	private String barcode;
	private String barcodeDescription;
	private String barcodeType;
	private Long cageOrRackId;
	private Collection<Long> breedingNumbers;
	private Collection<String> namePrefixes;
	private boolean timed;
	private Float timedEmbryoAge;
	private Long breedingCategoryDictId;

	private Date startDate;

	public AddBreedingForm() {
		super();
		females = ListUtils.lazyList(new ArrayList<Mouse>(), FactoryUtils.instantiateFactory(Mouse.class));
		breedingNumbers = ListUtils.lazyList(new ArrayList<Long>(), FactoryUtils.instantiateFactory(Long.class, new Class[]{long.class}, new Object[]{0}));
		namePrefixes = ListUtils.lazyList(new ArrayList<String>(), FactoryUtils.instantiateFactory(String.class));
		male = new Mouse();
	}

	public Date getStartDate() {
		return startDate;
	}

	public void setStartDate(Date datePaired) {
		this.startDate = datePaired;
	}

	public Collection<Mouse> getFemales() {
		return females;
	}

	public void setFemales(Collection<Mouse> females) {
		this.females = females;
	}

	public Mouse getMale() {
		return male;
	}

	public void setMale(Mouse male) {
		this.male = male;
	}

	public String getComments() {
		return comments;
	}

	public void setComments(String comments) {
		this.comments = comments;
	}

	public Long getOffspringColonyId() {
		return offspringColonyId;
	}

	public void setOffspringColonyId(Long offspringColonyId) {
		this.offspringColonyId = offspringColonyId;
	}

	public String getOffspringColonyName() {
		return offspringColonyName;
	}

	public void setOffspringColonyName(String offspringColonyName) {
		this.offspringColonyName = offspringColonyName;
	}

	public String getBarcode() {
		return barcode;
	}

	public void setBarcode(String barcode) {
		this.barcode = barcode;
	}

	public String getBarcodeDescription() {
		return barcodeDescription;
	}

	public void setBarcodeDescription(String barcodeDescription) {
		this.barcodeDescription = barcodeDescription;
	}

	public String getBarcodeType() {
		return barcodeType;
	}

	public void setBarcodeType(String barcodeType) {
		this.barcodeType = barcodeType;
	}

	public Long getCageOrRackId() {
		return cageOrRackId;
	}

	public void setCageOrRackId(Long cageOrRackId) {
		this.cageOrRackId = cageOrRackId;
	}

	public String getOffspringColonyPrefix() {
		return offspringColonyPrefix;
	}

	public void setOffspringColonyPrefix(String offspringColonyPrefix) {
		this.offspringColonyPrefix = offspringColonyPrefix;
	}

	public Collection<Long> getBreedingNumbers() {
		return breedingNumbers;
	}

	public void setBreedingNumbers(Collection<Long> breedingNumbers) {
		this.breedingNumbers = breedingNumbers;
	}

	public Collection<String> getNamePrefixes() {
		return namePrefixes;
	}

	public void setNamePrefixes(Collection<String> namePrefixes) {
		this.namePrefixes = namePrefixes;
	}

	public String getOffspringGeneration() {
		return offspringGeneration;
	}

	public void setOffspringGeneration(String offspringGeneration) {
		this.offspringGeneration = offspringGeneration;
	}

	public boolean isTimed() {
		return timed;
	}

	public void setTimed(boolean timed) {
		this.timed = timed;
	}

	public Float getTimedEmbryoAge() {
		return timedEmbryoAge;
	}

	public void setTimedEmbryoAge(Float timedEmbryoAge) {
		this.timedEmbryoAge = timedEmbryoAge;
	}

	public Long getBreedingCategoryDictId() {
		return breedingCategoryDictId;
	}

	public void setBreedingCategoryDictId(Long breedingCategoryDictId) {
		this.breedingCategoryDictId = breedingCategoryDictId;
	}
}
