/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.forms;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.forms.ValidatableForm;

public class BulkUpdateMiceForm extends ValidatableForm {

	private Collection<Long> mouseIds;
	private ProcedureSubform procedureSubform;
	private Long colonyInfoId;
	private String colonyPrefix;
	private String colonyName;
	private Long currentOwnerId;
	private String currentOwnerDisplayText;
	private Boolean provenStud;
	private Boolean stud;
	private Boolean sterile;
	private String comments;
	private boolean overwriteComments;
	private boolean mouseAlleleQcLock;

	public BulkUpdateMiceForm() {
		initMice();
		procedureSubform = new ProcedureSubform();
	}
	public Collection<Long> getMouseIds() {
		return mouseIds;
	}
	public void setMouseIds(Collection<Long> mouseIds) {
		this.mouseIds = mouseIds;
	}
	public ProcedureSubform getProcedureSubform() {
		return procedureSubform;
	}
	public void setProcedureSubform(ProcedureSubform procedureSubform) {
		this.procedureSubform = procedureSubform;
	}

	public Long getColonyInfoId() {
		return colonyInfoId;
	}
	public void setColonyInfoId(Long colonyInfoId) {
		this.colonyInfoId = colonyInfoId;
	}
	public String getColonyName() {
		return colonyName;
	}
	public void setColonyName(String colonyName) {
		this.colonyName = colonyName;
	}
	public String getColonyPrefix() {
		return colonyPrefix;
	}
	public void setColonyPrefix(String colonyPrefix) {
		this.colonyPrefix = colonyPrefix;
	}
	public String getCurrentOwnerDisplayText() {
		return currentOwnerDisplayText;
	}
	public void setCurrentOwnerDisplayText(String ownerFullname) {
		this.currentOwnerDisplayText = ownerFullname;
	}
	public Long getCurrentOwnerId() {
		return currentOwnerId;
	}
	public void setCurrentOwnerId(Long ownerPersonId) {
		this.currentOwnerId = ownerPersonId;
	}
	private void initMice() {
		mouseIds = new ArrayList<Long>();
	}
	public Boolean getProvenStud() {
		return provenStud;
	}
	public void setProvenStud(Boolean provenStud) {
		this.provenStud = provenStud;
	}
	public Boolean getSterile() {
		return sterile;
	}
	public void setSterile(Boolean sterile) {
		this.sterile = sterile;
	}
	public Boolean getStud() {
		return stud;
	}
	public void setStud(Boolean stud) {
		this.stud = stud;
	}

	public String getComments() {
		return comments;
	}
	public void setComments(String comments) {
		this.comments = comments;
	}
	public boolean isOverwriteComments() {
		return overwriteComments;
	}
	public void setOverwriteComments(boolean overwriteComments) {
		this.overwriteComments = overwriteComments;
	}
	public boolean isMinimumOneFieldSet() {
		return (
				colonyInfoId != null ||
				currentOwnerId != null ||
				procedureSubform.getProcedureId() != null ||
				stud != null ||
				provenStud != null ||
				sterile != null ||
				comments != null ||
				mouseAlleleQcLock == true
		);
	}
	public boolean isMouseAlleleQcLock() {
		return mouseAlleleQcLock;
	}
	public void setMouseAlleleQcLock(boolean mouseAlleleQcLock) {
		this.mouseAlleleQcLock = mouseAlleleQcLock;
	}
}