/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.forms;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.mousetracking.Cage;
import uk.ac.sanger.mig.mousetracking.Cohort;
import uk.ac.sanger.mig.mousetracking.Mouse;

public class EditMiceForm {

	private Cohort cohort;
	private Cage cage;
	private Mouse defaultMouseValues;
	private ProcedureSubform procedureSubform;
	private boolean harmfulMutant;

	public Collection<Mouse> getMice() {
		if(cage == null && cohort == null) {
			return new ArrayList<Mouse>();
		}
		else if(cage == null) {
			return cohort.getMice();
		}
		else {
			return cage.getContents();
		}
	}

	public Cage getCage() {
		return cage;
	}

	public void setCage(Cage cage) {
		this.cage = cage;
	}

	public Mouse getDefaultMouseValues() {
		return defaultMouseValues;
	}

	public void setDefaultMouseValues(Mouse defaultMouseValues) {
		this.defaultMouseValues = defaultMouseValues;
	}

	public boolean hasHarmfulMutant() {
		return harmfulMutant;
	}

	public void setHarmfulMutant(boolean harmfulMutant) {
		this.harmfulMutant = harmfulMutant;
	}

	public Cohort getCohort() {
		return cohort;
	}

	public void setCohort(Cohort cohort) {
		this.cohort = cohort;
	}

	public String getDescription() {
		if(cage == null && cohort == null) {
			return null;
		}
		else if (cage == null || cage.getCageHeader() == null) {
			return cohort.getCohortName();
		}
		else {
			return cage.getCageHeader().getLocationDescription();
		}
	}

	public ProcedureSubform getProcedureSubform() {
		return procedureSubform;
	}

	public void setProcedureSubform(ProcedureSubform procedureSubform) {
		this.procedureSubform = procedureSubform;
	}

	/**
	 * return the cage and rack barcodes if present (for display purposes)
	 * @return
	 */
	public String getBarcodes() {
		String barcodes = "";
		if(cage != null) {
			barcodes += cage.getBarcode() + " " + cage.getRack().getBarcode();
		}
		return barcodes;
	}
}
