/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.forms;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

import uk.ac.sanger.mig.histology.forms.MouseCheckbox;
import uk.ac.sanger.mig.mousetracking.Cohort;
import uk.ac.sanger.mig.mousetracking.Mouse;
import uk.ac.sanger.mig.mousetracking.Room;

public class ManageCohortForm {

	private List<MouseCheckbox> miceToSelectFrom = new ArrayList<MouseCheckbox>();
	private List<MouseCheckbox> miceInCohort = new ArrayList<MouseCheckbox>();
	private Cohort cohort;

	private BarcodeForm barcodeForm;
	private boolean newCohort;
	public Room room = new Room();
	public Cohort chooserCohort = new Cohort();

	private boolean isDescriptionRequired;
	private boolean isPipelineRequired;

	public BarcodeForm getBarcodeForm() {
		return barcodeForm;
	}

	public void setBarcodeForm(BarcodeForm barcodeForm) {
		this.barcodeForm = barcodeForm;
	}

	public Cohort getCohort() {
		return cohort;
	}

	public void setCohort(Cohort cohort) {
		this.cohort = cohort;

		miceInCohort = new ArrayList<MouseCheckbox>();

		if (cohort.getMice() != null) {
			for(Mouse m : cohort.getMice()) {
				miceInCohort.add( new MouseCheckbox(m, false) );
			}
		}
	}

	public boolean isNewCohort() {
		return newCohort;
	}

	public void setNewCohort(boolean newCohort) {
		this.newCohort = newCohort;
	}

	public Cohort getChooserCohort() {
		return chooserCohort;
	}

	public void setChooserCohort(Cohort chooserCohort) {
		this.chooserCohort = chooserCohort;
	}

	public Room getRoom() {
		return room;
	}

	public void setRoom(Room room) {
		this.room = room;
	}

	public void addSelectableMice(Collection<Mouse> miceToAdd) {
		if (miceToSelectFrom == null) {
			miceToSelectFrom = new ArrayList<MouseCheckbox>();
		}

		for (Mouse mouse : miceToAdd) {
			if (!isMouseAlreadyListed(mouse)) {
				// mice will default to selected
				miceToSelectFrom.add( new MouseCheckbox(mouse,true));
			}
		}
	}

	/**
	 * update the list of mice in the cohort, so that the checked mice that are
	 * currently in the cohort are removed, and the checked mice that are
	 * available are added
	 *
	 */
	public void updateMice() {

		Iterator<MouseCheckbox> addIter = miceToSelectFrom.iterator();
		while (addIter.hasNext()) {
			MouseCheckbox mc = addIter.next();

			if (mc.isChecked()) {
				mc.setChecked(false);
				addIter.remove();
				miceInCohort.add(mc);
			}
		}

		Collection<Mouse> mice = new ArrayList<Mouse>(miceInCohort.size());

		Iterator<MouseCheckbox> removeIter = miceInCohort.iterator();
		while (removeIter.hasNext()) {
			MouseCheckbox mc = removeIter.next();
			if (mc.isChecked()) {
				removeIter.remove();
				// move it over to the addable list
				mc.setChecked(false);
				miceToSelectFrom.add(mc);
			}
			else {
				mice.add(mc.getMouse());
			}
		}


		cohort.setMice(mice);
	}

	public List<MouseCheckbox> getMiceInCohort() {
		return miceInCohort;
	}

	public void setMiceInCohort(List<MouseCheckbox> miceInCohort) {
		this.miceInCohort = miceInCohort;
	}

	public List<MouseCheckbox> getMiceToSelectFrom() {
		return miceToSelectFrom;
	}

	public void setMiceToSelectFrom(List<MouseCheckbox> miceToSelectFrom) {
		this.miceToSelectFrom = miceToSelectFrom;
	}

	private boolean isMouseAlreadyListed(Mouse m) {
		boolean isDuplicate = false;

		if (miceToSelectFrom != null){
			isDuplicate = isMouseInCollection(m,  miceToSelectFrom);
		}
		if (miceInCohort != null && !isDuplicate) {
			isDuplicate = isMouseInCollection(m, miceInCohort);
		}

		return isDuplicate;
	}

	private boolean isMouseInCollection(Mouse m, Collection<MouseCheckbox> mouseCheckboxes) {
		for (MouseCheckbox mc : mouseCheckboxes) {
			if (mc.getMouse().equals(m)) {
				return true;
			}
		}
		return false;
	}

	public boolean isDescriptionRequired() {
		return isDescriptionRequired;
	}

	public void setDescriptionRequired(boolean isDescriptionRequired) {
		this.isDescriptionRequired = isDescriptionRequired;
	}

	public boolean isPipelineRequired() {
		return isPipelineRequired;
	}

	public void setPipelineRequired(boolean isPipelineRequired) {
		this.isPipelineRequired = isPipelineRequired;
	}

}
