/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.forms;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Date;

import uk.ac.sanger.mig.common.forms.ValidatableForm;
import uk.ac.sanger.mig.mousetracking.Cage;
import uk.ac.sanger.mig.mousetracking.BarcodedObject.BarcodeType;

/**
 * Use this form to move mice from a cage (or cages) into one group cage or individual cages.
 */
public class MoveMouseForm extends ValidatableForm {

	private Collection<Cage> cages = new ArrayList<Cage>();
	private Long[] movingMouseIds;
	private Long destinationId;
	private String destinationBarcode;
	private String destinationBarcodeDescription;
	private BarcodeType destinationBarcodeType;
	private String originCageBarcode;
	private Long originCageId;
	private String originCageBarcodeDescription;
	private boolean singleHousing;
	private boolean stud;
	private boolean femalePool;
	private boolean displayStudField;
	private boolean displayFemalePool;
	private Date femalePoolDate;
	private int totalScannedMice;

	/**
	 * Return the list of IDs for the mice being moved.
	 * @return
	 */
	public Long[] getMovingMouseIds() {
		return movingMouseIds;
	}
	public void setMovingMouseIds(Long[] destinationMouseIds) {
		this.movingMouseIds = destinationMouseIds;
	}
	public String getOriginCageBarcode() {
		return originCageBarcode;
	}
	public void setOriginCageBarcode(String originCageBarcode) {
		this.originCageBarcode = originCageBarcode;
	}
	public String getOriginCageBarcodeDescription() {
		return originCageBarcodeDescription;
	}
	public void setOriginCageBarcodeDescription(String originCageBarcodeDescription) {
		this.originCageBarcodeDescription = originCageBarcodeDescription;
	}
	public Long getOriginCageId() {
		return originCageId;
	}
	public void setOriginCageId(Long originCageId) {
		this.originCageId = originCageId;
	}
	public Collection<Cage> getCages() {
		return cages;
	}
	public void setCages(Collection<Cage> cages) {
		this.cages = cages;
	}
	public String getDestinationBarcode() {
		return destinationBarcode;
	}
	public void setDestinationBarcode(String destinationBarcode) {
		this.destinationBarcode = destinationBarcode;
	}
	public String getDestinationBarcodeDescription() {
		return destinationBarcodeDescription;
	}
	public void setDestinationBarcodeDescription(
			String destinationBarcodeDescription) {
		this.destinationBarcodeDescription = destinationBarcodeDescription;
	}
	public BarcodeType getDestinationBarcodeType() {
		return destinationBarcodeType;
	}
	public void setDestinationBarcodeType(BarcodeType destinationBarcodeType) {
		this.destinationBarcodeType = destinationBarcodeType;
	}
	public Long getDestinationId() {
		return destinationId;
	}
	public void setDestinationId(Long destinationId) {
		this.destinationId = destinationId;
	}
	public boolean isStud() {
		return stud;
	}
	public void setStud(boolean singlyHoused) {
		this.stud = singlyHoused;
	}
	/**
	 * If the form contains one cage and all the mice in the cage are selected to be moved
	 * without being singly housed,
	 * then the whole cage can be moved to a new rack rather than creating a new cage and
	 * moving the mice into it.
	 *
	 * @return true if the cage can be moved rather than the mice.
	 */
	public boolean canMoveAsCage() {
		boolean canMoveAsCage = false;
		if(cages != null && cages.size() == 1 && !isStud() && !isFemalePool()) {
			Cage testCage = cages.iterator().next();
			if(getDestinationBarcodeType().equals("RACK") && testCage.getContents() != null && movingMouseIds != null && testCage.getContents().size() == movingMouseIds.length) {
				canMoveAsCage = true;
			}
		}
		return canMoveAsCage;
	}
	public boolean isDisplayStudField() {
		return displayStudField;
	}
	public void setDisplayStudField(boolean displaySinglyHousedStudField) {
		this.displayStudField = displaySinglyHousedStudField;
	}

	/**
	 * If true, each mouse should be housed in an individual new cage.
	 * @return true if each mouse should be individually housed, otherwise false.
	 */
	public boolean isSingleHousing() {
		return singleHousing;
	}
	public void setSingleHousing(boolean singleHousing) {
		this.singleHousing = singleHousing;
	}
	public boolean isDisplayFemalePool() {
		return displayFemalePool;
	}
	public void setDisplayFemalePool(boolean displayFemalePool) {
		this.displayFemalePool = displayFemalePool;
	}
	public boolean isFemalePool() {
		return femalePool;
	}
	public void setFemalePool(boolean femalePool) {
		this.femalePool = femalePool;
	}
	public Date getFemalePoolDate() {
		return femalePoolDate;
	}
	public void setFemalePoolDate(Date femalePoolDate) {
		this.femalePoolDate = femalePoolDate;
	}
	public int getTotalScannedMice() {
		return totalScannedMice;
	}
	public void setTotalScannedMice(int totalScannedMice) {
		this.totalScannedMice = totalScannedMice;
	}

}
