/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.services;

import java.util.Collection;
import java.util.Date;
import java.util.Map;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.services.CommonServices;
import uk.ac.sanger.mig.mousetracking.Cage;
import uk.ac.sanger.mig.mousetracking.forms.RegisterCagesForm;
import uk.ac.sanger.mig.personnel.Person;

public interface CageService extends CommonServices<Cage> {

	public Cage fetchForViewById(Long cageId);

	public Collection<Cage> fetchByLitterId(Long litterId, ComponentMap requiredComponents);

	public Cage fetchByBarcode(String barcode, ComponentMap requiredComponents);

	public Cage fetchPoolCage(Long colonyId, Date birthDate, ComponentMap requiredComponents);

	public Collection<Cage> fetchByRackId(Long rackId, ComponentMap requiredComponents);

	public void moveCagesToAuditRack(Long roomId, Person user);

	/**
	 * Clean all cages in a rack in one go
	 *
	 * @param rackId
	 * @param user
	 */
	public void cleanCagesByRack(Long rackId, Person user);

	/**
	 * Track the cleaning of a cage and return the number of mice culled in the process
	 * @param cage
	 * @param user
	 * @return
	 */
	public int clean(Cage cage, Person user);

	/**
	 * Create (and save) a new cage in a given rack.
	 * The cage will have a number automatically generated based on the available numbers
	 * in the rack.
	 * @param rackId - the rack where the new cage will be generated
	 * @param user - the person creating the new cage
	 * @return Long ID of the newly created cage.
	 */
	public Long createInRack(Long rackId, Person user);

	public Collection<Cage> fetchInUseByRackId(Long rackId, ComponentMap requiredComponents);

	public int getTotalCagesByRoomId(Long roomId);

	public int getTotalCagesByRackId(Long rackId);

	public void inflateCageComponents(Cage cage);

	public CageType fetchCageType(Long cageId);

	public Map<String, Object> registerCagesInRack(RegisterCagesForm form, Person user);
}
