/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.services;

import org.springframework.transaction.annotation.Transactional;

import uk.ac.sanger.mig.common.AbstractServiceImpl2;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.mirequest.services.CellLineService;
import uk.ac.sanger.mig.mousetracking.ChimericMouseData;
import uk.ac.sanger.mig.mousetracking.dao.ChimericMouseDataDao;
import uk.ac.sanger.mig.personnel.Person;

public class ChimericMouseDataServiceImpl extends AbstractServiceImpl2<ChimericMouseData, ChimericMouseDataDao> implements ChimericMouseDataService {

	private CellLineService cellLineService;

	public void setCellLineService(CellLineService cellLineService) {
		this.cellLineService = cellLineService;
	}

	public ChimericMouseData fetchByMouseId(Long mouseId, ComponentMap requiredComponents) {
		ChimericMouseData chimera = getPrimaryDao().fetchByMouseId(mouseId);

		if(chimera != null) {
			attachComponents(chimera, requiredComponents);
		}

		return chimera;
	}

	@Transactional
	public void storeForMouse(Long mouseId, ChimericMouseData chimericMouseData, Person person) {
		if(chimericMouseData == null) {
			throw new RuntimeException("Cannot save a null chimericMouseData");
		}

		// delete record if existing record and percent is null
		if(chimericMouseData.getPercentChimeric() == null) {
			if(chimericMouseData.getId() != null) {
				getPrimaryDao().delete(chimericMouseData, person);
			}
		}
		else {
			chimericMouseData.setMouseId(mouseId);
			store(chimericMouseData, person);
		}
	}

	@Override
	protected void attachComponents(ChimericMouseData chimericMouseData, ComponentMap requiredComponents) {
		if(chimericMouseData == null) {
			throw new RuntimeException("Cannot attach components to null chimericMouseData");
		}

		// always attach cell line data if available
		if(chimericMouseData.getCellLineId() != null) {
			chimericMouseData.setCellLine(cellLineService.fetchById(chimericMouseData.getCellLineId(),null));
		}
	}
}

