/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.services;

import java.util.Collection;
import java.util.Set;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.Pair;
import uk.ac.sanger.mig.common.services.CommonServices;
import uk.ac.sanger.mig.mousetracking.Cohort;
import uk.ac.sanger.mig.mousetracking.CohortSearchBean;
import uk.ac.sanger.mig.mousetracking.Mouse;
import uk.ac.sanger.mig.mousetracking.views.CohortListView;
import uk.ac.sanger.mig.personnel.Person;

public interface CohortService extends CommonServices<Cohort> {

	public static final Long COHORT_TYPE_PHENOTYPING = 1L;
	public static final Long COHORT_TYPE_HISTOLOGY = 2L;
	public static final Long COHORT_TYPE_STUD_BANK = 3L;
	public static final Long COHORT_TYPE_GENOTYPING = 4L;
	public static final Long COHORT_TYPE_CULL_LIST = 5L;

	public Collection<Cohort> fetchByMouseId(Long mouseId, ComponentMap requiredComponents);

	public void inflateCohortComponents(Cohort cohort);

	public Cohort fetchByName(String cohortName, ComponentMap requiredComponents);

	/**
	 * Take a collection of mice and compare to the existing mice in a cohort.
	 * Mice in the new list will be added if not already in the cohort.
	 * Mice in the new list which are already in the cohort will be ignored.
	 * Mice not in the new list but in the cohort will be removed from the cohort.
	 *
	 * @param cohort cohort to be updated.
	 * @param newMice definitive Collection of mice that the cohort should contain after updating
	 * @param user
	 * @return a Pair of Sets of unique mouse ids.
	 * The first Set is mice that have been newly added to the cohort.
	 * The second Set is mice that have been removed from the cohort.
	 */
	public Pair<Set<Long>, Set<Long>> manageCohort(Cohort cohort, Collection<Mouse> newMice, Person user);

	public Collection<Cohort> fetchForLookup(Long typeId);

	public Collection<Cohort> fetchForLookup(Long typeId, Long pipelineId);

	public Collection<CohortListView> search(CohortSearchBean bean);

	public CohortListView fetchListViewById(Long id);
}