/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.mousetracking.services;

import java.util.Collection;
import uk.ac.sanger.mig.common.services.CommonServices;
import uk.ac.sanger.mig.mousetracking.CohortSetElement;
import uk.ac.sanger.mig.mousetracking.views.CohortSetElementListView;
import uk.ac.sanger.mig.personnel.Person;

public interface CohortSetElementService extends CommonServices<CohortSetElement>{


	/**
	 * @param cohortSetId
	 * @return an empty list if there is no cohort set elements
	 *         otherwise a collection of cohort set elements for this cohort set
	 */
	public Collection<CohortSetElementListView> fetchByCohortSetId(Long cohortSetId);

	/**
	 * @param cohortId
	 * 		- cohort ID
	 * @return
	 *        null if no cohort set element returned, otherwise the CohorSetElement
	 */
	public CohortSetElement fetchByCohortAndSetId(Long cohortId, Long setId);
	public void delete(CohortSetElement cohortSetElement, Person person);


}