/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.mousetracking.services;

import java.util.Collection;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.AbstractServiceImpl2;
import uk.ac.sanger.mig.mousetracking.Cohort;
import uk.ac.sanger.mig.mousetracking.CohortSet;
import uk.ac.sanger.mig.mousetracking.CohortSetElement;
import uk.ac.sanger.mig.mousetracking.dao.CohortSetElementDao;
import uk.ac.sanger.mig.mousetracking.views.CohortSetElementListView;
import uk.ac.sanger.mig.personnel.Person;

public class CohortSetElementServiceImpl extends AbstractServiceImpl2<CohortSetElement,CohortSetElementDao> implements CohortSetElementService {


	private CohortService cohortService;
	private CohortSetService cohortSetService;

	public void setCohortService(CohortService cohortService) {
		this.cohortService = cohortService;
	}

	public void setCohortSetService(CohortSetService cohortSetService) {
		this.cohortSetService = cohortSetService;
	}

	public Collection<CohortSetElementListView> fetchByCohortSetId(Long cohortSetId) {
		Collection<CohortSetElementListView>  cohortSetElements =
			getPrimaryDao().fetchByCohortSetId(cohortSetId);

		return cohortSetElements;
	}

	public CohortSetElement fetchByCohortAndSetId(Long cohortSetId, Long setId) {
		CohortSetElement cohortSetElement = getPrimaryDao().fetchByCohortAndSetId(cohortSetId, setId);

		return cohortSetElement;
	}

	public void delete(CohortSetElement cohortSetElement, Person person){
         getPrimaryDao().delete(cohortSetElement, person);
	}


	@Override
	protected void attachComponents(CohortSetElement cohortSetElement, ComponentMap requiredComponents) {
		if(cohortSetElement == null) {
			throw new RuntimeException("Cannot attach components to null cohortSetElement");
		}

		boolean fetchAll = false;

		if(requiredComponents != null) {

			if(requiredComponents.containsKey(CohortSetElement.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}

			if(requiredComponents.containsKey(CohortSetElement.Component.COHORT)||fetchAll){
				cohortSetElement.setCohort(
						fetchCohort(cohortSetElement, requiredComponents.get(CohortSetElement.Component.COHORT)));
			}

			if(requiredComponents.containsKey(CohortSetElement.Component.COHORT_SET)||fetchAll){
				cohortSetElement.setCohortSet(
						fetchCohortSet(cohortSetElement, requiredComponents.get(CohortSetElement.Component.COHORT_SET)));
			}
		}
	}

	private CohortSet fetchCohortSet(CohortSetElement cohortSetElement, ComponentMap map) {
		return cohortSetService.fetchById(cohortSetElement.getSetId(), map);
	}

	private Cohort fetchCohort(CohortSetElement cohortSetElement, ComponentMap map) {

		return cohortService.fetchById(cohortSetElement.getCohortId(), map);
	}


}
