/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.services;

import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.database.TableMetadataEnum;
import uk.ac.sanger.mig.mousetracking.EnvironmentReport;
import uk.ac.sanger.mig.mousetracking.EnvironmentReportSearchBean;
import uk.ac.sanger.mig.mousetracking.dao.EnvironmentReportDao;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.personnel.services.PersonService;
import uk.ac.sanger.mig.tecniplast.services.AirHandlingUnitService;

public class EnvironmentReportServiceImpl extends AbstractServiceImpl<EnvironmentReport> implements EnvironmentReportService {
	
	private EnvironmentReportDao environmentReportDao;
	private PersonService personService; 
	private RoomService roomService; 
	private RackService rackService; 
	private CageService cageService; 
	private AirHandlingUnitService airHandlingUnitService;
	
	

	public void setAirHandlingUnitService(
			AirHandlingUnitService airHandlingUnitService) {
		this.airHandlingUnitService = airHandlingUnitService;
	}


	public void setCageService(CageService cageService) {
		this.cageService = cageService;
	}


	public void setRackService(RackService rackService) {
		this.rackService = rackService;
	}


	public void setRoomService(RoomService roomService) {
		this.roomService = roomService;
	}


	public void setPersonService(PersonService personService) {
		this.personService = personService;
	}


	public void setEnvironmentReportDao(EnvironmentReportDao environmentReportDao) {
		this.environmentReportDao = environmentReportDao;
	}


	public Long storeAuthenticated(EnvironmentReport environmentReport, Person user) {
		if(environmentReport == null) {
			throw new RuntimeException("Cannot save a null environmentReport");
		}
		
		return environmentReportDao.store(environmentReport, user);
	}
	
	public EnvironmentReport fetchById(Long environmentReportId, ComponentMap requiredComponents) {
		EnvironmentReport environmentReport = environmentReportDao.fetchById(environmentReportId);
		
		if(environmentReport != null)
			attachComponents(environmentReport, requiredComponents);
		
		return environmentReport;
	}

	public Collection<EnvironmentReport> fetchPreviousReports(Long id, Long currentId, ComponentMap requiredComponents) {
		Collection<EnvironmentReport> environmentReport = environmentReportDao.fetchPreviousReports(id,currentId);
		
		if(environmentReport != null)
			attachComponents(environmentReport, requiredComponents);
		
		return environmentReport;
	}
	
	@Override
	protected void attachComponents(EnvironmentReport environmentReport, ComponentMap requiredComponents) {
		if(environmentReport == null) {
			throw new RuntimeException("Cannot attach components to null environmentReport");
		}		
		
		boolean fetchAll = false;
		
		if(requiredComponents != null) {
			
			if(requiredComponents.containsKey(EnvironmentReport.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}
			if(fetchAll || requiredComponents.containsKey(EnvironmentReport.Component.REPORTED_BY)) {
				environmentReport.setReporter(fetchReportedBy(environmentReport.getCreatorId()));
			}
			if(fetchAll || requiredComponents.containsKey(EnvironmentReport.Component.REPORTED_ITEM_NAME)) {
				environmentReport.setReportedItemName(fetchReportedItemName(environmentReport.getForeignKeyId(),environmentReport.getForeignTableName()));
			}
			
		}
	}

	private Person fetchReportedBy(Long creatorId) {
		return personService.fetchById(creatorId, null);
	}
	
	private String fetchReportedItemName(Long foreignKeyId, TableMetadataEnum tableMetadata) {
		// Get name of the item reported.
		if(TableMetadataEnum.MTS_ROOM == tableMetadata) {
			return roomService.fetchById(foreignKeyId, null).getRoomNumber();
		}
		else if (TableMetadataEnum.MTS_RACK == tableMetadata) {
			return rackService.fetchById(foreignKeyId, null).getBarcode();
		}
		else if(TableMetadataEnum.MTS_CAGE == tableMetadata) {
			return cageService.fetchById(foreignKeyId, null).getBarcode();
		}
		else if(TableMetadataEnum.MTS_AIR_HANDLING_UNIT == tableMetadata) {
			return airHandlingUnitService.fetchById(foreignKeyId, null).getName();
		}else{
			return null;
		}

	}

	public Collection<EnvironmentReport> search(EnvironmentReportSearchBean environmentReportSearchBean, ComponentMap requiredComponents) {

		Collection<EnvironmentReport>  reports = environmentReportDao.search(environmentReportSearchBean);
		if(reports != null)
			attachComponents(reports, requiredComponents);
		
		return reports;
	}
	
}
								