package uk.ac.sanger.mig.mousetracking.services;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.histology.services.NecropsyService;
import uk.ac.sanger.mig.mousetracking.ExperimentData;

public class ExperimentDataServiceImpl extends AbstractServiceImpl<ExperimentData> implements ExperimentDataService {

	private MouseService mouseService;
	private MouseWeightService mouseWeightService;
	private MouseProcedureService mouseProcedureService;
	private NecropsyService necropsyService;
	
	public void setNecropsyService(NecropsyService necropsyService) {
    this.necropsyService = necropsyService;
  }

  public MouseService getMouseService() {
		return mouseService;
	}

	public void setMouseService(MouseService mouseService) {
		this.mouseService = mouseService;
	}

	public MouseWeightService getMouseWeightService() {
		return mouseWeightService;
	}

	public void setMouseWeightService(MouseWeightService mouseWeightService) {
		this.mouseWeightService = mouseWeightService;
	}

	public MouseProcedureService getMouseProcedureService() {
		return mouseProcedureService;
	}

	public void setMouseProcedureService(MouseProcedureService mouseProcedureService) {
		this.mouseProcedureService = mouseProcedureService;
	}

	public ExperimentData fetchByMouseId(Long mouseId, ComponentMap requiredComponents) {
		ExperimentData experimentData = new ExperimentData();
		if(mouseId != null) {		
			experimentData.setMouseId(mouseId);
			attachComponents(experimentData, requiredComponents);
		}
		return experimentData;
	}

	@Override
	/**
	 * NOTE: fetchAll IS NOT being implemented by this method.
	 */
	protected void attachComponents(ExperimentData experimentData, ComponentMap requiredComponents) {
		if(experimentData == null) {
			throw new RuntimeException("Cannot attach components to null experimentData");
		}		

		Long mouseId = experimentData.getMouseId();

		if(requiredComponents != null) {
			
			if(requiredComponents.containsKey(ExperimentData.Component.MOUSE)) {
				experimentData.setMouse(mouseService.fetchById(mouseId, requiredComponents.get(ExperimentData.Component.MOUSE)));
			}
			
			if(requiredComponents.containsKey(ExperimentData.Component.MOUSE_WEIGHTS)) {
				experimentData.setMouseWeights(mouseWeightService.fetchByMouseId(mouseId, requiredComponents.get(ExperimentData.Component.MOUSE_WEIGHTS)));
			}	
			
			if(requiredComponents.containsKey(ExperimentData.Component.PROCEDURES)) {
				experimentData.setMouseProcedures(mouseProcedureService.fetchByMouseId(mouseId, requiredComponents.get(ExperimentData.Component.PROCEDURES)));
			}
			
			if (requiredComponents.containsKey(ExperimentData.Component.NECROPSY)) {
			  experimentData.setNecropsy(necropsyService.fetchByMouseId(mouseId, requiredComponents.get(ExperimentData.Component.NECROPSY)));
			}
		}
	}
}
