/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.mousetracking.services;

import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractServiceImpl2;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.mousetracking.GenotypeHistory;
import uk.ac.sanger.mig.mousetracking.MouseAllele;
import uk.ac.sanger.mig.mousetracking.dao.GenotypeHistoryDao;

public class GenotypeHistoryServiceImpl extends AbstractServiceImpl2<GenotypeHistory,GenotypeHistoryDao> implements GenotypeHistoryService {

	private MouseAlleleService mouseAlleleService;

	public void setMouseAlleleService(MouseAlleleService mouseAlleleService) {
		this.mouseAlleleService = mouseAlleleService;
	}

	@Override
	protected void attachComponents(GenotypeHistory genotypeHistory, ComponentMap requiredComponents) {
		if(genotypeHistory == null) {
			throw new RuntimeException("Cannot attach components to null genotypeHistory");
		}

		boolean fetchAll = false;

		if(requiredComponents != null) {

			if(requiredComponents.containsKey(GenotypeHistory.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}

			if(fetchAll || requiredComponents.containsKey(GenotypeHistory.Component.MOUSE_ALLELE)) {
				genotypeHistory.setMouseAllele(fetchMouseAllele(genotypeHistory, ComponentMap.of(GenotypeHistory.Component.MOUSE_ALLELE)));
			}
		}
	}

	public GenotypeHistory fetchLatestByMouseAlleleId(Long mouseAlleleId, ComponentMap requiredComponents) {
		GenotypeHistory genotypeHistory = getPrimaryDao().fetchLatestByMouseAlleleId(mouseAlleleId);
		if(genotypeHistory != null) {
			attachComponents(genotypeHistory, requiredComponents);
		}
		return genotypeHistory;
	}

	private MouseAllele fetchMouseAllele(GenotypeHistory genotypeHistory, ComponentMap requiredComponents) {
		if(genotypeHistory.getMouseAlleleId() == null) {
			return null;
		}
		else {
			return mouseAlleleService.fetchById(genotypeHistory.getMouseAlleleId(), requiredComponents);
		}
	}

	public Collection<GenotypeHistory> fetchByMouseAlleleId(Long mouseAlleleId, ComponentMap requiredComponents) {
		Collection<GenotypeHistory> histories = getPrimaryDao().fetchByMouseAlleleId(mouseAlleleId);
		attachComponents(histories, requiredComponents);
		return histories;
	}
}
