/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.services;

import java.util.Collection;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.services.CommonServices;
import uk.ac.sanger.mig.mousetracking.Breeding;
import uk.ac.sanger.mig.mousetracking.Litter;
import uk.ac.sanger.mig.mousetracking.LitterSearchBean;
import uk.ac.sanger.mig.mousetracking.Mouse;
import uk.ac.sanger.mig.mousetracking.forms.LitterForm;
import uk.ac.sanger.mig.mousetracking.views.LitterListView;
import uk.ac.sanger.mig.personnel.Person;

public interface LitterService extends CommonServices<Litter>{

	public static final String LITTER_STATUS_UNBORN = "Unborn";
	public static final String LITTER_STATUS_PREWEAN = "Prewean";
	public static final String LITTER_STATUS_WEANED = "Weaned";
	public static final String LITTER_STATUS_HARVESTED = "Harvested";
	public static final String LITTER_STATUS_NOT_PREGNANT = "Not Pregnant";

	public Collection<Litter> fetchByBreedingId(Long breedingId, ComponentMap requiredComponents);

	public Litter fetchByEmbryoTransferId(Long embryoTransferId, ComponentMap requiredComponents);

	public void inflateLitterComponents(Litter litter);

	public Long processLitterForm(LitterForm litter, Person person);

	public int nextLitterNumber(Long breedingId);

	public Collection<LitterListView> search(LitterSearchBean searchBean);

	public boolean delete(Long litterId, Person user);

	public Mouse getDefaultPupValues(Breeding breeding);

	public Mouse createPup(LitterForm form);

	public String setDefault19b(LitterForm form);

	public void makeLitterName(Litter litter);

	public Litter fetchByName(String litterName, ComponentMap requiredComponents);
}
