/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.services;

import java.util.Collection;
import java.util.Date;

import org.springframework.transaction.annotation.Transactional;

import uk.ac.sanger.mig.common.AbstractServiceImpl2;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.common.LookupListElement;
import uk.ac.sanger.mig.mousetracking.Mouse;
import uk.ac.sanger.mig.mousetracking.MouseHealth;
import uk.ac.sanger.mig.mousetracking.dao.MouseHealthDao;
import uk.ac.sanger.mig.personnel.Person;

public class MouseHealthServiceImpl extends AbstractServiceImpl2<MouseHealth, MouseHealthDao> implements MouseHealthService {

	private MouseService mouseService;

	public void setMouseService(MouseService mouseService) {
		this.mouseService = mouseService;
	}

	@Transactional
	public void closeCurrentForMouse(Long mouseId, Date closeDate, Person user) {
		Collection<MouseHealth> healths = getPrimaryDao().fetchByMouseId(mouseId);

		for(MouseHealth health : healths) {
			if(health.getEndDate() == null) {
				health.setEndDate(closeDate);
				store(health, user);
			}
		}
	}

	protected void attachComponents(MouseHealth mouseHealth, ComponentMap requiredComponents) {
		if(mouseHealth == null) {
			throw new RuntimeException("Cannot attach components to null mouseHealth");
		}

		boolean fetchAll = false;

		if(requiredComponents != null) {

			if(requiredComponents.containsKey(MouseHealth.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}

			if(fetchAll || requiredComponents.containsKey(MouseHealth.Component.MOUSE)) {
				mouseHealth.setMouse(fetchMouse(mouseHealth, requiredComponents.get(MouseHealth.Component.MOUSE)));
			}
		}
	}

	private Mouse fetchMouse(MouseHealth mouseHealth, ComponentMap requiredComponents) {
		return mouseService.fetchById(mouseHealth.getMouseId(), requiredComponents);
	}

	public void inflateMouseHealthComponents(MouseHealth health) {
		if(health == null) {
			throw new RuntimeException("MouseHealth cannot be null when inflating components.");
		}

		// Mouse
		if(health.getMouse() == null) {
			health.setMouse(new Mouse());
		}

		// Body System
		if(health.getBodySystem() == null) {
			health.setBodySystem(new DictionaryEntry());
		}

		// Body Subsystem
		if(health.getBodySubsystem() == null) {
			health.setBodySubsystem(new DictionaryEntry());
		}

		// Health Concern
		if(health.getHealthConcern() == null) {
			health.setHealthConcern(new DictionaryEntry());
		}
	}

	public Collection<LookupListElement> lookup() {
		return getPrimaryDao().lookup();
	}

	@Transactional
	public void deleteHealthRecord(MouseHealth health, Person user) {
		getPrimaryDao().delete(health, user);
	}

	public Collection<MouseHealth> fetchByMouseId(Long mouseId, ComponentMap requiredComponents) {
		Collection<MouseHealth> healths = getPrimaryDao().fetchByMouseId(mouseId);
		attachComponents(healths, requiredComponents);
		return healths;
	}

}