/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.mousetracking.services;

import java.util.Date;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.services.CommonServices;
import uk.ac.sanger.mig.mousetracking.Mouse;
import uk.ac.sanger.mig.mousetracking.MousePool;
import uk.ac.sanger.mig.personnel.Person;

public interface MousePoolService extends CommonServices<MousePool>{

	public MousePool fetchPool(Long colonyId, Date poolDate, ComponentMap requiredComponents);

	public MousePool fetchByCageId(Long cageId, ComponentMap requiredComponents);

	public MousePool fetchByBarcode(String barcode, ComponentMap requiredComponents);

	public Long fetchPoolCageId(Mouse mouse, Long rackId, Person user);

	/**
	 * Set the fields in a mouse to indicate it is a pooled female (Production Colonies)
	 * A pooled female is not uniquely indentifiable in reality.
	 *
	 * This method performs the following operations:
	 * name field is replaced with contents of barcode field.
	 * pooled flag is set to true.
	 * birth date is rounded down to the nearest Monday.
	 *
	 * Non-female mice will be ignored.
	 *
	 * <b>NOTE: a store operation is NOT performed by this method.</b>
	 *
	 * @param mouse
	 * @param poolDate new pooled date of birth
	 * @return true if female was pooled successfully, otherwise false
	 * @throws IllegalArgumentException if no birth date can be determined for the mouse
	 */
	public boolean poolFemale(Mouse mouse, Date poolDate);

}