/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.services;

import java.util.Collection;

import org.springframework.transaction.annotation.Transactional;

import uk.ac.sanger.mig.common.AbstractServiceImpl2;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.mousetracking.MouseWeight;
import uk.ac.sanger.mig.mousetracking.dao.MouseWeightDao;
import uk.ac.sanger.mig.personnel.Person;

public class MouseWeightServiceImpl extends AbstractServiceImpl2<MouseWeight,MouseWeightDao> implements MouseWeightService {

	@Transactional
	public void storeCollection(Collection<MouseWeight> mouseWeights, Person user) {
		if(mouseWeights != null) {
			for(MouseWeight mouseWeight : mouseWeights) {
				if(mouseWeight.getWeightValue() != null) {
					store(mouseWeight, user);
				}
			}
		}
	}

	@Transactional
	public void storeForMouse(Long mouseId, MouseWeight mouseWeight, Person user) {
		if(mouseWeight == null) {
			throw new RuntimeException("Cannot save a null mouseWeight");
		}

		if(mouseWeight.getWeightValue() != null ) {
			mouseWeight.setWeightUnits("g");
			mouseWeight.setMouseId(mouseId);
			store(mouseWeight, user);
		}
	}

	public MouseWeight fetchCurrentByMouseId(Long mouseId, ComponentMap requiredComponents) {
		MouseWeight mouseWeight = getPrimaryDao().fetchCurrentByMouseId(mouseId);

		if(mouseWeight != null)
			attachComponents(mouseWeight, requiredComponents);

		return mouseWeight;
	}

	public Collection<MouseWeight> fetchByMouseId(Long mouseId, ComponentMap requiredComponents) {
		Collection<MouseWeight> weights = getPrimaryDao().fetchByMouseId(mouseId);

		attachComponents(weights, requiredComponents);

		return weights;
	}

	@Override
	protected void attachComponents(MouseWeight mouseWeight, ComponentMap requiredComponents) {
		if(mouseWeight == null) {
			throw new RuntimeException("Cannot attach components to null mouseWeight");
		}
	}
}
