/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.mousetracking.services;

import java.util.Collection;
import java.util.Date;
import java.util.Map;
import java.util.Set;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.services.CommonServices;
import uk.ac.sanger.mig.mousetracking.Cage;
import uk.ac.sanger.mig.mousetracking.StudBreeding;
import uk.ac.sanger.mig.mousetracking.StudBreedingSearchBean;
import uk.ac.sanger.mig.mousetracking.forms.AddStudBreedingForm;
import uk.ac.sanger.mig.mousetracking.forms.SeparateStudBreedingsForm;
import uk.ac.sanger.mig.mousetracking.forms.StudBreedingForm;
import uk.ac.sanger.mig.personnel.Person;

public interface StudBreedingService extends CommonServices<StudBreeding>{

	public Set<Long> addBreedings(AddStudBreedingForm form, Person user);

	public Collection<StudBreeding> fetchByCageId(Long cageId, ComponentMap requiredComponents);

	public Collection<StudBreeding> fetchByMouseId(Long mouseId, ComponentMap requiredComponents);

	public Collection<StudBreeding> fetch(StudBreedingSearchBean searchBean, ComponentMap requiredComponents);

	public Map<String, Object> separateBreedings(SeparateStudBreedingsForm form, Person user);

	public void closeCurrentForMouse(Long mouseId, Date endDate, Person user);

	public Cage fetchForCageView(Long breedingId);

	public Long editBreeding(StudBreedingForm form, Person user);

	public void storeCollection(Collection<StudBreeding> breedings, Person user);

	/**
	 * Return the latest (by date) stud breeding for a mouse (male or female)
	 * @param mouseId
	 * @param requiredComponents
	 * @return StudBreeding or null if no breedings available for the mouse
	 */
	public StudBreeding fetchLatestForMouse(Long mouseId, ComponentMap requiredComponents);
}