/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.validators;

import java.util.Collection;
import java.util.Hashtable;

import org.springframework.validation.Errors;
import org.springframework.validation.Validator;

import uk.ac.sanger.mig.mousetracking.TissueSample;
import uk.ac.sanger.mig.mousetracking.forms.BloodSampleForm;
import uk.ac.sanger.mig.mousetracking.services.TissueSampleService;

public class BloodSampleFormValidator implements Validator {

	private TissueSampleService tissueSampleService;


	public void setTissueSampleService(TissueSampleService tissueSampleService) {
		this.tissueSampleService = tissueSampleService;
	}

	public boolean supports(Class clazz) {
		return BloodSampleForm.class.equals(clazz);
	}

	public void validate(Object command, Errors errors) {
		BloodSampleForm form = (BloodSampleForm)command;

		if(form.getCohort().getId() == null && form.getCage().getId() == null) {
			errors.reject(null, "Please select a cage/cohort of mice to take blood samples from.");
		}
		else {

			if(form.getProjectLicenceId() == null) {
				errors.reject(null, "You must specify a project licence for this procedure.");
			}

			if(form.getBloodSamples() != null) {
				// Check for unique barcodes...
				Collection<TissueSample> samples = form.getBloodSamples();

				Hashtable<Integer, String> tab = new Hashtable<Integer, String>();
				int numBarcodes = 0;
				int i = 0;
				for(TissueSample sample : samples) {
					if(sample.getBarcode() != null) {

						TissueSample barcodeCheck = tissueSampleService.fetchByBarcode(sample.getBarcode(), null);
						if(barcodeCheck != null) {
							errors.reject(null, "Barcode "+sample.getBarcode()+" has already been assigned to a mouse.");
						}
						if(tab.containsValue(sample.getBarcode())) {
							errors.reject(null, "Barcodes must be unique for each mouse.");
							return;
						}
						tab.put(i++, sample.getBarcode());
						numBarcodes++;
					}
				}
				// Check if any barcodes have been assigned, reject if the user tries to submit an empty form.
				if(numBarcodes == 0) {
					errors.reject(null, "No Barcodes have been assigned for any mice.");
				}
			}
		}
	}
}