/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.validators;

import org.springframework.validation.Errors;
import org.springframework.validation.ValidationUtils;
import org.springframework.validation.Validator;


import uk.ac.sanger.mig.mousetracking.forms.EditCohortSetForm;
import uk.ac.sanger.mig.mousetracking.services.CohortSetService;



public class CohortSetFormValidator implements Validator {

	private CohortSetService cohortSetService;

	public void setCohortSetService(CohortSetService cohortSetService) {
		this.cohortSetService = cohortSetService;
	}

	public boolean supports(Class clazz) {
		return EditCohortSetForm.class.equals(clazz);
	}

	public void validate(Object command, Errors errors) {

		EditCohortSetForm cohortSetForm = (EditCohortSetForm)command;

		if(cohortSetForm.getCohortSet().getId() == null){

			// if the allele has a cohort set corresponding to it, then show error message
			if(!cohortSetService.checkAlleleAvaiable(cohortSetForm.getAllele().getId())){
				errors.reject(null,
						"There is a cohort set for this allele already, please choose a differnt allele or edit the exsiting cohort set!");
			}
		}

        ValidationUtils.rejectIfEmptyOrWhitespace(errors,"allele.id",null, null,"Allele is a required field.");
        ValidationUtils.rejectIfEmptyOrWhitespace(errors,"cohortSet.cohortSetTypeDictId",null, null ,"Cohort Set Type is a required field.");


	}
}
