/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.validators;

import org.springframework.validation.Errors;
import org.springframework.validation.ValidationUtils;
import org.springframework.validation.Validator;

import uk.ac.sanger.mig.histology.forms.MouseCheckbox;
import uk.ac.sanger.mig.mousetracking.forms.ManageCohortForm;
import uk.ac.sanger.mig.mousetracking.services.CohortService;

public class ManageCohortFormValidator implements Validator {

	public boolean supports(Class clazz) {
		return ManageCohortForm.class.equals(clazz);
	}

	public void validate(Object target, Errors errors) {
		ManageCohortForm form = (ManageCohortForm)target;

		Long cohortType = form.getCohort().getCohortTypeDictId();
		if (cohortType.equals(CohortService.COHORT_TYPE_HISTOLOGY)) {
			throw new IllegalArgumentException("This validator does not work with histology cohorts");
		}
		else {
			checkName(errors);

			if (CohortService.COHORT_TYPE_GENOTYPING.equals(cohortType)) {
				checkMiceForAlleles(form,errors);
			}

			if (CohortService.COHORT_TYPE_PHENOTYPING.equals(cohortType)) {
				checkReason(errors);
			}
		}
	}

	private void checkMiceForAlleles(ManageCohortForm form, Errors errors) {

		for (MouseCheckbox mc : form.getMiceToSelectFrom()) {
			if (mc.isChecked() && mc.getMouse().getAlleles().isEmpty()) {
				String errorMessage = "Mouse "+mc.getMouse().getName()+" has no alleles";
				errors.reject(null, errorMessage);
			}
		}

	}

	private void checkName(Errors errors) {
		ValidationUtils.rejectIfEmptyOrWhitespace(errors, "cohort.cohortName", null, "Name is a required field.");
	}
	private void checkReason(Errors errors) {
		ValidationUtils.rejectIfEmptyOrWhitespace(errors, "cohort.reason", null, "Description is a required field.");
	}

}
