package uk.ac.sanger.mig.mousetracking.validators;

import java.text.SimpleDateFormat;

import org.springframework.validation.Errors;
import org.springframework.validation.Validator;

import uk.ac.sanger.mig.mousetracking.StudBreeding;
import uk.ac.sanger.mig.mousetracking.forms.SeparateStudBreedingsForm;
import uk.ac.sanger.mig.mousetracking.forms.SeparateStudBreedingsForm.PlugStates;

public class SeparateStudBreedingsFormValidator implements Validator {

	private static final SimpleDateFormat sdf = new SimpleDateFormat("dd-MMM-yyyy");

	public boolean supports(Class clazz) {
		return SeparateStudBreedingsForm.class.equals(clazz);
	}

	public void validate(Object target, Errors errors) {
		SeparateStudBreedingsForm form = (SeparateStudBreedingsForm)target;
		form.setValidated(false);

		if(form.getCheckDateTime() == null) {
			errors.reject(null, "Plug Check Date is a required field.");
		}
		else {
			checkDates(form, errors);
		}

		if(form.getCheckPerson().getId() == null) {
			errors.reject(null, "Checked By is a required field.");
		}

		if(form.getStudBreedingPlugs().isEmpty()) {
			errors.reject(null, "At least one paired stud is required.");
		}
		else {
			boolean validPlugStateFound = false;
			boolean extrasRequired = false;
			int unselectedRecords = 0;
			for(PlugStates state : form.getStudBreedingPlugs()) {
				if(state == PlugStates.DEFAULT) {
					unselectedRecords++;
				}
				if(state != PlugStates.IGNORE) {
					validPlugStateFound = true;
				}
				if(state == PlugStates.PLUGGED) {
					extrasRequired = true;
				}
			}
			if(unselectedRecords > 0) {
				errors.reject(null, "Not all stud records have been updated.");
			}
			if(!validPlugStateFound) {
				errors.reject(null, "Select 'Plug' or 'No Plug' for at least one stud.");
			}
			if(extrasRequired && form.getDestinationRack().getId() == null) {
				errors.reject(null, "Please select destination rack for plugged females.");
			}

			if(extrasRequired && form.getTimedEmbryoAge() == null) {
				errors.reject(null, "Embryo Age is a required field.");
			}
		}

		if(!errors.hasErrors()) {
			form.setValidated(true);
		}
	}

	private void checkDates(SeparateStudBreedingsForm form, Errors errors) {

		for(StudBreeding breeding : form.getStudBreedings()) {
			if(breeding.getStartDateTime() != null && form.getCheckDateTime() != null && form.getCheckDateTime().before(breeding.getStartDateTime())) {
				errors.reject(null, "Plug Date " + sdf.format(form.getCheckDateTime()) + " cannot be before Start Date " + sdf.format(breeding.getStartDateTime()));
				break;
			}
		}
	}


}
