package uk.ac.sanger.mig.mousetracking.validators;

import org.springframework.validation.Errors;
import org.springframework.validation.Validator;

import uk.ac.sanger.mig.mousetracking.StudBreeding;
import uk.ac.sanger.mig.mousetracking.forms.StudBreedingForm;
import uk.ac.sanger.mig.mousetracking.forms.StudBreedingForm.FemaleOption;
import uk.ac.sanger.mig.mousetracking.forms.StudBreedingForm.MaleOption;

public class StudBreedingFormValidator implements Validator {

	public boolean supports(Class clazz) {
		return StudBreedingForm.class.equals(clazz);
	}

	public void validate(Object target, Errors errors) {
		StudBreedingForm form = (StudBreedingForm)target;

		formObjectValidation(form, errors);

		if(!errors.hasErrors()) {
			businessLogicValidation(form, errors);
		}

		form.setValidated(!errors.hasErrors());
	}

	private void formObjectValidation(StudBreedingForm form, Errors errors) {
		if(form == null) {
			errors.reject(null, "Fatal Validation Error: Form cannot be null!");
		}
		else {
			StudBreeding breeding = form.getBreeding();

			if(breeding == null) {
				errors.reject(null, "Fatal Validation Error: Breeding Object cannot be null!");
			}
			else {
				if(breeding.getMale() == null) {
					errors.reject(null, "Fatal Validation Error: Male Object cannot be null!");
				}
				if(breeding.getFemale() == null) {
					errors.reject(null, "Fatal Validation Error: Female Object cannot be null!");
				}
			}
		}
	}

	private void businessLogicValidation(StudBreedingForm form, Errors errors) {
		StudBreeding breeding = form.getBreeding();

		if(breeding.getStartDateTime() == null) {
			errors.reject(null, "Date paired is a required field.");
		}

		if(((!form.getFemaleOption().equals(FemaleOption.DO_NOTHING)) ||
		!form.getMaleOption().equals(MaleOption.DO_NOTHING))
		&& breeding.getEndDate() == null) {
			errors.reject(null, "Date separated is a required field.");

		}

		if(form.getFemaleOption().equals(StudBreedingForm.FemaleOption.MOVE_FEMALE) && form.getFemaleLocation().getId() == null) {
			errors.reject(null, "Female Location is a required field.");
		}

		if(breeding.getStartDateTime() != null && breeding.getEndDate() != null && breeding.getStartDateTime().after(breeding.getEndDate())) {
			errors.reject(null, "Date paired cannot be after date separated.");
		}

		if(breeding.getPlugDateTime() != null && breeding.getEndDate() != null && breeding.getPlugDateTime().after(breeding.getEndDate())) {
			errors.reject(null, "Plug date cannot be after date separated.");
		}

		if(breeding.getPlugDateTime() != null && breeding.getStartDateTime() != null && breeding.getPlugDateTime().before(breeding.getStartDateTime())) {
			errors.reject(null, "Plug date cannot be before date paired.");
		}
	}

}
