/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.views;

import java.util.Date;

import uk.ac.sanger.mig.common.CalendarUtils;

public class LitterListView {

	private Long id;

	private Long fatherId;
	private String fatherName;
	private Long motherId;
	private String motherName;
	private Long microInjectionRequestId;
	private String litterName;
	private Date birthDate;
	private Integer numberPups;
	private Integer numberBorn;
	private Integer numberWeaned;
	private Integer numberWeanedFemale;
	private Integer numberWeanedMale;
	private Integer numberUsedOrDied;
	private Integer numberEmbryos;
	private Date plugDate;
	private String comments;
	private boolean notPregnant;

	public String getEmbryoAge() {
		// don't return embryo age if pups are already born
		if(birthDate != null) {
			return null;
		}
		// try to calculate based on plug date
		else if (plugDate != null ){
			return CalendarUtils.diffInDays(plugDate, new Date()) + ".5E";
		}
		else {
			return "?";
		}
	}

	public Date getBirthDate() {
		return birthDate;
	}

	public void setBirthDate(Date birthDate) {
		this.birthDate = birthDate;
	}

	public String getComments() {
		return comments;
	}

	public void setComments(String comments) {
		this.comments = comments;
	}

	public Long getFatherId() {
		return fatherId;
	}

	public void setFatherId(Long fatherId) {
		this.fatherId = fatherId;
	}

	public String getFatherName() {
		return fatherName;
	}

	public void setFatherName(String fatherName) {
		this.fatherName = fatherName;
	}

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public String getLitterName() {
		return litterName;
	}

	public void setLitterName(String litterName) {
		this.litterName = litterName;
	}

	public Long getMicroInjectionRequestId() {
		return microInjectionRequestId;
	}

	public void setMicroInjectionRequestId(Long microInjectionRequestId) {
		this.microInjectionRequestId = microInjectionRequestId;
	}

	public Long getMotherId() {
		return motherId;
	}

	public void setMotherId(Long motherId) {
		this.motherId = motherId;
	}

	public String getMotherName() {
		return motherName;
	}

	public void setMotherName(String motherName) {
		this.motherName = motherName;
	}

	public boolean isNotPregnant() {
		return notPregnant;
	}

	public void setNotPregnant(boolean notPregnant) {
		this.notPregnant = notPregnant;
	}

	public Integer getNumberBorn() {
		return numberBorn;
	}

	public void setNumberBorn(Integer numberBorn) {
		this.numberBorn = numberBorn;
	}

	public Integer getNumberEmbryos() {
		return numberEmbryos;
	}

	public void setNumberEmbryos(Integer numberEmbryos) {
		this.numberEmbryos = numberEmbryos;
	}

	public Integer getNumberUsedOrDied() {
		return numberUsedOrDied;
	}

	public void setNumberUsedOrDied(Integer numberUsedOrDied) {
		this.numberUsedOrDied = numberUsedOrDied;
	}

	public Integer getNumberWeaned() {
		return numberWeaned;
	}

	public void setNumberWeaned(Integer numberWeaned) {
		this.numberWeaned = numberWeaned;
	}

	public Date getPlugDate() {
		return plugDate;
	}

	public void setPlugDate(Date plugDate) {
		this.plugDate = plugDate;
	}

	public Integer getNumberWeanedFemale() {
		return numberWeanedFemale;
	}

	public void setNumberWeanedFemale(Integer numberWeanedFemale) {
		this.numberWeanedFemale = numberWeanedFemale;
	}

	public Integer getNumberWeanedMale() {
		return numberWeanedMale;
	}

	public void setNumberWeanedMale(Integer numberWeanedMale) {
		this.numberWeanedMale = numberWeanedMale;
	}

	public Integer getNumberPups() {
		return numberPups;
	}

	public void setNumberPups(Integer numberPups) {
		this.numberPups = numberPups;
	}
}
