/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.views;

import java.util.Date;

import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.SelectableRecordSet;

public class MouseListView extends AuthenticatedDataObject implements SelectableRecordSet  {

    /**
	 *
	 */
	private static final long serialVersionUID = -234989541333506497L;
	private Long litterId;
    private String name;
    private Long coatColourDictId;
    private String coatColour;
    private Long eyeColourDictId;
    private String eyeColour;
    private Long earmarkDictId;
    private String earmark;
    private Date birthDate;
    private Date deathDate;
    private Long causeOfDeathDictId;
    private String causeOfDeath;
    private Date weanDate;
    private Long cageId;
    private String cageName;
    private Long rackId;
    private String rackName;
    private Long roomId;
    private String roomName;
    private Long currentOwnerId;
    private String currentOwner;
    private Long currentProjectLicenceId;
    private String currentProjectLicence;
    private Long currentProtocolId;
    private String currentProtocolCode;
    private Long genderDictId;
    private String gender;
    private Long mouseStrainDictId;
    private String strain;
    private String status;
    private String barcode;
    private String comments;
    private boolean nonBreeder;
    private boolean sentinel;
    private String generation;
    private Long colonyInfoId;
    private String colonyName;
    private String colonyPrefix;
    private Date latestPlugDate;
    private Date arrivalDate;
    private Float ageInWeeks;
    private Float ageAtDeath;
    private String cageBarcode;
    private String selected;
    //private Long selectedValue;
    private Long recordNumber;
    private String breedingName;
    private String genotype;
    private String fatherName;
    private String fatherGenotype;
    private String motherName;
    private String motherGenotype;
    private String rfidTag;
    private String reservation;


    public String getReservation() {
      return reservation;
    }

    public void setReservation(String reservation) {
      this.reservation = reservation;
    }

    public Date getLatestPlugDate() {
		return latestPlugDate;
	}

	public void setLatestPlugDate(Date latestPlugDate) {
		this.latestPlugDate = latestPlugDate;
	}

	public Long getLitterId() {
        return litterId;
    }

    public void setLitterId(Long litterId) {
        this.litterId = litterId;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Long getCoatColourDictId() {
        return coatColourDictId;
    }

    public void setCoatColourDictId(Long coatColourDictId) {
        this.coatColourDictId = coatColourDictId;
    }
    public String getCoatColour() {
        return coatColour;
    }

    public void setCoatColour(String coatColour) {
        this.coatColour = coatColour;
    }
    public Long getEyeColourDictId() {
        return eyeColourDictId;
    }

    public void setEyeColourDictId(Long eyeColourDictId) {
        this.eyeColourDictId = eyeColourDictId;
    }
    public String getEyeColour() {
        return eyeColour;
    }

    public void setEyeColour(String eyeColour) {
        this.eyeColour = eyeColour;
    }
    public Long getEarmarkDictId() {
        return earmarkDictId;
    }

    public void setEarmarkDictId(Long earmarkDictId) {
        this.earmarkDictId = earmarkDictId;
    }
    public String getEarmark() {
        return earmark;
    }

    public void setEarmark(String earmark) {
        this.earmark = earmark;
    }
    public Date getBirthDate() {
        return birthDate;
    }

    public void setBirthDate(Date birthDate) {
        this.birthDate = birthDate;
    }
    public Date getDeathDate() {
        return deathDate;
    }

    public void setDeathDate(Date deathDate) {
        this.deathDate = deathDate;
    }

    public Long getCauseOfDeathDictId() {
        return causeOfDeathDictId;
    }

    public void setCauseOfDeathDictId(Long causeOfDeathDictId) {
        this.causeOfDeathDictId = causeOfDeathDictId;
    }
    public String getCauseOfDeath() {
        return causeOfDeath;
    }

    public void setCauseOfDeath(String causeOfDeath) {
        this.causeOfDeath = causeOfDeath;
    }
    public Date getWeanDate() {
        return weanDate;
    }

    public void setWeanDate(Date weanDate) {
        this.weanDate = weanDate;
    }
    public Long getCageId() {
        return cageId;
    }

    public void setCageId(Long cageId) {
        this.cageId = cageId;
    }
    public String getCageName() {
        return cageName;
    }

    public void setCageName(String cageName) {
        this.cageName = cageName;
    }
    public Long getRackId() {
        return rackId;
    }

    public void setRackId(Long rackId) {
        this.rackId = rackId;
    }
    public String getRackName() {
        return rackName;
    }

    public void setRackName(String rackName) {
        this.rackName = rackName;
    }
    public Long getRoomId() {
        return roomId;
    }

    public void setRoomId(Long roomId) {
        this.roomId = roomId;
    }
    public String getRoomName() {
        return roomName;
    }

    public void setRoomName(String roomName) {
        this.roomName = roomName;
    }
    public Long getCurrentOwnerId() {
        return currentOwnerId;
    }

    public void setCurrentOwnerId(Long currentOwnerId) {
        this.currentOwnerId = currentOwnerId;
    }
    public String getCurrentOwner() {
        return currentOwner;
    }

    public void setCurrentOwner(String currentOwner) {
        this.currentOwner = currentOwner;
    }
    public Long getCurrentProjectLicenceId() {
        return currentProjectLicenceId;
    }

    public void setCurrentProjectLicenceId(Long currentProjectLicenceId) {
        this.currentProjectLicenceId = currentProjectLicenceId;
    }
    public String getCurrentProjectLicence() {
        return currentProjectLicence;
    }

    public void setCurrentProjectLicence(String currentProjectLicence) {
        this.currentProjectLicence = currentProjectLicence;
    }
    public Long getCurrentProtocolId() {
        return currentProtocolId;
    }

    public void setCurrentProtocolId(Long currentProtocolId) {
        this.currentProtocolId = currentProtocolId;
    }
    public String getCurrentProtocolCode() {
        return currentProtocolCode;
    }

    public void setCurrentProtocolCode(String currentProtocolCode) {
        this.currentProtocolCode = currentProtocolCode;
    }
    public Long getGenderDictId() {
        return genderDictId;
    }

    public void setGenderDictId(Long genderDictId) {
        this.genderDictId = genderDictId;
    }
    public String getGender() {
        return gender;
    }

    public void setGender(String gender) {
        this.gender = gender;
    }
    public Long getMouseStrainDictId() {
        return mouseStrainDictId;
    }

    public void setMouseStrainDictId(Long mouseStrainDictId) {
        this.mouseStrainDictId = mouseStrainDictId;
    }
    public String getStrain() {
        return strain;
    }

    public void setStrain(String strain) {
        this.strain = strain;
    }
    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getBarcode() {
        return barcode;
    }

    public void setBarcode(String barcode) {
        this.barcode = barcode;
    }
    public String getComments() {
        return comments;
    }

    public void setComments(String comments) {
        this.comments = comments;
    }

    public boolean isNonBreeder() {
        return nonBreeder;
    }

    public void setNonBreeder(boolean nonBreeder) {
        this.nonBreeder = nonBreeder;
    }
    public boolean isSentinel() {
        return sentinel;
    }

    public void setSentinel(boolean sentinel) {
        this.sentinel = sentinel;
    }

    public String getGeneration() {
        return generation;
    }

    public void setGeneration(String generation) {
        this.generation = generation;
    }
    public Long getColonyInfoId() {
        return colonyInfoId;
    }

    public void setColonyInfoId(Long colonyInfoId) {
        this.colonyInfoId = colonyInfoId;
    }

    public Date getArrivalDate() {
        return arrivalDate;
    }

    public void setArrivalDate(Date arrivalDate) {
        this.arrivalDate = arrivalDate;
    }

	public Long getRecordNumber() {
		return recordNumber;
	}

	public void setRecordNumber(Long recordNumber) {
		this.recordNumber = recordNumber;
	}

	public String getSelected() {
		return selected;
	}

	public void setSelected(String selected) {
		this.selected = selected;
	}

	/*public Long getSelectedValue() {
		return selectedValue;
	}

	public void setSelectedValue(Long selectedValue) {
		this.selectedValue = selectedValue;
	}*/

	public String getColonyName() {
		return colonyName;
	}

	public void setColonyName(String colonyName) {
		this.colonyName = colonyName;
	}

	public Float getAgeAtDeath() {
		return ageAtDeath;
	}

	public void setAgeAtDeath(Float ageAtDeath) {
		this.ageAtDeath = ageAtDeath;
	}

	public Float getAgeInWeeks() {
		return ageInWeeks;
	}

	public void setAgeInWeeks(Float ageInWeeks) {
		this.ageInWeeks = ageInWeeks;
	}

	public String getCageBarcode() {
		return cageBarcode;
	}

	public void setCageBarcode(String cageBarcode) {
		this.cageBarcode = cageBarcode;
	}

	public String getBreedingName() {
		return breedingName;
	}

	public void setBreedingName(String breedingName) {
		this.breedingName = breedingName;
	}

	public String getColonyPrefix() {
		return colonyPrefix;
	}

	public void setColonyPrefix(String colonyPrefix) {
		this.colonyPrefix = colonyPrefix;
	}

	public String getGenotype() {
		return genotype;
	}

	public void setGenotype(String genotype) {
		this.genotype = genotype;
	}

	public String getFatherGenotype() {
		return fatherGenotype;
	}

	public void setFatherGenotype(String fatherGenotype) {
		this.fatherGenotype = fatherGenotype;
	}

	public String getMotherGenotype() {
		return motherGenotype;
	}

	public void setMotherGenotype(String motherGenotype) {
		this.motherGenotype = motherGenotype;
	}

	public String getRfidTag() {
		return rfidTag;
	}

	public void setRfidTag(String rfidTag) {
		this.rfidTag = rfidTag;
	}

	public String getFatherName() {
		return fatherName;
	}

	public void setFatherName(String fatherName) {
		this.fatherName = fatherName;
	}

	public String getMotherName() {
		return motherName;
	}

	public void setMotherName(String motherName) {
		this.motherName = motherName;
	}
}