/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.personnel.controllers;

import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.Map;
import java.util.TreeMap;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.bind.ServletRequestBindingException;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.SimpleFormController;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.licensing.ProjectLicence;
import uk.ac.sanger.mig.licensing.services.ProjectLicenceService;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.personnel.Role;
import uk.ac.sanger.mig.personnel.Team;
import uk.ac.sanger.mig.personnel.forms.PersonForm;
import uk.ac.sanger.mig.personnel.services.PersonService;
import uk.ac.sanger.mig.personnel.services.RoleService;
import uk.ac.sanger.mig.personnel.services.TeamService;

public class EditPersonFormController extends SimpleFormController {

	private PersonService personService;
	private TeamService teamService;
	private RoleService roleService;
	private ProjectLicenceService projectLicenceService;

	public void setPersonService(PersonService personService) {
		this.personService = personService;
	}

	public void setTeamService(TeamService teamService) {
		this.teamService = teamService;
	}

	public void setRoleService(RoleService roleService) {
		this.roleService = roleService;
	}

	public void setProjectLicenceService(ProjectLicenceService projectLicenceService) {
		this.projectLicenceService = projectLicenceService;
	}

	@Override
	protected boolean isFormChangeRequest(HttpServletRequest request) {
		String changeRequest = null;

		try{
			changeRequest = ServletRequestUtils.getStringParameter(request, "changeForm");
		}
		catch(ServletRequestBindingException e) {

		}

		if(changeRequest != null && changeRequest.length() >0) {
			return true;
		}
		else {
			return false;
		}
	}

	@Override
	protected void onFormChange(HttpServletRequest request, HttpServletResponse response, Object command) throws Exception {
		PersonForm form = (PersonForm)command;
		String changeRequest = ServletRequestUtils.getRequiredStringParameter(request, "changeForm");
		String changeRequestValue = ServletRequestUtils.getRequiredStringParameter(request, "changeFormValue");

		if(changeRequest.equals("addRole")) {
			Role newRole = roleService.fetchById(Long.valueOf(changeRequestValue),null);
			form.getPerson().getRoles().put(newRole.getLowerCaseName(), newRole);
		}
		else if(changeRequest.equals("removeRole")) {
			form.getPerson().getRoles().remove(changeRequestValue);
		}
		else if(changeRequest.equals("addPpl")) {
			ProjectLicence ppl = projectLicenceService.fetchById(Long.valueOf(changeRequestValue), null);
			form.getPpls().add(ppl);
		}
		else if(changeRequest.equals("removePpl")) {
			ProjectLicence ppl = projectLicenceService.fetchById(Long.valueOf(changeRequestValue), null);
			form.getPpls().remove(ppl);
		}
	}

	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		PersonForm form = (PersonForm)command;

		Person user = RequestUtils.getUser(request);

		personService.store(form, user);

		return new ModelAndView(getSuccessView(), "id", form.getPerson().getId());
	}

	@Override
	protected Map referenceData(HttpServletRequest request, Object command, Errors errors) throws Exception {
		PersonForm form = (PersonForm)command;
		Map<String, Object> referenceData = new HashMap<String, Object>();

		Collection<Team> teams = teamService.fetchAll();
		referenceData.put("teams", teams);

		Map<String, Role> roles = new TreeMap<String, Role>();
		roles.putAll(roleService.fetchAll(null));
		for(String key : form.getPerson().getRoles().keySet()) {
			roles.remove(key);
		}

		referenceData.put("roles", roles);

		Collection<ProjectLicence> ppls = projectLicenceService.fetchCurrent(null);
		Collection<ProjectLicence> userPpls = form.getPpls();
		ppls.removeAll(userPpls);
		referenceData.put("ppls", ppls);

		return referenceData;
	}

	@Override
	protected Object formBackingObject(HttpServletRequest request) throws Exception {
		PersonForm form = (PersonForm)createCommand();

		Long personId = ServletRequestUtils.getLongParameter(request, "id");

		if(personId == null && form.getPerson() != null && form.getPerson().getId() != null) {
			personId = form.getPerson().getId();
		}

		Person person = personService.fetchById(personId, ComponentMap.of(Person.Component.ALL_COMPONENTS));

		if(person == null) {
			person = new Person();
			form.setPpls(new ArrayList<ProjectLicence>());
			person.setActive(true);
		}

		Collection<ProjectLicence> ppls = null;
		if(personId != null) {
			ppls = projectLicenceService.fetchByLicenceHolder(personId, null);
		}
		else {
			ppls = new ArrayList<ProjectLicence>();
		}
		form.setPpls(ppls);

		personService.inflatePersonComponents(person);
		form.setPerson(person);

		return form;
	}
}
