/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.personnel.dao;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.personnel.PersonColumnPref;
import uk.ac.sanger.mig.personnel.dao.rowmappers.PersonColumnPrefListViewRowMapper;
import uk.ac.sanger.mig.personnel.views.PersonColumnPrefListView;

public class PersonColumnPrefDaoSpringImpl extends AbstractDaoSpringImpl<PersonColumnPref> implements PersonColumnPrefDao {

	private PersonColumnPrefListViewRowMapper personColumnPrefListViewRowMapper;

	public void setPersonColumnPrefListViewRowMapper(
			PersonColumnPrefListViewRowMapper personColumnPrefListViewRowMapper) {
		this.personColumnPrefListViewRowMapper = personColumnPrefListViewRowMapper;
	}

	public Collection<PersonColumnPrefListView> fetchCurrent(String tableName, Long personId) {
		String sql = " select * from per_person_column_prefs_vw where table_name = ? and person_id = ? order by order_by ";

		Collection<PersonColumnPrefListView> prefs = getSimpleJdbcTemplate().query(sql, personColumnPrefListViewRowMapper, tableName, personId);

		return (prefs == null) ? new ArrayList<PersonColumnPrefListView>() : prefs;
	}

	public Collection<PersonColumnPrefListView> fetchAvailable(String tableName, Long personId) {
		String sql = " select a.*, a.id column_pref_id, 0 person_id from app_column_prefs a where table_name = ? and not exists (select null from per_person_column_prefs p where p.person_id = ? and p.column_pref_id = a.id) order by order_by ";

		Collection<PersonColumnPrefListView> prefs = getSimpleJdbcTemplate().query(sql, personColumnPrefListViewRowMapper, tableName, personId);

		return (prefs == null) ? new ArrayList<PersonColumnPrefListView>() : prefs;
	}

	public int deleteCurrent(String tableName, Long personId) {
		String sql = " delete per_person_column_prefs where person_id = ? and column_pref_id in (select id from app_column_prefs where table_name = ? )";

		return getSimpleJdbcTemplate().update(sql, personId, tableName);
	}

	@Override
	protected Long insert(PersonColumnPref personColumnPref) {
		personColumnPref.setId(getPk());
		ParameterizedSqlUpdate sql = new ParameterizedSqlUpdate(getJdbcTemplate());
		bindVariables(sql,personColumnPref);
		sql.executeInsert(getTableName());
		return personColumnPref.getId();
	}

	@Override
	protected Long update(PersonColumnPref personColumnPref) {
		ParameterizedSqlUpdate sql = new ParameterizedSqlUpdate(getJdbcTemplate(),"ID");
		bindVariables(sql,personColumnPref);
		sql.executeUpdate(getTableName());
		return personColumnPref.getId();
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, PersonColumnPref personColumnPref) {
		sql.addLongParam(personColumnPref.getPersonId(), "PERSON_ID");
		sql.addLongParam(personColumnPref.getColumnPrefId(), "COLUMN_PREF_ID");
		sql.addIntParam(personColumnPref.getOrderBy(), "ORDER_BY");
		sql.addLongParam(personColumnPref.getId(), "ID");
	}
}