/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.personnel.dao;

import java.util.Collection;

import uk.ac.sanger.mig.database.TypedDao;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.personnel.PersonSearchBean;

public interface PersonDao extends TypedDao<Person> {

	/**
	 * Determine if the supplied userName and password pair are valid login details. This perfoms
	 * a 1-way hash of the password and looks the username/password-hash pair up in the database. 
	 * If the pair exists then a Person object is created to represent the users details within
	 * the system.
	 * 
	 * @param userName a string representing the user name entered by the user at the login prompt.
	 * @param password a string representing the password (clear-text) entered by the user at the login
	 *     prompt.
	 * @return A valid Person object or null if the user is not authorised to use the system.
	 */
	public boolean authoriseAgainstDatabase(String userName, String password);

	public Person fetchPersonByFirstAndLastName(String fName, String lName);
	
	public Person fetchByUserName(String userName);	
	
	public Collection<Person> fetch(PersonSearchBean searchBean);
	
}