/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.personnel.dao;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.personnel.Role;

public class RoleDaoSpringImpl extends AbstractDaoSpringImpl<Role> implements RoleDao {

	public Map<String, Role> fetchByPersonId(Long personId) {
		
		Map<String, Role> rolesMap = new HashMap<String, Role>();
		
		String sql = 
			" select r.* " +
			" from " +
			"  per_role r, " +
			"  per_person_2_role p2r " +
			" where " +
			"  r.role_id = p2r.role_id and " +
			"  p2r.person_id = ? order by r.name ";
		
		Collection<Role> roles = getSimpleJdbcTemplate().query(sql, getRowMapper(), personId);
		
		for(Role role : roles) {
			rolesMap.put(role.getLowerCaseName(), role);
		}
		
		return rolesMap;			
	}

	public int linkToPerson(Long roleId, Long personId) {
		String sql = " insert into per_person_2_role(person_id,role_id) select ?,? from dual where not exists (select null from per_person_2_role where person_id = ? and role_id = ?) ";
		return getSimpleJdbcTemplate().update(sql, personId, roleId, personId, roleId);
	}
	
	public int clearLinksToPerson(Long personId) {
		String sql = " delete from per_person_2_role where person_id = ?";
		
		return getSimpleJdbcTemplate().update(sql, personId);
	}

	public Map<String, Role> fetchAll() {
		Map<String, Role> rolesMap = new HashMap<String, Role>();
		
		String sql = " select * from per_role order by name ";
		
		Collection<Role> roles = getSimpleJdbcTemplate().query(sql, getRowMapper());
		
		for(Role role : roles) {
			rolesMap.put(role.getLowerCaseName(), role);
		}
		
		return rolesMap;		
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, Role role) {
		sql.addStringParam(role.getLowerCaseName(), "NAME");
		sql.addIntParam(role.getRank(), "RANK");
		sql.addLongParam(role.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(role.getCreatedDate(), "CREATED_DATE");
		sql.addStringParam(role.getEditedBy(), "EDITED_BY");
		sql.addDateParam(role.getEditDate(), "EDIT_DATE");
		sql.addLongParam(role.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(role.getId(), "ID");
	}
}
