/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.personnel.dao;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.personnel.Team;

public class TeamDaoSpringImpl extends AbstractDaoSpringImpl<Team> implements TeamDao {

	public Team fetchPrimaryByTeamNumber(String teamNumberStr) {
		long teamNumber = Long.parseLong(teamNumberStr);
		String sql = " select * from per_team where team_number = ? ";	
		return getSimpleJdbcTemplate().queryForObject(sql, getRowMapper(), teamNumber);			
	}

	public Collection<Team> fetchAll() {
		String sql = "select * from per_team order by team_number ";

		Collection<Team> teams = null;

		teams = getSimpleJdbcTemplate().query(sql, getRowMapper());

		return (teams  != null) ? teams  : new ArrayList<Team>();	
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, Team team) {
		sql.addStringParam(team.getTeamName(), "TEAM_NAME");
		sql.addStringParam(team.getTeamNumber(), "TEAM_NUMBER");
		sql.addStringParam(team.getTeamLeader(), "TEAM_LEADER");
		sql.addLongParam(team.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(team.getCreatedDate(), "CREATED_DATE");
		sql.addDateParam(team.getEditDate(), "EDIT_DATE");
		sql.addStringParam(team.getEditedBy(), "EDITED_BY");
		sql.addLongParam(team.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(team.getId(), "ID");
	}
}
