/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.personnel.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.personnel.Person;

public class PersonRowMapper implements ParameterizedRowMapper<Person> {

	public Person mapRow(ResultSet rs, int rowNum) throws SQLException {
		
		Person person = new Person();
		
		person.setId(rs.getLong("PERSON_ID"));
		person.setFirstName(rs.getString("FIRST_NAME"));
		person.setLastName(rs.getString("LAST_NAME"));
		person.setPasswordHash(rs.getString("PASSWORD_HASH"));
		person.setUserName(rs.getString("USER_NAME"));
		person.setCreatorId(rs.getLong("CREATOR_ID"));
		if(rs.wasNull()) person.setCreatorId(null);
		person.setCreatedDate(rs.getDate("CREATED_DATE"));
		person.setEmail(rs.getString("EMAIL"));
		person.setAddress(rs.getString("ADDRESS"));
		person.setRoomNumber(rs.getString("ROOM"));
		person.setPhoneNumber(rs.getString("PHONE_NUMBER"));
		person.setEditedBy(rs.getString("EDITED_BY"));
		person.setEditDate(rs.getDate("EDIT_DATE"));
		person.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) person.setCheckNumber(null);		
		person.setTeamId(rs.getLong("TEAM_ID"));
		if(rs.wasNull()) person.setTeamId(null);
		person.setHidden(rs.getBoolean("HIDDEN"));
		person.setActive(rs.getBoolean("ACTIVE"));
		
		return person;
	}
}
