/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.personnel.services;

import java.util.Collection;

import org.springframework.transaction.annotation.Transactional;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.personnel.PersonColumnPref;
import uk.ac.sanger.mig.personnel.dao.PersonColumnPrefDao;
import uk.ac.sanger.mig.personnel.forms.PersonColumnPrefsForm;
import uk.ac.sanger.mig.personnel.views.PersonColumnPrefListView;

public class PersonColumnPrefServiceImpl extends AbstractServiceImpl<PersonColumnPref> implements PersonColumnPrefService {
	
	private PersonColumnPrefDao personColumnPrefDao;
	
	public void setPersonColumnPrefDao(PersonColumnPrefDao personColumnPrefDao) {
		this.personColumnPrefDao = personColumnPrefDao;
	}

	public Long store(PersonColumnPref personColumnPref, Person user) {
		if(personColumnPref == null) {
			throw new RuntimeException("Cannot save a null personColumnPref");
		}
		
		return personColumnPrefDao.store(personColumnPref, user);
	}

	@Override
	protected void attachComponents(PersonColumnPref personColumnPref, ComponentMap requiredComponents) {

	}

	public Collection<PersonColumnPrefListView> fetchCurrent(String tableName, Long personId) {
		return personColumnPrefDao.fetchCurrent(tableName, personId);
	}	
	
	public Collection<PersonColumnPrefListView> fetchAvailable(String tableName, Long personId) {
		return personColumnPrefDao.fetchAvailable(tableName, personId);
	}

	@Transactional
	public void update(String tableName, Person person, PersonColumnPrefsForm form) {
		personColumnPrefDao.deleteCurrent(tableName, person.getId());
		
		if(form.getCurrentColumns() != null) {
		
			int orderBy = 1;
			for(Long columnPrefId : form.getCurrentColumns()) {
			
				PersonColumnPref columnPref = new PersonColumnPref();
				columnPref.setColumnPrefId(columnPrefId);
				columnPref.setPersonId(person.getId());
				columnPref.setOrderBy(orderBy++);
				
				personColumnPrefDao.store(columnPref, person);
			}			
		}	
	}		
}
								
		