/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.personnel.services;

import java.util.Map;

import org.springframework.transaction.annotation.Transactional;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.personnel.Role;
import uk.ac.sanger.mig.personnel.dao.RoleDao;
								
public class RoleServiceImpl extends AbstractServiceImpl<Role> implements RoleService {
	
	private RoleDao roleDao;
							
	public void setRoleDao (RoleDao roleDao) {
		this.roleDao= roleDao;
	} 

	public Long storeAuthenticated(Role role, Person person) {
		return roleDao.store( role, person );	
	}	

	public Role fetchById(Long id, ComponentMap componentMap) {
		Role role = roleDao.fetchById(id);
		
		if(role != null)
			attachComponents(role, componentMap);
		
		return role;
	}

	public Map<String, Role> fetchAll(ComponentMap requiredComponents) {
		Map<String, Role> roles = roleDao.fetchAll();
		
		attachComponents(roles.values(), requiredComponents);
		
		return roles;
	}

	public Map<String, Role> fetchByPersonId(Long personId, ComponentMap requiredComponents) {
		Map<String, Role> roles = roleDao.fetchByPersonId(personId);
		
		attachComponents(roles.values(), requiredComponents);
		
		return roles;
	}
	
	@Transactional
	public int linkToPerson(Long roleId, Long personId) {
		return roleDao.linkToPerson(roleId, personId);		
	}
	
	@Transactional
	public int clearLinksToPerson(Long personId) {
		return roleDao.clearLinksToPerson(personId);
	}

	@Override
	protected void attachComponents(Role object, ComponentMap requiredComponents) {
		// TODO Auto-generated method stub		
	}		
}