/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.abc;



public class ABCGraphData {

	private double[] dataPoints;

	private String graphString;

	public String getGraphString() {
		return this.graphString;
	}

	public void setGraphString(String graphString) {
		this.graphString = graphString;
	}

	public ABCGraphData(String data) {
		decodeData(data);
		setGraphString(data);
	}

	private void decodeData(String data) {
	
		double[] list = new double[128];
		for(int i =0; i<data.length(); i++) {
			char c = data.charAt(i);
			double p = (double)c;
			list[i] = p;
		}
		 
		double offset = getOffset(list);
		for(int i =0; i<list.length; i++) {
			double val = list[i];
			list[i] = val - offset;
		}
		dataPoints = list;
		
	}

	public double[] getDataPoints() {
		return dataPoints;
	}

	public double maxDataPoint() {
		double max = 0;
		for(int i =0; i<dataPoints.length; i++) {
			double t = dataPoints[i];
			if(t > max) { max = t; }
		}
		return max;
	}

	public double minDataPoint() {
		double min = 256;
		for(int i =0; i<dataPoints.length; i++) {
			double t = dataPoints[i];
			if(t < min) { min = t; }
		}
		return min;
	}

	public double getOffset(double[] list) {
		double min = 256;
		for(int i =0; i<list.length; i++) {
			double t = list[i];
			if(t < min) { min = t; }
		}
		return min;
	}
	
}