/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.abc;


import java.util.Date;


public class AbcData {


	private Date analysisDate;
	private Long runId;
	private Long sampleId;
	private String barcodeId;
	
	/** Calculated Values*/
	private Double WBC;
	private Double RBC;
	private Double HGB;
	private Double HCT;
	private Long PLT;
	private Long MCV;
	private Double MCH;
	private Double MCHC;
	private Double RDW;
	private Double MPV;
	private Double EOS;

	private Double percentLYM;
	private Double percentMON;
	private Double percentGRA;
	private Double numLYM;
	private Double numMON;
	private Double numGRA;

	private ABCGraphData graphWBC;
	private ABCGraphData graphRBC;
	private ABCGraphData graphPLT;
	
	private BloodsParamRange WBCRange;
	private BloodsParamRange RBCRange;
	private BloodsParamRange HGBRange;
	private BloodsParamRange HCTRange;
	private BloodsParamRange PLTRange;
	private BloodsParamRange MCVRange;
	private BloodsParamRange MCHRange;
	private BloodsParamRange MCHCRange;
	private BloodsParamRange RDWRange;
	private BloodsParamRange MPVRange;
	private BloodsParamRange percentLYMRange;
	private BloodsParamRange percentMONRange;
	private BloodsParamRange percentGRARange;
	private BloodsParamRange numLYMRange;
	private BloodsParamRange numMONRange;
	private BloodsParamRange numGRARange;
	
	private String WBCError;
	private String RBCError;
	private String HGBError;
	private String HCTError;
	private String PLTError;
	private String MCVError;
	private String MCHError;
	private String MCHCError;
	private String RDWError;
	private String MPVError;
	private String percentLYMError;
	private String percentMONError;
	private String percentGRAError;
	private String numLYMError;
	private String numMONError;
	private String numGRAError;
	
	
	private String pltFlags;
	private String errorComments;
	private boolean failedRun;

	
	/**
	 * @return the failedRun
	 */
	public boolean isFailedRun() {
		return failedRun;
	}
	/**
	 * @param failedRun the failedRun to set
	 */
	public void setFailedRun(boolean failedRun) {
		this.failedRun = failedRun;
	}
	public String getErrorComments() {
		return errorComments;
	}
	public void setErrorComments(String errorComments) {
		
		String lastComment = getErrorComments();
		if(lastComment != null) {
			this.errorComments = lastComment + errorComments;
		}else{
			this.errorComments = errorComments;
		}
	}
	
	/**
	 * @return the pltFlags
	 */
	public String getPltFlags() {
		return this.pltFlags;
	}
	/**
	 * @param pltFlags the pltFlags to set
	 */
	public void setPltFlags(String pltFlags) {
		this.pltFlags = pltFlags;
	}
	/**
	 * @return the graphPLT
	 */
	public ABCGraphData getGraphPLT() {
		return graphPLT;
	}
	/**
	 * @param graphPLT the graphPLT to set
	 */
	public void setGraphPLT(ABCGraphData graphPLT) {
		this.graphPLT = graphPLT;
	}
	/**
	 * @return the graphRBC
	 */
	public ABCGraphData getGraphRBC() {
		return graphRBC;
	}
	/**
	 * @param graphRBC the graphRBC to set
	 */
	public void setGraphRBC(ABCGraphData graphRBC) {
		this.graphRBC = graphRBC;
	}
	/**
	 * @return the graphWBC
	 */
	public ABCGraphData getGraphWBC() {
		return graphWBC;
	}
	/**
	 * @param graphWBC the graphWBC to set
	 */
	public void setGraphWBC(ABCGraphData graphWBC) {
		this.graphWBC = graphWBC;
	}
	/**
	 * @return the sampleId
	 */
	public Long getSampleId() {
		return sampleId;
	}
	/**
	 * @param sampleId the sampleId to set
	 */
	public void setSampleId(Long sampleId) {
		this.sampleId = sampleId;
	}
	/**
	 * @return the analysisDate
	 */
	public Date getAnalysisDate() {
		return analysisDate;
	}
	/**
	 * @param analysisDate the analysisDate to set
	 */
	public void setAnalysisDate(Date analysisDate) {
		this.analysisDate = analysisDate;
	}
	/**
	 * @return the hCT
	 */
	public Double getHCT() {
		return HCT;
	}
	/**
	 * @param hct the hCT to set
	 */
	public void setHCT(Double hct) {
		HCT = hct;
	}
	/**
	 * @return the hGB
	 */
	public Double getHGB() {
		return HGB;
	}
	/**
	 * @param hgb the hGB to set
	 */
	public void setHGB(Double hgb) {
		HGB = hgb;
	}
	/**
	 * @return the mCH
	 */
	public Double getMCH() {
		return MCH;
	}
	/**
	 * @param mch the mCH to set
	 */
	public void setMCH(Double mch) {
		MCH = mch;
	}
	/**
	 * @return the mCHC
	 */
	public Double getMCHC() {
		return MCHC;
	}
	/**
	 * @param mchc the mCHC to set
	 */
	public void setMCHC(Double mchc) {
		MCHC = mchc;
	}
	/**
	 * @return the mCV
	 */
	public Long getMCV() {
		return MCV;
	}
	/**
	 * @param mcv the mCV to set
	 */
	public void setMCV(Long mcv) {
		MCV = mcv;
	}
	/**
	 * @return the mPV
	 */
	public Double getMPV() {
		return MPV;
	}
	/**
	 * @param mpv the mPV to set
	 */
	public void setMPV(Double mpv) {
		MPV = mpv;
	}
	/**
	 * @return the numGRA
	 */
	public Double getNumGRA() {
		if(numGRA == null) { 
			return 0.0;
		}
		return numGRA;
	}
	/**
	 * @param numGRA the numGRA to set
	 */
	public void setNumGRA(Double numGRA) {
		this.numGRA = numGRA;
	}
	/**
	 * @return the numLYM
	 */
	public Double getNumLYM() {
		if(numLYM == null) { 
			return 0.0;
		}
		return numLYM;
	}
	/**
	 * @param numLYM the numLYM to set
	 */
	public void setNumLYM(Double numLYM) {
		this.numLYM = numLYM;
	}
	/**
	 * @return the numMON
	 */
	public Double getNumMON() {
		if(numMON == null) { 
			return 0.0;
		}
		return numMON;
	}
	/**
	 * @param numMON the numMON to set
	 */
	public void setNumMON(Double numMON) {
		this.numMON = numMON;
	}
	/**
	 * @return the percentGRA
	 */
	public Double getPercentGRA() {
		if(percentGRA == null) { 
			return 0.0;
		}
		return percentGRA;
	}
	/**
	 * @param percentGRA the percentGRA to set
	 */
	public void setPercentGRA(Double percentGRA) {
		this.percentGRA = percentGRA;
	}
	/**
	 * @return the percentLYM
	 */
	public Double getPercentLYM() {
		if(percentLYM == null) { 
			return 0.0;
		}
		return percentLYM;
	}
	/**
	 * @param percentLYM the percentLYM to set
	 */
	public void setPercentLYM(Double percentLYM) {
		this.percentLYM = percentLYM;
	}
	/**
	 * @return the percentMON
	 */
	public Double getPercentMON() {
		if(percentMON == null) { 
			return 0.0;
		}
		return percentMON;
	}
	/**
	 * @param percentMON the percentMON to set
	 */
	public void setPercentMON(Double percentMON) {
		this.percentMON = percentMON;
	}
	/**
	 * @return the pLT
	 */
	public Long getPLT() {
		return PLT;
	}
	/**
	 * @param plt the pLT to set
	 */
	public void setPLT(Long plt) {
		PLT = plt;
	}
	/**
	 * @return the rBC
	 */
	public Double getRBC() {
		return RBC;
	}
	/**
	 * @param rbc the rBC to set
	 */
	public void setRBC(Double rbc) {
		RBC = rbc;
	}
	/**
	 * @return the rDW
	 */
	public Double getRDW() {
		return RDW;
	}
	/**
	 * @param rdw the rDW to set
	 */
	public void setRDW(Double rdw) {
		RDW = rdw;
	}
	/**
	 * @return the wBC
	 */
	public Double getWBC() {
		return WBC;
	}
	/**
	 * @param wbc the wBC to set
	 */
	public void setWBC(Double wbc) {
		WBC = wbc;
	}

	/**
	 * @return the eOS
	 */
	public Double getEOS() {
		return this.EOS;
	}
	/**
	 * @param eos the eOS to set
	 */
	public void setEOS(Double eos) {
		this.EOS = eos;
	}
	/**
	 * @return the runId
	 */
	public Long getRunId() {
		return this.runId;
	}
	
	public BloodsParamRange getHCTRange() {
		if(HCTRange == null) { 
			return new BloodsParamRange();
		}
		return HCTRange;
	}
	public void setHCTRange(BloodsParamRange range) {
		HCTRange = range;
	}
	public BloodsParamRange getHGBRange() {
		if(HGBRange == null) { 
			return new BloodsParamRange();
		}
		return HGBRange;
	}
	public void setHGBRange(BloodsParamRange range) {
		HGBRange = range;
	}
	public BloodsParamRange getMCHCRange() {
		if(MCHCRange == null) { 
			return new BloodsParamRange();
		}
		return MCHCRange;
	}
	public void setMCHCRange(BloodsParamRange range) {
		MCHCRange = range;
	}
	public BloodsParamRange getMCHRange() {
		if(MCHRange == null) { 
			return new BloodsParamRange();
		}
		return MCHRange;
	}
	public void setMCHRange(BloodsParamRange range) {
		MCHRange = range;
	}
	public BloodsParamRange getMCVRange() {
		if(MCVRange == null) { 
			return new BloodsParamRange();
		}
		return MCVRange;
	}
	public void setMCVRange(BloodsParamRange range) {
		MCVRange = range;
	}
	public BloodsParamRange getMPVRange() {
		if(MPVRange == null) { 
			return new BloodsParamRange();
		}
		return MPVRange;
	}
	public void setMPVRange(BloodsParamRange range) {
		MPVRange = range;
	}
	public BloodsParamRange getNumGRARange() {
		if(numGRARange == null) { 
			return new BloodsParamRange();
		}
		return numGRARange;
	}
	public void setNumGRARange(BloodsParamRange numGRARange) {
		this.numGRARange = numGRARange;
	}
	public BloodsParamRange getNumLYMRange() {
		if(numLYMRange == null) { 
			return new BloodsParamRange();
		}
		return numLYMRange;
	}
	public void setNumLYMRange(BloodsParamRange numLYMRange) {
		this.numLYMRange = numLYMRange;
	}
	public BloodsParamRange getNumMONRange() {
		if(numMONRange == null) { 
			return new BloodsParamRange();
		}
		return numMONRange;
	}
	public void setNumMONRange(BloodsParamRange numMONRange) {
		this.numMONRange = numMONRange;
	}
	public BloodsParamRange getPercentGRARange() {
		if(percentGRARange == null) { 
			return new BloodsParamRange();
		}
		return percentGRARange;
	}
	public void setPercentGRARange(BloodsParamRange percentGRARange) {
		this.percentGRARange = percentGRARange;
	}
	public BloodsParamRange getPercentLYMRange() {
		if(percentLYMRange == null) { 
			return new BloodsParamRange();
		}
		return percentLYMRange;
	}
	public void setPercentLYMRange(BloodsParamRange percentLYMRange) {
		this.percentLYMRange = percentLYMRange;
	}
	public BloodsParamRange getPercentMONRange() {
		if(percentMONRange == null) { 
			return new BloodsParamRange();
		}
		return percentMONRange;
	}
	public void setPercentMONRange(BloodsParamRange percentMONRange) {
		this.percentMONRange = percentMONRange;
	}
	public BloodsParamRange getPLTRange() {
		if(PLTRange == null) { 
			return new BloodsParamRange();
		}
		return PLTRange;
	}
	public void setPLTRange(BloodsParamRange range) {
		PLTRange = range;
	}
	public BloodsParamRange getRBCRange() {
		if(RBCRange == null) { 
			return new BloodsParamRange();
		}
		return RBCRange;
	}
	public void setRBCRange(BloodsParamRange range) {
		RBCRange = range;
	}
	public BloodsParamRange getRDWRange() {
		if(RDWRange == null) { 
			return new BloodsParamRange();
		}
		return RDWRange;
	}
	public void setRDWRange(BloodsParamRange range) {
		RDWRange = range;
	}
	public BloodsParamRange getWBCRange() {
		if(WBCRange == null) { 
			return new BloodsParamRange();
		}
		return WBCRange;
	}
	public void setWBCRange(BloodsParamRange range) {
		WBCRange = range;
	}
	/**
	 * @param runId the runId to set
	 */
	public void setRunId(Long runId) {
		this.runId = runId;
	}
	/**
	 * @return the barcodeId
	 */
	public String getBarcodeId() {
		return this.barcodeId;
	}
	/**
	 * @param barcodeId the barcodeId to set
	 */
	public void setBarcodeId(String barcodeId) {
		this.barcodeId = barcodeId;
	}
	/**
	 * @return the hCTError
	 */
	public String getHCTError() {
		return HCTError;
	}
	/**
	 * @param error the hCTError to set
	 */
	public void setHCTError(String error) {
		HCTError = error;
	}
	/**
	 * @return the hGBError
	 */
	public String getHGBError() {
		return HGBError;
	}
	/**
	 * @param error the hGBError to set
	 */
	public void setHGBError(String error) {
		HGBError = error;
	}
	/**
	 * @return the mCHCError
	 */
	public String getMCHCError() {
		return MCHCError;
	}
	/**
	 * @param error the mCHCError to set
	 */
	public void setMCHCError(String error) {
		MCHCError = error;
	}
	/**
	 * @return the mCHError
	 */
	public String getMCHError() {
		return MCHError;
	}
	/**
	 * @param error the mCHError to set
	 */
	public void setMCHError(String error) {
		MCHError = error;
	}
	/**
	 * @return the mCVError
	 */
	public String getMCVError() {
		return MCVError;
	}
	/**
	 * @param error the mCVError to set
	 */
	public void setMCVError(String error) {
		MCVError = error;
	}
	/**
	 * @return the mPVError
	 */
	public String getMPVError() {
		return MPVError;
	}
	/**
	 * @param error the mPVError to set
	 */
	public void setMPVError(String error) {
		MPVError = error;
	}
	/**
	 * @return the numGRAError
	 */
	public String getNumGRAError() {
		return numGRAError;
	}
	/**
	 * @param numGRAError the numGRAError to set
	 */
	public void setNumGRAError(String numGRAError) {
		this.numGRAError = numGRAError;
	}
	/**
	 * @return the numLYMError
	 */
	public String getNumLYMError() {
		return numLYMError;
	}
	/**
	 * @param numLYMError the numLYMError to set
	 */
	public void setNumLYMError(String numLYMError) {
		this.numLYMError = numLYMError;
	}
	/**
	 * @return the numMONError
	 */
	public String getNumMONError() {
		return numMONError;
	}
	/**
	 * @param numMONError the numMONError to set
	 */
	public void setNumMONError(String numMONError) {
		this.numMONError = numMONError;
	}
	/**
	 * @return the percentGRAError
	 */
	public String getPercentGRAError() {
		return percentGRAError;
	}
	/**
	 * @param percentGRAError the percentGRAError to set
	 */
	public void setPercentGRAError(String percentGRAError) {
		this.percentGRAError = percentGRAError;
	}
	/**
	 * @return the percentLYMError
	 */
	public String getPercentLYMError() {
		return percentLYMError;
	}
	/**
	 * @param percentLYMError the percentLYMError to set
	 */
	public void setPercentLYMError(String percentLYMError) {
		this.percentLYMError = percentLYMError;
	}
	/**
	 * @return the percentMONError
	 */
	public String getPercentMONError() {
		return percentMONError;
	}
	/**
	 * @param percentMONError the percentMONError to set
	 */
	public void setPercentMONError(String percentMONError) {
		this.percentMONError = percentMONError;
	}
	/**
	 * @return the pLTError
	 */
	public String getPLTError() {
		return PLTError;
	}
	/**
	 * @param error the pLTError to set
	 */
	public void setPLTError(String error) {
		PLTError = error;
	}
	/**
	 * @return the rBCError
	 */
	public String getRBCError() {
		return RBCError;
	}
	/**
	 * @param error the rBCError to set
	 */
	public void setRBCError(String error) {
		RBCError = error;
	}
	/**
	 * @return the rDWError
	 */
	public String getRDWError() {
		return RDWError;
	}
	/**
	 * @param error the rDWError to set
	 */
	public void setRDWError(String error) {
		RDWError = error;
	}
	/**
	 * @return the wBCError
	 */
	public String getWBCError() {
		return WBCError;
	}
	/**
	 * @param error the wBCError to set
	 */
	public void setWBCError(String error) {
		WBCError = error;
	}



}