/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.abc;

import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.ComponentEnum;
import uk.ac.sanger.mig.common.DictionaryEntry;


public class BloodsData extends AuthenticatedDataObject  {

	public enum Component implements ComponentEnum {
		ALL_COMPONENTS  //add additional component enums here as needed for this AuthenticatedDataObject
	}

    private Long runId;
    private DictionaryEntry parameter;
    private Long parameterId;        
    private String value;        
    private String units;        
    private Double refHi;        
    private Double refLo;        
    private Long createdBy;        

    private String lot1;
    private String bottle1;
    private String lot2;
    private String bottle2;
    private DictionaryEntry errorCode1;
    private Long errorCode1Id;
    private DictionaryEntry errorCode2;
    private Long errorCode2Id;
    
    private BloodsParamRange range;
    private Long rangeId;
    
    private DictionaryEntry resultStatus;
    private Long resultStatusId;
    
    private Double meanValue;
    private Double sdValue;
    
    
    
    /**
	 * @return the meanValue
	 */
	public Double getMeanValue() {
		return meanValue;
	}

	/**
	 * @param meanValue the meanValue to set
	 */
	public void setMeanValue(Double meanValue) {
		this.meanValue = meanValue;
	}

	/**
	 * @return the sdValue
	 */
	public Double getSdValue() {
		return sdValue;
	}

	/**
	 * @param sdValue the sdValue to set
	 */
	public void setSdValue(Double sdValue) {
		this.sdValue = sdValue;
	}

	public DictionaryEntry getResultStatus() {
		return resultStatus;
	}

	public void setResultStatus(DictionaryEntry resultStatus) {
		this.resultStatus = resultStatus;
	}

	public Long getResultStatusId() {
		return resultStatusId;
	}

	public void setResultStatusId(Long resultStatusId) {
		this.resultStatusId = resultStatusId;
	}

	public Long getRangeId() {
		return rangeId;
	}

	public void setRangeId(Long rangeId) {
		this.rangeId = rangeId;
	}

	public BloodsParamRange getRange() {
		return range;
	}

	public void setRange(BloodsParamRange range) {
		this.range = range;
	}

	public DictionaryEntry getErrorCode1() {
		return errorCode1;
	}

	public void setErrorCode1(DictionaryEntry errorCode1) {
		this.errorCode1 = errorCode1;
	}

	public DictionaryEntry getErrorCode2() {
		return errorCode2;
	}

	public void setErrorCode2(DictionaryEntry errorCode2) {
		this.errorCode2 = errorCode2;
	}

	public DictionaryEntry getParameter() {
		return parameter;
	}

	public void setParameter(DictionaryEntry parameter) {
		this.parameter = parameter;
	}

	public Long getRunId() {
        return runId;
    }
    
    public void setRunId(Long runId) {
        this.runId = runId;
    }                                                                                                                                            
    public Long getParameterId() {
        return parameterId;
    }
    
    public void setParameterId(Long parameterId) {
        this.parameterId = parameterId;
    }                                                                                                                                            
    public String getValue() {
        return value;
    }
    
    public void setValue(String value) {
        this.value = value;
    }                                                                                                                                            
    public String getUnits() {
        return units;
    }
    
    public void setUnits(String units) {
        this.units = units;
    }                                                                                                                                            
    public Double getRefHi() {
        return refHi;
    }
    
    public void setRefHi(Double refHi) {
        this.refHi = refHi;
    }                                                                                                                                            
    public Double getRefLo() {
        return refLo;
    }
    
    public void setRefLo(Double refLo) {
        this.refLo = refLo;
    }                                                                                                                                            
    public Long getCreatedBy() {
        return createdBy;
    }
    
    public void setCreatedBy(Long createdBy) {
        this.createdBy = createdBy;
    }

	public String getBottle1() {
		return bottle1;
	}

	public void setBottle1(String bottle1) {
		this.bottle1 = bottle1;
	}

	public String getBottle2() {
		return bottle2;
	}

	public void setBottle2(String bottle2) {
		this.bottle2 = bottle2;
	}

	public Long getErrorCode1Id() {
		return errorCode1Id;
	}

	public void setErrorCode1Id(Long errorCode1Id) {
		this.errorCode1Id = errorCode1Id;
	}

	public Long getErrorCode2Id() {
		return errorCode2Id;
	}

	public void setErrorCode2Id(Long errorCode2Id) {
		this.errorCode2Id = errorCode2Id;
	}

	public String getLot1() {
		return lot1;
	}

	public void setLot1(String lot1) {
		this.lot1 = lot1;
	}

	public String getLot2() {
		return lot2;
	}

	public void setLot2(String lot2) {
		this.lot2 = lot2;
	}                                                                                                                                            




}