/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.abc;

import java.util.Date;

import uk.ac.sanger.mig.common.PaginatedSearchBean;


/**
 * This class serves as wrapper around domain object POJO for searching on particular fields that are set.
 * It also inherits orderBy and sortOrder methods from SortableSearchBean enabling sort functionlity.
 *
 * If you also need pagination functionality, subclass PaginatedSearchBean which extends SortableSearchBean
 * 
 * NOTE: Using wrapper is just one appraoch to search bean. You could alternatively created a standalone
 * search bean that effectively mimics all of the fields with getters and setters of your domain object POJO.
 */

public class BloodsRunSearchBean extends PaginatedSearchBean  {
	
	private Long id;
	private Long mouseId;
	private String barcode; 
	private String barcodeDescription;

	private String colonyName;
	private Long colonyInfoId;
	
	private String cohortName;
	private Long cohortId;
		
	private String strainName;
	private Long strainId;	
	
	private Date sampledDateFrom;
	private Date sampledDateTo;
	
	private boolean rejected;

	private Long instrumentId;
	
	private BloodsRun bloodsRun;

	
	public Long getInstrumentId() {
		return instrumentId;
	}

	public void setInstrumentId(Long instrumentId) {
		this.instrumentId = instrumentId;
	}

	public BloodsRun getBloodsRun() {
		return bloodsRun;
	}

	public void setBloodsRun(BloodsRun bloodsRun) {
		this.bloodsRun = bloodsRun;
	}

	
	public Long getMouseId() {
		return mouseId;
	}

	public void setMouseId(Long mouseId) {
		this.mouseId = mouseId;
	}

	public String getBarcode() {
		return barcode;
	}

	public void setBarcode(String barcode) {
		this.barcode = barcode;
	}

	public String getBarcodeDescription() {
		return barcodeDescription;
	}

	public void setBarcodeDescription(String barcodeDescription) {
		this.barcodeDescription = barcodeDescription;
	}

	public Long getCohortId() {
		return cohortId;
	}

	public void setCohortId(Long cohortId) {
		this.cohortId = cohortId;
	}

	public String getCohortName() {
		return cohortName;
	}

	public void setCohortName(String cohortName) {
		this.cohortName = cohortName;
	}

	public Long getColonyInfoId() {
		return colonyInfoId;
	}

	public void setColonyInfoId(Long colonyInfoId) {
		this.colonyInfoId = colonyInfoId;
	}

	public String getColonyName() {
		return colonyName;
	}

	public void setColonyName(String colonyName) {
		this.colonyName = colonyName;
	}

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public boolean isRejected() {
		return rejected;
	}

	public void setRejected(boolean rejected) {
		this.rejected = rejected;
	}

	public Date getSampledDateFrom() {
		return sampledDateFrom;
	}

	public void setSampledDateFrom(Date sampledDateFrom) {
		this.sampledDateFrom = sampledDateFrom;
	}

	public Date getSampledDateTo() {
		return sampledDateTo;
	}

	public void setSampledDateTo(Date sampledDateTo) {
		this.sampledDateTo = sampledDateTo;
	}

	public Long getStrainId() {
		return strainId;
	}

	public void setStrainId(Long strainId) {
		this.strainId = strainId;
	}

	public String getStrainName() {
		return strainName;
	}

	public void setStrainName(String strainName) {
		this.strainName = strainName;
	}
	
	
	
}