/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.abc.controllers;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.bind.ServletRequestBindingException;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.AbstractCancellableFormController;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.phenotyping.abc.BloodsData;
import uk.ac.sanger.mig.phenotyping.abc.BloodsManualData;
import uk.ac.sanger.mig.phenotyping.abc.BloodsParamRange;
import uk.ac.sanger.mig.phenotyping.abc.BloodsRun;
import uk.ac.sanger.mig.phenotyping.abc.forms.BloodsParamRangeForm;
import uk.ac.sanger.mig.phenotyping.abc.forms.ManualBloodDataForm;
import uk.ac.sanger.mig.phenotyping.abc.services.BloodsDataService;
import uk.ac.sanger.mig.phenotyping.abc.services.BloodsParamRangeService;
import uk.ac.sanger.mig.phenotyping.abc.services.BloodsRunService;

public class AddManualBloodDataFormController extends AbstractCancellableFormController {

	private BloodsParamRangeService bloodsParamRangeService;
	private BloodsRunService bloodsRunService;
	private BloodsDataService bloodsDataService;

	public void setBloodsDataService(BloodsDataService bloodsDataService) {
		this.bloodsDataService = bloodsDataService;
	}

	public void setBloodsRunService(BloodsRunService bloodsRunService) {
		this.bloodsRunService = bloodsRunService;
	}

	public void setBloodsParamRangeService(BloodsParamRangeService bloodsParamRangeService) {
		this.bloodsParamRangeService = bloodsParamRangeService;
	}

	@Override
	protected Map referenceData(HttpServletRequest request, Object command, Errors errors) throws Exception {

		Map<String,Object> formMetaData = new HashMap<String,Object>();

		HashMap<Long,String> instrument = new HashMap<Long, String>();

		instrument.put(1L,"Scil Vet ABC Analyser");
		instrument.put(2L,"Olympus AU400");

		formMetaData.put("instrument", instrument);

		return formMetaData;
	}


	@Override
	protected boolean isFormChangeRequest(HttpServletRequest request) {
		String changeRequest = null;

		try {
			changeRequest = ServletRequestUtils.getStringParameter(request, "changeForm");
		}
		catch(ServletRequestBindingException e) {

		}

		if(changeRequest != null && changeRequest.length() >0) {
			return true;
		}
		else {
			return false;
		}
	}

	@Override
	protected void onFormChange(HttpServletRequest request, HttpServletResponse response, Object command) throws Exception {
		ManualBloodDataForm form = (ManualBloodDataForm)command;
		String changeRequest = ServletRequestUtils.getRequiredStringParameter(request, "changeForm");

		if(changeRequest.equals("1")) {
			form.setInstrumentId(1L);
		}else if(changeRequest.equals("2")){
			form.setInstrumentId(2L);
		}
		Collection<BloodsParamRange> bloodsParamRanges = bloodsParamRangeService.fetchCurrentParamRangesByInstrument(form.getInstrumentId());

		form.setRanges(bloodsParamRanges);

		initBloodData(form);
	}

	@Override
	protected Object formBackingObject(HttpServletRequest httpServletRequest) throws Exception {
		ManualBloodDataForm form = (ManualBloodDataForm)createCommand();

		Long instrumentId = form.getInstrumentId();
		// Default to olympus, abc wont need changing often, if at all.
		if(instrumentId == null) {
			instrumentId = 2L;
			form.setInstrumentId(2L);
		}

		Collection<BloodsParamRange> bloodsParamRanges = bloodsParamRangeService.fetchCurrentParamRangesByInstrument(instrumentId);
		form.setRanges(bloodsParamRanges);

		initBloodData(form);

		return form;
	}

	private void initBloodData(ManualBloodDataForm form) {

		Collection<BloodsData> data =  new ArrayList<BloodsData>();

		for(BloodsParamRange range : form.getRanges()) {
			Long paramId = range.getParameterId();
			BloodsData d = new BloodsData();
			d.setParameterId(paramId);
			data.add(d);
		}

		form.setData(data);
	}


	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response,
			Object command, BindException errors) throws Exception {
		ManualBloodDataForm form = (ManualBloodDataForm) command;
		Collection<BloodsData> bloodsData = form.getData();

		Person user = RequestUtils.getUser(request);

		// make new Run.
		BloodsRun run =  new BloodsRun();
		run.setComments("Manually added by "+user.getUserName());
		run.setCreator(user);
		run.setCreatedDate(new Date());
		run.setInstrumentId(form.getInstrumentId());
		run.setRunDate(form.getRunDate());
		run.setMouseId(form.getMouseId());

		Long runId = bloodsRunService.storeAuthenticated(run,user);
		if(runId != null) {
			for(BloodsData data: bloodsData) {
				if(data.getValue() != null) {
					data.setRunId(runId);
					data.setCreator(user);
					data.setCreatedDate(new Date());
					bloodsDataService.storeAuthenticated(data, user);
				}
			}
		}
		return new ModelAndView(getSuccessView()); // show list view
	}

	/*
	 * Create new range with the original values and overwrite with edited if found.
	 */
	private BloodsParamRange populateEditedRange(BloodsParamRange orig) {

		BloodsParamRange newRange = new BloodsParamRange();
		newRange.setParameterId(orig.getParameterId());

		if(orig.getNewRefHi() != null) {
			newRange.setRefHi(orig.getNewRefHi());
		}else{
			newRange.setRefHi(orig.getRefHi());
		}

		if(orig.getNewRefLo() != null) {
			newRange.setRefLo(orig.getNewRefLo());
		}else{
			newRange.setRefLo(orig.getRefLo());
		}

		if(orig.getNewInstrumentHi() != null) {
			newRange.setInstrumentHi(orig.getNewInstrumentHi());
		}else{
			newRange.setInstrumentHi(orig.getInstrumentHi());
		}

		if(orig.getNewInstrumentLo() != null) {
			newRange.setInstrumentLo(orig.getNewInstrumentLo());
		}else{
			newRange.setInstrumentLo(orig.getInstrumentLo());
		}

		return newRange;
	}


	private void addOlympusUnits(Collection<BloodsData> data) {

		for(BloodsData d : data) {
			switch(Integer.parseInt(d.getParameter().getDescription())){
			case 99: case 98: case 97: case 25: case 23: case 22: case 21:
			case 16: case 9: case 8: case 5: case 3: case 2: case 1:
				d.setUnits("mmol/l");
				break;
			case 20: case 15: case 13: case 12: case 11: case 4:
				d.setUnits("U/l");
				break;
			case 24: case 18: case 14: case 10:
				d.setUnits("\u00B5mol/l");
				break;
			case 7: case 6:
				d.setUnits("g/l");
				break;
			default:
				d.setUnits("Unknown");
			break;
			}
		}
	}

	private void addABCUnits(Collection<BloodsData> data) {

		for(BloodsData d : data) {
			switch(Integer.parseInt(d.getParameter().getDescription())){
			case 4: case 9:
				d.setUnits("g/dl");
				break;
			case 5: case 10: case 12: case 13: case 14:
				d.setUnits("%");
				break;
			case 2: case 6: case 15: case 16: case 17:
				d.setUnits("10<sup>3</sup>/mm<sup>3</sup>");
				break;
			case 3:
				d.setUnits("10<sup>6</sup>m<sup>3</sup>");
				break;
			case 7: case 11:
				d.setUnits("\u00B5m<sup>3</sup>");
				break;
			case 8:
				d.setUnits("pg");
				break;
			default:
				d.setUnits("");
			break;
			}
		}
	}

}