/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.abc.controllers;

import java.text.SimpleDateFormat;
import java.util.Collection;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.AbstractSearchFormController;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.mousetracking.Mouse;
import uk.ac.sanger.mig.mousetracking.services.MouseService;
import uk.ac.sanger.mig.phenotyping.abc.BloodsRun;
import uk.ac.sanger.mig.phenotyping.abc.BloodsRunSearchBean;
import uk.ac.sanger.mig.phenotyping.abc.services.BloodsRunService;

public class SearchBloodSampleController extends AbstractSearchFormController {

	private BloodsRunService bloodsRunService;
	private MouseService mouseService;
	
	public void setBloodsRunService(BloodsRunService bloodsRunService) {
		this.bloodsRunService = bloodsRunService;
	}

	public void setMouseService(MouseService mouseService) {
		this.mouseService = mouseService;
	}



	@Override
	protected ModelAndView onSearch(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		BloodsRunSearchBean searchBean = (BloodsRunSearchBean)command;
		searchBean.setQueryName(BloodsRunService.BLOOD_SEARCH_QUERY);
		searchBean.setSessionId(request.getSession().getId());
		
		
		Map<String, Object> model = new HashMap<String, Object>();		
		Collection<BloodsRun> samples = bloodsRunService.search(searchBean, ComponentMap.of(BloodsRun.Component.SERUM_BARCODE));	
		// Insert mouse info
		for(BloodsRun run : samples) {
			run.setMouse(mouseService.fetchById(run.getMouseId(), ComponentMap.of(Mouse.Component.COLONY, Mouse.Component.ALLELES)));
		}
	
		model.put("samples", samples);
	
		if(searchBean.getInstrumentId() == 2L){
			model.put("requireHitachiBarcode", true);
		}
		
		return new ModelAndView(getSuccessView(), model);
	}

	@Override
	protected Map referenceData(HttpServletRequest request, Object obj, Errors errors) throws Exception {
		Map<String,Object> formMetaData = new HashMap<String,Object>();	
		
		HashMap<Long,String> instrument = new HashMap<Long, String>();
		instrument.put(1L,"Scil Vet ABC Analyser");
		instrument.put(2L,"Olympus AU400");
		instrument.put(0L,"All");
		
		SimpleDateFormat sdf = new SimpleDateFormat("dd-MMM-yyyy");
		String today = sdf.format(new Date());
		formMetaData.put("today", today);
		
		formMetaData.put("instrument", instrument);
		
		return formMetaData;
	}

	
	
}




