/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.abc.controllers;

import java.util.Collection;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.ParameterizableViewController;

import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.mousetracking.Mouse;
import uk.ac.sanger.mig.mousetracking.services.MouseService;
import uk.ac.sanger.mig.phenotyping.abc.ABCGraphData;
import uk.ac.sanger.mig.phenotyping.abc.AbcData;
import uk.ac.sanger.mig.phenotyping.abc.BloodsData;
import uk.ac.sanger.mig.phenotyping.abc.BloodsRun;
import uk.ac.sanger.mig.phenotyping.abc.services.BloodsDataService;
import uk.ac.sanger.mig.phenotyping.abc.services.BloodsParamRangeService;
import uk.ac.sanger.mig.phenotyping.abc.services.BloodsRunService;
import uk.ac.sanger.mig.phenotyping.abc.views.AbcBloodDataChart;
import ChartDirector.MultiChart;

public class ViewOneAbcDataController extends ParameterizableViewController {
	
	private BloodsRunService bloodsRunService;
	private BloodsDataService bloodsDataService;
	private BloodsParamRangeService bloodsParamRangeService;
	private MouseService mouseService;
	private DictionaryService dictionaryService;
	
	public void setBloodsRunService(BloodsRunService bloodsRunService) {
		this.bloodsRunService = bloodsRunService;
	}
	public void setBloodsDataService(BloodsDataService bloodsDataService) {
		this.bloodsDataService = bloodsDataService;
	}
	public void setBloodsParamRangeService(
			BloodsParamRangeService bloodsParamRangeService) {
		this.bloodsParamRangeService = bloodsParamRangeService;
	}
	public void setMouseService(MouseService mouseService) {
		this.mouseService = mouseService;
	}
	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	protected ModelAndView handleRequestInternal(HttpServletRequest request, HttpServletResponse response) throws Exception {
		Long id = ServletRequestUtils.getRequiredLongParameter(request, "id");		
	
		AbcData data = new AbcData();

		BloodsRun run = bloodsRunService.fetchById(id, null);
		if(run != null) { 
			data.setAnalysisDate(run.getRunDate());
			Mouse mouse = mouseService.fetchById(run.getMouseId(), null);
			if(mouse != null) {
				data.setBarcodeId(mouse.getBarcode());
				data.setSampleId(mouse.getId());
			}else{
				data.setBarcodeId("Unable to retrieve!");
				data.setSampleId(null);
			}
			data.setRunId(id);
			data.setErrorComments(run.getComments());
			
			data.setFailedRun(run.isFailed());
		}

		Collection<BloodsData> runData = bloodsDataService.fetchByRunId(id, null);

		// Error code dictionary entries.
		Collection<DictionaryEntry>  errorCodes  = dictionaryService.fetchDependant(DictionaryEnum.PHENOTYPING_ERROR_CODES, 1L, "INSTRUMENT_ID");

		if(runData != null) {
			for(BloodsData obj : runData) {

				// Get errors back from database.
				String error = "";
				if(obj.getErrorCode1Id() != null) {
					DictionaryEntry err = dictionaryService.fetchEntry(DictionaryEnum.PHENOTYPING_ERROR_CODES, obj.getErrorCode1Id());
					if(err.getName().equals("H") || err.getName().equals("L")) {
						error =  "<b><font color='blue'> " + err.getName() + "</font></b>";
					}else{
						error =  "<b><font color='red'> " + err.getName() + "</font></b>";
					}
				}

				if(obj.getParameterId() == 1){
					data.setPltFlags(obj.getValue());
				}else if(obj.getParameterId()== 2){
					data.setWBC(Double.valueOf(obj.getValue()));
					data.setWBCRange(bloodsParamRangeService.fetchById(obj.getRangeId(), null));
					data.setWBCError(error);
				}else if(obj.getParameterId() == 3){
					data.setRBC(Double.valueOf(obj.getValue()));
					data.setRBCRange(bloodsParamRangeService.fetchById(obj.getRangeId(), null));
					data.setRBCError(error);
				}else if(obj.getParameterId() == 4){
					data.setHGB(Double.valueOf(obj.getValue()));
					data.setHGBRange(bloodsParamRangeService.fetchById(obj.getRangeId(), null));
					data.setHGBError(error);
				}else if(obj.getParameterId() == 5){
					data.setHCT(Double.valueOf(obj.getValue()));
					data.setHCTRange(bloodsParamRangeService.fetchById(obj.getRangeId(), null));
					data.setHCTError(error);
				}else if(obj.getParameterId() == 6){
					data.setPLT(Long.valueOf(obj.getValue()));
					data.setPLTRange(bloodsParamRangeService.fetchById(obj.getRangeId(), null));
					data.setPLTError(error);
				}else if(obj.getParameterId() == 7){
					data.setMCV(Long.valueOf(obj.getValue()));
					data.setMCVRange(bloodsParamRangeService.fetchById(obj.getRangeId(), null));
					data.setMCVError(error);
				}else if(obj.getParameterId() == 8){
					data.setMCH(Double.valueOf(obj.getValue()));
					data.setMCHRange(bloodsParamRangeService.fetchById(obj.getRangeId(), null));
					data.setMCHError(error);
				}else if(obj.getParameterId() == 9){
					data.setMCHC(Double.valueOf(obj.getValue()));
					data.setMCHCRange(bloodsParamRangeService.fetchById(obj.getRangeId(), null));
					data.setMCHCError(error);
				}else if(obj.getParameterId() == 10){
					data.setRDW(Double.valueOf(obj.getValue()));
					data.setRDWRange(bloodsParamRangeService.fetchById(obj.getRangeId(), null));
					data.setRDWError(error);
				}else if(obj.getParameterId() == 11){
					data.setMPV(Double.valueOf(obj.getValue()));
					data.setMPVRange(bloodsParamRangeService.fetchById(obj.getRangeId(), null));
					data.setMPVError(error);
				}else if(obj.getParameterId() == 12){
					data.setPercentLYM(Double.valueOf(obj.getValue()));
					data.setPercentLYMRange(bloodsParamRangeService.fetchById(obj.getRangeId(), null));
					data.setPercentLYMError(error);
				}else if(obj.getParameterId() == 13){
					data.setPercentMON(Double.valueOf(obj.getValue()));
					data.setPercentMONRange(bloodsParamRangeService.fetchById(obj.getRangeId(), null));
					data.setPercentMONError(error);
				}else if(obj.getParameterId() == 14){
					data.setPercentGRA(Double.valueOf(obj.getValue()));
					data.setPercentGRARange(bloodsParamRangeService.fetchById(obj.getRangeId(), null));
					data.setPercentGRAError(error);
				}else if(obj.getParameterId() == 15){
					data.setNumLYM(Double.valueOf(obj.getValue()));
					data.setNumLYMRange(bloodsParamRangeService.fetchById(obj.getRangeId(), null));
					data.setNumLYMError(error);
				}else if(obj.getParameterId() == 16){
					data.setNumMON(Double.valueOf(obj.getValue()));
					data.setNumMONRange(bloodsParamRangeService.fetchById(obj.getRangeId(), null));
					data.setNumMONError(error);
				}else if(obj.getParameterId() == 17){
					data.setNumGRA(Double.valueOf(obj.getValue()));
					data.setNumGRARange(bloodsParamRangeService.fetchById(obj.getRangeId(), null));
					data.setNumGRAError(error);
				}else if(obj.getParameterId() == 18){
					data.setGraphPLT(new ABCGraphData(obj.getValue()));
				}else if(obj.getParameterId() == 19){
					data.setGraphRBC(new ABCGraphData(obj.getValue()));
				}else if(obj.getParameterId() == 20){
					data.setGraphWBC(new ABCGraphData(obj.getValue()));
				}else if(obj.getParameterId() == 21){
					data.setEOS(Double.valueOf(obj.getValue()));
				}
			}
		}

		
		AbcBloodDataChart chart = new AbcBloodDataChart(data.getGraphPLT(), data.getGraphRBC(), 
					data.getGraphWBC(), data.getPercentLYM(), data.getPercentMON());
		MultiChart m = chart.getChart();
		m.makeSession(request, "bloodchart");
		
		
		return new ModelAndView(getViewName(), "abcData", data);
		
	}
}

