/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.abc.dao;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.charting.ChartData;
import uk.ac.sanger.mig.charting.DatabaseChartData;
import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.phenotyping.abc.BloodsData;
import uk.ac.sanger.mig.phenotyping.abc.BloodsDataSearchBean;
import uk.ac.sanger.mig.phenotyping.olympus.forms.SerumQCForm;

public class BloodsDataDaoSpringImpl extends AbstractDaoSpringImpl<BloodsData> implements BloodsDataDao {


	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, BloodsData bloodsData) {
		sql.addLongParam(bloodsData.getRunId(), "RUN_ID");
		sql.addLongParam(bloodsData.getParameterId(), "PARAMETER_ID");
		sql.addStringParam(bloodsData.getValue(), "VALUE");
		sql.addStringParam(bloodsData.getUnits(), "UNITS");
		sql.addDoubleParam(bloodsData.getRefHi(), "REF_HI");
		sql.addDoubleParam(bloodsData.getRefLo(), "REF_LO");
		sql.addLongParam(bloodsData.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(bloodsData.getCreatedBy(), "CREATED_BY");
		sql.addDateParam(bloodsData.getCreatedDate(), "CREATED_DATE");
		sql.addStringParam(bloodsData.getEditedBy(), "EDITED_BY");
		sql.addDateParam(bloodsData.getEditDate(), "EDIT_DATE");		
		sql.addStringParam(bloodsData.getLot1(), "LOT_1");
		sql.addStringParam(bloodsData.getBottle1(), "BOTTLE_1");
		sql.addStringParam(bloodsData.getLot2(), "LOT_2");
		sql.addStringParam(bloodsData.getBottle2(), "BOTTLE_2");
		sql.addLongParam(bloodsData.getErrorCode1Id(), "ERROR_1_ID");
		sql.addLongParam(bloodsData.getErrorCode2Id(), "ERROR_2_ID");
		sql.addLongParam(bloodsData.getRangeId(), "PARAM_RANGE_ID");
		sql.addLongParam(bloodsData.getResultStatusId(), "RESULT_STATUS_ID");
		
		sql.addLongParam(bloodsData.getId(), "ID");
	}

	
	public Collection<BloodsData> fetchByRunId(Long runId) {

		String sql = " select * from phn_bloods_data where run_id = ? " +
				"order by parameter_id";
		
		Collection<BloodsData> data = getSimpleJdbcTemplate().query(sql, getRowMapper(), runId);
		
		return (data == null) ? new ArrayList<BloodsData>() : data;
	
	}
	
	// Fetch data by run_id BUT ignore the ABC graphs, plt flags and EOS as this shouldnt be validated.
	public Collection<BloodsData> fetchByRunIdNoGraphs(Long runId) {

		String sql = " select * from phn_bloods_data where run_id = ? and parameter_id not in (1,18,19,20,21) " +
				"order by parameter_id";
		
		Collection<BloodsData> data = getSimpleJdbcTemplate().query(sql, getRowMapper(), runId);
		
		return (data == null) ? new ArrayList<BloodsData>() : data;
	
	}
	
	
	public Collection<BloodsData> fetchAllByParameterId(Long parameterId) {

		String sql = " select * from phn_bloods_data where parameter_id = ? ";
		
		Collection<BloodsData> data = getSimpleJdbcTemplate().query(sql, getRowMapper(), parameterId);
		
		return (data == null) ? new ArrayList<BloodsData>() : data;
	
	}
	
	
	public Collection<BloodsData> search(BloodsDataSearchBean bloodsDataSearchBean) {
		// TODO Auto-generated method stub
		return null;
	}
	
	public ChartData fetchChartData(SerumQCForm form) {
	
		Collection<BloodsData> allTestData = fetchAllByParameterId(form.getParameterId());
		
		
		return null;
	}
	
	public ChartData fetchChartDataByParameterId(Long parameterId) {
		
		Collection<Object> bindVariables = new ArrayList<Object>();
	    
		String selectSql = "select created_date label, to_number(value) data0 from phn_bloods_data where parameter_id = ? ";
		bindVariables.add(parameterId);
		
		String orderBySql = "order by created_date";

		String sql = selectSql + orderBySql;
				
		DatabaseChartData data = new DatabaseChartData(1);
		
		getJdbcTemplate().query(sql, bindVariables.toArray(),data);     
		
		if(data.getLabels().length == 0) {
			return null;
		}else {
		 return data;
		}
	}
}