/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.abc.dao;

import java.util.Collection;

import org.springframework.dao.IncorrectResultSizeDataAccessException;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.phenotyping.abc.BloodsParamRange;
import uk.ac.sanger.mig.phenotyping.abc.BloodsParamRangeSearchBean;

public class BloodsParamRangeDaoSpringImpl extends AbstractDaoSpringImpl<BloodsParamRange> implements BloodsParamRangeDao {

	
	
	/*
	 * Fetch the most current range information for a given parameter.
	 */
	public BloodsParamRange fetchCurrentByParamId(Long paramId) {
		String sql = " select * from phn_bloods_param_range_curr_vw where parameter_id = ? ";
		
		BloodsParamRange range = null;
		
		try {
			range = getSimpleJdbcTemplate().queryForObject(sql, getRowMapper(), paramId);
		}
		catch(IncorrectResultSizeDataAccessException e) {
			//no record, do nothing.
		}
		
		return range;
	}
	
	/*
	 * Fetch all the current range information for all tests.
	 */
	public Collection<BloodsParamRange> fetchCurrentParamRanges() {
		
		String sql = " select * from phn_bloods_param_range_curr_vw ";
		
		Collection<BloodsParamRange> ranges = null;
		
		try {
			ranges = getSimpleJdbcTemplate().query(sql, getRowMapper());
		}
		catch(IncorrectResultSizeDataAccessException e) {
			//no record, do nothing.
		}
		
		return ranges;
	
	}
	
	public Collection<BloodsParamRange> fetchCurrentParamRangesByInstrument(Long instrumentId) {
		
		String sql = "";
		// Hack refactor....!!!!
		if(instrumentId == 2) {
			sql = " select v.* from phn_bloods_param_range_curr_vw v, phn_parameter_dict d " +
				"where d.id = v.parameter_id and d.instrument_id = ? and d.active = 1 order by v.parameter_id";
		}else{
			sql = " select v.* from phn_bloods_param_range_curr_vw v, phn_parameter_dict d " +
			"where d.id = v.parameter_id and d.instrument_id = ?  order by v.parameter_id";
		}
			
		Collection<BloodsParamRange> ranges = null;
		
		try {
			ranges = getSimpleJdbcTemplate().query(sql, getRowMapper(), instrumentId);
		}
		catch(IncorrectResultSizeDataAccessException e) {
			//no record, do nothing.
		}
		
		return ranges;
	
	}
	
	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, BloodsParamRange bloodsParamRange) {
		sql.addLongParam(bloodsParamRange.getParameterId(), "PARAMETER_ID");
		sql.addStringParam(bloodsParamRange.getRefHi(), "REF_HI");
		sql.addStringParam(bloodsParamRange.getRefLo(), "REF_LO");
		sql.addStringParam(bloodsParamRange.getInstrumentHi(), "INSTRUMENT_HI");
		sql.addStringParam(bloodsParamRange.getInstrumentLo(), "INSTRUMENT_LO");
		sql.addLongParam(bloodsParamRange.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(bloodsParamRange.getCreatedDate(), "CREATED_DATE");
		sql.addStringParam(bloodsParamRange.getEditedBy(), "EDITED_BY");
		sql.addDateParam(bloodsParamRange.getEditDate(), "EDIT_DATE");
		sql.addLongParam(bloodsParamRange.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(bloodsParamRange.getId(), "ID");
	}

	public Collection<BloodsParamRange> search(BloodsParamRangeSearchBean bloodsParamRangeSearchBean) {
		// TODO Auto-generated method stub
		return null;
	}
	
}