/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.abc.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.phenotyping.abc.BloodsData;
import uk.ac.sanger.mig.phenotyping.abc.services.BloodsParamRangeService;

public class BloodsDataRowMapper implements ParameterizedRowMapper<BloodsData> {

	private DictionaryService dictionaryService;
	private BloodsParamRangeService bloodsParamRangeService; 

	
	public void setBloodsParamRangeService(
			BloodsParamRangeService bloodsParamRangeService) {
		this.bloodsParamRangeService = bloodsParamRangeService;
	}

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}
	
	public BloodsData mapRow(ResultSet rs, int rowNum) throws SQLException {
		
		BloodsData bloodsData = new BloodsData();
		
		bloodsData.setRunId(rs.getLong("RUN_ID"));
		if(rs.wasNull()) bloodsData.setRunId(null);		

		bloodsData.setParameterId(rs.getLong("PARAMETER_ID"));
		if(rs.wasNull()) bloodsData.setParameterId(null);		

		bloodsData.setValue(rs.getString("VALUE"));

		bloodsData.setUnits(rs.getString("UNITS"));

		bloodsData.setRefHi(rs.getDouble("REF_HI"));

		bloodsData.setRefLo(rs.getDouble("REF_LO"));

		bloodsData.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) bloodsData.setCheckNumber(null);		

		bloodsData.setCreatedBy(rs.getLong("CREATED_BY"));

		bloodsData.setCreatedDate(rs.getTimestamp("CREATED_DATE"));

		bloodsData.setEditedBy(rs.getString("EDITED_BY"));

		bloodsData.setEditDate(rs.getTimestamp("EDIT_DATE"));
	
		bloodsData.setLot1(rs.getString("LOT_1"));
		bloodsData.setBottle1(rs.getString("BOTTLE_1"));
		bloodsData.setLot2(rs.getString("LOT_2"));
		bloodsData.setBottle2(rs.getString("BOTTLE_2"));
		bloodsData.setErrorCode1Id(rs.getLong("ERROR_1_ID"));
		if(rs.wasNull()) bloodsData.setErrorCode1Id(null);		 
		bloodsData.setErrorCode2Id(rs.getLong("ERROR_2_ID"));
		if(rs.wasNull()) bloodsData.setErrorCode2Id(null);		
		
		bloodsData.setRangeId(rs.getLong("PARAM_RANGE_ID"));
		if(rs.wasNull()) bloodsData.setRangeId(null);
		
		bloodsData.setResultStatusId(rs.getLong("RESULT_STATUS_ID"));
		if(rs.wasNull()) bloodsData.setResultStatusId(null);
		
		bloodsData.setId(rs.getLong("ID"));
		
		bloodsData.setParameter(dictionaryService.fetchEntry(DictionaryEnum.PHENOTYPING_PARAMS, bloodsData.getParameterId()));		
		bloodsData.setErrorCode1(dictionaryService.fetchEntry(DictionaryEnum.PHENOTYPING_ERROR_CODES, bloodsData.getErrorCode1Id()));	
		bloodsData.setErrorCode2(dictionaryService.fetchEntry(DictionaryEnum.PHENOTYPING_ERROR_CODES, bloodsData.getErrorCode2Id()));	
		bloodsData.setResultStatus(dictionaryService.fetchEntry(DictionaryEnum.PHENOTYPING_RESULT_STATUS, bloodsData.getResultStatusId()));
		
		bloodsData.setRange(bloodsParamRangeService.fetchById(bloodsData.getRangeId(), null));
		
		
		
		return bloodsData;
		
	}
}