/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.abc.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.phenotyping.abc.BloodsRun;

public class BloodsRunRowMapper implements ParameterizedRowMapper<BloodsRun> {

	private DictionaryService dictionaryService;

	
	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}
	
	public BloodsRun mapRow(ResultSet rs, int rowNum) throws SQLException {
		
		BloodsRun bloodsRun = new BloodsRun();
		
		bloodsRun.setId(rs.getLong("ID"));

		bloodsRun.setRunDate(rs.getTimestamp("RUN_DATE"));

		bloodsRun.setMouseId(rs.getLong("MOUSE_ID"));

		bloodsRun.setInstrumentId(rs.getLong("INSTRUMENT_ID"));
		if(rs.wasNull()) bloodsRun.setInstrumentId(null);		

		bloodsRun.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) bloodsRun.setCheckNumber(null);		

		bloodsRun.setCreatedBy(rs.getLong("CREATED_BY"));

		bloodsRun.setCreatedDate(rs.getTimestamp("CREATED_DATE"));

		bloodsRun.setEditedBy(rs.getString("EDITED_BY"));

		bloodsRun.setEditDate(rs.getTimestamp("EDIT_DATE"));

		bloodsRun.setComments(rs.getString("COMMENTS"));

		bloodsRun.setFailed(rs.getBoolean("FAILED"));
		
		bloodsRun.setRunTypeDictId(rs.getLong("RUN_TYPE"));
		
		bloodsRun.setValidated(rs.getBoolean("VALIDATED"));
		
		bloodsRun.setInstrument(dictionaryService.fetchEntry(DictionaryEnum.PHENOTYPING_INSTRUMENT_DICT, bloodsRun.getInstrumentId()));		
		bloodsRun.setRunType(dictionaryService.fetchEntry(DictionaryEnum.PHENOTYPING_RUN_TYPE, bloodsRun.getRunTypeDictId()));	
		
	
		return bloodsRun;
		
	}
}