/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.abc.services;

import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.phenotyping.abc.BloodsData;
import uk.ac.sanger.mig.phenotyping.abc.BloodsRun;
import uk.ac.sanger.mig.phenotyping.abc.BloodsRunSearchBean;
import uk.ac.sanger.mig.phenotyping.abc.dao.BloodsRunDao;
import uk.ac.sanger.mig.phenotyping.olympus.SerumTest;
import uk.ac.sanger.mig.phenotyping.olympus.services.SerumTestService;

public class BloodsRunServiceImpl extends AbstractServiceImpl<BloodsRun> implements BloodsRunService {
	
	private BloodsRunDao bloodsRunDao;
	private SerumTestService serumService;
	private BloodsDataService bloodsDataService;
	
	
	
	public void setBloodsDataService(BloodsDataService bloodsDataService) {
		this.bloodsDataService = bloodsDataService;
	}


	public void setSerumService(SerumTestService serumService) {
		this.serumService = serumService;
	}


	public void setBloodsRunDao(BloodsRunDao bloodsRunDao) {
		this.bloodsRunDao = bloodsRunDao;
	}


	public Long storeAuthenticated(BloodsRun bloodsRun, Person user) {
		if(bloodsRun == null) {
			throw new RuntimeException("Cannot save a null bloodsRun");
		}
		
		return bloodsRunDao.store(bloodsRun, user);
	}
	
	public BloodsRun fetchById(Long bloodsRunId, ComponentMap requiredComponents) {
		BloodsRun bloodsRun = bloodsRunDao.fetchById(bloodsRunId);
	
		if(bloodsRun != null)
			attachComponents(bloodsRun, requiredComponents);
		
		return bloodsRun;
	}

	@Override
	protected void attachComponents(BloodsRun bloodsRun, ComponentMap requiredComponents) {
		if(bloodsRun == null) {
			throw new RuntimeException("Cannot attach components to null bloodsRun");
		}		
		
		boolean fetchAll = false;
		
		if(requiredComponents != null) {
			
			if(requiredComponents.containsKey(BloodsRun.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}
			
			if(fetchAll || requiredComponents.containsKey(BloodsRun.Component.SERUM_BARCODE)) {
				bloodsRun.setSerumTest(fetchSerumBarcode(bloodsRun, requiredComponents.get(BloodsRun.Component.SERUM_BARCODE)));
			}
			
		}
	}

	
	private SerumTest fetchSerumBarcode(BloodsRun bloodsRun, ComponentMap requiredComponents) {
		// fix. 
		return serumService.fetchByMouseId(bloodsRun.getMouseId());
	
		
	}

	public Collection<BloodsRun> search(BloodsRunSearchBean bloodsRunSearchBean, ComponentMap requiredComponents) {
		Collection<BloodsRun> runs = bloodsRunDao.search(bloodsRunSearchBean);

		if(runs != null)
			attachComponents(runs, requiredComponents);
		
		return runs;
	}


	public void deleteSerumResultsByRunId(Long runId, Person user) {		

		if(runId != null) {
			BloodsRun runObj = bloodsRunDao.fetchById(runId);
				if(runObj != null) {
					bloodsDataService.deleteResultsByRunId(runId, user);
					bloodsRunDao.delete(runObj, user);
				}
		}
	}

	
}
								