/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.abc.validators;

import java.util.Collection;
import java.util.Date;

import org.springframework.validation.Errors;
import org.springframework.validation.Validator;

import uk.ac.sanger.mig.phenotyping.abc.BloodsData;
import uk.ac.sanger.mig.phenotyping.abc.forms.ManualBloodDataForm;


public class AddManualBloodDataFormValidator implements Validator {

public boolean supports(Class clazz) {
		return ManualBloodDataForm.class.equals(clazz);
	}

	public void validate(Object commandForm, Errors errors) {

		ManualBloodDataForm form = (ManualBloodDataForm)commandForm;

		// Check for valid mouse.
		if(form.getMouseId() == null || form.getMouseId().equals("")) {
			errors.reject(null,"Please specify a mouse to assign the values to.");
		}

		// check for date
		Date now = new Date();
		if(form.getRunDate()== null) {
			errors.reject(null,"Please enter a date for this run.");
		}else if(form.getRunDate().after(now)) {
			errors.reject(null,"Unable to add a run that is in the future!! Please choose another date.");
		}

		// Make sure at least one sample is entered.
		Collection<BloodsData> data = form.getData();
		boolean atLeastOneSample = false;
		for(BloodsData d : data) {
			if(d.getValue() != null && !d.getValue().equals("")) {
				atLeastOneSample = true;
			}
		}
		if(!atLeastOneSample) {
			errors.reject(null,"Unable to create a run with not sample data attached. Please add sample data!");
		}

	}

}