/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.phenotyping.calorimetry.dao;


import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;

import uk.ac.sanger.mig.phenotyping.calorimetry.CalorimetryDataPoint;

public class CalorimetryDataPointDaoSpringImpl extends AbstractDaoSpringImpl<CalorimetryDataPoint> implements CalorimetryDataPointDao {


	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, CalorimetryDataPoint calorimetryData) {
		sql.addLongParam(calorimetryData.getExperimentId(), "EXPERIMENT_ID");
		sql.addDateParam(calorimetryData.getSampleTime(), "SAMPLE_TIME");
		sql.addFloatParam(calorimetryData.getMinutesElapsed(), "MINUTES_ELAPSED");
		sql.addFloatParam(calorimetryData.getCo2(), "CO2");
		sql.addFloatParam(calorimetryData.getO2(), "O2");
		sql.addFloatParam(calorimetryData.getRefCo2(), "REF_CO2");
		sql.addFloatParam(calorimetryData.getRefO2(), "REF_O2");
		sql.addFloatParam(calorimetryData.getCo2Difference(), "CO2_DIFFERENCE");
		sql.addFloatParam(calorimetryData.getO2Difference(), "O2_DIFFERENCE");
		sql.addFloatParam(calorimetryData.getCumulativeFoodIntake(), "CUMULATIVE_FOOD_INTAKE");
		sql.addFloatParam(calorimetryData.getFlowRateIn(), "FLOW_RATE_IN");
		sql.addFloatParam(calorimetryData.getSampleFlowRateOut(), "SAMPLE_FLOW_RATE_OUT");
		sql.addFloatParam(calorimetryData.getTemperature(), "TEMPERATURE");
		sql.addFloatParam(calorimetryData.getRespiratoryExchangeRatio(), "RESPIRATORY_EXCHANGE_RATIO");
		sql.addIntParam(calorimetryData.getVco2Bodyweight(), "VCO2_BODYWEIGHT");
		sql.addIntParam(calorimetryData.getVco2LeanMass(), "VCO2_LEAN_MASS");
		sql.addIntParam(calorimetryData.getVco2Animal(), "VCO2_ANIMAL");
		sql.addIntParam(calorimetryData.getVo2Bodyweight(), "VO2_BODYWEIGHT");
		sql.addIntParam(calorimetryData.getVo2LeanMass(), "VO2_LEAN_MASS");
		sql.addIntParam(calorimetryData.getVo2Animal(), "VO2_ANIMAL");
		sql.addFloatParam(calorimetryData.getEnergyExpendBodyweight(), "ENERGY_EXPEND_BODYWEIGHT");
		sql.addFloatParam(calorimetryData.getEnergyExpendLeanMass(), "ENERGY_EXPEND_LEAN_MASS");
		sql.addFloatParam(calorimetryData.getEnergyExpendAnimal(), "ENERGY_EXPEND_ANIMAL");
		sql.addFloatParam(calorimetryData.getHeatBodyweight(), "HEAT_BODYWEIGHT");
		sql.addFloatParam(calorimetryData.getHeatLeanMass(), "HEAT_LEAN_MASS");
		sql.addFloatParam(calorimetryData.getHeatAnimal(), "HEAT_ANIMAL");
		sql.addIntParam(calorimetryData.getXaxisActivityCount(), "XAXIS_ACTIVITY_COUNT");
		sql.addIntParam(calorimetryData.getXaxisActivityCountTotal(), "XAXIS_ACTIVITY_COUNT_TOTAL");
		sql.addIntParam(calorimetryData.getYaxisActivityCount(), "YAXIS_ACTIVITY_COUNT");
		sql.addIntParam(calorimetryData.getYaxisActivityCountTotal(), "YAXIS_ACTIVITY_COUNT_TOTAL");
		sql.addDateParam(calorimetryData.getCreatedDate(), "CREATED_DATE");
		sql.addLongParam(calorimetryData.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(calorimetryData.getEditDate(), "EDIT_DATE");
		sql.addStringParam(calorimetryData.getEditedBy(), "EDITED_BY");
		sql.addLongParam(calorimetryData.getCheckNumber(), "CHECK_NUMBER");
    sql.addFloatParam(calorimetryData.getRateXA(), "RATE_XA");
    sql.addFloatParam(calorimetryData.getRateXT(), "RATE_XT");
    sql.addFloatParam(calorimetryData.getRateYA(), "RATE_YA");
    sql.addFloatParam(calorimetryData.getRateYT(), "RATE_YT");
    sql.addFloatParam(calorimetryData.getRateFeed(), "RATE_FEED");
    sql.addFloatParam(calorimetryData.getFeedInInterval(), "FEED_IN_INTERVAL");

    sql.addLongParam(calorimetryData.getId(), "ID");
	}

	public Collection<CalorimetryDataPoint> fetchByExperimentId(Long id) {
		String sql = "select * from "+getTableName()+" where experiment_id = ? order by minutes_elapsed";
		return fetchCollection(sql, id);
	}

}