/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.phenotyping.calorimetry.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;
import uk.ac.sanger.mig.phenotyping.calorimetry.CalorimetryDataPoint;

public class CalorimetryDataPointRowMapper implements ParameterizedRowMapper<CalorimetryDataPoint> {

	public CalorimetryDataPoint mapRow(ResultSet rs, int rowNum) throws SQLException {

		CalorimetryDataPoint calorimetryData = new CalorimetryDataPoint();


		calorimetryData.setId(rs.getLong("ID"));

		calorimetryData.setExperimentId(rs.getLong("EXPERIMENT_ID"));
		if(rs.wasNull()) calorimetryData.setExperimentId(null);

		calorimetryData.setSampleTime(rs.getTimestamp("SAMPLE_TIME"));

		calorimetryData.setMinutesElapsed(rs.getFloat("MINUTES_ELAPSED"));

		calorimetryData.setCo2(rs.getFloat("CO2"));

		calorimetryData.setO2(rs.getFloat("O2"));

		calorimetryData.setRefCo2(rs.getFloat("REF_CO2"));

		calorimetryData.setRefO2(rs.getFloat("REF_O2"));

		calorimetryData.setCo2Difference(rs.getFloat("CO2_DIFFERENCE"));

		calorimetryData.setO2Difference(rs.getFloat("O2_DIFFERENCE"));

		calorimetryData.setCumulativeFoodIntake(rs.getFloat("CUMULATIVE_FOOD_INTAKE"));

		calorimetryData.setFlowRateIn(rs.getFloat("FLOW_RATE_IN"));

		calorimetryData.setSampleFlowRateOut(rs.getFloat("SAMPLE_FLOW_RATE_OUT"));

		calorimetryData.setTemperature(rs.getFloat("TEMPERATURE"));

		calorimetryData.setRespiratoryExchangeRatio(rs.getFloat("RESPIRATORY_EXCHANGE_RATIO"));

		calorimetryData.setVco2Bodyweight(rs.getInt("VCO2_BODYWEIGHT"));

		calorimetryData.setVco2LeanMass(rs.getInt("VCO2_LEAN_MASS"));

		calorimetryData.setVco2Animal(rs.getInt("VCO2_ANIMAL"));

		calorimetryData.setVo2Bodyweight(rs.getInt("VO2_BODYWEIGHT"));

		calorimetryData.setVo2LeanMass(rs.getInt("VO2_LEAN_MASS"));

		calorimetryData.setVo2Animal(rs.getInt("VO2_ANIMAL"));

		calorimetryData.setEnergyExpendBodyweight(rs.getFloat("ENERGY_EXPEND_BODYWEIGHT"));

		calorimetryData.setEnergyExpendLeanMass(rs.getFloat("ENERGY_EXPEND_LEAN_MASS"));

		calorimetryData.setEnergyExpendAnimal(rs.getFloat("ENERGY_EXPEND_ANIMAL"));

		calorimetryData.setHeatBodyweight(rs.getFloat("HEAT_BODYWEIGHT"));

		calorimetryData.setHeatLeanMass(rs.getFloat("HEAT_LEAN_MASS"));

		calorimetryData.setHeatAnimal(rs.getFloat("HEAT_ANIMAL"));

		calorimetryData.setXaxisActivityCount(rs.getInt("XAXIS_ACTIVITY_COUNT"));

		calorimetryData.setXaxisActivityCountTotal(rs.getInt("XAXIS_ACTIVITY_COUNT_TOTAL"));

		calorimetryData.setYaxisActivityCount(rs.getInt("YAXIS_ACTIVITY_COUNT"));

		calorimetryData.setYaxisActivityCountTotal(rs.getInt("YAXIS_ACTIVITY_COUNT_TOTAL"));

    calorimetryData.setRateFeed(rs.getFloat("RATE_FEED"));
    if(rs.wasNull()) calorimetryData.setRateFeed(null);

    calorimetryData.setRateXA(rs.getFloat("RATE_XA"));
    if(rs.wasNull()) calorimetryData.setRateXA(null);

    calorimetryData.setRateXT(rs.getFloat("RATE_XT"));
    if(rs.wasNull()) calorimetryData.setRateXT(null);

    calorimetryData.setRateYA(rs.getFloat("RATE_YA"));
    if(rs.wasNull()) calorimetryData.setRateYA(null);

    calorimetryData.setRateYT(rs.getFloat("RATE_YT"));
    if(rs.wasNull()) calorimetryData.setRateYT(null);

    calorimetryData.setFeedInInterval(rs.getFloat("FEED_IN_INTERVAL"));
    if(rs.wasNull()) calorimetryData.setFeedInInterval(null);

		calorimetryData.setCreatedDate(rs.getTimestamp("CREATED_DATE"));
    if(rs.wasNull()) calorimetryData.setCreatedDate(null);

		calorimetryData.setCreatorId(rs.getLong("CREATOR_ID"));
    if(rs.wasNull()) calorimetryData.setCreatorId(null);

		calorimetryData.setEditDate(rs.getTimestamp("EDIT_DATE"));
    if(rs.wasNull()) calorimetryData.setEditDate(null);

		calorimetryData.setEditedBy(rs.getString("EDITED_BY"));
    if(rs.wasNull()) calorimetryData.setEditedBy(null);

		calorimetryData.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) calorimetryData.setCheckNumber(null);

		return calorimetryData;

	}
}