package uk.ac.sanger.mig.phenotyping.calorimetry.parser;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;
import java.util.TreeSet;

public class CalorimetryData {

	private String runName;
	private String experimentId;
	private String textField1, textField2, textField3;
	private Collection<BoxData> boxes;
	private Collection<Sample> samples;

	public Collection<BoxData> getBoxes() {
		return boxes;
	}
	public void setBoxes(Collection<BoxData> boxes) {
		this.boxes = boxes;
	}
	public String getExperimentId() {
		return experimentId;
	}
	public void setExperimentId(String experimentId) {
		this.experimentId = experimentId;
	}
	public String getRunName() {
		return runName;
	}
	public void setRunName(String runName) {
		this.runName = runName;
	}
	public String getTextField1() {
		return textField1;
	}
	public void setTextField1(String textField1) {
		this.textField1 = textField1;
	}
	public String getTextField2() {
		return textField2;
	}
	public void setTextField2(String textField2) {
		this.textField2 = textField2;
	}
	public String getTextField3() {
		return textField3;
	}
	public void setTextField3(String textField3) {
		this.textField3 = textField3;
	}
	public Collection<Sample> getSamples() {
		return samples;
	}
	public void setSamples(Collection<Sample> samples) {
		this.samples = samples;
	}

  public void interpolateTimepoints() {
    if (boxes == null || samples == null) throw new IllegalStateException();

    int boxCount = boxes.size();

    Collection<Sample> sortedSamples = new TreeSet<Sample>(samples);

    Collection<Sample> buffer = new ArrayList<Sample>();

    Map<Integer,Sample> lastSampleBuffer = new HashMap<Integer, Sample>();

    Date cycleStartTime = null;
    Collection<Long> intervals = new ArrayList<Long>();

    for (Sample s : sortedSamples) {

      // add the last time point
      Sample lastSample = lastSampleBuffer.get(s.getBox());
      if (lastSample != null) s.setPreviousSample(lastSample);
      lastSampleBuffer.put(s.getBox(), s);

      // interval
      if (cycleStartTime == null) {
        cycleStartTime = s.getDate();
      }

      if (s.getDate().equals(cycleStartTime)) {
        buffer.add(s);
      }
      else {
        Date nextCycleStartTime = s.getDate();

        long interval = calculateInterval(boxCount,cycleStartTime,nextCycleStartTime);
        intervals.add(interval);

        interpolate(buffer,interval);

        // start a new cycle
        buffer.clear();
        buffer.add(s);
        cycleStartTime = nextCycleStartTime;
      }
    }

    long sum = 0;
    for (long interval : intervals) {
      sum = sum + interval;
    }
    long averageInterval = sum/intervals.size(); // loss of precision is insignificant

    // sort out the last set, there isn't an end point
    interpolate(buffer,averageInterval);

  }

  private long calculateInterval(int sampleCount, Date cycleStart, Date nextCycleStart) {
    long refStart = cycleStart.getTime();
    long nextRefStart = nextCycleStart.getTime();

    long interval = (nextRefStart - refStart) / (sampleCount + 1);

    return interval;
  }

  private void interpolate(Collection<Sample> samples, long interval) {
    for (Sample s : samples) {
      // reference box is 0
      int boxIndex = 0;

      for (BoxData b : boxes) {
        boxIndex++;

        if (b.getBox() == s.getBox()) break;
      }

      long start = s.getDate().getTime();
      long interpolated = start + (interval * boxIndex);

      s.setDate(new Date(interpolated));
    }
  }
}
