/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.datacapture;

import java.util.Date;

import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.ComponentEnum;

public class Observation extends AuthenticatedDataObject {

  public enum Component implements ComponentEnum {
    ALL_COMPONENTS,
    EXPERIMENT,
    REQUIRED_OBSERVATION
    // add additional component enums here as needed for this
    // AuthenticatedDataObject
  }

  private Long experimentId;
  private Long requiredObservationId;
  private String value;
  private Long instrumentId;
  private Date observationTime = new Date();
  private Experiment experiment;
  private RequiredObservation requiredObservation;

  public Experiment getExperiment() {
    return experiment;
  }

  public void setExperiment(Experiment experiment) {
    this.experiment = experiment;
  }

  public RequiredObservation getRequiredObservation() {
    return requiredObservation;
  }

  public void setRequiredObservation(RequiredObservation requiredObservation) {
    this.requiredObservation = requiredObservation;
  }

  public Long getExperimentId() {
    return experimentId;
  }

  public void setExperimentId(Long experimentId) {
    this.experimentId = experimentId;
  }

  public Long getRequiredObservationId() {
    return requiredObservationId;
  }

  public void setRequiredObservationId(Long requiredObservationId) {
    this.requiredObservationId = requiredObservationId;
  }

  /**
   * Give the value, or a default if the value field is null
   *
   * Reading this in the UI, but not the persistence layer
   * allows our form to show value or default, without storing the default value
   *
   * @return
   */
  public String getValueOrDefault() {
    String returnValue = null;

    if (value == null &&
        requiredObservation != null &&
        requiredObservation.getDefaultValue() != null) {
      returnValue = requiredObservation.getDefaultValue();
    }
    else {
      returnValue = value;
    }

      return returnValue;
  }
  /**
   * Set the value field,
   *
   * Yes, it's identical in function to setValue()
   * This method is here because spring forms expect get/set pairs,
   * and we need the form to read from getValueOrDefault - therefore it
   * must write with setValueOrDefault
   *
   * This feels dirty.
   *
   * @param value
   */
  public void setValueOrDefault(String value) {
    this.setValue(value);
  }

  public String getValue() {
    return value;
  }

  public String getDisplayValue() {
    String displayValue = null;
    if (requiredObservation != null &&
        requiredObservation.getObservationType() != null &&
        requiredObservation.getObservationType().isRestrictedOption() &&
        requiredObservation.getObservationType().getRestrictedOptions() != null) {
      displayValue = lookupOptionText();
    }
    else {
      displayValue = value;
    }

    return displayValue;
  }

  private String lookupOptionText() {
    String optionText = null;

    try {
      Long id = Long.parseLong(value);

      for (RestrictedOption option : requiredObservation.getObservationType().getRestrictedOptions()) {
        if (option.getId().equals(id)) {
          optionText = option.getName();
          break;
        }
      }
    }
    catch(NumberFormatException e) {}

    return optionText;
  }

  public void setValue(String value) {
    this.value = value;
  }

  public Long getInstrumentId() {
    return instrumentId;
  }

  public void setInstrumentId(Long instrumentId) {
    this.instrumentId = instrumentId;
  }

  public Date getObservationTime() {
    return observationTime;
  }

  public void setObservationTime(Date observationTime) {
    this.observationTime = observationTime;
  }

  public boolean isValid() {
    return requiredObservation.getObservationType().isObservationValid(this);
  }

}