/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.datacapture;

import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.ComponentEnum;
/**
 * This class describes an Observation that must be made during an Experiment.
 * It describes the type of observation that is required, and has information
 * used to create a form to record data.
 *
 * @see StdOperatingProcedure
 * @see Observation
 * @see ObservationType
 */
public class RequiredObservation extends AuthenticatedDataObject  {

	public enum Component implements ComponentEnum {
		ALL_COMPONENTS,
    OBSERVATION_TYPE,
    SOP
	}

    private Long observationTypeId;
    private int orderBy;
    private String displayName;
    private boolean active = true; // default to true
    private Long sopId;
    private String defaultValue;
    private boolean mandatoryObservation = true;
    private StdOperatingProcedure sop;
    private ObservationType observationType;
    private String sectionTitle;

    private boolean seriesData;
    private boolean machineData;


    public String getSectionTitle() {
      return sectionTitle;
    }

    public void setSectionTitle(String sectionTitle) {
      this.sectionTitle = sectionTitle;
    }

    public Long getObservationTypeId() {
        return observationTypeId;
    }

    public void setObservationTypeId(Long observationTypeId) {
        this.observationTypeId = observationTypeId;
    }
    public int getOrderBy() {
      if (sop != null &&
          (id == null || id < 1)) {
        return sop.getNextObservationPosition();
      }

        return orderBy;
    }

    public void setOrderBy(int orderBy) {
        this.orderBy = orderBy;
    }
    public String getDisplayName() {
      return displayName;
    }

    public void setDisplayName(String displayName) {
        this.displayName = displayName;
    }
    public boolean isActive() {
        return active;
    }

    public void setActive(boolean active) {
        this.active = active;
    }

	public ObservationType getObservationType() {
		return observationType;
	}

	public void setObservationType(ObservationType observationType) {
		this.observationType = observationType;
	}

	public StdOperatingProcedure getSop() {
		return sop;
	}

	public void setSop(StdOperatingProcedure sop) {
		this.sop = sop;
	}

	public Long getSopId() {
		return sopId;
	}

	public void setSopId(Long sopId) {
		this.sopId = sopId;
	}

  public String getDefaultValue() {
    return defaultValue;
  }

  public void setDefaultValue(String defaultValue) {
    this.defaultValue = defaultValue;
  }

  public boolean isMandatoryObservation() {
    return mandatoryObservation;
  }

  public void setMandatoryObservation(boolean mandatoryObservation) {
    this.mandatoryObservation = mandatoryObservation;
  }

  public boolean isSeriesData() {
    return seriesData;
  }

  public void setSeriesData(boolean seriesData) {
    this.seriesData = seriesData;
  }

  public boolean isMachineData() {
    return machineData;
  }

  public void setMachineData(boolean machineData) {
    this.machineData = machineData;
  }

}