/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.datacapture;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;

import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.ComponentEnum;

public class RestrictedOption extends AuthenticatedDataObject  {

	public enum Component implements ComponentEnum {
		ALL_COMPONENTS,  //add additional component enums here as needed for this AuthenticatedDataObject
		OBSERVATION_TYPE
	}

    private Long observationTypeId;        
    private Long parentOptionId;        
    private String name;        
    private int orderBy;        
    private String description;        
    private boolean active = true;
    
    private RestrictedOption parentOption;
    private Collection<RestrictedOption> childOptions;
    private ObservationType observationType;

	public ObservationType getObservationType() {
		return observationType;
	}

	public void setObservationType(ObservationType observationType) {
		this.observationType = observationType;
	}

	public Long getObservationTypeId() {
        return observationTypeId;
    }
    
    public void setObservationTypeId(Long observationTypeId) {
        this.observationTypeId = observationTypeId;
    }                                                                                                                                            
    public Long getParentOptionId() {
        return parentOptionId;
    }
    
    public void setParentOptionId(Long parentOptionId) {
        this.parentOptionId = parentOptionId;
    }                                                                                                                                            
    public String getName() {
        return name;
    }
    
    public void setName(String name) {
        this.name = name;
    }                
    
    public int getOrderBy() {
      if (orderBy < 1 &&
          observationType != null) {
        return observationType.getNextOptionPosition();
      }
      
      return orderBy;
    }
    
    public void setOrderBy(int orderBy) {
        this.orderBy = orderBy;
    }                                                                                                                                            
    public String getDescription() {
        return description;
    }
    
    public void setDescription(String description) {
        this.description = description;
    }                                                                                                                                            
    public boolean isActive() {
        return active;
    }
    
    public void setActive(boolean active) {
        this.active = active;
    }

	public RestrictedOption getParentOption() {
		return parentOption;
	}

	public void setParentOption(RestrictedOption parentOption) {
		this.parentOption = parentOption;
	}

	public Collection<RestrictedOption> getChildOptions() {
		return Collections.unmodifiableCollection(childOptions);
	}

	public void setChildOptions(Collection<RestrictedOption> childOptions) {
		this.childOptions = childOptions;
	}
	
	/**
	 * Adds a child to this node. Creates a collection to hold children if one don't already exist
	 * 
	 * @param childOption
	 */
	public void addChildOption(RestrictedOption childOption) {
		if (childOptions == null) {
			childOptions = new ArrayList<RestrictedOption>();
		}
		
		childOptions.add(childOption);
	}
	/**
	 * 
	 * @return true, if this node does not have a parent
	 */
	public boolean isRootNode() {
		return (parentOptionId == null || parentOptionId < 1);
	}
	/**
	 * 
	 * @return true, if this node does not have any children
	 */
	public boolean isLeafNode() {
		return (childOptions == null || childOptions.size() < 1);
	}
	
	/**
	 * Find the depth of this node within the option tree. Recurses up the tree, using parentOption.
	 * Root nodes have a depth of 0, their immediate children have a depth of one, etc.
	 * 
	 * @return depth of this node within the option tree
	 */
	public int getNodeDepth() {
		int depth = 0;
		
		if (parentOption != null) {
			depth = parentOption.getNodeDepth() + 1;
		}
		
		return depth;
	}

}