/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.datacapture;

import java.util.Collection;

import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.ComponentEnum;
import uk.ac.sanger.mig.common.LookupListElement;
import uk.ac.sanger.mig.common.LookupListUtil;
import uk.ac.sanger.mig.filesupport.BinaryFile;
import uk.ac.sanger.mig.mousetracking.MouseProcedureDictionaryEntry;

/**
 * A Standard Operating Procedure contains requirements for data to be recording during an experiment.
 * It also contains a reference to the Mouse Procedure dictionary entry that will be used to record
 * which protocol work was performed under.
 *
 * @see RequiredObservation
 * @see Experiment
 */
public class StdOperatingProcedure extends AuthenticatedDataObject implements LookupListElement  {

	public enum Component implements ComponentEnum {
		ALL_COMPONENTS,
    DOCUMENTATION,
    PROCEDURE_ENTRY,
    REQUIRED_OBSERVATIONS,
		REQUIRED_OBSERVATIONS_FOR_EDIT
	}

    private Long procedureId;
    private String name;
    private boolean active;
    private BinaryFile documentation;
    private MouseProcedureDictionaryEntry procedureEntry;
    private boolean isHidden;

    // use a list, as we want to maintain explicit ordering
    private Collection<RequiredObservation> requiredObservations;

    public Long getProcedureId() {
        return procedureId;
    }

    public void setProcedureId(Long procedureId) {
        this.procedureId = procedureId;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public boolean isActive() {
        return active;
    }

    public void setActive(boolean active) {
        this.active = active;
    }

	public Collection<RequiredObservation> getRequiredObservations() {
		return requiredObservations;
	}

	public void setRequiredObservations(
			Collection<RequiredObservation> requiredObservations) {
		this.requiredObservations = requiredObservations;
	}

  public String getDisplayText() {
    return this.getName();
  }

  public String getElementData() {
    return LookupListUtil.format("sopId", id) + LookupListUtil.format("sopName", name);
  }

  public void setDisplayText(String displayText) {} //not necessary


  public void setElementData(String elementData) {} // not necessary

  public int getNextObservationPosition() {
    int maxOrderPos = 0;

    if (requiredObservations != null) {
      for (RequiredObservation requiredObservation : requiredObservations) {
        if (requiredObservation.getOrderBy() > maxOrderPos) {
          maxOrderPos = requiredObservation.getOrderBy();
        }
      }
    }

    return maxOrderPos + 1;
  }

  public BinaryFile getDocumentation() {
    return documentation;
  }

  public void setDocumentation(BinaryFile documentation) {
    this.documentation = documentation;
  }

  public MouseProcedureDictionaryEntry getProcedureEntry() {
    return procedureEntry;
  }

  public void setProcedureEntry(MouseProcedureDictionaryEntry procedureEntry) {
    this.procedureEntry = procedureEntry;
  }

  public boolean isHidden() {
    return isHidden;
  }

  public void setHidden(boolean isHidden) {
    this.isHidden = isHidden;
  }

}