/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.datacapture.controllers;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.SimpleFormController;

import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.phenotyping.datacapture.ExperimentSet;
import uk.ac.sanger.mig.phenotyping.datacapture.forms.CalorimetryUploadForm;
import uk.ac.sanger.mig.phenotyping.datacapture.services.UploadMappingService;

/**
 *
 */
public class CalorimetryUploadController extends SimpleFormController {

  private UploadMappingService uploadMappingService;

  @Override
  protected Object formBackingObject(HttpServletRequest request) throws Exception {
    CalorimetryUploadForm form = new CalorimetryUploadForm();

    Person person = RequestUtils.getUser(request);

    if (person.getPersonalLicence() != null) {
      person.getPersonalLicence().setPerson(person);
      form.setPilId(person.getPersonalLicence().getId());
      form.setPilName(person.getPersonalLicence().getDisplayText());
      form.setPersonId(person.getId());
    }

    return form;
  }

  protected ModelAndView onSubmit(HttpServletRequest request,
      HttpServletResponse response, Object command, BindException errors)
      throws Exception {
    CalorimetryUploadForm form = (CalorimetryUploadForm)command;
    Person person = RequestUtils.getUser(request);

    ExperimentSet experimentSet = uploadMappingService.uploadCalorimetryData(form, person);

    return new ModelAndView(getSuccessView(), "experimentSet", experimentSet);
  }

  public void setUploadMappingService(UploadMappingService uploadMappingService) {
    this.uploadMappingService = uploadMappingService;
  }

}
