/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.datacapture.controllers;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.propertyeditors.CustomDateEditor;
import org.springframework.beans.propertyeditors.CustomNumberEditor;
import org.springframework.validation.BindException;
import org.springframework.web.bind.ServletRequestDataBinder;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.AbstractCancellableFormController;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.phenotyping.datacapture.ExperimentSet;
import uk.ac.sanger.mig.phenotyping.datacapture.forms.ExperimentSetForm;
import uk.ac.sanger.mig.phenotyping.datacapture.services.ExperimentSetService;
import uk.ac.sanger.mig.phenotyping.datacapture.views.ExperimentSetListView;

public class ExperimentSetFormController extends AbstractCancellableFormController {

  private ExperimentSetService experimentSetService;

  public void setExperimentSetService(ExperimentSetService experimentSetService) {
    this.experimentSetService = experimentSetService;
  }

  @Override
  protected void initBinder(HttpServletRequest request, ServletRequestDataBinder binder) throws Exception {
    binder.registerCustomEditor(Long.class, new CustomNumberEditor(Long.class, true));
    binder.registerCustomEditor(Double.class, new CustomNumberEditor(Integer.class, true));
    binder.registerCustomEditor(Integer.class, new CustomNumberEditor(Double.class, true));
    binder.registerCustomEditor(Date.class, new CustomDateEditor(new SimpleDateFormat("dd-MMM-yyyy"), true));
  }

  @Override
  protected Object formBackingObject(HttpServletRequest httpServletRequest) throws Exception {
    ExperimentSetForm experimentSetForm = (ExperimentSetForm)createCommand();
    Long id = ServletRequestUtils.getRequiredLongParameter(httpServletRequest, "id");

    ExperimentSet experimentSet = experimentSetService.fetchForPhenotyping(id);


    experimentSetForm.setExperimentSet(experimentSet);

    return experimentSetForm;
  }


  @Override
  protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response,
      Object command, BindException errors) throws Exception {
    ExperimentSetForm experimentSetForm = (ExperimentSetForm) command;
    ExperimentSet experimentSet = experimentSetForm.getExperimentSet();
    experimentSetService.store(experimentSet, RequestUtils.getUser(request));
    return new ModelAndView(getSuccessView()); // show list view
  }

	@Override
	protected Map<String,Object> referenceData(HttpServletRequest request) throws Exception {
		Map<String,Object> model = new HashMap<String, Object>();
		Long id = ServletRequestUtils.getRequiredLongParameter(request, "id");
		ExperimentSetListView view = experimentSetService.fetchViewById(id);
		model.put("view",view);
		return model;
	}

}