/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.datacapture.controllers;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.AbstractSearchFormController;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.common.Pair;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.phenotyping.datacapture.ExperimentSetSearchBean;
import uk.ac.sanger.mig.phenotyping.datacapture.services.ExperimentSetService;
import uk.ac.sanger.mig.phenotyping.datacapture.services.UploadMappingService;
import uk.ac.sanger.mig.phenotyping.datacapture.services.UploadMappingService.Type;
import uk.ac.sanger.mig.phenotyping.datacapture.views.ExperimentSetListView;

public class ExperimentSetListController extends AbstractSearchFormController {

	private ExperimentSetService experimentSetService;
	private DictionaryService dictionaryService;
  private UploadMappingService uploadMappingService;
  private Map<Type,String> typesToUrls = new HashMap<Type, String>();

	public void setCalorimetryEditUrl(String calorimetryEditUrl) {
    typesToUrls.put(Type.MGP_CALORIMETRY, calorimetryEditUrl);
  }
  public void setUploadMappingService(UploadMappingService uploadMappingService) {
    this.uploadMappingService = uploadMappingService;
  }
  public void setExperimentSetService(ExperimentSetService experimentSetService) {
		this.experimentSetService = experimentSetService;
	}
	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}


	@Override
	protected ModelAndView onSearch(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		ExperimentSetSearchBean searchBean = (ExperimentSetSearchBean)command;

		searchBean.setQueryName("listExperimentSets");

		Map<String, Object> model = referenceData(request);

		Collection<ExperimentSetListView> results = experimentSetService.search(searchBean);
		model.put("results", results);

		return new ModelAndView(getSuccessView(),model);
	}

	@Override
	protected Map<String, Object> referenceData(HttpServletRequest request) throws Exception {
		Map<String, Object> referenceData = new HashMap<String, Object>();

		Collection<DictionaryEntry> procedures = dictionaryService.fetch(DictionaryEnum.PHENOTYPING_PROCEDURES);

		referenceData.put("procedures",procedures);
		referenceData.put("sopEditUrlMappings", sopEditUrlMappings());


		return referenceData;
	}

  private Map<Long,String> sopEditUrlMappings() {
    Map<Long,String> sopToUrl = new HashMap<Long, String>();

    Collection<Pair<Long,Type>> sopsToType = uploadMappingService.fetchSopsToUploadType();

    for (Pair<Long,Type> pair : sopsToType) {
      Long sopId = pair.getObjectA();
      Type type = pair.getObjectB();

      String url = typesToUrls.get(type);

      if (url != null) sopToUrl.put(sopId, url);
    }

    return sopToUrl;
  }



}



