/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.datacapture.controllers;

import java.text.SimpleDateFormat;
import java.util.Collection;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.propertyeditors.CustomDateEditor;
import org.springframework.beans.propertyeditors.CustomNumberEditor;
import org.springframework.beans.propertyeditors.StringTrimmerEditor;
import org.springframework.validation.BindException;
import org.springframework.web.bind.ServletRequestDataBinder;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.SimpleFormController;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.phenotyping.datacapture.ObservationType;
import uk.ac.sanger.mig.phenotyping.datacapture.forms.ObservationTypeForm;
import uk.ac.sanger.mig.phenotyping.datacapture.services.ObservationTypeService;

public class ObservationTypeFormController extends SimpleFormController {
	
	private ObservationTypeService observationTypeService;
	private DictionaryService dictionaryService;

	public void setObservationTypeService(ObservationTypeService observationTypeService) {
		this.observationTypeService = observationTypeService;
	}

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}
	
	@Override
	protected void initBinder(HttpServletRequest request, ServletRequestDataBinder binder) throws Exception {
		binder.registerCustomEditor(Long.class, new CustomNumberEditor(Long.class, true));
		binder.registerCustomEditor(Double.class, new CustomNumberEditor(Double.class, true));
		binder.registerCustomEditor(Integer.class, new CustomNumberEditor(Integer.class, true));
		binder.registerCustomEditor(Date.class, new CustomDateEditor(new SimpleDateFormat("dd-MMM-yyyy"), true));
		binder.registerCustomEditor(String.class, new StringTrimmerEditor(true)); //empty strings convert to null
	}

	@Override
	protected Object formBackingObject(HttpServletRequest httpServletRequest) throws Exception {
		ObservationTypeForm observationtypeForm = (ObservationTypeForm)createCommand();				    
		Long id = ServletRequestUtils.getLongParameter(httpServletRequest, "id");		
		
		ObservationType observationType = null; 
					        
		if(id != null) {
			//ok, existing observationType id provided, so fetch for edit. NOTE: ALL_COMPONENTS not obligatory
			//fetch component map that you need... 
		observationType = observationTypeService.fetchById(id,ComponentMap.of(ObservationType.Component.ALL_COMPONENTS));
	
		} else {//else make new observationType	
			observationType = buildNewObservationtype();
		}
   
		observationtypeForm.setObservationType(observationType);	
		return observationtypeForm;
	}
		
	//called after databinding, before showForm(), merges Map into ModelAndView
	//to populate our form with form "metadata" -- eg, drop-down select lists, etc.
	@Override
	protected Map referenceData(HttpServletRequest httpServletRequest) throws Exception {
		Map<String,Object> formMetaData = new HashMap<String,Object>();				
			
		//..fetch and put any  dropdown list Collections, etc into Map
		Collection<DictionaryEntry> metaTypes = dictionaryService.fetch(DictionaryEnum.OBSERVATION_META_TYPE_DICT);
		formMetaData.put("metaTypes", metaTypes);	
		
		return formMetaData;
	} 
	
	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, 
				Object command, BindException errors) throws Exception {
		ObservationTypeForm observationTypeForm = (ObservationTypeForm) command;
		ObservationType observationType = observationTypeForm.getObservationType();
		observationTypeService.storeWithRestrictedOptions(observationType, RequestUtils.getUser(request));

		return new ModelAndView(getSuccessView());
	}
	
	private ObservationType buildNewObservationtype() {		
		ObservationType observationType = new ObservationType();
		    
		long defaultMetaTypeId = 0L;
		observationType.setObservationMetaTypeId(defaultMetaTypeId);
		observationType.setObservationMetaType(new DictionaryEntry(defaultMetaTypeId, "DEFAULT"));
		
		
		return observationType;
	}	
}