/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.datacapture.controllers;

import java.text.SimpleDateFormat;
import java.util.Date;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.propertyeditors.CustomDateEditor;
import org.springframework.beans.propertyeditors.CustomNumberEditor;
import org.springframework.beans.propertyeditors.StringTrimmerEditor;
import org.springframework.validation.BindException;
import org.springframework.web.bind.ServletRequestBindingException;
import org.springframework.web.bind.ServletRequestDataBinder;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.SimpleFormController;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.phenotyping.datacapture.ObservationType;
import uk.ac.sanger.mig.phenotyping.datacapture.RestrictedOption;
import uk.ac.sanger.mig.phenotyping.datacapture.forms.RestrictedOptionForm;
import uk.ac.sanger.mig.phenotyping.datacapture.services.ObservationTypeService;
import uk.ac.sanger.mig.phenotyping.datacapture.services.RestrictedOptionService;

public class RestrictedOptionFormController extends SimpleFormController {
	
	private RestrictedOptionService restrictedOptionService;
	private ObservationTypeService observationTypeService;

	public void setRestrictedOptionService(RestrictedOptionService restrictedOptionService) {
		this.restrictedOptionService = restrictedOptionService;
	}
	
	public void setObservationTypeService(ObservationTypeService observationTypeService) {
		this.observationTypeService = observationTypeService;
	}

	@Override
	protected void initBinder(HttpServletRequest request, ServletRequestDataBinder binder) throws Exception {
		binder.registerCustomEditor(Long.class, new CustomNumberEditor(Long.class, true));
		binder.registerCustomEditor(Double.class, new CustomNumberEditor(Integer.class, true));
		binder.registerCustomEditor(Integer.class, new CustomNumberEditor(Double.class, true));
		binder.registerCustomEditor(Date.class, new CustomDateEditor(new SimpleDateFormat("dd-MMM-yyyy"), true));
		binder.registerCustomEditor(String.class, new StringTrimmerEditor(false)); 
  }

	@Override
	protected Object formBackingObject(HttpServletRequest httpServletRequest) throws Exception {
		RestrictedOptionForm restrictedOptionForm = (RestrictedOptionForm)createCommand();				    
		Long id = ServletRequestUtils.getLongParameter(httpServletRequest, "id");		
		
		RestrictedOption restrictedOption = null; 
		        
		//REM always ensure our *full* object graph (all sub-objects) available for binding!
					        
		if(id != null) {
			//ok, existing restrictedOption id provided, so fetch for edit. NOTE: ALL_COMPONENTS not obligatory
			//fetch component map that you need... 
		  restrictedOption = restrictedOptionService.fetchById(id,
		      new ComponentMap(
		          RestrictedOption.Component.OBSERVATION_TYPE,
		          ComponentMap.of(ObservationType.Component.RESTRICTED_OPTIONS)
		      )
		  );
	
		} else {//else make new restrictedOption	
			restrictedOption = buildNewRestrictedOption(httpServletRequest);
		}
   
		restrictedOptionForm.setRestrictedOption(restrictedOption);	
		return restrictedOptionForm;
	}
			
	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, 
				Object command, BindException errors) throws Exception {
		RestrictedOptionForm restrictedOptionForm = (RestrictedOptionForm) command;
		RestrictedOption restrictedOption = restrictedOptionForm.getRestrictedOption();
		restrictedOptionService.storeAuthenticated(restrictedOption, RequestUtils.getUser(request));
		logger.debug("Object " + restrictedOption + " successfully stored.");
		return new ModelAndView(getSuccessView() + restrictedOption.getObservationTypeId());
	}
	
	private RestrictedOption buildNewRestrictedOption(HttpServletRequest request) throws ServletRequestBindingException {		
		RestrictedOption restrictedOption = new RestrictedOption();    
    Long observationTypeId = ServletRequestUtils.getRequiredLongParameter(request, "observationTypeId");
		    
		
		restrictedOption.setObservationTypeId(observationTypeId);
    restrictedOption.setObservationType(observationTypeService.fetchById(observationTypeId,
        ComponentMap.of(ObservationType.Component.RESTRICTED_OPTIONS)));
		    
		return restrictedOption;
	}	
}