/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.datacapture.dao;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.PaginatedSearchUtils;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.phenotyping.datacapture.Observation;
import uk.ac.sanger.mig.phenotyping.datacapture.ObservationSearchBean;

public class ObservationDaoSpringImpl extends AbstractDaoSpringImpl<Observation> implements ObservationDao {

	private PaginatedSearchUtils<Observation> paginator;

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, Observation observation) {
		sql.addLongParam(observation.getExperimentId(), "EXPERIMENT_ID");
		sql.addLongParam(observation.getRequiredObservationId(), "REQUIRED_OBSERVATION_ID");
		sql.addStringParam(observation.getValue(), "VALUE");
		sql.addLongParam(observation.getInstrumentId(), "INSTRUMENT_ID");
		sql.addDateParam(observation.getObservationTime(), "OBSERVATION_TIME");
		sql.addDateParam(observation.getCreatedDate(), "CREATED_DATE");
		sql.addLongParam(observation.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(observation.getEditDate(), "EDIT_DATE");
		sql.addStringParam(observation.getEditedBy(), "EDITED_BY");
		sql.addLongParam(observation.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(observation.getId(), "ID");
	}

	public Collection<Observation> search(ObservationSearchBean searchBean) {
    Collection<Object> bindVariables = new ArrayList<Object>();
    StringBuilder sql = new StringBuilder("select * from PHN_OBSERVATION where 1=1 ");

    if (searchBean.getOrderBy() != null && searchBean.getOrderBy().length() > 0) {
      sql.append(" order by " + searchBean.getOrderBy());
      if (searchBean.isOrderDesc()) {
        sql.append(" desc ");
      }
    } else {
      sql.append("order by id");
    }

    return paginator.fetchSearchResults(sql.toString(), bindVariables, searchBean, getRowMapper());
	}

	public void setPaginator(PaginatedSearchUtils<Observation> paginator) {
		this.paginator = paginator;
	}

  public Collection<Observation> fetchByExperimentId(Long experimentId) {
    String sql =
      "select o.*, r.order_by "+
      "from phn_observation o "+
      "join phn_required_observation r on o.required_observation_id = r.id "+
      "where o.experiment_id = ? "+
      "order by r.order_by asc, o.id asc";

    Object[] bindVariables = {experimentId};

    Collection<Observation> observations = getSimpleJdbcTemplate().query(
        sql,
        getRowMapper(),
        bindVariables);

    return observations;
  }

  public Collection<Observation> fetchByObservationTypeId(Long observationTypeId) {
    String sql = "select o.* from PHN_OBSERVATION o join PHN_REQUIRED_OBSERVATION ro on o.REQUIRED_OBSERVATION_ID = ro.ID where ro.OBSERVATION_TYPE_ID = ?";

    Object[] bindVariables = {observationTypeId};

    Collection<Observation> observations = getSimpleJdbcTemplate().query(
        sql,
        getRowMapper(),
        bindVariables);

    return observations;
  }

  public Observation fetchByExperimentIdAndRequiredObservationId(Long experimentId, Long requiredObservationId) {
	 String sql = "select * from phn_observation where experiment_id = ? and required_observation_id=?";
	return fetchOne(sql, experimentId,requiredObservationId);
}

}