/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.datacapture.dao;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.common.PaginatedSearchUtils;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.phenotyping.datacapture.ObservationType;
import uk.ac.sanger.mig.phenotyping.datacapture.ObservationTypeSearchBean;

public class ObservationTypeDaoSpringImpl extends
		AbstractDaoSpringImpl<ObservationType> implements ObservationTypeDao {

	private PaginatedSearchUtils<ObservationType> paginator;

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql,
			ObservationType observationtype) {
		sql.addLongParam(observationtype.getObservationMetaTypeId(),
				"OBSERVATION_META_TYPE_ID");
		sql.addStringParam(observationtype.getName(), "NAME");
		sql.addStringParam(observationtype.getDescription(), "DESCRIPTION");
		sql.addDoubleParam(observationtype.getRangeMin(), "RANGE_MIN");
		sql.addDoubleParam(observationtype.getRangeMax(), "RANGE_MAX");
		sql.addStringParam(observationtype.getUnits(), "UNITS");
		sql.addBooleanParam(observationtype.isRecordInstrument(),
				"RECORD_INSTRUMENT");
		sql.addDateParam(observationtype.getCreatedDate(), "CREATED_DATE");
		sql.addLongParam(observationtype.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(observationtype.getEditDate(), "EDIT_DATE");
		sql.addStringParam(observationtype.getEditedBy(), "EDITED_BY");
		sql.addLongParam(observationtype.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(observationtype.getId(), "ID");
	}

	public Collection<ObservationType> search(
			ObservationTypeSearchBean searchBean) {
		Collection<Object> bindVariables = new ArrayList<Object>();
		ObservationType observationType = searchBean.getObservationType();

		StringBuilder sql = new StringBuilder(
				"select * from PHN_OBSERVATION_TYPE where 1=1 ");

		if (observationType.getObservationMetaTypeId() != null
				&& observationType.getObservationMetaTypeId() > 0) {
			sql.append("and OBSERVATION_META_TYPE_ID = ? ");
			bindVariables.add(observationType.getObservationMetaTypeId());
		}

		if (searchBean.getOrderBy() != null
				&& searchBean.getOrderBy().length() > 0) {
			sql.append(" order by " + searchBean.getOrderBy());
			if (searchBean.isOrderDesc()) {
				sql.append(" desc ");
			}
		} else {
			sql.append("order by id");
		}
		return paginator.fetchSearchResults(sql.toString(), bindVariables,
				searchBean, getRowMapper());
	}

	public Collection<ObservationType> fetchAll() {
		String sql = "select * from PHN_OBSERVATION_TYPE order by lower(name)";

		return getSimpleJdbcTemplate().query(sql,getRowMapper());
	}

	public void setPaginator(PaginatedSearchUtils<ObservationType> paginator) {
		this.paginator = paginator;
	}

	public Collection<ObservationType> fetchByMetaType(ObservationType.MetaType metaType) {
		String sql = "select * from PHN_OBSERVATION_TYPE where observation_meta_type_id = ? order by id";
		
		return getSimpleJdbcTemplate().query(
        sql,
        getRowMapper(),
        metaType.getId()
		);
	}

  public Collection<ObservationType> fetchBySopId(Long sopId) {
    String sql = "select distinct ot.* from PHN_OBSERVATION_TYPE ot " +
                  "join PHN_REQUIRED_OBSERVATION ro on ot.id = ro.observation_type_id " +
                  "where ro.sop_id = ?";
    return getSimpleJdbcTemplate().query(sql, getRowMapper(), sopId);
  }

}