/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.datacapture.dao;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.common.PaginatedSearchUtils;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.phenotyping.datacapture.RequiredObservation;
import uk.ac.sanger.mig.phenotyping.datacapture.RequiredObservationSearchBean;

public class RequiredObservationDaoSpringImpl extends AbstractDaoSpringImpl<RequiredObservation> implements RequiredObservationDao {
	
	private PaginatedSearchUtils<RequiredObservation> paginator;

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, RequiredObservation requiredObservation) {
    sql.addBooleanParam(requiredObservation.isSeriesData(), "IS_SERIES_DATA");
	  sql.addBooleanParam(requiredObservation.isMachineData(), "IS_MACHINE_DATA");
	  sql.addStringParam(requiredObservation.getSectionTitle(), "SECTION_TITLE");
    sql.addBooleanParam(requiredObservation.isMandatoryObservation(), "MANDATORY_OBSERVATION");
    sql.addStringParam(requiredObservation.getDefaultValue(), "DEFAULT_VALUE");
		sql.addLongParam(requiredObservation.getObservationTypeId(), "OBSERVATION_TYPE_ID");
		sql.addIntParam(requiredObservation.getOrderBy(), "ORDER_BY");
		sql.addStringParam(requiredObservation.getDisplayName(), "DISPLAY_NAME");
		sql.addBooleanParam(requiredObservation.isActive(), "ACTIVE");
		sql.addDateParam(requiredObservation.getCreatedDate(), "CREATED_DATE");
		sql.addLongParam(requiredObservation.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(requiredObservation.getEditDate(), "EDIT_DATE");
		sql.addStringParam(requiredObservation.getEditedBy(), "EDITED_BY");
		sql.addLongParam(requiredObservation.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(requiredObservation.getSopId(), "SOP_ID");
		sql.addLongParam(requiredObservation.getId(), "ID");    
	}

	public Collection<RequiredObservation> search(RequiredObservationSearchBean searchBean) {
		Collection<Object> bindVariables = new ArrayList<Object>();
		RequiredObservation requiredObservation = searchBean.getRequiredObservation();
		
		StringBuffer sql = new StringBuffer("select * from PHN_REQUIRED_OBSERVATION where 1=1 ");
		
		if (requiredObservation.getObservationTypeId() != null && requiredObservation.getObservationTypeId() > 0) {
			sql.append(" and observation_type_id = ?");
			bindVariables.add(requiredObservation.getObservationTypeId());			
		}
		
		if (requiredObservation.getSopId() != null && requiredObservation.getSopId() > 0) {
			sql.append(" and sop_id = ?");
			bindVariables.add(requiredObservation.getSopId());
		}
		
		if (searchBean.getOrderBy() != null
				&& searchBean.getOrderBy().length() > 0) {
			sql.append(" order by " + searchBean.getOrderBy());
			if (searchBean.isOrderDesc()) {
				sql.append(" desc ");
			}
		} else {
			sql.append("order by id");
		}
		
		return paginator.fetchSearchResults(sql.toString(), bindVariables,
				searchBean, getRowMapper());
	}

	public PaginatedSearchUtils<RequiredObservation> getPaginator() {
		return paginator;
	}

	public void setPaginator(PaginatedSearchUtils<RequiredObservation> paginator) {
		this.paginator = paginator;
	}

	public Collection<RequiredObservation> fetchBySopId(Long sopId, boolean activeOnly) {
		String sql = "select * from PHN_REQUIRED_OBSERVATION where sop_id = ? ";
		
		if (activeOnly) {
		 sql += " and active = 1 "; 
		}
		
		sql += "order by order_by asc";
		
		return getSimpleJdbcTemplate().query(
        sql,
        getRowMapper(),
        sopId
		);
	}
	
	
	
	public Collection<RequiredObservation> fetchForEditBySopId(Long sopId) {
		String sql = "select * from PHN_REQUIRED_OBSERVATION where sop_id = ? order by order_by asc";
		
		Object[] bindVariables = {sopId};
		
		Collection<RequiredObservation> observations = getSimpleJdbcTemplate().query(
				sql,
				getRowMapper(),
				bindVariables);
		
		return observations;
	}
	
}