/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.datacapture.dao;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.common.PaginatedSearchUtils;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.phenotyping.datacapture.ObservationType;
import uk.ac.sanger.mig.phenotyping.datacapture.RestrictedOption;
import uk.ac.sanger.mig.phenotyping.datacapture.RestrictedOptionSearchBean;

public class RestrictedOptionDaoSpringImpl extends AbstractDaoSpringImpl<RestrictedOption> implements RestrictedOptionDao {

	private PaginatedSearchUtils<RestrictedOption> paginator;
	
	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, RestrictedOption restrictedOption) {
		sql.addLongParam(restrictedOption.getObservationTypeId(), "OBSERVATION_TYPE_ID");
		sql.addLongParam(restrictedOption.getParentOptionId(), "PARENT_OPTION_ID");
		sql.addStringParam(restrictedOption.getName(), "NAME");
		sql.addIntParam(restrictedOption.getOrderBy(), "ORDER_BY");
		sql.addStringParam(restrictedOption.getDescription(), "DESCRIPTION");
		sql.addBooleanParam(restrictedOption.isActive(), "ACTIVE");
		sql.addDateParam(restrictedOption.getCreatedDate(), "CREATED_DATE");
		sql.addLongParam(restrictedOption.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(restrictedOption.getEditDate(), "EDIT_DATE");
		sql.addStringParam(restrictedOption.getEditedBy(), "EDITED_BY");
		sql.addLongParam(restrictedOption.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(restrictedOption.getId(), "ID");
	}
	
	public Collection<RestrictedOption> fetchAll() {
		String sql = "select * from PHN_RESTRICTED_OPTION order by observation_type_id, order_by, id";
		
		Collection<RestrictedOption> options = getSimpleJdbcTemplate().query(sql, getRowMapper());
			
		return options;
	}
	
	public Collection<RestrictedOption> search(RestrictedOptionSearchBean searchBean) {
		Collection<Object> bindVariables = new ArrayList<Object>();
		RestrictedOption restrictedOption = searchBean.getRestrictedOption();

		StringBuffer sql = new StringBuffer(
				"select * from PHN_RESTRICTED_OPTION where 1=1 ");

		if (restrictedOption.getObservationTypeId() != null
				&& restrictedOption.getObservationTypeId() > 0) {
			sql.append("and OBSERVATION_TYPE_ID = ? ");
			bindVariables.add(restrictedOption.getObservationTypeId());
		}

		if (searchBean.getOrderBy() != null
				&& searchBean.getOrderBy().length() > 0) {
			sql.append(" order by " + searchBean.getOrderBy());
			if (searchBean.isOrderDesc()) {
				sql.append(" desc ");
			}
		} else {
			sql.append("order by observation_type_id, order_by, id");
		}
		return paginator.fetchSearchResults(
				sql.toString(),
				bindVariables,
				searchBean,
				getRowMapper());
	}
	
	public Collection<RestrictedOption> fetchByObservationType(ObservationType observationType) {
		String sql = "select * from PHN_RESTRICTED_OPTION where OBSERVATION_TYPE_ID = ? order by order_by, id";
		
    return fetchByTypeWithSql(sql, observationType);
	}
  
  public Collection<RestrictedOption> fetchActiveByObservationType(ObservationType observationType) {
    String sql = "select * from PHN_RESTRICTED_OPTION where OBSERVATION_TYPE_ID = ? and active = 1 order by order_by, id";
    
    return fetchByTypeWithSql(sql, observationType);
  }
  
  private Collection<RestrictedOption> fetchByTypeWithSql(String sql, ObservationType observationType) {
    Object[] bindVariables = {observationType.getId()};
    
    Collection<RestrictedOption> options = getSimpleJdbcTemplate().query(
        sql,
        getRowMapper(),
        bindVariables);
    
    return options;    
  }
	
	public void setPaginator(PaginatedSearchUtils<RestrictedOption> paginator) {
		this.paginator = paginator;
	}
}