/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.datacapture.dao;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.common.PaginatedSearchUtils;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.phenotyping.datacapture.StdOperatingProcedure;
import uk.ac.sanger.mig.phenotyping.datacapture.StdOperatingProcedureSearchBean;

public class StdOperatingProcedureDaoSpringImpl extends AbstractDaoSpringImpl<StdOperatingProcedure> implements StdOperatingProcedureDao {

  private PaginatedSearchUtils<StdOperatingProcedure> paginator;

  @Override
  protected void bindVariables(ParameterizedSqlUpdate sql, StdOperatingProcedure stdOperatingProcedure) {
    sql.addLongParam(stdOperatingProcedure.getProcedureId(), "PROCEDURE_ID");
    sql.addStringParam(stdOperatingProcedure.getName(), "NAME");
    sql.addBooleanParam(stdOperatingProcedure.isActive(), "ACTIVE");
    sql.addDateParam(stdOperatingProcedure.getCreatedDate(), "CREATED_DATE");
    sql.addLongParam(stdOperatingProcedure.getCreatorId(), "CREATOR_ID");
    sql.addDateParam(stdOperatingProcedure.getEditDate(), "EDIT_DATE");
    sql.addStringParam(stdOperatingProcedure.getEditedBy(), "EDITED_BY");
    sql.addLongParam(stdOperatingProcedure.getCheckNumber(), "CHECK_NUMBER");
    sql.addBooleanParam(stdOperatingProcedure.isHidden(), "IS_HIDDEN");
    sql.addLongParam(stdOperatingProcedure.getId(), "ID");
  }

  public Collection<StdOperatingProcedure> fetchAll() {
    String sql = "select * from PHN_STD_OPERATING_PROCEDURE  where is_hidden = 0order by name";

    Collection<StdOperatingProcedure> sops = getSimpleJdbcTemplate().query(sql, getRowMapper());

    return sops;
  }

  public Collection<StdOperatingProcedure> fetchAllActive() {
    String sql = "select * from PHN_STD_OPERATING_PROCEDURE where active = 1 and is_hidden = 0 order by name";

    Collection<StdOperatingProcedure> sops = getSimpleJdbcTemplate().query(sql, getRowMapper());

    return sops;
  }

  public Collection<StdOperatingProcedure> search(StdOperatingProcedureSearchBean searchBean) {
    Collection<Object> bindVariables = new ArrayList<Object>();
    StringBuilder sql = new StringBuilder("select * from PHN_STD_OPERATING_PROCEDURE where is_hidden = 0");

    if (searchBean.getOrderBy() != null && searchBean.getOrderBy().length() > 0) {
      sql.append(" order by " + searchBean.getOrderBy());
      if (searchBean.isOrderDesc()) {
        sql.append(" desc ");
      }
    } else {
      sql.append("order by id");
    }

    return paginator.fetchSearchResults(sql.toString(), bindVariables, searchBean, getRowMapper());
  }

  public void setPaginator(PaginatedSearchUtils<StdOperatingProcedure> paginator) {
    this.paginator = paginator;
  }

  public Collection<StdOperatingProcedure> fetchAllAvailableToUser(Person user) {
    Object bindVariables[] = {user.getId()};
    StringBuilder sql = new StringBuilder();

    sql.append("select distinct sop.*");
    sql.append(" from PHN_STD_OPERATING_PROCEDURE sop");
    sql.append(" join LIC_PROCEDURE_2_PROTOCOL pd_2_pr on sop.PROCEDURE_ID = pd_2_pr.PROCEDURE_DICT_ID");
    sql.append(" join LIC_PROTOCOL_19B pr on pd_2_pr.PROTOCOL_ID = pr.ID");
    sql.append(" join LIC_PROJECT_2_PERSONAL_LICENCE ppl_2_pil on pr.PROJECT_LICENCE_ID = ppl_2_pil.PROJECT_LICENCE_ID");
    sql.append(" join LIC_PERSONAL_LICENCE pil on ppl_2_pil.PERSONAL_LICENCE_ID = pil.PERSONAL_LICENCE_ID");
    sql.append(" where sop.ACTIVE = 1");
    sql.append(" and pil.PERSON_ID = ?");
    sql.append(" order by sop.name asc");

    Collection<StdOperatingProcedure> sops = getSimpleJdbcTemplate().query(
        sql.toString(), getRowMapper(), bindVariables);

    return sops;
  }

}