/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.datacapture.dao;

import java.util.Collection;

import org.springframework.dao.IncorrectResultSizeDataAccessException;
import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.common.Pair;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.phenotyping.datacapture.UploadMapping;
import uk.ac.sanger.mig.phenotyping.datacapture.services.UploadMappingService;
import uk.ac.sanger.mig.phenotyping.datacapture.services.UploadMappingService.Type;

/**
 *
 */
public class UploadMappingDaoSpringImpl extends AbstractDaoSpringImpl<UploadMapping> implements UploadMappingDao {

	private ParameterizedRowMapper<Pair<Long, Type>>	sopUploadTypeRowMapper;


	/*
	 * (non-Javadoc)
	 *
	 * @see uk.ac.sanger.mig.common.AbstractDaoSpringImpl#bindVariables(uk.ac.sanger.mig.database.ParameterizedSqlUpdate,
	 *      uk.ac.sanger.mig.common.AuthenticatedDataObject)
	 */

	public void setSopUploadTypeRowMapper(ParameterizedRowMapper<Pair<Long, Type>> sopUploadTypeRowMapper) {
		this.sopUploadTypeRowMapper = sopUploadTypeRowMapper;
	}


	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, UploadMapping um) {
		sql.addStringParam(um.getFieldName(), "FIELD_NAME");
		sql.addStringParam(um.getName(), "NAME");
		sql.addLongParam(um.getRequiredObservationId(), "REQUIRED_OBSERVATION_ID");
		sql.addDateParam(um.getCreatedDate(), "CREATED_DATE");
		sql.addLongParam(um.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(um.getEditDate(), "EDIT_DATE");
		sql.addStringParam(um.getEditedBy(), "EDITED_BY");
		sql.addLongParam(um.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(um.getId(), "ID");
	}


	public Long fetchActiveSopIdForUploadType(UploadMappingService.Type uploadType) {
		String sql = "select distinct s.id from phn_upload_mapping m"
				+ " join phn_required_observation ro on m.required_observation_id = ro.id"
				+ " join phn_std_operating_procedure s on ro.sop_id = s.id" + " where s.active = 1 and m.name = ?";

		Long sopId = null;
		try {
			sopId = getSimpleJdbcTemplate().queryForLong(sql, uploadType.name());
		} catch (IncorrectResultSizeDataAccessException e) {
			if (e.getActualSize() > 1)
				throw e;
		}

		return sopId;
	}


	public Collection<UploadMapping> fetchBySopId(Long sopId) {
		String sql = "select m.* from phn_upload_mapping m"
				+ " join phn_required_observation ro on m.required_observation_id = ro.id" + " where ro.sop_id = ?";

		return getSimpleJdbcTemplate().query(sql, getRowMapper(), sopId);
	}


	public Collection<UploadMapping> fetchBySopIdAndName(Long sopId, UploadMappingService.Type uploadType) {
		String sql = "select m.* from phn_upload_mapping m"
				+ " join phn_required_observation ro on m.required_observation_id = ro.id"
				+ " where ro.sop_id = ? and name = ?";

		return getSimpleJdbcTemplate().query(sql, getRowMapper(), sopId, uploadType.name());
	}


	public Collection<Pair<Long, Type>> fetchSopsToUploadType() {
		String sql = "select distinct ro.sop_id, um.name type_name from PHN_UPLOAD_MAPPING um"
				+ " join PHN_REQUIRED_OBSERVATION ro on um.required_observation_id = ro.id" + " order by ro.sop_id";

		return getSimpleJdbcTemplate().query(sql, sopUploadTypeRowMapper);
	}

}
