/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.datacapture.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.phenotyping.datacapture.Experiment;

public class ExperimentRowMapper implements ParameterizedRowMapper<Experiment> {

	public Experiment mapRow(ResultSet rs, int rowNum) throws SQLException {
		
		Experiment experiment = new Experiment();
		

		experiment.setId(rs.getLong("ID"));

		experiment.setSopId(rs.getLong("SOP_ID"));
		if(rs.wasNull()) experiment.setSopId(null);		

		experiment.setMouseId(rs.getLong("MOUSE_ID"));
		if(rs.wasNull()) experiment.setMouseId(null);		

		experiment.setComplete(rs.getBoolean("IS_COMPLETE"));
    
    experiment.setExperimentSetId(rs.getLong("EXPERIMENT_SET_ID"));
    if(rs.wasNull()) experiment.setExperimentSetId(null);
    
		experiment.setCreatedDate(rs.getTimestamp("CREATED_DATE"));

		experiment.setCreatorId(rs.getLong("CREATOR_ID"));
		if(rs.wasNull()) experiment.setCreatorId(null);		

		experiment.setEditDate(rs.getTimestamp("EDIT_DATE"));

		experiment.setEditedBy(rs.getString("EDITED_BY"));

		experiment.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) experiment.setCheckNumber(null);		
		
		return experiment;
		
	}
}