/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.datacapture.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.phenotyping.datacapture.ObservationType;

public class ObservationTypeRowMapper implements ParameterizedRowMapper<ObservationType> {
	private DictionaryService dictionaryService;

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}
	public ObservationType mapRow(ResultSet rs, int rowNum) throws SQLException {
		
		ObservationType obsType = new ObservationType();
		
		// std values
		obsType.setId(rs.getLong("ID"));
		
		obsType.setName(rs.getString("NAME"));
		obsType.setDescription(rs.getString("DESCRIPTION"));
		obsType.setRecordInstrument( rs.getBoolean("RECORD_INSTRUMENT") );
		
		// dictionary ids
		obsType.setObservationMetaTypeId(rs.getLong("OBSERVATION_META_TYPE_ID"));		
		
		// dictionary values
		obsType.setObservationMetaType(	dictionaryService.fetchEntry(DictionaryEnum.OBSERVATION_META_TYPE_DICT, obsType.getObservationMetaTypeId()));
		
		// optional values
		obsType.setRangeMin(rs.getDouble("RANGE_MIN")); if (rs.wasNull()) obsType.setRangeMin(null);
		obsType.setRangeMax(rs.getDouble("RANGE_MAX")); if (rs.wasNull()) obsType.setRangeMax(null);
		obsType.setUnits(rs.getString("UNITS")); if (rs.wasNull()) obsType.setUnits(null);
		
		// common columns for AuthenticatedDataObject
		obsType.setCreatedDate(rs.getTimestamp("CREATED_DATE"));
		obsType.setCreatorId(rs.getLong("CREATOR_ID")); if(rs.wasNull()) obsType.setCreatorId(null);		
		obsType.setEditDate(rs.getTimestamp("EDIT_DATE"));
		obsType.setEditedBy(rs.getString("EDITED_BY"));
		obsType.setCheckNumber(rs.getLong("CHECK_NUMBER"));	if(rs.wasNull()) obsType.setCheckNumber(null);		
		
		return obsType;
		
	}
}