/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.datacapture.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.phenotyping.datacapture.RequiredObservation;

public class RequiredObservationRowMapper implements ParameterizedRowMapper<RequiredObservation> {

	public RequiredObservation mapRow(ResultSet rs, int rowNum) throws SQLException {

		RequiredObservation requiredObservation = new RequiredObservation();

		requiredObservation.setId(rs.getLong("ID"));

		requiredObservation.setObservationTypeId(rs.getLong("OBSERVATION_TYPE_ID"));
		if(rs.wasNull()) requiredObservation.setObservationTypeId(null);

		requiredObservation.setOrderBy(rs.getInt("ORDER_BY"));

		requiredObservation.setDisplayName(rs.getString("DISPLAY_NAME"));

		requiredObservation.setActive(rs.getBoolean("ACTIVE"));

		requiredObservation.setCreatedDate(rs.getTimestamp("CREATED_DATE"));

		requiredObservation.setCreatorId(rs.getLong("CREATOR_ID"));
		if(rs.wasNull()) requiredObservation.setCreatorId(null);

		requiredObservation.setEditDate(rs.getTimestamp("EDIT_DATE"));

		requiredObservation.setEditedBy(rs.getString("EDITED_BY"));

		requiredObservation.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) requiredObservation.setCheckNumber(null);

		requiredObservation.setSopId(rs.getLong("SOP_ID"));

    requiredObservation.setDefaultValue(rs.getString("DEFAULT_VALUE"));
    if(rs.wasNull()) requiredObservation.setDefaultValue(null);

    requiredObservation.setMandatoryObservation(rs.getBoolean("MANDATORY_OBSERVATION"));

    requiredObservation.setSectionTitle(rs.getString("SECTION_TITLE"));
    if(rs.wasNull()) requiredObservation.setSectionTitle(null);

    requiredObservation.setMachineData(rs.getBoolean("IS_MACHINE_DATA"));
    if(rs.wasNull()) requiredObservation.setMachineData(false);

    requiredObservation.setSeriesData(rs.getBoolean("IS_SERIES_DATA"));
    if(rs.wasNull()) requiredObservation.setSeriesData(false);

		return requiredObservation;
	}
}