/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.datacapture.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.phenotyping.datacapture.RestrictedOption;

public class RestrictedOptionRowMapper implements ParameterizedRowMapper<RestrictedOption> {

	public RestrictedOption mapRow(ResultSet rs, int rowNum) throws SQLException {
		
		RestrictedOption restrictedOption = new RestrictedOption();
		

		restrictedOption.setId(rs.getLong("ID"));

		restrictedOption.setObservationTypeId(rs.getLong("OBSERVATION_TYPE_ID"));
		if(rs.wasNull()) restrictedOption.setObservationTypeId(null);		

		restrictedOption.setParentOptionId(rs.getLong("PARENT_OPTION_ID"));
		if(rs.wasNull()) restrictedOption.setParentOptionId(null);		

		restrictedOption.setName(rs.getString("NAME"));

		restrictedOption.setOrderBy(rs.getInt("ORDER_BY"));

		restrictedOption.setDescription(rs.getString("DESCRIPTION"));

		restrictedOption.setActive(rs.getBoolean("ACTIVE"));

		restrictedOption.setCreatedDate(rs.getTimestamp("CREATED_DATE"));

		restrictedOption.setCreatorId(rs.getLong("CREATOR_ID"));
		if(rs.wasNull()) restrictedOption.setCreatorId(null);		

		restrictedOption.setEditDate(rs.getTimestamp("EDIT_DATE"));

		restrictedOption.setEditedBy(rs.getString("EDITED_BY"));

		restrictedOption.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) restrictedOption.setCheckNumber(null);		
		
		return restrictedOption;
		
	}
}