/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.datacapture.forms;

import java.util.Collection;
import java.util.Date;
import java.util.LinkedList;
import java.util.List;

import org.apache.commons.collections15.FactoryUtils;
import org.apache.commons.collections15.list.LazyList;

import uk.ac.sanger.mig.licensing.PersonalLicence;
import uk.ac.sanger.mig.licensing.ProjectLicence;
import uk.ac.sanger.mig.mousetracking.Cohort;
import uk.ac.sanger.mig.mousetracking.Mouse;
import uk.ac.sanger.mig.phenotyping.datacapture.StdOperatingProcedure;

public class BeginPhenotypingForm {
  private StdOperatingProcedure sop;
  private ProjectLicence projectLicence;
  private PersonalLicence personalLicence;
  private Cohort cohort;

  private String sopName;
  private Long sopId;

  private String pplName;
  private Long pplId;

  private String pilName;
  private Long pilId;

  private String cohortName;
  private Long cohortId;

  private Long personId;
  private boolean formChange;

  // default to now
  private Date procedureDate = new Date();

  private List<MouseProcedureDate> miceInCohort =
    LazyList.decorate(
        new LinkedList<MouseProcedureDate>(),
        FactoryUtils.instantiateFactory(MouseProcedureDate.class));


  public boolean isFormChange() {
    return formChange;
  }
  public void setFormChange(boolean formChange) {
    this.formChange = formChange;
  }
  public Long getPersonId() {
    return personId;
  }
  public void setPersonId(Long personId) {
    this.personId = personId;
  }
  public Cohort getCohort() {
    return cohort;
  }
  public void setCohort(Cohort cohort) {
    this.cohort = cohort;
  }
  public Long getCohortId() {
    return cohortId;
  }
  public void setCohortId(Long cohortId) {
    this.cohortId = cohortId;
  }
  public String getCohortName() {
    return cohortName;
  }
  public void setCohortName(String cohortName) {
    this.cohortName = cohortName;
  }
  public Long getPplId() {
    return pplId;
  }
  public void setPplId(Long pplId) {
    this.pplId = pplId;
  }
  public String getPplName() {
    return pplName;
  }
  public void setPplName(String pplName) {
    this.pplName = pplName;
  }
  public ProjectLicence getProjectLicence() {
    return projectLicence;
  }
  public void setProjectLicence(ProjectLicence projectLicence) {
    this.projectLicence = projectLicence;
  }
  public StdOperatingProcedure getSop() {
    return sop;
  }
  public void setSop(StdOperatingProcedure sop) {
    this.sop = sop;
  }
  public Long getSopId() {
    return sopId;
  }
  public void setSopId(Long sopId) {
    this.sopId = sopId;
  }
  public String getSopName() {
    return sopName;
  }
  public void setSopName(String sopName) {
    this.sopName = sopName;
  }

  public PersonalLicence getPersonalLicence() {
    return personalLicence;
  }
  public void setPersonalLicence(PersonalLicence personalLicence) {
    this.personalLicence = personalLicence;
  }
  public Long getPilId() {
    return pilId;
  }
  public void setPilId(Long pilId) {
    this.pilId = pilId;
  }
  public String getPilName() {
    return pilName;
  }
  public void setPilName(String pilName) {
    this.pilName = pilName;
  }



  public List<MouseProcedureDate> getMiceInCohort() {
    return miceInCohort;
  }
  public void setMiceInCohort(List<MouseProcedureDate> miceInProcedure) {
    this.miceInCohort = miceInProcedure;
  }

  public void createMouseProcedureDateEntries(Collection<Mouse> mice) {
    miceInCohort.clear();
    for (Mouse mouse : mice) {
      miceInCohort.add(new MouseProcedureDate(mouse));
    }
  }
  public List<MouseProcedureDate> getMiceIncludedInProcedure() {
    List<MouseProcedureDate> mpds = new LinkedList<MouseProcedureDate>();
    for (MouseProcedureDate mpd : miceInCohort) {
      if (mpd.isUseInProcedure()) {
        mpds.add(mpd);
      }
    }
    return mpds;
  }
  public Date getProcedureDate() {
    return procedureDate;
  }
  public void setProcedureDate(Date procedureDate) {
    this.procedureDate = procedureDate;
  }

  public InitialisationInfo getInitialisationInfo() {
    Collection<Mouse> mice = new LinkedList<Mouse>();

    for(MouseProcedureDate mpd : getMiceIncludedInProcedure()) {
      mice.add(mpd.getMouse());
    }

    InitialisationInfo info = new InitialisationInfo(
        sopId,
        pplId,
        pilId,
        mice,
        procedureDate
    );


    return info;
  }


}
