/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.datacapture.services;

import java.util.Collection;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.phenotyping.datacapture.ExperimentSet;
import uk.ac.sanger.mig.phenotyping.datacapture.ExperimentSetSearchBean;
import uk.ac.sanger.mig.phenotyping.datacapture.forms.InitialisationInfo;
import uk.ac.sanger.mig.phenotyping.datacapture.views.ExperimentSetListView;

public interface ExperimentSetService {

	/**
	 * Stores ExperimentSet as record in database and returns the record's primary key
	 * @param experimentSet
	 * @return
	 */
	public Long store(ExperimentSet experimentSet, Person person);

  public Long storeWithExperimentsAndObservations(ExperimentSet experimentSet, Person user);

  public Long[] storeWithExperimentsAndObservations(Collection<ExperimentSet> experimentSets, Person user);

	/**
	 * Returns experimentSet for a given id that maps to primary key
	 * of a record in a database table.
	 * @param id
	 * @return
	 */
	public ExperimentSet fetchById(Long id, ComponentMap componentMap);

	public ExperimentSetListView fetchViewById(Long id);


	/**
	 * Takes search bean and returns a Collection of ExperimentSet objects
	 * based on set fields in bean *and* (this is important) your implementation
	 * of search method in Dao layer -- eg, are you testing for equality?
	 * Greater than/less than, etc?
	 * @param experimentSetSearchBean
	 * @return
	 */
	public Collection<ExperimentSetListView> search(ExperimentSetSearchBean experimentSetSearchBean);


	/**
	 * Attempt to delete the experiment set and all records associated with it
	 * <ul>
	 *   <li>Experiment Set</li>
	 *   <li>Experiments</li>
	 *   <li>Procedure records</li>
	 *   <li>Observations</li>
	 * </ul>
	 *
	 * It will refuse to delete the record if any observations have been recorded
	 * (have a non-null, non-empty value).
	 *
	 *
	 * @param experimentSetId
	 * @param user
	 * @return true if the experiment set was deleted
	 */
	public boolean fullDelete(Long experimentSetId, Person user);

	public void createBloodSampleBarcodesWhereRequired(Long experimentSetId, Person user);

	public boolean delete(ExperimentSet es, Person user);

	/**
	 * Similar to fetchById, but with a specific set of components attached
	 * Implementations may use alternative attachment strategy, as normal component map system is slow for large SOPs
	 * @return
	 */
	public ExperimentSet fetchForPhenotyping(Long id);

  public ExperimentSet createExperimentSet(InitialisationInfo info);
}