/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.datacapture.services;

import java.util.Collection;

import org.springframework.transaction.annotation.Transactional;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.phenotyping.datacapture.ObservationType;
import uk.ac.sanger.mig.phenotyping.datacapture.RequiredObservation;
import uk.ac.sanger.mig.phenotyping.datacapture.RequiredObservationSearchBean;
import uk.ac.sanger.mig.phenotyping.datacapture.StdOperatingProcedure;
import uk.ac.sanger.mig.phenotyping.datacapture.dao.RequiredObservationDao;

public class RequiredObservationServiceImpl extends AbstractServiceImpl<RequiredObservation> implements RequiredObservationService {
	
	private RequiredObservationDao requiredObservationDao;
	private ObservationTypeService observationTypeService;
	private StdOperatingProcedureService sopService;
	
	public void setSopService(StdOperatingProcedureService sopService) {
		this.sopService = sopService;
	}


	public void setRequiredObservationDao(RequiredObservationDao requiredObservationDao) {
		this.requiredObservationDao = requiredObservationDao;
	}

  @Transactional
	public Long storeAuthenticated(RequiredObservation requiredObservation, Person user) {
		if(requiredObservation == null) {
			throw new RuntimeException("Cannot save a null requiredObservation");
		}
		
		return requiredObservationDao.store(requiredObservation, user);
	}
	
	public RequiredObservation fetchById(Long requiredObservationId, ComponentMap requiredComponents) {
		RequiredObservation requiredObservation = requiredObservationDao.fetchById(requiredObservationId);
		
		if(requiredObservation != null)
			attachComponents(requiredObservation, requiredComponents);
		
		return requiredObservation;
	}

	@Override
	protected void attachComponents(RequiredObservation requiredObservation, ComponentMap requiredComponents) {
		if(requiredObservation == null) {
			throw new RuntimeException("Cannot attach components to null requiredObservation");
		}		
		
		boolean fetchAll = false;
		
		if(requiredComponents != null) {
			
			if(requiredComponents.containsKey(RequiredObservation.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}
			
      if (fetchAll || requiredComponents.containsKey(RequiredObservation.Component.OBSERVATION_TYPE)) {
        ObservationType observationType = observationTypeService.fetchById(requiredObservation.getObservationTypeId(), requiredComponents.get(RequiredObservation.Component.OBSERVATION_TYPE));
			  requiredObservation.setObservationType(observationType);
      }
			
      if (fetchAll || requiredComponents.containsKey(RequiredObservation.Component.SOP)) {
        StdOperatingProcedure sop = sopService.fetchById(requiredObservation.getSopId(), requiredComponents.get(RequiredObservation.Component.SOP));
			  requiredObservation.setSop(sop);
      }
		}
    
	}



	public Collection<RequiredObservation> search(RequiredObservationSearchBean searchBean) {
		Collection<RequiredObservation> observations = requiredObservationDao.search(searchBean);
		attachComponents(observations, ComponentMap.of(RequiredObservation.Component.ALL_COMPONENTS));
		return observations;
	}


	public void setObservationTypeService(
			ObservationTypeService observationTypeService) {
		this.observationTypeService = observationTypeService;
	}


	public Collection<RequiredObservation> fetchBySopId(Long sopId, ComponentMap componentMap) {
	  return this.fetchBySopId(sopId,false,componentMap);
	}
	 public Collection<RequiredObservation> fetchBySopId(Long sopId, boolean activeOnly, ComponentMap componentMap) {
	    Collection<RequiredObservation> observations = requiredObservationDao.fetchBySopId(sopId,activeOnly);
	    attachComponents(observations, componentMap);
	    return observations;
	  }
  
  public Collection<RequiredObservation> fetchForEditBySopId(Long sopId, ComponentMap componentMap) {
    Collection<RequiredObservation> observations = requiredObservationDao.fetchForEditBySopId(sopId);
    attachComponents(observations, componentMap);
    return observations;
  }
		
}
								