/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.datacapture.validators;

import org.springframework.validation.Errors;
import org.springframework.validation.Validator;

import uk.ac.sanger.mig.phenotyping.datacapture.Experiment;
import uk.ac.sanger.mig.phenotyping.datacapture.ExperimentSet;
import uk.ac.sanger.mig.phenotyping.datacapture.Observation;
import uk.ac.sanger.mig.phenotyping.datacapture.forms.CalorimetryForm;
import uk.ac.sanger.mig.phenotyping.datacapture.forms.CalorimetryForm.CalorimetryRow;

/**
 *
 */
public class CalorimetryFormValidator implements Validator {

  public boolean supports(Class clazz) {
    return CalorimetryForm.class.equals(clazz);
  }

  public void validate(Object target, Errors errors) {
    CalorimetryForm form = (CalorimetryForm)target;

    // validate extra data
    for (int i = 0; i < form.getRows().size(); i++) {
      CalorimetryRow row = form.getRows().get(i);
      check(row.getBadFoodData(), i, "badFoodData", errors);
      check(row.getWeightAfter(), i, "weightAfter", errors);
      check(row.getWaterBottleWeightBefore(), i, "waterBottleWeightBefore", errors);
      check(row.getWaterBottleWeightAfter(), i, "waterBottleWeightAfter", errors);

      boolean complete = true;

      for (Observation o : row.getExperiment().getObservations()) {
      	if (o.getRequiredObservation().isMandatoryObservation() &&
      			o.getValue() == null) {
      		complete = false;
      		break;
      	}
      	if (!o.isValid()){
      		complete = false;
      		break;
      	}
      }

      row.getExperiment().setComplete(complete);

    }

    // set completion overall
    for (int i = 0; i < form.getSets().size(); i++) {
      ExperimentSet es = form.getSets().get(i);
      if (!es.isComplete()) {
        es.setComplete(isCompletable(es));
      }
    }
  }

  private void check(Observation observation, int i, String pathEnd, Errors errors) {

      if (!observation.isValid() && observation.getValue() != null) {
        String path = "rows[" + i + "]."+pathEnd;
        errors.rejectValue(path, null, "Invalid value");
      }
  }

  private boolean isCompletable(ExperimentSet es) {
    boolean completable = true;

    for (Experiment e : es.getExperiments()) {
      if (e.getMouse().isAlive() && !e.isComplete())
        completable = false;
    }

    return completable;
  }


}
