/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.datacapture.validators;

import org.springframework.validation.Errors;
import org.springframework.validation.ValidationUtils;
import org.springframework.validation.Validator;

import uk.ac.sanger.mig.mousetracking.Mouse;
import uk.ac.sanger.mig.mousetracking.services.MouseService;
import uk.ac.sanger.mig.phenotyping.datacapture.Experiment;
import uk.ac.sanger.mig.phenotyping.datacapture.ExperimentSet;
import uk.ac.sanger.mig.phenotyping.datacapture.forms.ExperimentSetForm;


public class ExperimentSetFormValidator implements Validator {

  private MouseService mouseService;

  public void setMouseService(MouseService mouseService) {
    this.mouseService = mouseService;
  }

  public boolean supports(Class clazz) {
    return ExperimentSetForm.class.equals(clazz);
  }

  public void validate(Object command, Errors errors) {
    ExperimentSetForm form = (ExperimentSetForm)command;

    ValidationUtils.rejectIfEmpty(errors, "experimentSet", null, "Experiment Set object is missing");
    ValidationUtils.rejectIfEmpty(errors, "experimentSet.experiments", null, "Experiment objects are missing");

    if (form.getExperimentSet() != null && form.getExperimentSet().getExperiments() != null) {

      if (form.getExperimentSet().isComplete() && !experimentsCompleteOnLiveMice(form.getExperimentSet())) {
        errors.reject(null, "This set of work cannot be marked as complete, some experiments for live mice have not been finished");
      }
    }
  }

  private boolean experimentsCompleteOnLiveMice(ExperimentSet es) {
    boolean complete = true;

    for (Experiment e : es.getExperiments()) {
      if (!e.isComplete()) {
        Mouse m = mouseService.fetchById(e.getMouseId(), null);

        // this experiment isn't complete yet, and the mouse is alive
        if (m.isAlive()) {
          complete = false;
          break;
        }
      }
    }

    return complete;
  }





}