/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.datacapture.validators;

import org.springframework.validation.Errors;
import org.springframework.validation.ValidationUtils;
import org.springframework.validation.Validator;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.phenotyping.datacapture.RequiredObservation;
import uk.ac.sanger.mig.phenotyping.datacapture.StdOperatingProcedure;
import uk.ac.sanger.mig.phenotyping.datacapture.forms.RequiredObservationForm;
import uk.ac.sanger.mig.phenotyping.datacapture.services.StdOperatingProcedureService;

public class RequiredObservationFormValidator implements Validator {
  
  private StdOperatingProcedureService sopService;
  
  public void setSopService(StdOperatingProcedureService sopService) {
    this.sopService = sopService;
  }

  public boolean supports(Class clazz) {
    return RequiredObservationForm.class.equals(clazz);
  }

  public void validate(Object commandForm, Errors errors) { 
    RequiredObservationForm requiredObservationForm = (RequiredObservationForm)commandForm;
    RequiredObservation requiredObservation = requiredObservationForm.getRequiredObservation();

    ValidationUtils.rejectIfEmptyOrWhitespace(errors, "requiredObservation.displayName", null, "Please provide a display name");

    if (requiredObservation.getObservationTypeId() < 1) {
      errors.rejectValue("requiredObservation.observationTypeId", null, "Please select an observation type");
    }
    
    StdOperatingProcedure sop = null;
    
    if (requiredObservation.getSopId() != null && requiredObservation.getSopId() > 0) {
      sop= sopService.fetchById(requiredObservation.getSopId(), ComponentMap.of(StdOperatingProcedure.Component.REQUIRED_OBSERVATIONS));
    }
    
    if (sop == null) {
      errors.rejectValue("requiredObservation.sopId", null, "SOP ID should be pre-determined");
    }
    else if (requiredObservation.getDisplayName() != null){
      boolean newRecord = (requiredObservation.getId() == null || requiredObservation.getId() < 1);
      boolean duplicateName = false;
      
       for (RequiredObservation storedReq : sop.getRequiredObservations()) {
        
         boolean doCheck =  (newRecord || !storedReq.getId().equals(requiredObservation.getId()));
         
         if (doCheck && storedReq.getDisplayName().equalsIgnoreCase(requiredObservation.getDisplayName())) {
           duplicateName = true;
           break;
         }
         
       }
       
       if (duplicateName) {
         errors.rejectValue("requiredObservation.displayName", null, "This name is already in use");
       }
    }
    
  }

}