/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.faxitron.dao;


import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.phenotyping.faxitron.DicomFilteredImage;
import uk.ac.sanger.mig.phenotyping.faxitron.DicomFilteredImageSearchBean;



public class DicomFilteredImageDaoSpringImpl extends AbstractDaoSpringImpl<DicomFilteredImage> implements DicomFilteredImageDao {


	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, DicomFilteredImage dicomFilteredImage) {
		
		sql.addLongParam(dicomFilteredImage.getDicomId(), "DICOM_ID");
		sql.addStringParam(dicomFilteredImage.getFilteredDicomName(), "FILTERED_DICOM_NAME");
		sql.addStringParam(dicomFilteredImage.getFilteredDicomPath(), "FILTERED_DICOM_PATH");
		sql.addBlobParam(dicomFilteredImage.getFilteredThumbnail(), "FILTERED_THUMBNAIL", true);
		sql.addLongParam(dicomFilteredImage.getLevelId(), "DICOM_LEVEL_ID");
		sql.addLongParam(dicomFilteredImage.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(dicomFilteredImage.getCreatorId(), "CREATED_BY");
		sql.addDateParam(dicomFilteredImage.getCreatedDate(), "CREATED_DATE");
		sql.addStringParam(dicomFilteredImage.getEditedBy(), "EDITED_BY");
		sql.addDateParam(dicomFilteredImage.getEditDate(), "EDIT_DATE");
		sql.addLongParam(dicomFilteredImage.getId(), "ID");
	
		
	}

	public Collection<DicomFilteredImage> search(DicomFilteredImageSearchBean dicomFilteredImageSearchBean) {
		// TODO Auto-generated method stub
		return null;
	}

	public Collection<DicomFilteredImage> fetchFilteredImagesByDicomId(Long dicomId) {

		String sql = "select * from phn_dicom_filtered_image where dicom_id = ?";
		
		Collection<DicomFilteredImage> dicoms = getSimpleJdbcTemplate().query(sql, getRowMapper(), dicomId);
		
		return (dicoms == null) ? new ArrayList<DicomFilteredImage>() : dicoms;
		
	}


	

	
}