/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.faxitron.dao;


import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.phenotyping.faxitron.DicomImage;
import uk.ac.sanger.mig.phenotyping.faxitron.DicomImageSearchBean;



public class DicomImageDaoSpringImpl extends AbstractDaoSpringImpl<DicomImage> implements DicomImageDao {


	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, DicomImage dicomImage) {
		
		
		sql.addLongParam(dicomImage.getMouseId(), "MOUSE_ID");
		sql.addLongParam(dicomImage.getOperatorId(), "OPERATOR_ID");
		sql.addStringParam(dicomImage.getDicomName(), "IMAGE_NAME");
		sql.addStringParam(dicomImage.getDicomPathOriginal(), "ORIGINAL_DICOM_PATH");
		sql.addStringParam(dicomImage.getDicomPath(), "ANONYMIZED_DICOM_PATH");
		sql.addDateParam(dicomImage.getImageDate(), "IMAGE_DATE");
		sql.addIntParam(dicomImage.getImageWidth(), "WIDTH");
		sql.addIntParam(dicomImage.getImageHeight(), "HEIGHT");
		sql.addIntParam(dicomImage.getResolutionPerMM(), "RESOLUTION_PER_MM");
		sql.addStringParam(dicomImage.getDose(), "DOSE");
		
		sql.addLongParam(dicomImage.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(dicomImage.getCreatorId(), "CREATED_BY");
		sql.addDateParam(dicomImage.getCreatedDate(), "CREATED_DATE");
		sql.addStringParam(dicomImage.getEditedBy(), "EDITED_BY");
		sql.addDateParam(dicomImage.getEditDate(), "EDIT_DATE");
		sql.addLongParam(dicomImage.getId(), "ID");
	
	}

	public Collection<DicomImage> search(DicomImageSearchBean dicomInfoSearchBean) {
		// TODO Auto-generated method stub
		return null;
	}

	public Collection<DicomImage> fetchDicomImagesByMouseId(Long mouseId) {
	
		String sql = "select * from phn_dicom_image where mouse_id = ?";
		
		Collection<DicomImage> dicoms = getSimpleJdbcTemplate().query(sql, getRowMapper(), mouseId);
		
		return (dicoms == null) ? new ArrayList<DicomImage>() : dicoms;
		
		
		
	}
	
}