/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.faxitron.services;

import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.phenotyping.faxitron.DicomFilteredImage;
import uk.ac.sanger.mig.phenotyping.faxitron.DicomFilteredImageSearchBean;
import uk.ac.sanger.mig.phenotyping.faxitron.DicomImage;
import uk.ac.sanger.mig.phenotyping.faxitron.DicomLevel;
import uk.ac.sanger.mig.phenotyping.faxitron.dao.DicomFilteredImageDao;


public class DicomFilteredImageServiceImpl extends AbstractServiceImpl<DicomFilteredImage> implements DicomFilteredImageService {

	private DicomFilteredImageDao dicomFilteredImageDao;
	private DicomLevelService dicomLevelService;
	private DicomImageService dicomImageService;
	


	public void setDicomImageService(DicomImageService dicomImageService) {
		this.dicomImageService = dicomImageService;
	}

	public void setDicomLevelService(DicomLevelService dicomLevelService) {
		this.dicomLevelService = dicomLevelService;
	}

	public void setDicomFilteredImageDao(DicomFilteredImageDao dicomFilteredImageDao) {
		this.dicomFilteredImageDao = dicomFilteredImageDao;
	}

	
	public Long storeAuthenticated(DicomFilteredImage dicomFilteredImage, Person user) {
		if(dicomFilteredImage == null) {
			throw new RuntimeException("Cannot save a null dicomFilteredImage");
		}

		return dicomFilteredImageDao.store(dicomFilteredImage, user);
	}

	public DicomFilteredImage fetchById(Long dicomFilteredImageId, ComponentMap requiredComponents) {
		DicomFilteredImage dicomFilteredImage = dicomFilteredImageDao.fetchById(dicomFilteredImageId);

		if(dicomFilteredImage != null)
			attachComponents(dicomFilteredImage, requiredComponents);

		return dicomFilteredImage;
	}

	@Override
	protected void attachComponents(DicomFilteredImage dicomFilteredImage, ComponentMap requiredComponents) {
		if(dicomFilteredImage == null) {
			throw new RuntimeException("Cannot attach components to null dicomFilteredImage");
		}		

		boolean fetchAll = false;

		if(requiredComponents != null) {

			if(requiredComponents.containsKey(DicomFilteredImage.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}

			if(fetchAll || requiredComponents.containsKey(DicomFilteredImage.Component.DICOM_IMAGE)) {
				dicomFilteredImage.setDicom(fetchDicom(dicomFilteredImage, requiredComponents.get(DicomImage.Component.ALL_COMPONENTS)));
			}
			
			if(fetchAll || requiredComponents.containsKey(DicomFilteredImage.Component.LEVEL)) {
				dicomFilteredImage.setLevel(fetchLevel(dicomFilteredImage));
			}
		
		}
	}

	
	private DicomImage fetchDicom(DicomFilteredImage info, ComponentMap requiredComponents) {
		if(info.getDicomId() != null) {
			return dicomImageService.fetchById(info.getDicomId(), requiredComponents);
		}
		else {
			return null;
		}
	}		

	private DicomLevel fetchLevel(DicomFilteredImage info) {
		if(info.getLevelId()!= null) {
			return dicomLevelService.fetchById(info.getLevelId(), null);
		}
		else {
			return null;
		}
	}	
	
	public Collection<DicomFilteredImage> search(DicomFilteredImageSearchBean dicomFilteredImageSearchBean) {
		// TODO Auto-generated method stub
		return null;
	}

	public Collection<DicomFilteredImage> fetchFilteredImagesByDicomId(Long dicomId) {

		return dicomFilteredImageDao.fetchFilteredImagesByDicomId(dicomId);

	}

	
}
