/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.olympus.controllers;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.CancellableFormController;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.mousetracking.services.MouseService;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.phenotyping.abc.BloodsData;
import uk.ac.sanger.mig.phenotyping.abc.BloodsRun;
import uk.ac.sanger.mig.phenotyping.abc.services.BloodsDataService;
import uk.ac.sanger.mig.phenotyping.abc.services.BloodsRunService;
import uk.ac.sanger.mig.phenotyping.olympus.forms.SerumResultsForm;

public class ValidateSerumResultsFormController extends CancellableFormController {

	private BloodsRunService bloodsRunService;
	private BloodsDataService bloodsDataService;
	private DictionaryService dictionaryService;
	private MouseService mouseService;
	private String addTestSuccessView;

	public void setMouseService(MouseService mouseService) {
		this.mouseService = mouseService;
	}
	public void setBloodsDataService(BloodsDataService bloodsDataService) {
		this.bloodsDataService = bloodsDataService;
	}
	public void setBloodsRunService(BloodsRunService bloodsRunService) {
		this.bloodsRunService = bloodsRunService;
	}
	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}
	public void setAddTestSuccessView(String addTestSuccessView) {
		this.addTestSuccessView = addTestSuccessView;
	}


	public String getAddTestSuccessView() {
		return addTestSuccessView;
	}
	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		SerumResultsForm form = (SerumResultsForm)command;

		Person user = RequestUtils.getUser(request);

		BloodsRun run  = form.getRun();

		String addTest = ServletRequestUtils.getRequiredStringParameter(request, "addTest");
		if(addTest.equals("addTest")) {
			BloodsData newTest = new BloodsData();
			newTest.setParameterId(form.getTestId());
			newTest.setValue(form.getTestValue());
			newTest.setErrorCode1Id(51L); // manually added by user.
			newTest.setRunId(run.getId());

			bloodsDataService.storeAuthenticated(newTest, user);

			return new ModelAndView(getAddTestSuccessView(), "id", run.getId());

		}

		Collection<BloodsData> data = form.getData();

		int validCount = 0;
		int failedCount = 0;
		for(BloodsData d : data) {
			if(d.getResultStatusId() != null) {
				validCount++;
				if(d.getResultStatusId() == 2L) {
					failedCount++;
				}
			}
			bloodsDataService.storeAuthenticated(d, user);
		}

		if(run != null) {
			// if all samples have been validated, set the run validated flag to true.
			if(validCount == data.size()) {
				run.setValidated(true);
			}
			// If all samples have been rejected, fail the run.
			if(failedCount == data.size()) {
				run.setFailed(true);
			}
			bloodsRunService.storeAuthenticated(run, user);
		}



		return new ModelAndView(getSuccessView()+"newQuery=false&bypassForm=true");


	}




	@Override
	protected Map referenceData(HttpServletRequest request, Object command, Errors errors) throws Exception {

		Map<String,Object> formMetaData = new HashMap<String,Object>();

		Collection<BloodsData> testCodes = new ArrayList<BloodsData>();
		// temporary.
		Collection<DictionaryEntry> entries = dictionaryService.fetchDependant(DictionaryEnum.PHENOTYPING_PARAMS, 1L, "ACTIVE");

		for(DictionaryEntry entry : entries) {
			BloodsData code = new BloodsData();
			code.setId(Long.valueOf(entry.getId()));
			code.setValue(entry.getName());
			testCodes.add(code);
		}

		formMetaData.put("testCodes", testCodes);

		return formMetaData;

	}
	@Override
	protected Object formBackingObject(HttpServletRequest request) throws Exception {
		SerumResultsForm resultForm = (SerumResultsForm)createCommand();

		Long runId = ServletRequestUtils.getRequiredLongParameter(request, "id");

		BloodsRun run = bloodsRunService.fetchById(runId, ComponentMap.of(BloodsRun.Component.SERUM_BARCODE));
		if(run != null) {
			run.setMouse(mouseService.fetchById(run.getMouseId(), null));
			Collection<BloodsData> data = bloodsDataService.fetchByRunIdNoGraphs(runId);


			// Olympus specific.
			if(run.getInstrumentId() == 2L) {
				addOlympusUnits(data);
				/*for(BloodsData d : data) {

					Collection<BloodsData> dataSet = bloodsDataService.fetchAllByParameterId(d.getParameterId());
					// Users wanted to see Mean and StandardDeviation for each test.
					Double mean = bloodsDataService.calculateMeanForDataSet(dataSet);
					d.setMeanValue(mean);

					Double standardDeviation = bloodsDataService.calculateStandardDeviationForDataSet(dataSet);
					Double limitHi = mean + (standardDeviation * 2);
					Double limitLo = mean - (standardDeviation * 2);
					d.setSdValue(standardDeviation);

					// If value is greater than / less than 2 SD then we need to error.
					// Generate a dictionary entry and attach.
//					Double compVal = Double.parseDouble(d.getValue());
//					if(compVal < limitLo) {
//						DictionaryEntry err = new DictionaryEntry();
//						err.setDescription("Value is less than 2 Standard Deviations.");
//						d.setErrorCode1(err);
//						// set errorCodeId to 0 as we check for a value in the JSP.
//						d.setErrorCode1Id(0L);
//					}
//					if(compVal > limitHi) {
//						DictionaryEntry err = new DictionaryEntry();
//						err.setDescription("Value is greater than 2 Standard Deviations.");
//						d.setErrorCode1(err);
//						// set errorCodeId to 0 as we check for a value in the JSP.
//						d.setErrorCode1Id(0L);
//					}
				}*/
			}else{
				// ABC specific.
				addABCUnits(data);
			}

			if(data != null) {
				resultForm.setData(data);
			}

			resultForm.setRun(run);
		}

		return resultForm;
	}


	private void addOlympusUnits(Collection<BloodsData> data) {

		for(BloodsData d : data) {
			switch(Integer.parseInt(d.getParameter().getDescription())){
			case 99: case 98: case 97: case 25: case 23: case 22: case 21:
			case 16: case 9: case 8: case 5: case 3: case 2: case 1:
				d.setUnits("mmol/l");
				break;
			case 20: case 15: case 13: case 12: case 11: case 4:
				d.setUnits("U/l");
				break;
			case 24: case 18: case 14: case 10:
				d.setUnits("\u00B5mol/l");
				break;
			case 7: case 6:
				d.setUnits("g/l");
				break;
			default:
				d.setUnits("Unknown");
			break;
			}
		}
	}

	private void addABCUnits(Collection<BloodsData> data) {

		for(BloodsData d : data) {
			switch(Integer.parseInt(d.getParameter().getDescription())){
			case 4: case 9:
				d.setUnits("g/dl");
				break;
			case 5: case 10: case 12: case 13: case 14:
				d.setUnits("%");
				break;
			case 2: case 6: case 15: case 16: case 17:
				d.setUnits("10<sup>3</sup>/mm<sup>3</sup>");
				break;
			case 3:
				d.setUnits("10<sup>6</sup>/mm<sup>3</sup>");
				break;
			case 7: case 11:
				d.setUnits("\u00B5m<sup>3</sup>");
				break;
			case 8:
				d.setUnits("pg");
				break;
			default:
				d.setUnits("");
			break;
			}
		}
	}



}
