/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.olympus.controllers;


import java.util.ArrayList;
import java.util.Calendar;
import java.util.Collection;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.charting.ChartData;
import uk.ac.sanger.mig.common.AbstractCancellableFormController;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.phenotyping.abc.BloodsData;
import uk.ac.sanger.mig.phenotyping.abc.services.BloodsDataService;
import uk.ac.sanger.mig.phenotyping.abc.services.BloodsRunService;
import uk.ac.sanger.mig.phenotyping.olympus.forms.SerumQCForm;
import uk.ac.sanger.mig.phenotyping.olympus.services.SerumTestService;
import uk.ac.sanger.mig.phenotyping.olympus.views.SerumQCChart;
import ChartDirector.MultiChart;


public class ViewSerumQCFormController extends AbstractCancellableFormController {

	private BloodsRunService bloodsRunService;
	private BloodsDataService bloodsDataService;
	private DictionaryService dictionaryService;
	private SerumTestService serumTestService;

	public void setBloodsDataService(BloodsDataService bloodsDataService) {
		this.bloodsDataService = bloodsDataService;
	}
	public void setBloodsRunService(BloodsRunService bloodsRunService) {
		this.bloodsRunService = bloodsRunService;
	}
	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}
	public void setSerumTestService(SerumTestService serumTestService) {
		this.serumTestService = serumTestService;
	}



	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {	
		SerumQCForm form = (SerumQCForm)command;

		Long parameterId = ServletRequestUtils.getRequiredLongParameter(request, "parameterId");
		
		DictionaryEntry entry = dictionaryService.fetchEntry(DictionaryEnum.PHENOTYPING_PARAMS, parameterId);
		form.setParameter(entry);


		Collection<BloodsData> dataSet = bloodsDataService.fetchAllByParameterId(parameterId);

		form.setBaseCV(bloodsDataService.calcuateCoefficientOfVariation(dataSet));
		form.setBaseMean(bloodsDataService.calculateMeanForDataSet(dataSet));
		form.setBaseRange(bloodsDataService.calculateRangeForDataSet(dataSet));
		form.setBaseSD(bloodsDataService.calculateStandardDeviationForDataSet(dataSet));

		Collection<BloodsData> subDataSet = subsetFromAllData(form.getSampledDateFrom(), form.getSampledDateTo(), dataSet);
		
		form.setDayCV(bloodsDataService.calcuateCoefficientOfVariation(subDataSet));
		form.setDayMean(bloodsDataService.calculateMeanForDataSet(subDataSet));
		form.setDayRange(bloodsDataService.calculateRangeForDataSet(subDataSet));
		form.setDaySD(bloodsDataService.calculateStandardDeviationForDataSet(subDataSet));
		form.setDayN(subDataSet.size());

		Map<String, Object> model = new HashMap<String, Object>();	

		ChartData data = bloodsDataService.fetchChartDataByParameterId(parameterId);
		
		if(data != null ) {

		SerumQCChart chart = new SerumQCChart(600,600, data, form.getBaseMean(), form.getBaseSD(), form.getBaseRange());
		MultiChart m = chart.getChart();
		m.makeSession(request, "xychart");

		//		 Include tool tip for the chart
		String imageMap1 = m.getHTMLImageMap("", "", "title='{dataSetName} : {value} '");

		model.put("imageMap1", imageMap1);
		
		}else{
			model.put("errors", "No Data Available.");
		}

		if(form.getSampledDateFrom() == null) {
			form.setSampledDateFrom(new Date());
		}
		if(form.getSampledDateTo() == null) {
			form.setSampledDateTo(new Date());
		}	
		
		return showForm(request, response, errors, model);
	}


	
	private Collection<BloodsData> subsetFromAllData(Date from, Date to, Collection<BloodsData> data) {

		Calendar cl = Calendar.getInstance();
		cl.setTime(to);
		cl.add(Calendar.DATE, 1);
		Date newTo = cl.getTime();
		
		Collection<BloodsData> subset = new ArrayList<BloodsData>();
		for(BloodsData d : data) {
			if(d.getCreatedDate().after(from) && d.getCreatedDate().before(newTo) ) {
				subset.add(d);
			}
		} 
		return subset;
	}

	@Override
	protected Object formBackingObject(HttpServletRequest request) throws Exception {
		SerumQCForm form = (SerumQCForm)createCommand();	


		Collection<BloodsData> testCodes = new ArrayList<BloodsData>();

//		Collection<DictionaryEntry> entries = dictionaryService.fetchDependant(DictionaryEnum.PHENOTYPING_PARAMS, 2L, "INSTRUMENT_ID");

		Collection<DictionaryEntry> entries = dictionaryService.fetchDependant(DictionaryEnum.PHENOTYPING_PARAMS, 2L, "ACTIVE");

		
		for(DictionaryEntry entry : entries) {
			BloodsData code = new BloodsData();
			code.setParameterId(Long.valueOf(entry.getId()));
			code.setValue(entry.getName());
			testCodes.add(code);
		}
		form.setTestCodes(testCodes);

		if(form.getSampledDateFrom() == null) {
			form.setSampledDateFrom(new Date());
		}
		if(form.getSampledDateTo() == null) {
			form.setSampledDateTo(new Date());
		}	
		
		return form;
	}


}
