/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.olympus.controllers;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.ParameterizableViewController;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.mousetracking.services.MouseService;
import uk.ac.sanger.mig.phenotyping.abc.BloodsData;
import uk.ac.sanger.mig.phenotyping.abc.BloodsRun;
import uk.ac.sanger.mig.phenotyping.abc.services.BloodsDataService;
import uk.ac.sanger.mig.phenotyping.abc.services.BloodsRunService;

public class ViewSerumResultsFormController extends ParameterizableViewController {

	private BloodsRunService bloodsRunService;
	private BloodsDataService bloodsDataService;
	private MouseService mouseService;


	public void setMouseService(MouseService mouseService) {
		this.mouseService = mouseService;
	}
	public void setBloodsDataService(BloodsDataService bloodsDataService) {
		this.bloodsDataService = bloodsDataService;
	}
	public void setBloodsRunService(BloodsRunService bloodsRunService) {
		this.bloodsRunService = bloodsRunService;
	}


	@Override
	protected ModelAndView handleRequestInternal(HttpServletRequest request, HttpServletResponse response) throws Exception {

		Long runId = ServletRequestUtils.getRequiredLongParameter(request, "id");

		Map<String, Object> model = new HashMap<String, Object>();

		BloodsRun run = bloodsRunService.fetchById(runId, ComponentMap.of(BloodsRun.Component.ALL_COMPONENTS));
		if(run != null) {
			run.setMouse(mouseService.fetchById(run.getMouseId(), null));
			Collection<BloodsData> data = bloodsDataService.fetchByRunIdNoGraphs(runId);

			// Add units for each machine type.
			if(run.getInstrumentId() == 2L) {
				addOlympusUnits(data);
			}else{
				addABCUnits(data);
			}

			if(data != null) {
				model.put("data",data);
			}
			model.put("run",run);
		}

		return new ModelAndView(getViewName(), model);
	}

	private void addOlympusUnits(Collection<BloodsData> data) {

		for(BloodsData d : data) {
			switch(Integer.parseInt(d.getParameter().getDescription())){
			case 99: case 98: case 97: case 25: case 23: case 22: case 21:
			case 16: case 9: case 8: case 5: case 3: case 2: case 1:
				d.setUnits("mmol/l");
				break;
			case 20: case 15: case 13: case 12: case 11: case 4:
				d.setUnits("U/l");
				break;
			case 24: case 18: case 14: case 10:
				d.setUnits("\u00B5mol/l");
				break;
			case 7: case 6:
				d.setUnits("g/l");
				break;
			default:
				d.setUnits("Unknown");
			break;
			}
		}
	}

	private void addABCUnits(Collection<BloodsData> data) {

		for(BloodsData d : data) {
			switch(Integer.parseInt(d.getParameter().getDescription())){
			case 4: case 9:
				d.setUnits("g/dl");
			break;
			case 5: case 10: case 12: case 13: case 14:
				d.setUnits("%");
				break;
			case 2: case 6: case 15: case 16: case 17:
				d.setUnits("10<sup>3</sup>/mm<sup>3</sup>");
				break;
			case 3:
				d.setUnits("10<sup>6</sup>/mm<sup>3</sup>");
				break;
			case 7: case 11:
				d.setUnits("\u00B5m<sup>3</sup>");
				break;
			case 8:
				d.setUnits("pg");
				break;
			default:
				d.setUnits("");
			break;
			}
		}
	}

}
