/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.olympus.dao;

import java.util.ArrayList;
import java.util.Collection;

import org.springframework.dao.IncorrectResultSizeDataAccessException;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.phenotyping.olympus.SerumTest;
import uk.ac.sanger.mig.phenotyping.olympus.SerumTestSearchBean;

public class SerumTestDaoSpringImpl extends AbstractDaoSpringImpl<SerumTest> implements SerumTestDao {


	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, SerumTest serumTest) {
		sql.addStringParam(serumTest.getBarcode(), "BARCODE");
		sql.addStringParam(serumTest.getTestCodes(), "TEST_CODES");
		sql.addBooleanParam(serumTest.getIsPreset(), "IS_PRESET");
		sql.addLongParam(serumTest.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(serumTest.getCreatedDate(), "CREATED_DATE");
		sql.addStringParam(serumTest.getEditedBy(), "EDITED_BY");
		sql.addDateParam(serumTest.getEditDate(), "EDIT_DATE");
		sql.addLongParam(serumTest.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(serumTest.getMouseId(), "MOUSE_ID");
		sql.addLongParam(serumTest.getMethod(), "METHOD");
		sql.addLongParam(serumTest.getId(), "ID");
	}

	public Collection<SerumTest> search(SerumTestSearchBean serumTestSearchBean) {
		// TODO Auto-generated method stub
		return null;
	}
	
	public SerumTest fetchByBarcode(String barcode, ComponentMap requiredComponents) {
		SerumTest test = null;
		
		String sql = "select * from phn_serum_test where barcode = ? ";
		
		try {
			test = getSimpleJdbcTemplate().queryForObject(sql, getRowMapper(), barcode);
		}
		catch(IncorrectResultSizeDataAccessException e) {
		}
		
		return test;
	}
	
	public Collection<SerumTest> fetchTestPresets() {
		
		String sql = "select * from phn_serum_test where is_preset = 1";
		
		Collection<SerumTest> presets = getSimpleJdbcTemplate().query(sql, getRowMapper());
		
		return (presets == null) ? new ArrayList<SerumTest>() : presets;
		
	}
	
	public SerumTest fetchByMouseId(Long mouseId) {
		String sql = "select * from phn_serum_test where mouse_id = ?";
		SerumTest test = null;
		try {
		 test = getSimpleJdbcTemplate().queryForObject(sql, getRowMapper(),mouseId);
		}catch(IncorrectResultSizeDataAccessException e) {
			
		}
		return (test == null) ? new SerumTest() : test;
	}
	
	
	
}