/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


package uk.ac.sanger.mig.phenotyping.olympus.forms;

import java.util.ArrayList;
import java.util.Collection;

import org.apache.commons.collections15.FactoryUtils;
import org.apache.commons.collections15.ListUtils;

import uk.ac.sanger.mig.phenotyping.abc.BloodsData;
import uk.ac.sanger.mig.phenotyping.olympus.SerumTest;


public class SerumChemistryForm {

	private int testCount = 0;
	private String serumTestCodes;
	private String bloodBarcode;
	private String hitachiBarcode;
	private Long tissueId;
	private String barcodeDescription;
	private Collection<BloodsData> testCodes;
	private Collection<SerumTest> presetTests;
	
	private String changeForm;
	private String changeFormValue;
	private Collection<SerumTest> serumTests;
	
	private String profileName;
	
	public SerumChemistryForm() {
		super();
		serumTests = ListUtils.lazyList(new ArrayList<SerumTest>(), FactoryUtils.instantiateFactory(SerumTest.class));
	}
	
	public String getChangeForm() {
		return changeForm;
	}
	public void setChangeForm(String changeForm) {
		this.changeForm = changeForm;
	}
	public String getChangeFormValue() {
		return changeFormValue;
	}
	public void setChangeFormValue(String changeFormValue) {
		this.changeFormValue = changeFormValue;
	}

	public Collection<SerumTest> getSerumTests() {
		return serumTests;
	}

	public void setSerumTests(Collection<SerumTest> serumTests) {
		this.serumTests = serumTests;
	}

	public String getSerumTestCodes() {
		return serumTestCodes;
	}

	public void setSerumTestCodes(String serumTestCodes) {
		this.serumTestCodes = serumTestCodes;
	}

	public String getBloodBarcode() {
		return bloodBarcode;
	}

	public void setBloodBarcode(String bloodBarcode) {
		this.bloodBarcode = bloodBarcode;
	}

	public String getHitachiBarcode() {
		return hitachiBarcode;
	}

	public void setHitachiBarcode(String hitachiBarcode) {
		this.hitachiBarcode = hitachiBarcode;
	}

	public Long getTissueId() {
		return tissueId;
	}

	public void setTissueId(Long tissueId) {
		this.tissueId = tissueId;
	}

	public String getBarcodeDescription() {
		return barcodeDescription;
	}

	public void setBarcodeDescription(String barcodeDescription) {
		this.barcodeDescription = barcodeDescription;
	}

	public void incrTestCount() {
		++testCount;
	}

	public void decrTestCount() {
		--testCount;
	}

	public int getTestCount() {
		return testCount;
	}

	public Collection<BloodsData> getTestCodes() {
		return testCodes;
	}

	public void setTestCodes(Collection<BloodsData> testCodes) {
		this.testCodes = testCodes;
	}

	public Collection<SerumTest> getPresetTests() {
		return presetTests;
	}

	public void setPresetTests(Collection<SerumTest> presetTests) {
		this.presetTests = presetTests;
	}

	public String getProfileName() {
		return profileName;
	}

	public void setProfileName(String profileName) {
		this.profileName = profileName;
	}
	
	
	
}
