/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.olympus.services;

import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.phenotyping.olympus.SerumTest;
import uk.ac.sanger.mig.phenotyping.olympus.SerumTestSearchBean;
import uk.ac.sanger.mig.phenotyping.olympus.dao.SerumTestDao;

public class SerumTestServiceImpl extends AbstractServiceImpl<SerumTest> implements SerumTestService {

	private SerumTestDao serumTestDao;

	//IMPORTANT: add other dependencies here: Should be other services *not* dao typically
	/**
	 * eg 	private SerumTestDao serumTestDao;
	 *    private MouseService mouseService
	 *    private PersonService personService; 
	 */

	public void setSerumTestDao(SerumTestDao serumTestDao) {
		this.serumTestDao = serumTestDao;
	}


	public Long storeAuthenticated(SerumTest serumTest, Person user) {
		if(serumTest == null) {
			throw new RuntimeException("Cannot save a null serumTest");
		}

		return serumTestDao.store(serumTest, user);
	}

	public SerumTest fetchById(Long serumTestId, ComponentMap requiredComponents) {
		SerumTest serumTest = serumTestDao.fetchById(serumTestId);

		if(serumTest != null)
			attachComponents(serumTest, requiredComponents);

		return serumTest;
	}

	@Override
	protected void attachComponents(SerumTest serumTest, ComponentMap requiredComponents) {
		if(serumTest == null) {
			throw new RuntimeException("Cannot attach components to null serumTest");
		}		

		boolean fetchAll = false;

		if(requiredComponents != null) {

			if(requiredComponents.containsKey(SerumTest.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}

			// query required components map and fetch/attach sub-components as needed
			// ...........

		}
	}


	public Collection<SerumTest> search(SerumTestSearchBean serumTestSearchBean) {
		// TODO Auto-generated method stub
		return null;
	}


	public SerumTest fetchByBarcode(String barcode, ComponentMap requiredComponents) {
		SerumTest serumTest = serumTestDao.fetchByBarcode(barcode, requiredComponents);

		if(serumTest != null)
			attachComponents(serumTest, requiredComponents);

		return serumTest;
	}

	public Collection<SerumTest> fetchTestPresets() {
		return serumTestDao.fetchTestPresets();
	}


	public SerumTest fetchByMouseId(Long mouseId) {

		return serumTestDao.fetchByMouseId(mouseId);
	}

}
