/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.olympus.validators;

import java.util.Collection;

import org.springframework.validation.Errors;
import org.springframework.validation.Validator;

import uk.ac.sanger.mig.phenotyping.olympus.SerumTest;
import uk.ac.sanger.mig.phenotyping.olympus.forms.SerumChemistryForm;
import uk.ac.sanger.mig.phenotyping.olympus.services.SerumTestService;



public class SerumTest2FormValidator implements Validator {

	private SerumTestService serumTestService;

	public void setSerumTestService(SerumTestService serumTestService) {
		this.serumTestService = serumTestService;
	}

	public boolean supports(Class clazz) {
		return SerumChemistryForm.class.equals(clazz);
	}

	public void validate(Object commandForm, Errors errors) {	
		SerumChemistryForm form = (SerumChemistryForm)commandForm;

		Collection<SerumTest> tests = form.getSerumTests();
		for(SerumTest test : tests) {
			SerumTest savedTest = serumTestService.fetchByBarcode(test.getBarcode(), null);
			if(savedTest != null) {
				errors.reject(null,"Serum Barcode ("+test.getBarcode()+") has already been assigned and saved to the database.\nPlease delete and use another serum barcode.");
			}
		}
	}

}
