/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.printers.controllers;

import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;

import uk.ac.sanger.mig.common.AbstractCancellableFormController;
import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.printers.Printer;
import uk.ac.sanger.mig.printers.forms.PrinterForm;
import uk.ac.sanger.mig.printers.services.PrinterService;

public class PrinterFormController extends AbstractCancellableFormController {

  private PrinterService printerService;

	@Override
	protected Object formBackingObject(HttpServletRequest httpServletRequest) throws Exception {

		PrinterForm printerForm = (PrinterForm)createCommand();

		Long id = ServletRequestUtils.getLongParameter(httpServletRequest, "id");

		Printer printer = null;

		if(id != null) {

			printer = printerService.fetchById( id, null );

			if( printer == null )
				throw new Exception("Could not find Printer with ID = " + id);

		} else {
			//else make new printer
			printer = printerService.createPrinter();
		}

		printerForm.setPrinter(printer);

		return printerForm;
	}

	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response,
				Object command, BindException errors) throws Exception {
		PrinterForm printerForm = (PrinterForm) command;

		Printer printer = printerForm.getPrinter();

		boolean newPrinter = ( printer.getId() == null );

		Long id = printerService.store(printer, RequestUtils.getUser(request));

		if( newPrinter )
			return new ModelAndView( getSuccessView()
					+ "?retrieveFromSession=false&newQuery=true&bypassForm=true&orderBy=id&orderDesc=true" );
		else
			return new ModelAndView( getSuccessView()
					+ "?retrieveFromSession=true&newQuery=false&bypassForm=true&currentRecordId=" + id);
	}

  @Override
  protected Map referenceData(HttpServletRequest arg0) throws Exception {
    Map<String, Object> referenceData = new HashMap<String, Object>();

    referenceData.put("mediaTypes",printerService.fetchMediaTypes());
    referenceData.put("printerModels",printerService.fetchPrinterModels());

    return referenceData;
  }

	public void setPrinterService(PrinterService printerService) {
		this.printerService = printerService;
	}

}