/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.printers.dao;

import java.util.ArrayList;
import java.util.Collection;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.common.PaginatedSearchUtils;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.printers.Printer;
import uk.ac.sanger.mig.printers.PrinterSearchBean;

public class PrinterDaoSpringImpl extends AbstractDaoSpringImpl<Printer>
		implements PrinterDao {

	private PaginatedSearchUtils<Printer> paginator;
	private ParameterizedRowMapper<String> stringRowMapper;
	public Collection<Printer> fetch(PrinterSearchBean printerSearchBean) {

		Collection<Object> bindVariables = new ArrayList<Object>();

		String selectSql = " select p.* from " + getTableName() + " p ";
		String whereSql = " where 1=1 ";

		/*
		if(printerSearchBean.getPrinter().getId() != null) {
			whereSql += " and p.id = ? ";
			bindVariables.add(printerSearchBean.getPrinter().getId());
		}
		*/

		String orderBySql = "";

		if(printerSearchBean.getOrderBy() != null && printerSearchBean.getOrderBy().length() > 0) {
			orderBySql += " order by p." + printerSearchBean.getOrderBy();
			if(printerSearchBean.isOrderDesc()) {
				orderBySql += " desc ";
			}
		}

		String sql = selectSql + whereSql + orderBySql;

		logger.debug(sql);

		return paginator.fetchSearchResults(sql, bindVariables,
				printerSearchBean, getRowMapper());

	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, Printer printer) {
		sql.addStringParam(printer.getPrinterModel(), "PRINTER_MODEL");
		sql.addStringParam(printer.getLoadedMedia(), "LOADED_MEDIA");
		sql.addStringParam(printer.getSysName(), "SYS_NAME");
		sql.addStringParam(printer.getDescription(), "DESCRIPTION");
		sql.addStringParam(printer.getCorridor(), "CORRIDOR");
		sql.addBooleanParam(printer.getActive(), "ACTIVE");
		sql.addStringParam(printer.getEditedBy(), "EDITED_BY");
		sql.addLongParam(printer.getCreatorId(), "CREATOR_ID");
		sql.addLongParam(printer.getCheckNumber(), "CHECK_NUMBER");
		sql.addDateParam(printer.getEditDate(), "EDIT_DATE");
		sql.addDateParam(printer.getCreatedDate(), "CREATED_DATE");
		sql.addLongParam(printer.getId(), "ID");
	}

	public void setPaginator(PaginatedSearchUtils<Printer> paginator) {
		this.paginator = paginator;
	}

  public Collection<String> fetchMediaTypes() {
    String sql = " select distinct LOADED_MEDIA return_string from " + getTableName() + " order by LOADED_MEDIA";

    return getSimpleJdbcTemplate().query(sql, stringRowMapper);
  }

  public void setStringRowMapper(ParameterizedRowMapper<String> stringRowMapper) {
    this.stringRowMapper = stringRowMapper;
  }

  public Collection<String> fetchPrinterModels() {
    String sql = " select distinct PRINTER_MODEL return_string from " + getTableName() + " order by PRINTER_MODEL";

    return getSimpleJdbcTemplate().query(sql, stringRowMapper);
  }


}