/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.printers.services;

import java.util.Collection;

import org.springframework.transaction.annotation.Transactional;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.personnel.services.PersonService;
import uk.ac.sanger.mig.printers.Printer;
import uk.ac.sanger.mig.printers.PrinterSearchBean;
import uk.ac.sanger.mig.printers.dao.PrinterDao;



public class PrinterServiceImpl extends AbstractServiceImpl<Printer> implements PrinterService {

	private PrinterDao printerDao;
	private PersonService personService;

	public Printer createPrinter() {

		Printer printer = new Printer();

		printer.setActive( true );

		return printer;
	}

	@Transactional
	public Long deActivate(Printer printer, Person user) {

		if( printer == null)
			throw new IllegalArgumentException("Printer cannot be null!");

		printer.setActive( false );

		return store( printer, user );
	}


	public Collection<Printer> fetch(PrinterSearchBean printerSearchBean, ComponentMap componentMap) {

		Collection<Printer> printers = printerDao.fetch( printerSearchBean );

		attachComponents(printers, componentMap);

		return printers;
	}

	@Transactional
	public Long store(Printer printer, Person user) {
		if(printer == null) {
			throw new RuntimeException("Cannot save a null printer");
		}

		return printerDao.store(printer, user);
	}

	public Printer fetchById(Long printerId, ComponentMap requiredComponents) {
		Printer printer = printerDao.fetchById(printerId);

		if(printer != null)
			attachComponents(printer, requiredComponents);

		return printer;
	}

	@Override
	protected void attachComponents(Printer printer, ComponentMap requiredComponents) {
		if(printer == null) {
			throw new RuntimeException("Cannot attach components to null printer");
		}

		boolean fetchAll = false;

		if(requiredComponents != null) {

			if(requiredComponents.containsKey(Printer.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}

			if(fetchAll || requiredComponents.containsKey(Printer.Component.CREATOR)) {

				printer.setCreator( fetchCreator(printer.getCreatorId(),
						requiredComponents.get(Printer.Component.CREATOR)));

			}

		}
	}

	private Person fetchCreator(Long personId, ComponentMap requiredComponents) {
		return personService.fetchById(personId, requiredComponents);
	}

	public void setPrinterDao(PrinterDao printerDao) {
		this.printerDao = printerDao;
	}


	public void setPersonService(PersonService personService) {
		this.personService = personService;
	}

  public Collection<String> fetchMediaTypes() {
    return printerDao.fetchMediaTypes();
  }

  public Collection<String> fetchPrinterModels() {
    return printerDao.fetchPrinterModels();
  }


}
