/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.pubmedsorter;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.ComponentEnum;

public class Article extends AuthenticatedDataObject {
	
	public enum Component implements ComponentEnum{
		ALL_COMPONENTS,
		ABSTRACT,
		AUTHORS
	}

	private Long abstractId;
	private ArticleAbstract articleAbstract;
	private Long gevSupportRefId;
	private String pubmedId;
	private String journalTitle;
	private String volume;
	private String issue;
	private int year;
	private String month;
	private int day;
	private String articleTitle;
	private String pages;
	private String notes;
	private String affiliation;
	
	private String abstractText;
	private Collection<Author> authors;
	
	private int score;//only use as template to hold the user input.

	public int getScore() {
		return score;
	}

	public void setScore(int score) {
		this.score = score;
	}

	public Article() {
		super();
		this.authors = new ArrayList<Author>();
	}
	
	private boolean selected = false;
	
	public void setPubmedId(String pubmedId) {
		this.pubmedId = pubmedId;
	}
	
	public String getPubmedId() {
		return pubmedId;
	}
	
	public void setDay(int day) {
		this.day = day;
	}
	
	public int getDay() {
		return day;
	}
	
	public void setJournalTitle(String journal) {
		this.journalTitle = journal;
	}
	
	public String getJournalTitle() {
		return journalTitle;
	}
	
	
	
	public void setIssue(String issue) {
		this.issue = issue;
	}
	
	public String getIssue() {
		return issue;
	}
	
	public void setMonth(String month) {
		this.month = month;
	}
	
	public String getMonth() {
		return month;
	}
	
	public void setYear(int year) {
		this.year = year;
	}
	
	public int getYear() {
		return year;
	}
	
	public void setArticleTitle(String title) {
		this.articleTitle = title;
	}
	
	public String getArticleTitle() {
		return articleTitle;
	}
	
	public void setPages(String pages) {
		this.pages = pages;
	}
	
	public String getPages() {
		return pages;
	}
	
	public void setAbstractText(String abstractText) {
		this.abstractText = abstractText;
	}
	
	public String getAbstractText() {
		return abstractText;
	}
	
	public void setAffiliation(String affiliation) {
		this.affiliation = affiliation;
	}
	
	public String getAffiliation() {
		return affiliation;
	}
	

	public void setAbstractId(Long abstractId) {
		this.abstractId = abstractId;
	}
	
	public Long getAbstractId() {
		return abstractId;
	}
		
	public void addOneAuthor(Author author){
		//add one author at one time
		authors.add(author);
	}

	public Collection<Author> getAuthors() {
		return authors;
	}

	public void setAuthors(Collection<Author> authors) {
		this.authors = authors;
	}

	public boolean isSelected() {
		return selected;
	}

	public void setSelected(boolean selected) {
		this.selected = selected;
	}

	public String getNotes() {
		return notes;
	}

	public void setNotes(String notes) {
		this.notes = notes;
	}

	public Long getGevSupportRefId() {
		return gevSupportRefId;
	}

	public void setGevSupportRefId(Long gevSupportRefId) {
		this.gevSupportRefId = gevSupportRefId;
	}

	public String getVolume() {
		return volume;
	}

	public void setVolume(String volume) {
		this.volume = volume;
	}

	public ArticleAbstract getArticleAbstract() {
		return articleAbstract;
	}

	public void setArticleAbstract(ArticleAbstract articleAbstract) {
		this.articleAbstract = articleAbstract;
	}
}

	
