/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.pubmedsorter.controllers;

import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.ParameterizableViewController;

import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.pubmedsorter.Article;
import uk.ac.sanger.mig.pubmedsorter.PubmedSearchEngine;

public class PubmedArticlesDisplayController extends
ParameterizableViewController {
	
	protected ModelAndView handleRequestInternal(HttpServletRequest request, HttpServletResponse response) throws Exception {
		

		String action = null;
		String destination = getViewName();//the jsp name
		action = ServletRequestUtils.getRequiredStringParameter(request,"action");
		int page = (Integer)request.getSession().getAttribute("page");
		
		if (action.equals("<< Back")) {
			doPubmedArticlesDisplay(request, response, "backwards",page );
		}else if (action.equals("Forward >>")) {
			doPubmedArticlesDisplay(request, response, "forwards", page);
		}else if (action.equals("Back to PubMed search results")) {
			destination = "pubmed/pubmed_main";
		}else if (action.equals("Finish browsing")) {
			destination = "pubmed/pubmed_confirmation";
			doPubmedFinishArticles(request, response, page);
		}else{
			
		}
		
		return new ModelAndView(destination);
	}
	
	@SuppressWarnings("unchecked")
	private void doPubmedArticlesDisplay(HttpServletRequest request, HttpServletResponse response, String direction, int pageNumber){
		
		//logger.warn("Got to doPubmedArticlesDisplay");
		
		HttpSession session = request.getSession(false);
		Person user = RequestUtils.getUser(request);	
		PubmedSearchEngine se = (PubmedSearchEngine)session.getAttribute("pubmedsearch");
		List<String> articlesSelected = (List)session.getAttribute("selected");
		
		if(direction.equals("forwards")){
			//Increment the page number because you are moving forwards
			pageNumber++;
			//Next if statement checks to see if the articles to be displayed on the next page have already
			//been searched for or not.  For example if moving from the first page to the second page of 
			//articles then pageNumber will be 0 on page one, then the user presses the forwards button and
			//the pageNumber, by the time it gets here, has incremented to 1.  If 10 articles have been 
			//displayed on the first page then se.getArticles().size() should equal ten, so the if() below
			//will work out that (pageNumber*10 + 1) equals 11 and is bigger than se.getArticles().size(), 
			//therefore more articles need to be fetched.
			if((pageNumber*10 + 1) > se.getArticles().size()){
				int counter;
				//The below if() is just to check what to set the counter to in order to either call ten
				//articles if the next page is not the final page of articles, or to whatever the remaining
				//amount is.
				if((se.getArticles().size() + 10) > se.getPubmedIds().size()){
					counter = se.getPubmedIds().size();
				}else{
					counter = se.getArticles().size() + 10;
				}
				for (int i = se.getArticles().size(); i < counter; i++){
				
					se.fetchArticle(se.getPubmedIds().get(i), user);//because make the pubmedids arrayList generic,do not need cast each element of the arrayList
				}
			}
			
			int previousPageArticleLimit = 0;
			//Next line has - 1 because you added 1 to the pageNumber of the previous page in the call to this method above
			int previousPageNumber = pageNumber - 1;
			
			//Next section is to work out how many articles to iterate through to check if they have been selected or not on the
			//page being moved away from, it may be 20 on the second page, for example if there are more than 20 articles, or it 
			//may be 17 if there are only 17 articles
			previousPageArticleLimit = (9*(previousPageNumber + 1) + (previousPageNumber + 1));
						
			for(int j = 10*(previousPageNumber); j < previousPageArticleLimit; j++){
				
				//Article article = se.getArticles().get(j);
				Article article = se.getArticle(se.getPubmedIds().get(j));
				//String pubmedId = article.getPubmedId();
				String pubmedId = article.getPubmedId();
				
				//Get the checkbox parameter from articles page - will only be non-null if checked
				//String selected = request.getParameter(pubmedId);
				//System.out.println("selected is "+selected+" for pubmed id "+pubmedId+" j is "+j);
				String selected = request.getParameter("Checkbox"+pubmedId);
								
				if(selected != null){
					
					//Defunct code if using the HashSet method
					//article.setSelected(true);
					
					if(articlesSelected.isEmpty()){
						articlesSelected.add(pubmedId);
					}else{
						//Need to check the article has not been added already
						if(!articlesSelected.contains(pubmedId)){
							articlesSelected.add(pubmedId);
						}
					}
					
					//Get any score that has been added
					String scoreTextArea = "Score"+pubmedId;
					int score = Integer.parseInt(request.getParameter(scoreTextArea));
					if(score != 0){
						article.setScore(score);
					}

					//Get any notes that have been added
					String textArea = "TextArea"+pubmedId;
					String notes =  request.getParameter(textArea);
					if(notes != null){
						article.setNotes(notes);
					}
					
				}else{
					
					//Defunct code if using the HashSet method
					//article.setSelected(false);
					
					//If the article has now been de-selected then it needs to be removed from the HashSet...
					if(!articlesSelected.isEmpty()){
						if(articlesSelected.contains(pubmedId)){
							articlesSelected.remove(pubmedId);
						}
					}
					//...and its score and notes removed
					article.setScore(0);
					article.setNotes("");
				}
			}
			request.getSession().setAttribute("page", pageNumber);
		}
		
		if(direction.equals("backwards")){
			//Decrease the page number because you are moving backwards
			pageNumber--;
			int previousPageArticleLimit = 0;
			//Next line has + 1 because you added 1 to the pageNumber of the previous page in the call to this method above
			int previousPageNumber = pageNumber + 1;
			//Next section is to work out how many articles to iterate through to check if they have been selected or not on the
			//page being moved away from, it may be 20 on the second page, for example if there are more than 20 articles, or it 
			//may be 17 if there are only 17 articles
			
			if((9*(previousPageNumber + 1) + (previousPageNumber + 1)) > se.getArticles().size()){
				previousPageArticleLimit = se.getArticles().size();
			}else{
				previousPageArticleLimit = (9*(previousPageNumber + 1) + previousPageNumber + 1);
			}
			
			//FOR MOVING BACK FROM THE CONFIRM PAGE THE WHOLE "FOR" LOOP GETS MISSED
			for(int j = 10*(previousPageNumber); j < previousPageArticleLimit; j++){
				
				//Article article = se.getArticles().get(j);
				Article article = se.getArticle(se.getPubmedIds().get(j));
				
				//String pubmedId = article.getPubmedId();
				String pubmedId = article.getPubmedId();
				
				//Need next few lines to distinguish between Back button being hit on normal results page or
				//on the Confirm page.  If the former then the checkbox values are passed back as parameters
				//if the latter then selected articles (i.e. ones that appear on the Confirm page) have to 
				//be set as selected using the attribute mechanism, as there are no checkboxes on the Confirm page
				
			
				
				//String selected = ServletRequestUtils.getStringParameter(request, "pubmedId");
				String selected = request.getParameter("Checkbox"+pubmedId);
				
				if(selected != null){
					
					//Defunct code if using the HashSet method
					//article.setSelected(true);
					
					if(articlesSelected.isEmpty()){
						articlesSelected.add(pubmedId);
					}else{
						if(!articlesSelected.contains(pubmedId)){
							articlesSelected.add(pubmedId);
						}
					}
					
					
					//Get any score that has been added
					String scoreTextArea = "Score"+pubmedId;
					int score = Integer.parseInt(request.getParameter(scoreTextArea));

					if(score != 0){
						article.setScore(score);
					}
					
					//Get any notes that have been added
					String textArea = "TextArea"+pubmedId;
					String notes = request.getParameter(textArea);
					
					if(notes != null){
						article.setNotes(notes);						
					}
					
				}else{
					
					//Defunct code if using the HashSet method
					//article.setSelected(false);
					
					//If the HashSet is not empty check if it contains the de-selected article... 
					if(!articlesSelected.isEmpty()){
						
						//...if it does then t means that it has been selected previously and then de-selected...
						if(articlesSelected.contains(pubmedId)){
							//...so it needs to be removed
							articlesSelected.remove(pubmedId);						
						}
					}
					
					article.setScore(0);
					article.setNotes("");
				}
			}
			request.getSession().setAttribute("page", pageNumber);
		}
	}
	
	@SuppressWarnings("unchecked")
	private void doPubmedFinishArticles(HttpServletRequest request, HttpServletResponse response, int pageNumber){
		
		HttpSession session = request.getSession(false);
		
		//Get the HashSet containing the selected articles' pubmed ids
		List<String> articlesSelected = (List<String>)session.getAttribute("selected");
		
		PubmedSearchEngine se = (PubmedSearchEngine)session.getAttribute("pubmedsearch");
		
		
		//Next section is to take whatever was highlighted on the last page before the confirm button was hit
		//and make sure it's entered into the ArrayList...
		int pageArticleLimit = 0;	
		
		if((9*(pageNumber + 1) + (pageNumber + 1)) > se.getPubmedIds().size()){
			pageArticleLimit = se.getPubmedIds().size();
		}else{
			pageArticleLimit = (9*(pageNumber + 1) + (pageNumber + 1));
		}
		
		for(int j= 10*(pageNumber);j< pageArticleLimit;j++){
			Article article = se.getArticle(se.getPubmedIds().get(j));
			String pubmedId = article.getPubmedId();
			String selected = request.getParameter("Checkbox"+pubmedId);
			
			if(selected != null){
				
				if(articlesSelected.isEmpty()){
					articlesSelected.add(pubmedId);
				}else{
					if(!articlesSelected.contains(pubmedId)){
						articlesSelected.add(pubmedId);
					}
				}
				

				//Get any score that has been added
				int score = 0;
				String scoreTextArea = "Score"+pubmedId;
				String scoreTextAreaContents = request.getParameter(scoreTextArea);
				Pattern p = Pattern.compile("[0-9]+");
				Matcher m = p.matcher(scoreTextAreaContents);
				if(m.find()){
					score = Integer.parseInt(request.getParameter(scoreTextArea));
				}

				if(score != 0){
					article.setScore(score);
				}
				
				String textArea = "TextArea"+pubmedId;
				String notes =  request.getParameter(textArea);
				if(notes != null){
					article.setNotes(notes);
				}
			}else{
				
				if(!articlesSelected.isEmpty()){
					if(articlesSelected.contains(pubmedId)){
						articlesSelected.remove(pubmedId);
					}
				}
				
				article.setScore(0);
				article.setNotes("");
			}
		}
		//...and not discarded
		
		request.getSession().setAttribute("pubmedsearch", se);
		
		//Need to increment the page number before it is sent because it will be used (and only used) if the user hits the 
		//Back button on the Confirm page to get back to the page they hit the Finish Browsing button on, and the "<< Back" 
		//button action decrements the page number before sending it to the doPubmedArticlesDisplay method
		request.getSession().setAttribute("page", pageNumber + 1);
		
	}
	
}