/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.pubmedsorter.controllers;

import java.util.ArrayList;
import java.util.List;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.ParameterizableViewController;

import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.pubmedsorter.PubmedSearchEngine;

public class PubmedArticlesInitialDisplayController extends ParameterizableViewController {
	
	protected ModelAndView handleRequestInternal(HttpServletRequest request, HttpServletResponse response) throws Exception {

		Person user = RequestUtils.getUser(request);	
		int choice = -1;
		choice = ServletRequestUtils.getRequiredIntParameter(request,"choice");
		doPubmedArticlesInitialDisplay(request, response, choice, user);	
		
		return new ModelAndView(getViewName());
	}
	
	private void doPubmedArticlesInitialDisplay(HttpServletRequest request, HttpServletResponse response, int choice, Person user){
	
		HttpSession session = request.getSession(false);
		PubmedSearchEngine se1 = (PubmedSearchEngine)session.getAttribute("pubmedsearch1");
		PubmedSearchEngine se2 = (PubmedSearchEngine)session.getAttribute("pubmedsearch2");
		PubmedSearchEngine se3 = (PubmedSearchEngine)session.getAttribute("pubmedsearch3");
		
		//Create ArrayList to store selected articles in, make it passable between sessions
		
		List<String> articlesSelected = new ArrayList<String>();
		
		request.getSession().setAttribute("selected", articlesSelected);
		
		//First results set is chosen
		if(choice == 1){
			
			int counter1 = se1.getPubmedIds().size();
			if (counter1 > 10) {
				counter1 = 10;
			}
			
			
			for (int i = 0; i < counter1 ; i++) {
				se1.fetchArticle(se1.getPubmedIds().get(i), user);//because make the pubmedids arrayList generic,do not need cast each element of the arrayList
			}
			
			request.getSession().setAttribute("pubmedsearch", se1);
					
		}
		//Second results set is chosen
		else if(choice == 2){
			int counter2 = se2.getPubmedIds().size();
			if (counter2 > 10) {
				counter2 = 10;
			}
			
			for (int i = 0; i < counter2; i++){
				se2.fetchArticle(se2.getPubmedIds().get(i), user);//because make the pubmedids arrayList generic,do not need cast each element of the arrayList
			}
			
			request.getSession().setAttribute("pubmedsearch", se2);
		}
		//Third results set is chosen
		else if(choice == 3){
			int counter3 = se3.getPubmedIds().size();
			if (counter3>10) {
				counter3 = 10;
			}
			for (int i = 0; i < counter3; i++){
				se3.fetchArticle(se3.getPubmedIds().get(i), user);//because make the pubmedids arrayList generic,do not need cast each element of the arrayList
			}
			
			request.getSession().setAttribute("pubmedsearch", se3);
			
		}else{
			//Have a Back/Cancel button on main results page perhaps
		}
		
		request.getSession().setAttribute("page", 0);
		
	}
	
}