/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.pubmedsorter.controllers;

import java.util.List;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.ParameterizableViewController;

import uk.ac.sanger.mig.common.RequestUtils;
import uk.ac.sanger.mig.geneevidence.MigGeneArticleRef;
import uk.ac.sanger.mig.geneevidence.services.MigGeneArticleRefService;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.pubmedsorter.Article;
import uk.ac.sanger.mig.pubmedsorter.PubmedSearchEngine;

public class PubmedArticlesSaveController extends ParameterizableViewController {
	

	MigGeneArticleRefService migGeneArticleRefService;

	
	public void setMigGeneArticleRefService(MigGeneArticleRefService migGeneArticleRefService) {
		this.migGeneArticleRefService = migGeneArticleRefService;

	}
	
	protected ModelAndView handleRequestInternal(HttpServletRequest request, HttpServletResponse response) throws Exception {
		HttpSession session = request.getSession(false);
		Person currentUser = RequestUtils.getUser(request);
		PubmedSearchEngine se = (PubmedSearchEngine)session.getAttribute("pubmedsearch");
		String destination = getViewName();
		String action = ServletRequestUtils.getRequiredStringParameter(request,"action");
		int page = (Integer)request.getSession().getAttribute("page");
		List<String> articlesSelected = (List)session.getAttribute("selected");
		
		if (action.equals("<< Back")) {
			page--;
			int previousPageArticleLimit = 0;
			int previousPageNumber = page + 1;
			
			if((9*(previousPageNumber + 1) + (previousPageNumber + 1)) > se.getArticles().size()){
				previousPageArticleLimit = se.getArticles().size();
			}else{
				previousPageArticleLimit = (9*(previousPageNumber + 1) + previousPageNumber + 1);
			}
			
			//FOR MOVING BACK FROM THE CONFIRM PAGE THE WHOLE "FOR" LOOP GETS MISSED
			for(int j = 10*(previousPageNumber); j < previousPageArticleLimit; j++){
				Article article = se.getArticle(se.getPubmedIds().get(j));
				String pubmedId = article.getPubmedId();
				String selected = request.getParameter("Checkbox"+pubmedId);
				
				if(selected != null){
					
					if(articlesSelected.isEmpty()){
						articlesSelected.add(pubmedId);
					}else{
						if(!articlesSelected.contains(pubmedId)){
							articlesSelected.add(pubmedId);
						}
					}
					
					String scoreTextArea = "Score"+pubmedId;
					int score = Integer.parseInt(request.getParameter(scoreTextArea));
					
					if(score != 0){
						article.setScore(score);
					}
					
					String textArea = "TextArea"+pubmedId;
					String notes = request.getParameter(textArea);
					
					if(notes != null){
						article.setNotes(notes);						
					}
				}
			}
		}else if (action.equals("Back to PubMed search results")) {
			destination = "pubmed/pubmed_main";
		}else{
			
			Long migGeneId = (Long) session.getAttribute("id");
			
			for(int j = 0; j < se.getArticles().size(); j++){
				
				Article article = se.getArticles().get(j);
				
				if(articlesSelected.contains(article.getPubmedId())){
					
					MigGeneArticleRef migGeneArticleRef = new MigGeneArticleRef();
					migGeneArticleRef.setArticleId(article.getId());
					migGeneArticleRef.setScore(article.getScore());
					migGeneArticleRef.setNote(article.getNotes());
					migGeneArticleRef.setMigGeneId(migGeneId);
					migGeneArticleRefService.storeAuthenticated(migGeneArticleRef, currentUser);
				
				}
			}
		}
		return new ModelAndView(destination);		
	}
}
