/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.pubmedsorter.controllers;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.ParameterizableViewController;

import uk.ac.sanger.mig.gene.services.MigGeneService;
import uk.ac.sanger.mig.pubmedsorter.PubmedSearchEngine;
import uk.ac.sanger.mig.pubmedsorter.services.ArticleService;

public class PubmedSearchController extends ParameterizableViewController {

	private MigGeneService migGeneService;
	private ArticleService articleService;
	
	public void setArticleService(ArticleService articleService) {
		this.articleService = articleService;
	}

	public void setMigGeneService(MigGeneService migGeneService) {
		this.migGeneService = migGeneService;
	}

	//	wl1 May 2006 pubmed systems
	protected ModelAndView handleRequestInternal(HttpServletRequest request, HttpServletResponse response) throws Exception {
		String ensemblId = ServletRequestUtils.getRequiredStringParameter(request, "ensemblId");;
		long migGeneId = ServletRequestUtils.getRequiredLongParameter(request, "migGeneId");
		
		Map<String,Object> model = new HashMap<String,Object>();
		List<String> keywords = migGeneService.fetchPubmedKeywords(ensemblId);
		String pubmedKeywords = null;
		String search1 = null;
		String search2 = null;
		String search3 = null;
		if (keywords.size() != 0) {
			pubmedKeywords = (String) keywords.get(0);
			for(int i=1;i<keywords.size();i++){
				pubmedKeywords = pubmedKeywords+"+OR+"+(String)keywords.get(i);
			}
			search1 = "mouse+AND+(knockout+OR+null)+AND+"+"("+pubmedKeywords+")";
			search2 = "mouse+AND+"+"("+pubmedKeywords+")";
			search3 = pubmedKeywords;
			//logger.warn("Keywords:"+pubmedKeywords);
			//logger.warn("Search 1"+search1);
			//logger.warn("Search 2"+search2);
			//logger.warn("Search 3"+search3);
		}
		
		String pubmedGeneQuery = "http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?CMD=search&cmd=Search&term="+search1;
		//logger.warn("pubmedquery"+pubmedGeneQuery);
		model.put("pubmedGeneQuery",pubmedGeneQuery);
		model.put("id", migGeneId);
		
		PubmedSearchEngine se1 = new PubmedSearchEngine();
		se1.setMigGeneId(migGeneId);
		se1.fetchPubmedIds(search1);
		se1.setArticleService(articleService);
		
		PubmedSearchEngine se2 = new PubmedSearchEngine();
		se2.setMigGeneId(migGeneId);
		se2.fetchPubmedIds(search2);
		se2.setArticleService(articleService);
		
		PubmedSearchEngine se3 = new PubmedSearchEngine();
		se3.setMigGeneId(migGeneId);
		se3.fetchPubmedIds(search3);
		se3.setArticleService(articleService);
		
		//or 2 steps. HttpSession session = request.getSession(true); session.setAttribute.
		request.getSession().setAttribute("pubmedsearch1", se1);
		request.getSession().setAttribute("pubmedsearch2", se2);
		request.getSession().setAttribute("pubmedsearch3", se3);
		request.getSession().setAttribute("keyword1",search1);
		request.getSession().setAttribute("keyword2",search2);
		request.getSession().setAttribute("keyword3",search3);
		request.getSession().setAttribute("id", migGeneId);
		request.getSession().setAttribute("pubmedGeneQuery",pubmedGeneQuery);
		
		return new ModelAndView(getViewName(),"pubmed",model);		
	}

	
	
	
}
