/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.pubmedsorter.dao;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.dao.IncorrectResultSizeDataAccessException;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.pubmedsorter.Article;

public class ArticleDaoSpringImpl extends AbstractDaoSpringImpl<Article> implements ArticleDao {
	
	private static final Log logger = LogFactory.getLog(ArticleDaoSpringImpl.class); 
	
	public Article fetchByPubmedId(String pubmedId){
		
		Object[] bindVariables = new Object[1];
		
		String sql = "SELECT * FROM pub_article WHERE pubmed_id = ?";
		
		bindVariables[0] = pubmedId;
		
		Article article = null;
		
		try {
			article = getSimpleJdbcTemplate().queryForObject(sql, getRowMapper(), bindVariables);
		}
		catch(IncorrectResultSizeDataAccessException e) {
			logger.debug("Look in database to see if article already exists.  If not fetch from pubmed. "+e);
		}
		
		return article;
		
	} 
	
	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, Article article) {
		
		sql.addIntParam(article.getYear(), "YEAR");
		sql.addStringParam(article.getArticleTitle(), "TITLE");
		sql.addStringParam(article.getPubmedId(), "PUBMED_ID");
		sql.addStringParam(article.getPages(), "PAGES");
		sql.addLongParam(article.getAbstractId(), "ABSTRACT_ID");
		sql.addStringParam(article.getMonth(), "MONTH");
		sql.addStringParam(article.getJournalTitle(), "JOURNAL");
		sql.addIntParam(article.getDay(), "DAY");
		sql.addStringParam(article.getAffiliation(), "AFFILIATION");
		sql.addStringParam(article.getVolume(), "VOLUME");
		sql.addStringParam(article.getIssue(), "ISSUE");
		sql.addLongParam(article.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(article.getCreatedDate(), "CREATED_DATE");
		sql.addStringParam(article.getEditedBy(), "EDITED_BY");
		sql.addDateParam(article.getEditDate(), "EDIT_DATE");
		sql.addLongParam(article.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(article.getId(), "ID");
		
	}
}
