/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.pubmedsorter.dao;

import java.util.Collection;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.dao.IncorrectResultSizeDataAccessException;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlQuery;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.pubmedsorter.Author;

public class AuthorDaoSpringImpl extends AbstractDaoSpringImpl<Author> implements AuthorDao {

	private static final Log logger = LogFactory.getLog(AuthorDaoSpringImpl.class); 

	public Collection<Author> fetchAuthorsByArticleId(Long articleId) {

		String sql = " select a.* from pub_author a join pub_article_2_author a2a" +
		" on(a.id = a2a.author_id) where a2a.article_id = ?";

		Collection<Author> authors = null;

		try{

			authors = getSimpleJdbcTemplate().query(sql, getRowMapper(), articleId);

		} catch(IncorrectResultSizeDataAccessException e) {
			logger.warn(e);
		}
		
		return authors;
	}

	public Long checkAuthor(Author author){
		
		Long id = null;
		String sql = "select id from pub_author where nvl(lastname,'NULL') = nvl(?,'NULL') and nvl(forename,'NULL') = nvl(?,'NULL') and nvl(initials,'NULL') = nvl(?,'NULL')";
		String lastName = author.getLastname(),foreName = author.getForename(),initials = author.getInitials();

		ParameterizedSqlQuery query = new ParameterizedSqlQuery();

		query.addStringParam(lastName);
		query.addStringParam(foreName);
		query.addStringParam(initials);

		try {	
			id = getJdbcTemplate().queryForLong(sql, query.getParameters(), query.getParametersType());
		}
		catch(IncorrectResultSizeDataAccessException e) {
			logger.debug("Look in database to see if author already exists.  If not fetch from pubmed. "+e);
		}
		author.setId(id);
		return id;
	}
	

	public int linkToArticle(Long articleId, Long authorId) {
		String sql = " insert into pub_article_2_author(article_id,author_id) select ?,? from dual where not exists (select null from pub_article_2_author where article_id = ? and author_id = ?) ";
		return getSimpleJdbcTemplate().update(sql, articleId, authorId, articleId, authorId);
	}
	
	public int clearLinksToArticle(Long articleId) {
		String sql = " delete from pub_article_2_author where article_id = ?";
		
		return getSimpleJdbcTemplate().update(sql, articleId);
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, Author author) {

		sql.addStringParam(author.getLastname(), "LASTNAME");
		sql.addStringParam(author.getForename(), "FORENAME");
		sql.addStringParam(author.getInitials(), "INITIALS");
		sql.addLongParam(author.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(author.getCreatedDate(), "CREATED_DATE");
		sql.addStringParam(author.getEditedBy(), "EDITED_BY");
		sql.addDateParam(author.getEditDate(), "EDIT_DATE");
		sql.addLongParam(author.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(author.getId(), "ID");

	}
}
