/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.pubmedsorter.dao.rowmappers;

import java.io.IOException;
import java.io.Reader;
import java.sql.Clob;
import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.pubmedsorter.ArticleAbstract;

public class ArticleAbstractRowMapper implements ParameterizedRowMapper<ArticleAbstract> {

	public ArticleAbstract mapRow(ResultSet rs, int rowNum) throws SQLException {
		
		ArticleAbstract articleAbstract = new ArticleAbstract();
		
		articleAbstract.setId(rs.getLong("ID"));
		
		Clob abstractClob = rs.getClob("ABSTRACT");
		if(abstractClob != null){
			Reader clobReader = abstractClob.getCharacterStream();
			char c;
			boolean done = false;
			StringBuffer buff = new StringBuffer();
			int next = 0;
			while(!done){
				try {
					next = clobReader.read();
				} catch (IOException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				}
				if(next == -1) done = true;
				else {
					c = (char)next;
					buff.append(c);
				}
			}
			String abstractText = buff.toString();
			articleAbstract.setAbstractText(abstractText);
		}else{
			articleAbstract.setAbstractText("");
		}
		
		articleAbstract.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) articleAbstract.setCheckNumber(null);
		articleAbstract.setCreatedDate(rs.getDate("CREATED_DATE"));
		articleAbstract.setCreatorId(rs.getLong("CREATOR_ID"));
		if(rs.wasNull()) articleAbstract.setCreatorId(null);
		articleAbstract.setEditDate(rs.getDate("EDIT_DATE"));
		articleAbstract.setEditedBy(rs.getString("EDITED_BY"));
		
		return articleAbstract;
		
	}
}