/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.pubmedsorter.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.pubmedsorter.Article;

public class ArticleRowMapper implements ParameterizedRowMapper<Article> {

	public Article mapRow(ResultSet rs, int rowNum) throws SQLException {
		
		Article article = new Article();

		article.setId(rs.getLong("ID"));
		article.setYear(rs.getInt("YEAR"));
		article.setArticleTitle(rs.getString("TITLE"));
		article.setPubmedId(rs.getString("PUBMED_ID"));
		article.setPages(rs.getString("PAGES"));
		article.setAbstractId(rs.getLong("ABSTRACT_ID"));
		if(rs.wasNull()) article.setAbstractId(null);
		article.setMonth(rs.getString("MONTH"));
		article.setJournalTitle(rs.getString("JOURNAL"));
		article.setDay(rs.getInt("DAY"));
		article.setAffiliation(rs.getString("AFFILIATION"));
		article.setVolume(rs.getString("VOLUME"));
		article.setIssue(rs.getString("ISSUE"));
		article.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) article.setCheckNumber(null);
		article.setCreatedDate(rs.getDate("CREATED_DATE"));
		article.setCreatorId(rs.getLong("CREATOR_ID"));
		if(rs.wasNull()) article.setCreatorId(null);
		article.setEditDate(rs.getDate("EDIT_DATE"));
		article.setEditedBy(rs.getString("EDITED_BY"));
		
		return article;
		
	}
}
