/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.pubmedsorter.services;

import java.util.Collection;

import org.springframework.transaction.annotation.Transactional;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.pubmedsorter.Author;
import uk.ac.sanger.mig.pubmedsorter.dao.AuthorDao;

public class AuthorServiceImpl extends AbstractServiceImpl<Author> implements AuthorService {
	
	private AuthorDao authorDao;

	public void setAuthorDao(AuthorDao authorDao) {
		this.authorDao = authorDao;
	}

	public Author fetchById(Long authorId, ComponentMap requiredComponents) {	
		Author author = authorDao.fetchById(authorId);
	
			if(author != null)
				attachComponents(author, requiredComponents);
		
		return author;
	}

	@Transactional
	public Long storeAuthenticated(Author author, Person user) {
		if(author == null) {
			throw new RuntimeException("Cannot save a null author");
		}

		return authorDao.store(author, user);
	}
	
	@Transactional
	public Long storeComplete(Author author, Long articleId, Person user){
		if(author == null) {
			throw new RuntimeException("Cannot save a null author");
		}
		
		return authorDao.store(author, user);
	}

	public Long checkAuthor(Author author){
		return authorDao.checkAuthor(author);
	}

	@Override
	protected void attachComponents(Author author, ComponentMap requiredComponents) {
		if(author == null) {
			throw new RuntimeException("Cannot attach components to null author");
		}
	}

	public Collection<Author> fetchAuthorsByArticleId(Long articleId, ComponentMap requiredComponents) {

		Collection<Author> authors = authorDao.fetchAuthorsByArticleId(articleId);
		
		attachComponents(authors, requiredComponents);
		
		return authors;
		
	}
	
	
	@Transactional
	public int linkToArticle(Long articleId, Long authorId) {
		return authorDao.linkToArticle(articleId, authorId);		
	}
	
	@Transactional
	public int clearLinksToArticle(Long articleId) {
		return authorDao.clearLinksToArticle(articleId);
	}

	public void inflateAuthorComponents(Author author, ComponentMap requiredComponents) {
		if(author == null) {
			throw new RuntimeException("Author cannot be null when inflating components.");
		}
	}
}
