/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.quartz;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.SimpleFormController;

/**
 * @author ae1
 *
 */
public class JobController extends SimpleFormController {


	private JobService quartzJobService;
	
	public enum ActionEnum {
		PAUSE,
		RESUME,
		FIRE_NOW,
		RESCHEDULE
	}
	
	@Override
	protected Object formBackingObject(HttpServletRequest request) throws Exception {

		return createCommand();

	}


	@Override
	protected Map referenceData(HttpServletRequest request) throws Exception {

		Map<String, Object> map = new HashMap<String, Object>();
		
		SchedulerInfo schedulerInfo = quartzJobService.getSchedulerInfo();
		
		Collection<StatefulTrigger> statefulTriggers = quartzJobService.getAllStatefulTriggers();
		
		map.put("quartzInfoBean", schedulerInfo);
		
		map.put("statefulTriggers", statefulTriggers);
		
		return map;
	}


	@Override
	protected boolean isFormSubmission(HttpServletRequest request) {
		boolean isSubmit = false;
		
		try {
			isSubmit = (ServletRequestUtils.getStringParameter(request, "action") != null);
		} catch(Exception e) {	}
		
		return isSubmit;
	}
	
	
	
	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, 
			Object command, BindException errs) throws Exception {

		JobForm form = (JobForm)command;
					
		switch( form.getActionEnum() ) {
		
			case PAUSE:
			
				quartzJobService.pauseJob( form.getJobName(), form.getJobGroup()  );
				
				logger.debug("Pausing " + form.getJobName());
				
				break;
			
			case RESUME:
			
				quartzJobService.resumeJob( form.getJobName(), form.getJobGroup() );
			
				break;
	
			case FIRE_NOW:
				
				quartzJobService.fireJobNow( form.getJobName(), form.getJobGroup()  );
			
				break;
		/*
			case RESCHEDULE:
				
				quartzJobService.rescheduleJob(form.getTriggerName(), form.getTriggerGroup(), form.getNewTrigger());
			
				break;
				
			default: //error
				*/
		}
		
		return new ModelAndView(getSuccessView());
	}
	
	
	public void setQuartzJobService(JobService quartzJobService) {
		this.quartzJobService = quartzJobService;
	}


	
}