/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.quartz;

import org.quartz.CronTrigger;
import org.quartz.SimpleTrigger;
import org.quartz.Trigger;

/**
 * 
 * Holds state of a Trigger.
 * 
 * @author ae1
 *
 */
public class StatefulTrigger  {

	/**
	 * Maps Trigger state to human readable names.
	 * @author ae1
	 *
	 */
	public enum StateEnum {
		
		STATE_NORMAL(Trigger.STATE_NORMAL, "Normal"),
		STATE_BLOCKED(Trigger.STATE_BLOCKED, "Blocked"),
		STATE_COMPLETE(Trigger.STATE_COMPLETE, "Complete"),
		STATE_PAUSED(Trigger.STATE_PAUSED, "Paused"),
		STATE_ERROR(Trigger.STATE_ERROR, "Error"),
		STATE_NONE(Trigger.STATE_NONE, "None - Trigger Non-existent");
		
		private int stateId;
		private String text;
		
		StateEnum(int stateId, String text) {
			this.stateId = stateId;
			this.text = text;
		}

		public int getStateId() {
			return this.stateId;
		}

		public String getText() {
			return this.text;
		}
	}
	
	private Trigger trigger;
	
	private StateEnum stateEnum;

	public StateEnum getStateEnum() {
		return this.stateEnum;
	}

	
	public String getCronExpression() {
		if( trigger instanceof CronTrigger ) 
			return ((CronTrigger)trigger).getCronExpression();
		else if( trigger instanceof SimpleTrigger ) 
			return "Firing Now";
		else 
			return null;
	}
	
	public void setState(int state) {
		
		switch(state) {
		
			case Trigger.STATE_NORMAL: {
				setStateEnum(StateEnum.STATE_NORMAL);
				break;
			}
			case Trigger.STATE_BLOCKED: {
				setStateEnum(StateEnum.STATE_BLOCKED);
				break;
			}
			
			case Trigger.STATE_COMPLETE: {
				setStateEnum(StateEnum.STATE_COMPLETE);
				break;
			}
			
			case Trigger.STATE_PAUSED: {
				setStateEnum(StateEnum.STATE_PAUSED);
				break;
			}
			
			case Trigger.STATE_ERROR: {
				setStateEnum(StateEnum.STATE_ERROR);
				break;
			}
			
			case Trigger.STATE_NONE: {
				setStateEnum(StateEnum.STATE_NONE);
				break;
			}
			
			default: setStateEnum(StateEnum.STATE_NONE);
		}
		
	}

	public void setStateEnum(StateEnum stateEnum) {
		this.stateEnum = stateEnum;
	}

	public Trigger getTrigger() {
		return this.trigger;
	}

	public void setTrigger(Trigger trigger) {
		this.trigger = trigger;
	}
	
	
	
}
