/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.quartz.jobs;


import java.util.Collection;
import java.util.Date;

import org.quartz.JobExecutionContext;
import org.quartz.JobExecutionException;
import org.quartz.UnableToInterruptJobException;

import uk.ac.sanger.mig.miprocessing.ScheduledMicroInjectionSearchBean;
import uk.ac.sanger.mig.miprocessing.services.ScheduledMicroInjectionService;
import uk.ac.sanger.mig.miprocessing.views.ScheduledMicroInjectionListView;
import uk.ac.sanger.mig.personnel.Person;

/**
 * 
 * Queries f0 and f1 endpoint mice for every ScheduledMicroInjection
 * and completes these milestones if non-null is returned.
 * 
 * @author ae1
 */
public class ReachMirMilestonesJob extends ScheduledJob {

	private ScheduledMicroInjectionService scheduledMicroInjectionService;
	
	@Override
	public void executeJob(JobExecutionContext context, Person quartzUser)
			throws JobExecutionException {
		
		ScheduledMicroInjectionSearchBean searchBean 
			= new ScheduledMicroInjectionSearchBean();
		
		searchBean.setAllRecords( true );
		searchBean.setPaginated( false );
		
		Collection<ScheduledMicroInjectionListView> smiList 
			= scheduledMicroInjectionService.search( searchBean );
		
		logger.debug("Found total SMI " + smiList.size());
		
		int totalF0s = 0, totalF1s = 0;
		
		for( ScheduledMicroInjectionListView smiView : smiList ) {
			
			if( smiView.getF0Status() != null && 
					smiView.getF0CompletionDate() == null ) {
				
				scheduledMicroInjectionService.reachF0Milestone(smiView.getId(), new Date(), quartzUser);
				totalF0s++;
				logger.debug("Reaching F0 Milestone for SMI " +  smiView.getJobId());
			}
		
			if( smiView.getF1Status() != null && 
					smiView.getF1CompletionDate() == null ) {
				
				scheduledMicroInjectionService.reachF1Milestone(smiView.getId(), new Date(), quartzUser);
				totalF1s++;
				logger.debug("Reaching F1 Milestone for SMI " + smiView.getJobId());
			}
			
		}
		
		logger.debug("Total F0 reached =  " + totalF0s);
		logger.debug("Total F1 reached =  " + totalF1s);
		
	}

	public void setScheduledMicroInjectionService(
			ScheduledMicroInjectionService scheduledMicroInjectionService) {
		this.scheduledMicroInjectionService = scheduledMicroInjectionService;
	}
	
	
	
	
}

