/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.quartz.jobs;

import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.Collection;

import org.quartz.JobExecutionContext;
import org.quartz.JobExecutionException;

import uk.ac.sanger.mig.common.services.ImageProcessingException;
import uk.ac.sanger.mig.microscopy.ReadOnlyMetaData;
import uk.ac.sanger.mig.microscopy.services.ImageSweepService;
import uk.ac.sanger.mig.microscopy.services.ReadOnlyMetaDataService;
import uk.ac.sanger.mig.personnel.Person;


/**
 * @author ae1
 *
 */
public class SweepMicroscopyJob extends ScheduledJob {

	private ImageSweepService imageSweepService;
	private ReadOnlyMetaDataService readOnlyMetaDataService;

	@Override
	public void executeJob(JobExecutionContext context, Person user)
			throws JobExecutionException {

		Collection<ReadOnlyMetaData> readOnlyMetaDatas
					= readOnlyMetaDataService.fetchUnsweptMetaData();
		int successCount = 0;

		for(ReadOnlyMetaData readOnlyMetaData : readOnlyMetaDatas) {
			try {

				imageSweepService.sweep(readOnlyMetaData, user);
				successCount++;
			} catch(FileNotFoundException e) 	{handleException( readOnlyMetaData, e );}
			  catch(IOException e) 			    {handleException( readOnlyMetaData, e );}
			  catch(InterruptedException e)     {handleException( readOnlyMetaData, e );}
			  catch(ImageProcessingException e) {handleException( readOnlyMetaData, e );}
		}
		logger.debug(successCount+" of " + readOnlyMetaDatas.size() + " new ReadonlyMetaData objects sucessfully swept into writable MetaData objects.");
	}

	public void setImageSweepService(ImageSweepService imageSweepService) {
		this.imageSweepService = imageSweepService;
	}

	public void setReadOnlyMetaDataService(
			ReadOnlyMetaDataService readOnlyMetaDataService) {
		this.readOnlyMetaDataService = readOnlyMetaDataService;
	}

	private void handleException(ReadOnlyMetaData readOnlyMetaData, Exception e) {
		logger.error( e );
		logger.error("Failed sweeping ReadonlyMetaData with ID " + readOnlyMetaData.getId());
		logger.error("Trying next ReadonlyMetaData.");
	}
}
