/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.quartz.jobs;

import org.quartz.JobExecutionContext;
import org.quartz.JobExecutionException;

import uk.ac.sanger.mig.histology.SweepScanException;
import uk.ac.sanger.mig.histology.services.ScanService;
import uk.ac.sanger.mig.personnel.Person;


/**
 * @author ae1
 *
 */
public class SweepScanJob extends ScheduledJob {
	
	private ScanService scanService;
	
	@Override
	public void executeJob(JobExecutionContext context, Person user)
			throws JobExecutionException {
	
		sweepScans( user, true );
		
	}
	
	/*
	 * TODO: Move to non-transactional service
	 * 
	 * Performs batch import of Dmetrix (*.dmi) image files and
	 * scan meta data into the MIG Database.
	 * 
	 * Based on the Slide barcode parsed from the dmi file name  
	 * a new Scan record is inserted into in the HTL_SCAN table with foreign
	 * key references to its parent Slide and to its thumbnail image (stored as BLOB
	 * in APP_BINARY_FILE).  The Scan is also added to Crop selection bin for 
	 * segmentation purposes.
	 * 
	 * Static configuration parameters are defined in XML via the Spring application 
	 * context and injected at startup (eg, sweep directory location, thumbnail file 
	 * extension, etc). 
	 * 
	 * If performCleanup is true, temporary thumbnails are deleted from 
	 * sweep directory and their source *.dmi files are moved to permanent directories  
	 * according to their sweep date.  
	 */
	private void sweepScans(Person user, boolean performCleanup)  {
		
		//1.
		String[] fileNames = scanService.fetchSweepFiles();
		
		int successCount = 0;
		
		for(String fileName : fileNames) {
			
			try {
				
				scanService.process( fileName, user );

				successCount++;
				
			} catch(SweepScanException e) {
				
				logger.warn( "Metadata/thumbnail extraction failed! Scan of Slide *not* stored, and DMI file will remain in sweep directory. CAUSE:\n" + e );
				continue;	
			}	
			
			
		}	
		
		logger.debug(successCount + " of " + fileNames.length + " images in sweep directory successfully processed.");
	}
	
	public void setScanService(ScanService scanService) {
		this.scanService = scanService;
	}

}
