package uk.ac.sanger.mig.reporting.controllers;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.bind.ServletRequestBindingException;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;


import uk.ac.sanger.mig.common.AbstractCancellableFormController;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.services.ComponentMapService;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.reporting.GraphMetaData;
import uk.ac.sanger.mig.reporting.RepGraph;
import uk.ac.sanger.mig.reporting.RepPageSubgroup;
import uk.ac.sanger.mig.reporting.RepPageType;
import uk.ac.sanger.mig.reporting.forms.GraphConfigForm;
import uk.ac.sanger.mig.reporting.services.GraphConfigService;
import uk.ac.sanger.mig.reporting.services.RepGraphService;
import uk.ac.sanger.mig.reporting.services.RepPageTypeService;


public class GraphConfigFormController extends AbstractCancellableFormController {

	private RepPageTypeService repPageTypeService;
	private DictionaryService dictionaryService;
	private RepGraphService graphService;
	private GraphConfigService graphConfigService;
	private ComponentMapService componentMapService;


	public void setComponentMapService(ComponentMapService componentMapService) {
		this.componentMapService = componentMapService;
	}

	public void setGraphConfigService(GraphConfigService graphConfigService) {
		this.graphConfigService = graphConfigService;
	}

	public void setGraphService(RepGraphService graphService) {
		this.graphService = graphService;
	}

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	public void setRepPageTypeService(RepPageTypeService repPageTypeService) {
		this.repPageTypeService = repPageTypeService;
	}

	@Override
	protected boolean isFormChangeRequest(HttpServletRequest request) {
		String changeRequest = null;

		try {
			changeRequest = ServletRequestUtils.getStringParameter(request, "changeForm");
		}
		catch(ServletRequestBindingException e) {

		}
		if(changeRequest != null && changeRequest.length() >0) {
			return true;
		}
		else {
			return false;
		}
	}


	@Override
	protected void onFormChange(HttpServletRequest request, HttpServletResponse response, Object command) throws Exception {
		GraphConfigForm form = (GraphConfigForm)command;
		String changeRequest = ServletRequestUtils.getRequiredStringParameter(request, "changeForm");

		if(changeRequest.equals("pageSelected")) {

				RepPageType page = repPageTypeService.fetchById(form.getSelectedPageId(),componentMapService.getComponentMap("graphConfig"));
				form.setSelectedPage(page);

		}else if(changeRequest.equals("addSubgroup")) {

			//RepPageSubgroup subGroup = new RepPageSubgroup();


		}else if(changeRequest.equals("addGraph")) {

			RepGraph graph = new RepGraph();
			GraphMetaData metaData = new GraphMetaData();
			graph.setMetaData(metaData);

		}

	}

	@Override
	protected Object formBackingObject(HttpServletRequest request) throws Exception {
		GraphConfigForm form = (GraphConfigForm)createCommand();

		Collection<RepPageType> pages = repPageTypeService.fetchAllForConfig(ComponentMap.of(RepPageType.Component.ALL_COMPONENTS));
		form.setPages(pages);


		return form;
	}


	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {

		return new ModelAndView(getSuccessView());
	}

	@Override
	protected Map<String, Object> referenceData(HttpServletRequest request, Object command, Errors errors) throws Exception {
		GraphConfigForm form = (GraphConfigForm)command;

		Map<String, Object> referenceData = new HashMap<String, Object>();

		Map<Boolean, String> yesNo = new HashMap<Boolean, String>();
		yesNo.put(false,"No");
		yesNo.put(true,"Yes");
		referenceData.put("yesNo",yesNo);

		referenceData.put("statBackgrounds", dictionaryService.fetch(DictionaryEnum.REPORTING_STAT_BACKGROUND));
		referenceData.put("graphTypes", dictionaryService.fetch(DictionaryEnum.REPORTING_GRAPH_TYPE));

		referenceData.put("views", graphConfigService.fetchAllGraphViews());


		return referenceData;
	}





}
