package uk.ac.sanger.mig.reporting.controllers;

import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.bind.ServletRequestBindingException;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;

import ChartDirector.XYChart;

import uk.ac.sanger.mig.common.AbstractCancellableFormController;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.reporting.BaselineQCRange;
import uk.ac.sanger.mig.reporting.GraphMetaData;
import uk.ac.sanger.mig.reporting.RepGraph;
import uk.ac.sanger.mig.reporting.RepPageSubgroup;
import uk.ac.sanger.mig.reporting.RepPageType;
import uk.ac.sanger.mig.reporting.RepPipelineTests;
import uk.ac.sanger.mig.reporting.forms.BaselineSearchForm;
import uk.ac.sanger.mig.reporting.services.BaselineQCRangeService;
import uk.ac.sanger.mig.reporting.services.GraphConfigService;
import uk.ac.sanger.mig.reporting.services.GraphMetaDataService;
import uk.ac.sanger.mig.reporting.services.RepGraphService;
import uk.ac.sanger.mig.reporting.services.RepPageTypeService;
import uk.ac.sanger.mig.reporting.services.RepPipelineTestsService;
import uk.ac.sanger.mig.reporting.views.WildtypeBaselineChart;


public class WildtypeBaselineSearchFormController extends AbstractCancellableFormController {

	private RepPageTypeService repPageTypeService;
	private DictionaryService dictionaryService;
	private RepGraphService graphService;
	private GraphConfigService graphConfigService;
	private BaselineQCRangeService baselineQCRangeService;
	private GraphMetaDataService graphMetaDataService;
	private RepPipelineTestsService pipelineTestsService;


	public void setPipelineTestsService(RepPipelineTestsService pipelineTestsService) {
		this.pipelineTestsService = pipelineTestsService;
	}

	public void setGraphMetaDataService(GraphMetaDataService graphMetaDataService) {
		this.graphMetaDataService = graphMetaDataService;
	}

	public void setBaselineQCRangeService(
			BaselineQCRangeService baselineQCRangeService) {
		this.baselineQCRangeService = baselineQCRangeService;
	}

	public void setGraphConfigService(GraphConfigService graphConfigService) {
		this.graphConfigService = graphConfigService;
	}

	public void setGraphService(RepGraphService graphService) {
		this.graphService = graphService;
	}

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	public void setRepPageTypeService(RepPageTypeService repPageTypeService) {
		this.repPageTypeService = repPageTypeService;
	}

	@Override
	protected boolean isFormChangeRequest(HttpServletRequest request) {
		String changeRequest = null;

		try {
			changeRequest = ServletRequestUtils.getStringParameter(request, "changeForm");
		}
		catch(ServletRequestBindingException e) {

		}
		if(changeRequest != null && changeRequest.length() >0) {
			return true;
		}
		else {
			return false;
		}
	}


	@Override
	protected void onFormChange(HttpServletRequest request, HttpServletResponse response, Object command) throws Exception {
		BaselineSearchForm form = (BaselineSearchForm)command;
		String changeRequest = ServletRequestUtils.getRequiredStringParameter(request, "changeForm");

		if(changeRequest.equals("pageSelected")) {
			for(RepPipelineTests test : form.getPages()) {
				if(test.getPageTypeId().equals(form.getSelectedPageId())) {
					form.setPipelineId(test.getPipelineId());
				}
			}
			Collection<RepGraph> graphs = new ArrayList<RepGraph>();
			if(form.getSelectedPageId() != null) {
				RepPageType page = repPageTypeService.fetchById(form.getSelectedPageId(), ComponentMap.of(RepPageType.Component.ALL_COMPONENTS));
				if(page != null) {
					form.setSelectedPage(page);
					for(RepPageSubgroup group : page.getSubGroups()) {
						graphs.addAll(graphService.fetchBySubgroupId(group.getId(), ComponentMap.of(RepGraph.Component.META_DATA)));
					}
				}
				form.setGraphs(graphs);
			}


		}else if(changeRequest.equals("testSelected")) {
			form.setChangeFormValue("");
			form.setChangeForm("");
		}

	}

	@Override
	protected Object formBackingObject(HttpServletRequest request) throws Exception {
		BaselineSearchForm form = (BaselineSearchForm)createCommand();

		Collection<RepPipelineTests> pages = pipelineTestsService.fetchAllPipelineTests();
		form.setPages(pages);


		return form;
	}


	@Override
	protected ModelAndView onSubmit(HttpServletRequest request, HttpServletResponse response, Object command, BindException errors) throws Exception {
		BaselineSearchForm form = (BaselineSearchForm)command;

		Map<String, Object> model = new HashMap<String, Object>();

		// get the metaData object.
		GraphMetaData metaData = graphMetaDataService.fetchById(form.getGraphMetadataId(), null);
		if(metaData != null) {
			Collection<BaselineQCRange> refRanges = baselineQCRangeService.fetchBaselineRangesForQC(
						metaData.getViewName(),
						metaData.getPlotColumn(),
						form.getStrainId(),
						form.getPipelineId(),
						form.getTimePeriodGrouping()
						);

			if(refRanges != null ) {

			WildtypeBaselineChart chart = new WildtypeBaselineChart(refRanges, metaData.getGraphTypeId());
			XYChart c = chart.createWildtypeBaselineChart();
			c.makeSession(request, "xychart");


			// Include tool tip for the chart
			String imageMap1 = c.getHTMLImageMap("", "", "title='{dataSetName} : {value} '");

			model.put("imageMap1", imageMap1);

			}else{
				model.put("errors", "No Data Available.");
			}
		}

		return showForm(request, response, errors, model);

	}

	@Override
	protected Map<String, Object> referenceData(HttpServletRequest request, Object command, Errors errors) throws Exception {
		BaselineSearchForm form = (BaselineSearchForm)command;

		Map<String, Object> referenceData = new HashMap<String, Object>();

		Map<Boolean, String> yesNo = new HashMap<Boolean, String>();
		yesNo.put(false,"No");
		yesNo.put(true,"Yes");
		referenceData.put("yesNo",yesNo);

		referenceData.put("statBackgrounds", dictionaryService.fetch(DictionaryEnum.REPORTING_STAT_BACKGROUND));
		referenceData.put("graphTypes", dictionaryService.fetch(DictionaryEnum.REPORTING_GRAPH_TYPE));

		referenceData.put("views", graphConfigService.fetchAllGraphViews());



		Map<String, String> timePeriodGroup = new HashMap<String, String>();
		timePeriodGroup.put("MON-YY","Monthly");
		timePeriodGroup.put("WW","Weekly");
		timePeriodGroup.put("DDD","Daily");
		timePeriodGroup.put("HH24","Hourly");
		referenceData.put("timePeriodGroup",timePeriodGroup);

		return referenceData;
	}





}
