/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.reporting.dao;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.reporting.BaselineQCRange;
import uk.ac.sanger.mig.reporting.Range;


public class BaselineQCRangeDaoSpringImpl extends AbstractDaoSpringImpl<BaselineQCRange> implements BaselineQCRangeDao {


	public Collection<BaselineQCRange> fetchBaselineRangesForQC(String viewName, String columnName, Long strainId, Long pipelineId, String timePeriodGrouping) {
		/**
		 * Credit to dg6.
		 * Sql to run the refrange sql but cumulatively bin the data based on year/month/week/day selected by the user.
		 * Used for working out refrange drift for QC over time.
		 */
		String sql="with dates as"+
		"("+
		"select distinct trunc(assay_date,'"+timePeriodGrouping+"') bucket_date "+
		"from "+viewName+
		")"+
		"select "+
		"  d.bucket_date,"+
		"  strain_id, gender_id, pipeline_id,  "+
		"  count(case when trunc(g.assay_date,'"+timePeriodGrouping+"') <= d.bucket_date then "+columnName+" else null end) num_rows,"+
		"  percentile_cont(0.975) within group (order by to_number(case when trunc(g.assay_date,'"+timePeriodGrouping+"') <= d.bucket_date then "+columnName+" else null end) desc) pct_975,"+
		"  percentile_cont(0.5) within group (order by to_number(case when trunc(g.assay_date,'"+timePeriodGrouping+"') <= d.bucket_date then "+columnName+" else null end) desc) median,"+
		"  percentile_cont(0.025) within group (order by to_number(case when trunc(g.assay_date,'"+timePeriodGrouping+"') <= d.bucket_date then "+columnName+" else null end) desc) pct_25,"+
		"  avg(case when trunc(g.assay_date,'"+timePeriodGrouping+"') <= d.bucket_date then "+columnName+" else null end)-2*stddev(case when trunc(g.assay_date,'"+timePeriodGrouping+"') <= d.bucket_date then "+columnName+" else null end) minus_2_sd,"+
		"  avg(case when trunc(g.assay_date,'"+timePeriodGrouping+"') <= d.bucket_date then "+columnName+" else null end)-stddev(case when trunc(g.assay_date,'"+timePeriodGrouping+"') <= d.bucket_date then "+columnName+" else null end)  minus_1_sd,"+
		"  avg(case when trunc(g.assay_date,'"+timePeriodGrouping+"') <= d.bucket_date then "+columnName+" else null end) mean,"+
		"  avg(case when trunc(g.assay_date,'"+timePeriodGrouping+"') <= d.bucket_date then "+columnName+" else null end)+stddev(case when trunc(g.assay_date,'"+timePeriodGrouping+"') <= d.bucket_date then "+columnName+" else null end) plus_1_sd,"+
		"  avg(case when trunc(g.assay_date,'"+timePeriodGrouping+"') <= d.bucket_date then "+columnName+" else null end)+2*stddev(case when trunc(g.assay_date,'"+timePeriodGrouping+"') <= d.bucket_date then "+columnName+" else null end) plus_2_sd"+
		" from "+
		"  "+viewName+" g,"+
		"  dates d "+
		"where "+
		"  not exists (select null from mts_mouse_allele ma where g.mouse_id = ma.mouse_id and ma.genotype_dict_id <> 1)"+
		"  and strain_id = ?"+
		"  and pipeline_id = ?"+
		"  and g.assay_date <= d.bucket_date"+
		"  group by "+
		"  d.bucket_date,"+
		"  strain_id,"+
		"  gender_id,"+
		"  pipeline_id"+
		" order by bucket_date";

		System.out.println(sql);

		Collection<BaselineQCRange> baselineRanges = null;
		baselineRanges = getSimpleJdbcTemplate().query(sql, getRowMapper(), strainId, pipelineId);

		return (baselineRanges==null)? new ArrayList<BaselineQCRange>(): baselineRanges;
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, BaselineQCRange t) {
		// TODO Auto-generated method stub
	}




}