/* Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.reporting.dao;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;

import org.springframework.jdbc.core.simple.SimpleJdbcDaoSupport;

import uk.ac.sanger.mig.abr.dao.rowmappers.AbrThresholdLineData;
import uk.ac.sanger.mig.reporting.ChartDisplay;
import uk.ac.sanger.mig.reporting.ChartDataSearchBean;
import uk.ac.sanger.mig.reporting.dao.rowmappers.BarChartData;
import uk.ac.sanger.mig.reporting.dao.rowmappers.LineChartData;
import uk.ac.sanger.mig.reporting.dao.rowmappers.ScatterChartData;
import uk.ac.sanger.mig.reporting.services.GraphMetaDataService;



public class ChartDataDaoSpringImpl extends SimpleJdbcDaoSupport implements ChartDataDao {

	public ChartDisplay fetchChartData(ChartDataSearchBean bean) {

		Collection<Object> bindVariables = new ArrayList<Object>();

		String selectSql = "select distinct mouse_name,gender_id, nvl(me.genotype_dict_id,1) as genotype_id, strain_id, "+bean.getPlotColumn()+" as plot_column";

		String orderSql = "";
		/**
		 * We need to union this query to pullout all mice for cohorts where we want all the mice
		 * against those where we only want the Wildtype mice. Use the value below to toggle.
		 * N.B this could well be a dirty solution but is the only one i could come up with at the time :-)
		 */
		String cohortSetWTOnly = " and nvl(CSE.WT_DICT_ID,'0') = 0 ";

		if(bean.getXAxisColumn()!= null && columnExists(bean.getViewName(), bean.getXAxisColumn())) {
			selectSql += ","+bean.getXAxisColumn()+" as xLabel";
			// must be line chart, so sort by xLabels for helping chart director.
			orderSql = "order by xLabel ";
		}
		String fromSql = " from "+bean.getViewName()+" v , mts_cohort_set cs, mts_cohort_set_element cse,mts_mouse m, mts_mouse_allele me";

		String whereSql = " where 1=1";

		if(!bean.getAlleleId().equals("")) {
			bindVariables.add(bean.getAlleleId());
			whereSql += " and cs.allele_id = ? and cs.id = cse.set_id";
		}

		if(!bean.getPipelineId().equals("")){
			bindVariables.add(bean.getPipelineId());
			whereSql += " and v.pipeline_id = ? ";
		}

		whereSql += " and v.cohort_id = cse.cohort_id and v.mouse = m.barcode and m.id = me.mouse_id(+) ";
		whereSql += " and "+bean.getPlotColumn()+" is not null ";

		String sql = selectSql + fromSql + whereSql + cohortSetWTOnly;

		// Create same sql but add wildtype only clause.
		cohortSetWTOnly = " AND NVL (me.genotype_dict_id, 1) = 1  AND cse.wt_dict_id = 3 and v.gender_id in (1,2) ";
		String sql2 = selectSql + fromSql + whereSql + cohortSetWTOnly;

		cohortSetWTOnly = " AND NVL (me.genotype_dict_id, 1) = 1  AND cse.wt_dict_id = 1 and v.gender_id = 1 ";
		String sql3 = selectSql + fromSql + whereSql + cohortSetWTOnly;

		cohortSetWTOnly = " AND NVL (me.genotype_dict_id, 1) = 1  AND cse.wt_dict_id = 2 and v.gender_id = 2 ";
		String sql4 = selectSql + fromSql + whereSql + cohortSetWTOnly;


		// union the two queries.
		sql = sql + " union " + sql2+" union " + sql3+ " union "+ sql4 + orderSql;


		Object[] extendedBindVariables = null;

		// need to duplicate bind variables for the union query
		if(bindVariables != null) {
			extendedBindVariables = new Object[bindVariables.toArray().length * 4];
			//copy the existing bind variables into the new array
			System.arraycopy(bindVariables.toArray(), 0, extendedBindVariables, 0, bindVariables.toArray().length);
			System.arraycopy(bindVariables.toArray(), 0, extendedBindVariables, bindVariables.toArray().length, bindVariables.toArray().length);
			System.arraycopy(bindVariables.toArray(), 0, extendedBindVariables, bindVariables.toArray().length * 2, bindVariables.toArray().length);
			System.arraycopy(bindVariables.toArray(), 0, extendedBindVariables, bindVariables.toArray().length * 3, bindVariables.toArray().length);
		}

		if(bean.getGraphTypeId() == GraphMetaDataService.SCATTER_GRAPH) {
			ScatterChartData data = new ScatterChartData();
			getJdbcTemplate().query(sql, extendedBindVariables,data);
			return data;
		}
		if(bean.getGraphTypeId() == GraphMetaDataService.BAR_GRAPH) {
			BarChartData data = new BarChartData();
			getJdbcTemplate().query(sql, extendedBindVariables,data);
			return data;
		}
		if(bean.getGraphTypeId() == GraphMetaDataService.LINE_GRAPH) {
			LineChartData data = new LineChartData();
			getJdbcTemplate().query(sql, extendedBindVariables,data);
			return data;
		}

		return null;

	}

	private boolean columnExists(String viewName, String columnName) {
		String sql = "select count(*) from user_tab_columns where table_name = ? and column_name = ?";
		Collection<Object> bindVariables = new ArrayList<Object>();
		bindVariables.add(viewName);
		bindVariables.add(columnName);
		int exists = getJdbcTemplate().queryForInt(sql, bindVariables.toArray());
		return (exists == 1) ? true : false;
	}


}

