/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.reporting.dao;

import java.util.Collection;
import java.util.List;
import java.util.Map;

import org.springframework.dao.DataAccessException;


import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.reporting.GraphDataAvailable;

public class GraphDataAvailableDaoSpringImpl extends AbstractDaoSpringImpl<GraphDataAvailable> implements GraphDataAvailableDao {


	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, GraphDataAvailable graphDataAvailable) {
		sql.addLongParam(graphDataAvailable.getGeneId(), "GENE_ID");
		sql.addStringParam(graphDataAvailable.getGeneName(), "GENE_NAME");
		sql.addLongParam(graphDataAvailable.getAlleleId(), "ALLELE_ID");
		sql.addStringParam(graphDataAvailable.getAlleleName(), "ALLELE_NAME");
		sql.addLongParam(graphDataAvailable.getPipelineId(), "PIPELINE_ID");
		sql.addStringParam(graphDataAvailable.getPipelineName(), "PIPELINE_NAME");
		sql.addStringParam(graphDataAvailable.getReportingTest(), "REPORTING_TEST");
		sql.addLongParam(graphDataAvailable.getPageTypeId(), "PAGE_TYPE_ID");
		sql.addBooleanParam(graphDataAvailable.getDataAvailable(), "DATA_AVAILABLE");
		sql.addIntParam(graphDataAvailable.getRecordCount(), "RECORD_COUNT");
		sql.addLongParam(graphDataAvailable.getColonyId(), "COLONY_ID");
		sql.addStringParam(graphDataAvailable.getColonyPrefix(), "COLONY_PREFIX");
		sql.addLongParam(graphDataAvailable.getId(), "ID");
	}

	public List<Map<String, Object>> fetchAllPipelinesByAlleleId(Long alleleId) {

		String sql = "select distinct(pipeline_id) id ,pipeline_name from " + getTableName()+" where data_available = 1 and allele_id = ?";

		List<Map<String, Object>> data = null;
		try {
			data = getSimpleJdbcTemplate().queryForList(sql,alleleId);
		} catch (DataAccessException e) {
		}
		return data;
	}

	public List<Map<String, Object>> fetchAllTestsByAllelePipelineId(Long alleleId, Long pipelineId) {

		String sql = "select distinct(page_type_id) id ,reporting_test test from " + getTableName()+" where data_available = 1  and allele_id = ? and pipeline_id = ?";

		List<Map<String, Object>> data = null;
		try {
			data = getSimpleJdbcTemplate().queryForList(sql,alleleId, pipelineId);
		} catch (DataAccessException e) {
		}
		return data;
	}

	public List<Map<String, Object>> fetchAllGraphsByPageId(Long pageId) {

		String sql = "select g.id id, translate(lower(m.title),'_',' ') graph_type from rep_graph_metadata m, rep_graph g, rep_page_subgroup s, rep_page_type t " +
					"where t.id = s.rep_page_type_id " +
					"and s.id = g.rep_subgroup_id " +
					"and g.graph_metadata_id = m.id " +
					"and t.id = ?";

		List<Map<String, Object>> data = null;
		try {
			data = getSimpleJdbcTemplate().queryForList(sql,pageId);
		} catch (DataAccessException e) {
		}
		return data;


	}



}