/* Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.reporting.dao;

import java.util.ArrayList;
import java.util.Collection;

import org.springframework.dao.IncorrectResultSizeDataAccessException;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.reporting.GraphMetaData;

public class GraphMetaDataDaoSpringImpl extends AbstractDaoSpringImpl<GraphMetaData> implements GraphMetaDataDao {

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, GraphMetaData t) {

	 sql.addStringParam(t.getPlotColumn(), "PLOT_COLUMN");
	 sql.addStringParam(t.getViewName(),"VIEW_NAME");
	 sql.addStringParam(t.getYaxisTitle(),"YAXIS_TITLE");
	 sql.addStringParam(t.getXaxisTitle(),"XAXIS_TITLE");
	 sql.addStringParam(t.getTitle(),"TITLE");
	 sql.addLongParam(t.getId(), "ID");
	 sql.addBooleanParam(t.isXPadding(),"X_PADDING");
	 sql.addBooleanParam(t.isXAxisAsLabels(),"XAXIS_AS_LABELS");
	 sql.addBooleanParam(t.isTimeAxis(),"TIME_AXIS");
	 sql.addBooleanParam(t.isScientificYAxis(),"SCIENTIFIC_Y_AXIS");
	 sql.addStringParam(t.getXAxisColumn(),"XAXIS_COLUMN");

	}
	public Collection<GraphMetaData> fetchByViewName(String viewName) {

		String sql = "select * from " + getTableName()+" where view_name = ?";
		Collection<GraphMetaData> metaData = getSimpleJdbcTemplate().query(sql, getRowMapper(), viewName);

		return (metaData == null)? new ArrayList<GraphMetaData>() : metaData;
	}

	public GraphMetaData fetchByViewNameAndColumn(String viewName, String column) {
		String sql = "select * from " + getTableName()+" where view_name = ? and plot_column = ?";

		GraphMetaData graphMetaData = null;

		try{
			graphMetaData = getSimpleJdbcTemplate().queryForObject(sql, getRowMapper(),viewName,column);
		}catch(IncorrectResultSizeDataAccessException e){

		}
		return graphMetaData;
	}
	public Collection<GraphMetaData> fetchAvailable(Long pageId, Long groupId) {
		// TODO Auto-generated method stub
		return null;
	}
	public Collection<GraphMetaData> fetchCurrent(Long pageId, Long groupId) {
		// TODO Auto-generated method stub
		return null;
	}

}

