/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.reporting.dao;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.reporting.LineRange;
import uk.ac.sanger.mig.reporting.Range;



public class LineRangeDaoSpringImpl extends AbstractDaoSpringImpl<LineRange> implements LineRangeDao {


	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, LineRange graphRefranges) {

		sql.addLongParam(graphRefranges.getGraphMetadataId(), "GRAPH_METADATA_ID");
		sql.addStringParam(graphRefranges.getXLabel(),"XLABEL");
		sql.addDoubleParam(graphRefranges.getMinus2Sd(), "MINUS_2_SD");
		sql.addDoubleParam(graphRefranges.getMinus1Sd(), "MINUS_1_SD");
		sql.addDoubleParam(graphRefranges.getMean(), "MEAN");
		sql.addDoubleParam(graphRefranges.getPlus1Sd(), "PLUS_1_SD");
		sql.addDoubleParam(graphRefranges.getPlus2Sd(), "PLUS_2_SD");
		sql.addLongParam(graphRefranges.getGenderId(), "GENDER_ID");
		sql.addLongParam(graphRefranges.getStrainId(), "STRAIN_ID");
		sql.addDoubleParam(graphRefranges.getPercentile25(), "PCT_25");
		sql.addDoubleParam(graphRefranges.getPercentile975(), "PCT_975");
		sql.addDoubleParam(graphRefranges.getMedian(), "MEDIAN");
		sql.addLongParam(graphRefranges.getNumRows(), "NUM_ROWS");
		sql.addLongParam(graphRefranges.getPipelineDictId(), "PIPELINE_DICT_ID");
		sql.addLongParam(graphRefranges.getId(), "ID");

	}

	public Collection<? extends Range> fetchByMetaDataStrainPipelineId(Long metaDataId, Long strainId, Long pipelineId) {

		String sql="select * from "+getTableName()+" where graph_metadata_id = ? and strain_id = ? and pipeline_dict_id = ?";
		Collection<LineRange> lineRanges = null;

		if(metaDataId != null) {
			lineRanges = getSimpleJdbcTemplate().query(sql, getRowMapper(), metaDataId, strainId, pipelineId);
		}
		return (lineRanges==null)? new ArrayList<Range>(): lineRanges;
	}
}