/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.reporting.dao;

import java.util.ArrayList;
import java.util.Collection;

import org.springframework.dao.IncorrectResultSizeDataAccessException;
import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;

import uk.ac.sanger.mig.reporting.RepGraph;
import uk.ac.sanger.mig.reporting.RepGraphSearchBean;

public class RepGraphDaoSpringImpl extends AbstractDaoSpringImpl<RepGraph> implements RepGraphDao {


	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, RepGraph repGraph) {
		sql.addLongParam(repGraph.getRepSubgroupId(), "REP_SUBGROUP_ID");
		sql.addLongParam(repGraph.getCohortSetId(), "COHORT_SET_ID");
		sql.addLongParam(repGraph.getGraphMetadataId(), "GRAPH_METADATA_ID");
		sql.addIntParam(repGraph.getDisplayOrder(), "DISPLAY_ORDER");
		sql.addLongParam(repGraph.getCheckNumber(), "CHECK_NUMBER");
		sql.addStringParam(repGraph.getEditedBy(), "EDITED_BY");
		sql.addDateParam(repGraph.getEditDate(), "EDIT_DATE");
		sql.addLongParam(repGraph.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(repGraph.getCreatedDate(), "CREATED_DATE");
		sql.addLongParam(repGraph.getId(), "ID");
	}

	public Collection<RepGraph> search(RepGraphSearchBean repGraphSearchBean) {
		// TODO Auto-generated method stub
		return null;
	}

	public Collection<RepGraph> fetchBySubgroupId(Long groupId) {

		String sql = "select * from " + getTableName()+" where rep_subgroup_id = ?";

		Collection<RepGraph> graphs = null;
		try{
			graphs = getSimpleJdbcTemplate().query(sql, getRowMapper(),groupId);
		}catch(IncorrectResultSizeDataAccessException e){
		}
		return (graphs == null)? new ArrayList<RepGraph>():graphs;
	}



}