/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.reporting.dao;

import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;

import org.apache.commons.collections15.FactoryUtils;
import org.apache.commons.collections15.ListUtils;
import org.springframework.dao.IncorrectResultSizeDataAccessException;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;

import uk.ac.sanger.mig.reporting.RepPipelineTests;
import uk.ac.sanger.mig.reporting.RepPipelineTestsSearchBean;

public class RepPipelineTestsDaoSpringImpl extends AbstractDaoSpringImpl<RepPipelineTests> implements RepPipelineTestsDao {


	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, RepPipelineTests repPipelineTests) {
		sql.addLongParam(repPipelineTests.getId(), "ID");
		sql.addLongParam(repPipelineTests.getPipelineId(), "PIPELEINE_ID");
		sql.addStringParam(repPipelineTests.getDescription(), "DESCRIPTION");
		sql.addLongParam(repPipelineTests.getPageTypeId(), "PAGE_TYPE_ID");
		sql.addStringParam(repPipelineTests.getAltUrl(), "ALT_URL");
		sql.addLongParam(repPipelineTests.getCheckNumber(), "CHECK_NUMBER");
		sql.addStringParam(repPipelineTests.getEditedBy(), "EDITED_BY");
		sql.addDateParam(repPipelineTests.getEditDate(), "EDIT_DATE");
		sql.addLongParam(repPipelineTests.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(repPipelineTests.getCreatedDate(), "CREATED_DATE");
	}

	public HashMap<String, Collection<RepPipelineTests>> fetchAllPipelinesWithTests() {

		HashMap<String, Collection<RepPipelineTests>> testMap
			= new HashMap<String, Collection<RepPipelineTests>>();

		String sql = "select * from " + getTableName();

		Collection<RepPipelineTests> tests = null;
		try{
			tests = getSimpleJdbcTemplate().query(sql, getRowMapper());
		}catch(IncorrectResultSizeDataAccessException e){
		}

		for(RepPipelineTests test : tests) {
			String pipeline = test.getPipeline().getName();
			// initialize if first entry.
			if(!testMap.containsKey(pipeline)){
				Collection<RepPipelineTests> theTests
					= ListUtils.lazyList(new ArrayList<RepPipelineTests>(), FactoryUtils.instantiateFactory(RepPipelineTests.class));
				theTests.add(test);
				testMap.put(pipeline, theTests);
			}else{
				Collection<RepPipelineTests> temp = testMap.get(pipeline);
				temp.add(test);
				testMap.put(pipeline, temp);
			}
		}

		return testMap;
	}

	public Collection<RepPipelineTests> search(
			RepPipelineTestsSearchBean repPipelineTestsSearchBean) {
		// TODO Auto-generated method stub
		return null;
	}

	public Collection<RepPipelineTests> fetchAllTestsByPipelineId(Long pipelineId) {

		String sql = "select * from " + getTableName() + " where pipeleine_id = " + pipelineId + " order by description";

		Collection<RepPipelineTests> tests = null;
		try{
			tests = getSimpleJdbcTemplate().query(sql, getRowMapper());
		}catch(IncorrectResultSizeDataAccessException e){
		}

		return tests;
	}

	public Collection<RepPipelineTests> fetchAllPipelineTests() {

		String sql = "select * from " + getTableName() + " order by description";

		Collection<RepPipelineTests> tests = null;
		try{
			tests = getSimpleJdbcTemplate().query(sql, getRowMapper());
		}catch(IncorrectResultSizeDataAccessException e){
		}

		return tests;
	}


}