/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.reporting.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.reporting.BaselineQCRange;


public class BaselineQCRangeRowMapper implements ParameterizedRowMapper<BaselineQCRange> {

	public BaselineQCRange mapRow(ResultSet rs, int rowNum) throws SQLException {

		BaselineQCRange baselineQCRange = new BaselineQCRange();

		baselineQCRange.setId(rs.getLong("ID"));
		if(rs.wasNull()) baselineQCRange.setId(null);

		baselineQCRange.setBucketDate(rs.getDate("BUCKET_DATE"));
		if(rs.wasNull()) baselineQCRange.setBucketDate(null);

		baselineQCRange.setGraphMetadataId(rs.getLong("GRAPH_METADATA_ID"));
		if(rs.wasNull()) baselineQCRange.setGraphMetadataId(null);

		baselineQCRange.setMinus2Sd(rs.getDouble("MINUS_2_SD"));
		if(rs.wasNull()) baselineQCRange.setMinus2Sd(null);

		baselineQCRange.setMinus1Sd(rs.getDouble("MINUS_1_SD"));
		if(rs.wasNull()) baselineQCRange.setMinus1Sd(null);

		baselineQCRange.setMean(rs.getDouble("MEAN"));
		if(rs.wasNull()) baselineQCRange.setMean(null);

		baselineQCRange.setPlus1Sd(rs.getDouble("PLUS_1_SD"));
		if(rs.wasNull()) baselineQCRange.setPlus1Sd(null);

		baselineQCRange.setPlus2Sd(rs.getDouble("PLUS_2_SD"));
		if(rs.wasNull()) baselineQCRange.setPlus2Sd(null);

		baselineQCRange.setGenderId(rs.getLong("GENDER_ID"));
		if(rs.wasNull()) baselineQCRange.setGenderId(null);

		baselineQCRange.setStrainId(rs.getLong("STRAIN_ID"));
		if(rs.wasNull()) baselineQCRange.setStrainId(null);

		baselineQCRange.setPercentile25(rs.getDouble("PCT_25"));
		if(rs.wasNull()) baselineQCRange.setPercentile25(null);

		baselineQCRange.setPercentile975(rs.getDouble("PCT_975"));
		if(rs.wasNull()) baselineQCRange.setPercentile975(null);

		baselineQCRange.setMedian(rs.getDouble("MEDIAN"));
		if(rs.wasNull()) baselineQCRange.setMedian(null);

		baselineQCRange.setNumRows(rs.getLong("NUM_ROWS"));
		if(rs.wasNull()) baselineQCRange.setNumRows(null);

		baselineQCRange.setPipelineDictId(rs.getLong("PIPELINE_ID"));
		if(rs.wasNull()) baselineQCRange.setPipelineDictId(null);

		return baselineQCRange;

	}
}