/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.reporting.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.reporting.GraphDataAvailable;

public class GraphDataAvailableRowMapper implements ParameterizedRowMapper<GraphDataAvailable> {

	public GraphDataAvailable mapRow(ResultSet rs, int rowNum) throws SQLException {
		GraphDataAvailable graphDataAvailable = new GraphDataAvailable();
		graphDataAvailable.setId(rs.getLong("ID"));
		graphDataAvailable.setGeneId(rs.getLong("GENE_ID"));
		if(rs.wasNull()) {graphDataAvailable.setGeneId(null);}
		graphDataAvailable.setGeneName(rs.getString("GENE_NAME"));
		graphDataAvailable.setAlleleId(rs.getLong("ALLELE_ID"));
		if(rs.wasNull()) {graphDataAvailable.setAlleleId(null);}
		graphDataAvailable.setAlleleName(rs.getString("ALLELE_NAME"));
		graphDataAvailable.setPipelineId(rs.getLong("PIPELINE_ID"));
		if(rs.wasNull()) {graphDataAvailable.setPipelineId(null);}
		graphDataAvailable.setPipelineName(rs.getString("PIPELINE_NAME"));
		graphDataAvailable.setReportingTest(rs.getString("REPORTING_TEST"));
		graphDataAvailable.setPageTypeId(rs.getLong("PAGE_TYPE_ID"));
		if(rs.wasNull()) {graphDataAvailable.setPageTypeId(null);}
		graphDataAvailable.setDataAvailable(rs.getBoolean("DATA_AVAILABLE"));
		graphDataAvailable.setRecordCount(rs.getInt("RECORD_COUNT"));
		graphDataAvailable.setColonyId(rs.getLong("COLONY_ID"));
		if(rs.wasNull()) {graphDataAvailable.setColonyId(null);}
		graphDataAvailable.setColonyPrefix(rs.getString("COLONY_PREFIX"));

		return graphDataAvailable;

	}
}