/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.reporting.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;
import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.reporting.GraphMetaData;

public class GraphMetaDataRowMapper implements ParameterizedRowMapper<GraphMetaData> {

	private DictionaryService dictionaryService;

	public void setDictionaryService(DictionaryService dictionaryService) {
		this.dictionaryService = dictionaryService;
	}

	public GraphMetaData mapRow(ResultSet rs, int rowNum) throws SQLException {

		GraphMetaData graphMetaData = new GraphMetaData();
		graphMetaData.setId(rs.getLong("ID"));
		graphMetaData.setViewName(rs.getString("VIEW_NAME"));
		graphMetaData.setPlotColumn(rs.getString("PLOT_COLUMN"));
		graphMetaData.setTitle(rs.getString("TITLE"));
		graphMetaData.setXaxisTitle(rs.getString("XAXIS_TITLE"));
		graphMetaData.setYaxisTitle(rs.getString("YAXIS_TITLE"));
		graphMetaData.setGraphTypeId(rs.getLong("GRAPH_TYPE_ID"));
		graphMetaData.setStatBackgroundId(rs.getLong("STAT_BACKGROUND_ID"));
		graphMetaData.setGraphType(dictionaryService.fetchEntry(DictionaryEnum.REPORTING_GRAPH_TYPE, graphMetaData.getGraphTypeId()));
		graphMetaData.setStatBackground(dictionaryService.fetchEntry(DictionaryEnum.REPORTING_STAT_BACKGROUND, graphMetaData.getStatBackgroundId()));
		graphMetaData.setXPadding(rs.getBoolean("X_PADDING"));
		graphMetaData.setXAxisAsLabels(rs.getBoolean("XAXIS_AS_LABELS"));
		graphMetaData.setTimeAxis(rs.getBoolean("TIME_AXIS"));
		graphMetaData.setScientificYAxis(rs.getBoolean("SCIENTIFIC_Y_AXIS"));
		graphMetaData.setXAxisColumn(rs.getString("XAXIS_COLUMN"));

		return graphMetaData;
	}
}
