/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.reporting.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.reporting.LineRange;



public class LineRangeRowMapper implements ParameterizedRowMapper<LineRange> {

	public LineRange mapRow(ResultSet rs, int rowNum) throws SQLException {

		LineRange lineRange = new LineRange();

		lineRange.setId(rs.getLong("ID"));
		if(rs.wasNull()) lineRange.setId(null);

		lineRange.setGraphMetadataId(rs.getLong("GRAPH_METADATA_ID"));
		if(rs.wasNull()) lineRange.setGraphMetadataId(null);

		lineRange.setXLabel(rs.getString("XLABEL"));

		lineRange.setMinus2Sd(rs.getDouble("MINUS_2_SD"));
		if(rs.wasNull()) lineRange.setMinus2Sd(null);

		lineRange.setMinus1Sd(rs.getDouble("MINUS_1_SD"));
		if(rs.wasNull()) lineRange.setMinus1Sd(null);

		lineRange.setMean(rs.getDouble("MEAN"));
		if(rs.wasNull()) lineRange.setMean(null);

		lineRange.setPlus1Sd(rs.getDouble("PLUS_1_SD"));
		if(rs.wasNull()) lineRange.setPlus1Sd(null);

		lineRange.setPlus2Sd(rs.getDouble("PLUS_2_SD"));
		if(rs.wasNull()) lineRange.setPlus2Sd(null);

		lineRange.setGenderId(rs.getLong("GENDER_ID"));
		if(rs.wasNull()) lineRange.setGenderId(null);

		lineRange.setStrainId(rs.getLong("STRAIN_ID"));
		if(rs.wasNull()) lineRange.setStrainId(null);

		lineRange.setPercentile25(rs.getDouble("PCT_25"));
		if(rs.wasNull()) lineRange.setPercentile25(null);

		lineRange.setPercentile975(rs.getDouble("PCT_975"));
		if(rs.wasNull()) lineRange.setPercentile975(null);

		lineRange.setMedian(rs.getDouble("MEDIAN"));
		if(rs.wasNull()) lineRange.setMedian(null);

		lineRange.setNumRows(rs.getLong("NUM_ROWS"));
		if(rs.wasNull()) lineRange.setNumRows(null);

		lineRange.setPipelineDictId(rs.getLong("PIPELINE_DICT_ID"));
		if(rs.wasNull()) lineRange.setPipelineDictId(null);

		return lineRange;

	}
}