/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.reporting.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Collection;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.reporting.DrawableChart;
import uk.ac.sanger.mig.reporting.Range;
import uk.ac.sanger.mig.reporting.Scatter;
import uk.ac.sanger.mig.reporting.ChartDisplay;


public class ScatterChartData implements ParameterizedRowMapper<Object>, ChartDisplay {

	/**
	 *  ScatterChartData data = new ScatterChartData("Bob");
	 *  data.setYAxisTitle("Some test title");
	 *
	 */

	private String title;
	private String xAxisTitle;
	private String yAxisTitle;
	private Long statBackgroundId;

	private Collection<DrawableChart> data = new ArrayList<DrawableChart>();

	private Collection<? extends Range> ranges;

	public ScatterChartData() {
		this.title = "";
	}

	public ScatterChartData(String title) {
		this.title = title;
	}

	public String getXAxisTitle() {
		return xAxisTitle;
	}

	public void setXAxisTitle(String axisTitle) {
		xAxisTitle = axisTitle;
	}

	public String getYAxisTitle() {
		return yAxisTitle;
	}

	public void setYAxisTitle(String axisTitle) {
		yAxisTitle = axisTitle;
	}

	public String getTitle() {
		return title;
	}

	public void setTitle(String title) {
		this.title = title;
	}

	public Collection<DrawableChart> getData() {
		return data;
	}

	public Collection<? extends Range> getRefRange() {
		return ranges;
	}

	public void setRefRange(Collection<? extends Range> ranges) {
		this.ranges = ranges;
	}

	public Object mapRow(ResultSet rs, int rowNum) throws SQLException {

		Long genderId = rs.getLong("gender_id");
		Long genotypeId = rs.getLong("genotype_id");
		Long strainId = rs.getLong("strain_id");
		String columnValue = rs.getString("plot_column");
		String mouseName = rs.getString("mouse_name");

		// plot values greater than zero.
		if(Double.valueOf(columnValue) > 0) {
			Scatter s = new Scatter(genderId,genotypeId,strainId,columnValue,mouseName);
			data.add(s);
		}

		return null;
	}

	public Long getStatBackgroundId() {
		return statBackgroundId;
	}

	public void setStatBackgroundId(Long statBackgroundId) {
		this.statBackgroundId = statBackgroundId;


	}


}
