/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.reporting.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.reporting.ScatterRange;



public class ScatterRangeRowMapper implements ParameterizedRowMapper<ScatterRange> {

	public ScatterRange mapRow(ResultSet rs, int rowNum) throws SQLException {

		ScatterRange scatterRange = new ScatterRange();

		scatterRange.setId(rs.getLong("ID"));
		if(rs.wasNull()) scatterRange.setId(null);

		scatterRange.setGraphMetadataId(rs.getLong("GRAPH_METADATA_ID"));
		if(rs.wasNull()) scatterRange.setGraphMetadataId(null);

		scatterRange.setMinus2Sd(rs.getDouble("MINUS_2_SD"));
		if(rs.wasNull()) scatterRange.setMinus2Sd(null);

		scatterRange.setMinus1Sd(rs.getDouble("MINUS_1_SD"));
		if(rs.wasNull()) scatterRange.setMinus1Sd(null);

		scatterRange.setMean(rs.getDouble("MEAN"));
		if(rs.wasNull()) scatterRange.setMean(null);

		scatterRange.setPlus1Sd(rs.getDouble("PLUS_1_SD"));
		if(rs.wasNull()) scatterRange.setPlus1Sd(null);

		scatterRange.setPlus2Sd(rs.getDouble("PLUS_2_SD"));
		if(rs.wasNull()) scatterRange.setPlus2Sd(null);

		scatterRange.setGenderId(rs.getLong("GENDER_ID"));
		if(rs.wasNull()) scatterRange.setGenderId(null);
		
		scatterRange.setStrainId(rs.getLong("STRAIN_ID"));
		if(rs.wasNull()) scatterRange.setStrainId(null);

		scatterRange.setPercentile25(rs.getDouble("PCT_25"));
		if(rs.wasNull()) scatterRange.setPercentile25(null);
		
		scatterRange.setPercentile975(rs.getDouble("PCT_975"));
		if(rs.wasNull()) scatterRange.setPercentile975(null);
		
		scatterRange.setMedian(rs.getDouble("MEDIAN"));
		if(rs.wasNull()) scatterRange.setMedian(null);
		
		scatterRange.setNumRows(rs.getLong("NUM_ROWS"));
		if(rs.wasNull()) scatterRange.setNumRows(null);
		
		scatterRange.setPipelineDictId(rs.getLong("PIPELINE_DICT_ID"));
		if(rs.wasNull()) scatterRange.setPipelineDictId(null);
		
		return scatterRange;

	}
}