/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.reporting.services;

import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.AbstractServiceImpl2;

import uk.ac.sanger.mig.reporting.GraphDataAvailable;
import uk.ac.sanger.mig.reporting.dao.GraphDataAvailableDao;

public class GraphDataAvailableServiceImpl extends AbstractServiceImpl2<GraphDataAvailable,GraphDataAvailableDao> implements GraphDataAvailableService {

	@Override
	protected void attachComponents(GraphDataAvailable graphDataAvailable, ComponentMap requiredComponents) {
		if(graphDataAvailable == null) {
			throw new RuntimeException("Cannot attach components to null graphDataAvailable");
		}
	}

	public HashMap<String, String> fetchAllPipelinesByAlleleId(Long alleleId) {

		HashMap<String, String> map = new HashMap<String, String>();
		List<Map<String, Object>> data =  getPrimaryDao().fetchAllPipelinesByAlleleId(alleleId);
		for(Map<String, Object> available : data) {
			String key = available.get("id")+"";
			String val = available.get("pipeline_name")+"";
			map.put(key, val);
		}
		return map;
	}

	public HashMap<String, String> fetchAllTestsByAllelePipelineId(Long alleleId, Long pipelineId) {

		HashMap<String, String> map = new HashMap<String, String>();
		List<Map<String, Object>> data =  getPrimaryDao().fetchAllTestsByAllelePipelineId(alleleId, pipelineId);
		for(Map<String, Object> available : data) {
			String key = available.get("id")+"";
			String val = convertToCamelCase(available.get("test")+"");
			map.put(key, val);
		}
		return map;
	}

	public Map<String, String> fetchAllGraphsByPageId(Long pageId) {

		HashMap<String, String> map = new HashMap<String, String>();
		List<Map<String, Object>> data =  getPrimaryDao().fetchAllGraphsByPageId(pageId);
		for(Map<String, Object> available : data) {
			String key = available.get("id")+"";
			String val = convertToCamelCase(available.get("graph_type")+"");
			map.put(key, val);
		}
		return map;


	}


	private String convertToCamelCase(String cn) {
		StringBuffer sb = new StringBuffer();
		String[] str = cn.split(" ");

		for(String temp : str) {
			sb.append(Character.toUpperCase(temp.charAt(0)));
			sb.append(temp.substring(1).toLowerCase());
			sb.append(" ");
		}
		return sb.toString();
	}

}
