/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.reporting.services;

import uk.ac.sanger.mig.common.AbstractServiceImpl2;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.personnel.Person;

import java.util.Collection;

import uk.ac.sanger.mig.reporting.RepGraph;
import uk.ac.sanger.mig.reporting.RepGraphSearchBean;
import uk.ac.sanger.mig.reporting.RepPageSubgroup;
import uk.ac.sanger.mig.reporting.dao.RepGraphDao;

public class RepGraphServiceImpl extends AbstractServiceImpl2<RepGraph,RepGraphDao> implements RepGraphService {


	private GraphMetaDataService metaDataService;

	public void setMetaDataService(GraphMetaDataService metaDataService) {
		this.metaDataService = metaDataService;
	}

	public Long store(RepGraph repGraph, Person user) {
		if(repGraph == null) {
			throw new RuntimeException("Cannot save a null repGraph");
		}

		return getPrimaryDao().store(repGraph, user);
	}

	public RepGraph fetchById(Long repGraphId, ComponentMap requiredComponents) {
		RepGraph repGraph = getPrimaryDao().fetchById(repGraphId);

		if(repGraph != null)
			attachComponents(repGraph, requiredComponents);

		return repGraph;
	}

	@Override
	protected void attachComponents(RepGraph repGraph, ComponentMap requiredComponents) {
		if(repGraph == null) {
			throw new RuntimeException("Cannot attach components to null repGraph");
		}

		boolean fetchAll = false;

		if(requiredComponents != null) {

			if(requiredComponents.containsKey(RepGraph.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}

			if(fetchAll || requiredComponents.containsKey(RepGraph.Component.META_DATA)) {
				repGraph.setMetaData(metaDataService.fetchById(repGraph.getGraphMetadataId(),
							requiredComponents.get(RepGraph.Component.META_DATA)));
			}

		}
	}


	public Collection<RepGraph> search(RepGraphSearchBean repGraphSearchBean) {
		// TODO Auto-generated method stub
		return null;
	}


	public Collection<RepGraph> fetchBySubgroupId(Long groupId, ComponentMap requiredComponents) {
		Collection<RepGraph> graphs =  getPrimaryDao().fetchBySubgroupId(groupId);

		if(graphs != null)
			attachComponents(graphs, requiredComponents);

		return graphs;

	}


}
