/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.reporting.services;

import uk.ac.sanger.mig.common.AbstractServiceImpl2;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.personnel.Person;

import java.util.Collection;

import uk.ac.sanger.mig.reporting.RepGraph;
import uk.ac.sanger.mig.reporting.RepPageSubgroup;
import uk.ac.sanger.mig.reporting.RepPageSubgroupSearchBean;
import uk.ac.sanger.mig.reporting.dao.RepPageSubgroupDao;


public class RepPageSubgroupServiceImpl extends AbstractServiceImpl2<RepPageSubgroup,RepPageSubgroupDao> implements RepPageSubgroupService {

	private RepGraphService repGraphService;

	public void setRepGraphService(RepGraphService repGraphService) {
		this.repGraphService = repGraphService;
	}

	public Long store(RepPageSubgroup repPageSubgroup, Person user) {
		if(repPageSubgroup == null) {
			throw new RuntimeException("Cannot save a null repPageSubgroup");
		}

		return getPrimaryDao().store(repPageSubgroup, user);
	}

	public RepPageSubgroup fetchById(Long repPageSubgroupId, ComponentMap requiredComponents) {
		RepPageSubgroup repPageSubgroup = getPrimaryDao().fetchById(repPageSubgroupId);

		if(repPageSubgroup != null)
			attachComponents(repPageSubgroup, requiredComponents);

		return repPageSubgroup;
	}

	@Override
	protected void attachComponents(RepPageSubgroup repPageSubgroup, ComponentMap requiredComponents) {
		if(repPageSubgroup == null) {
			throw new RuntimeException("Cannot attach components to null repPageSubgroup");
		}

		boolean fetchAll = false;

		if(requiredComponents != null) {

			if(requiredComponents.containsKey(RepPageSubgroup.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}

			if(fetchAll || requiredComponents.containsKey(RepPageSubgroup.Component.GRAPHS)) {
				repPageSubgroup.setGraphs(fetchAllGraphsForSubgroupId(repPageSubgroup.getId(),
							ComponentMap.of(RepPageSubgroup.Component.GRAPHS)));
			}

		}
	}

	private Collection<RepGraph> fetchAllGraphsForSubgroupId(Long subGroupId, ComponentMap requiredComponents) {

		return repGraphService.fetchBySubgroupId(subGroupId, requiredComponents);

	}


	public Collection<RepPageSubgroup> search(
			RepPageSubgroupSearchBean repPageSubgroupSearchBean) {
		// TODO Auto-generated method stub
		return null;
	}


	public Collection<RepPageSubgroup> fetchByPageId(Long pageId,
			ComponentMap requiredComponents) {

		Collection<RepPageSubgroup> repPageSubgroups = getPrimaryDao().fetchByPageId(pageId);

		if(repPageSubgroups != null)
			attachComponents(repPageSubgroups, requiredComponents);


		return repPageSubgroups;
	}

}
