/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.reporting.services;

import uk.ac.sanger.mig.common.AbstractServiceImpl2;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.personnel.Person;

import java.util.Collection;

import uk.ac.sanger.mig.reporting.RepPageSubgroup;
import uk.ac.sanger.mig.reporting.RepPageType;
import uk.ac.sanger.mig.reporting.RepPageTypeSearchBean;
import uk.ac.sanger.mig.reporting.dao.RepPageTypeDao;

public class RepPageTypeServiceImpl extends AbstractServiceImpl2<RepPageType,RepPageTypeDao> implements RepPageTypeService {

	private RepPageSubgroupService repPageSubgroupService;


	public void setRepPageSubgroupService(
			RepPageSubgroupService repPageSubgroupService) {
		this.repPageSubgroupService = repPageSubgroupService;
	}

	public Long store(RepPageType repPageType, Person user) {
		if(repPageType == null) {
			throw new RuntimeException("Cannot save a null repPageType");
		}

		return getPrimaryDao().store(repPageType, user);
	}

	public RepPageType fetchById(Long repPageTypeId, ComponentMap requiredComponents) {
		RepPageType repPageType = getPrimaryDao().fetchById(repPageTypeId);

		if(repPageType != null)
			attachComponents(repPageType, requiredComponents);

		return repPageType;
	}


	public Collection<RepPageType> fetchAllForConfig(ComponentMap requiredComponents) {
		Collection<RepPageType> pages =  getPrimaryDao().fetchAll();
		if(pages != null)
			attachComponents(pages, requiredComponents);

		return pages;
	}

	@Override
	protected void attachComponents(RepPageType repPageType, ComponentMap requiredComponents) {
		if(repPageType == null) {
			throw new RuntimeException("Cannot attach components to null repPageType");
		}

		boolean fetchAll = false;

		if(requiredComponents != null) {

			if(requiredComponents.containsKey(RepPageType.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}

			if(fetchAll || requiredComponents.containsKey(RepPageType.Component.SUBGROUPS)) {
				repPageType.setSubGroups(fetchSubGroups(repPageType, requiredComponents.get(RepPageType.Component.SUBGROUPS)));
			}

		}
	}

	public Collection<RepPageSubgroup> fetchSubGroups(RepPageType repPageType, ComponentMap requiredComponents) {
		return repPageSubgroupService.fetchByPageId(repPageType.getId(), requiredComponents);
	}


	public Collection<RepPageType> search(
			RepPageTypeSearchBean repPageTypeSearchBean) {
		// TODO Auto-generated method stub
		return null;
	}

}
