package uk.ac.sanger.mig.reporting.views;


import java.util.Arrays;
import java.util.HashMap;

import javax.servlet.ServletContext;

import uk.ac.sanger.mig.mousetracking.services.MouseService;
import uk.ac.sanger.mig.reporting.ChartDisplay;
import uk.ac.sanger.mig.reporting.services.ChartUtils;
import ChartDirector.*;


public class BarChart
{


	private ServletContext servletContext;
	private ChartUtils utils = null;

	private MultiChart chart;

	public MultiChart getChart() {
		return chart;
	}

	public BarChart(ServletContext servletContext, ChartDisplay displayData) {

		utils = new ChartUtils(displayData);
		this.servletContext = servletContext;

		// To make sure that these 2 charts are comparable in colour map, generate
		// a map based on the unique data types.
		utils.generateBarColourMap();


		chart = new MultiChart(940, 460);
		chart.setBackground(0x0f0f0f);
		chart.setTransparentColor(0x0f0f0f);
		// make a female chart.
		chart.addChart(0, 0, createBarChart(displayData.getTitle()+"-Female",displayData.getXAxisTitle(), displayData.getYAxisTitle(),
				utils.fetchBarData(MouseService.MOUSE_GENDER_FEMALE )));
		// make a male chart.
		chart.addChart(480, 0, createBarChart(displayData.getTitle()+"-Male",displayData.getXAxisTitle(), displayData.getYAxisTitle(),
				utils.fetchBarData(MouseService.MOUSE_GENDER_MALE)));

	}


	private XYChart createBarChart(String title, String xAxis, String yAxis, HashMap<String, double[]> data)
	{


		String[] labels = {"WT","Het","Hom","Base"};

		// create chart, grey background.
		XYChart chart = new XYChart(460, 430, 0xffffff, 0x004869);

		// Set the search path for images
		chart.setSearchPath3(servletContext,null, "/images");

		chart.addTitle(title, "Arial", 15, 0xffffff).setBackground(0x004869);
		// Add sanger image to top left corner.
		chart.addText(2, 1, "<*block,valign=absmiddle*><*img=/sangerdna.png*>" );

		if(data.size()==0) {
			chart.addText(180, 210, "No Data For Display");
		}else{

			// set drawing area, white background, grey axis lines.
			chart.setPlotArea(60, 90, 350, 300, 0xffffff, -1, 0xbdbdbd, 0xbdbdbd, -1);

			BarLayer layer = chart.addBarLayer2(Chart.Percentage);


			// Add the datasets, assign the colour from the utils colourmap.
			String[] keys = (String[]) data.keySet().toArray(new String[0]);
			Arrays.sort(keys);
			for(String name : keys) {
				layer.addDataSet(data.get(name), utils.getColourByType(name), name);
			}


			// Set the bar border to transparent
			layer.setBorderColor(Chart.Transparent);

			layer.setDataLabelStyle("Arial", 7).setAlignment(Chart.Center);
			layer.setDataLabelFormat("{value} ({percent|1}%)");


			// add X axis title
			chart.xAxis().setTitle(xAxis, "Arial", 10);

			// add Y axis title
			chart.yAxis().setTitle(yAxis, "Arial", 10);

			// set line widths and colors of the axis.
			chart.xAxis().setWidth(2);
			chart.yAxis().setWidth(2);
			chart.xAxis().setColors(0x000000,0x8d0017,0X000000,0x8d0017);
			chart.yAxis().setColors(0x000000,0x8d0017,0X000000,0x8d0017);

			// set the X axis labels.
			chart.xAxis().setLabels(labels);

			LegendBox legendBox = chart.addLegend2(30, 30, 3, "Arial", 8);

			// Set the format of the text displayed in the legend box
			legendBox.setText("{dataSetName}");

			legendBox.setWidth(400);

			legendBox.setBackground(0xffffff, 0x000000,1);

			// see how many legends we have.. get this from the number of keys in the colourmap.
			int numLegends = utils.getColourMapSize();
			// resize the columns so that it doesn't pad down over the graph.
			if(numLegends > 6) {
				legendBox.setCols(5);
			}
		}
		return chart;
	}




}