package uk.ac.sanger.mig.reporting.views;
/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

import java.util.ArrayList;
import java.util.HashMap;

import javax.servlet.ServletContext;

import ChartDirector.BoxWhiskerLayer;
import ChartDirector.Chart;
import ChartDirector.LineLayer;
import ChartDirector.MultiChart;
import ChartDirector.XYChart;

import uk.ac.sanger.mig.mousetracking.GenotypeDictionary;
import uk.ac.sanger.mig.mousetracking.services.MouseService;
import uk.ac.sanger.mig.reporting.ChartDisplay;
import uk.ac.sanger.mig.reporting.GraphColourMap;
import uk.ac.sanger.mig.reporting.GraphMetaData;
import uk.ac.sanger.mig.reporting.services.ChartUtils;

/**
 * Class to generate Line grahs.
 * Produces 4 graphs split by gender. One averaged with SEM whiskers and
 * one with the raw data lines for each mouse.
 *
 * @author mng
 *
 */
public class LineChart {

	// Display totals or male/female split.
	private enum DISPLAY_MODE {
		TOTAL,
		SPLIT
	};

	private DISPLAY_MODE displayMode =  DISPLAY_MODE.SPLIT;
	private MultiChart chart;
	private ServletContext servletContext;


	public MultiChart getChart() {
		return chart;
	}


	/**
	 * No excuses, this is nasty, invloves lots of mappings in the utils class to get rows from the db
	 * back to double[] at the correct xAxis index.
	 *
	 * @param servletContext
	 * @param displayData
	 * @param g
	 */
	public LineChart(ServletContext servletContext, ChartDisplay displayData, GraphMetaData g) {

		ChartUtils utils = new ChartUtils(displayData);
		utils.setMinMaxYForDataSet(); // required specifically for line charts.

		this.servletContext = servletContext;
		if(displayMode ==  DISPLAY_MODE.SPLIT) {
			chart = new MultiChart(940, 920);

			chart.setBackground(0x0f0f0f);
			chart.setTransparentColor(0x0f0f0f);

			String[] xLabels = utils.getUniqueXLabels(g.isTimeAxis());
			boolean onlyAverageDataLine = true;

			/**
			 * Average Data : wt, het, hom averages with error bars.
			 */

			// make a male chart.
			chart.addChart(0, 0, createLineChart(displayData.getTitle()+"-Female (average)", displayData.getXAxisTitle(),
					displayData.getYAxisTitle(), xLabels,
					utils.dataSetCount(GenotypeDictionary.WILDTYPE,MouseService.MOUSE_GENDER_FEMALE),
					utils.dataSetCount(GenotypeDictionary.HETEROZYGOUS,MouseService.MOUSE_GENDER_FEMALE),
					utils.dataSetCount(GenotypeDictionary.HOMOZYGOUS,MouseService.MOUSE_GENDER_FEMALE),
					utils.fetchLineData(g.isTimeAxis(),GenotypeDictionary.WILDTYPE, MouseService.MOUSE_GENDER_FEMALE,onlyAverageDataLine),
					utils.fetchLineData(g.isTimeAxis(),GenotypeDictionary.HETEROZYGOUS, MouseService.MOUSE_GENDER_FEMALE,onlyAverageDataLine),
					utils.fetchLineData(g.isTimeAxis(),GenotypeDictionary.HOMOZYGOUS, MouseService.MOUSE_GENDER_FEMALE,onlyAverageDataLine),
					utils.fetchLineRangeData(g.isTimeAxis(), MouseService.MOUSE_GENDER_FEMALE ),
					utils.getLinePointStandardError(g.isTimeAxis(),GenotypeDictionary.WILDTYPE,MouseService.MOUSE_GENDER_FEMALE),
					utils.getLinePointStandardError(g.isTimeAxis(),GenotypeDictionary.HETEROZYGOUS,MouseService.MOUSE_GENDER_FEMALE),
					utils.getLinePointStandardError(g.isTimeAxis(),GenotypeDictionary.HOMOZYGOUS,MouseService.MOUSE_GENDER_FEMALE),
					g.isXPadding(), g.isTimeAxis(), g.isScientificYAxis(),g.isXAxisAsLabels(), utils.getMaxY(),utils.getMinY())
			);

			// make female chart
			chart.addChart(500, 0, createLineChart(displayData.getTitle()+"-Male (average)", displayData.getXAxisTitle(),
					displayData.getYAxisTitle(), xLabels,
					utils.dataSetCount(GenotypeDictionary.WILDTYPE,MouseService.MOUSE_GENDER_MALE),
					utils.dataSetCount(GenotypeDictionary.HETEROZYGOUS,MouseService.MOUSE_GENDER_MALE),
					utils.dataSetCount(GenotypeDictionary.HOMOZYGOUS,MouseService.MOUSE_GENDER_MALE),
					utils.fetchLineData(g.isTimeAxis(),GenotypeDictionary.WILDTYPE, MouseService.MOUSE_GENDER_MALE,onlyAverageDataLine),
					utils.fetchLineData(g.isTimeAxis(),GenotypeDictionary.HETEROZYGOUS, MouseService.MOUSE_GENDER_MALE,onlyAverageDataLine),
					utils.fetchLineData(g.isTimeAxis(),GenotypeDictionary.HOMOZYGOUS, MouseService.MOUSE_GENDER_MALE,onlyAverageDataLine),
					utils.fetchLineRangeData(g.isTimeAxis(), MouseService.MOUSE_GENDER_MALE ),
					utils.getLinePointStandardError(g.isTimeAxis(),GenotypeDictionary.WILDTYPE,MouseService.MOUSE_GENDER_MALE),
					utils.getLinePointStandardError(g.isTimeAxis(),GenotypeDictionary.HETEROZYGOUS,MouseService.MOUSE_GENDER_MALE),
					utils.getLinePointStandardError(g.isTimeAxis(),GenotypeDictionary.HOMOZYGOUS,MouseService.MOUSE_GENDER_MALE),
					g.isXPadding(), g.isTimeAxis(), g.isScientificYAxis(),g.isXAxisAsLabels(), utils.getMaxY(),utils.getMinY())
			);

			/**
			 * RAW Data : Each mouse plotted as a single line
			 */
			onlyAverageDataLine = false;
			// make a male chart.
			chart.addChart(0, 460, createLineChart(displayData.getTitle()+"-Female", displayData.getXAxisTitle(),
					displayData.getYAxisTitle(), xLabels,
					utils.dataSetCount(GenotypeDictionary.WILDTYPE,MouseService.MOUSE_GENDER_FEMALE),
					utils.dataSetCount(GenotypeDictionary.HETEROZYGOUS,MouseService.MOUSE_GENDER_FEMALE),
					utils.dataSetCount(GenotypeDictionary.HOMOZYGOUS,MouseService.MOUSE_GENDER_FEMALE),
					utils.fetchLineData(g.isTimeAxis(),GenotypeDictionary.WILDTYPE, MouseService.MOUSE_GENDER_FEMALE,onlyAverageDataLine),
					utils.fetchLineData(g.isTimeAxis(),GenotypeDictionary.HETEROZYGOUS, MouseService.MOUSE_GENDER_FEMALE,onlyAverageDataLine),
					utils.fetchLineData(g.isTimeAxis(),GenotypeDictionary.HOMOZYGOUS, MouseService.MOUSE_GENDER_FEMALE,onlyAverageDataLine),
					utils.fetchLineRangeData(g.isTimeAxis(), MouseService.MOUSE_GENDER_FEMALE ),
					null, null, null,
					g.isXPadding(), g.isTimeAxis(), g.isScientificYAxis(),g.isXAxisAsLabels(), utils.getMaxY(),utils.getMinY())
			);

			// make female chart
			chart.addChart(500, 460, createLineChart(displayData.getTitle()+"-Male", displayData.getXAxisTitle(),
					displayData.getYAxisTitle(), xLabels,
					utils.dataSetCount(GenotypeDictionary.WILDTYPE,MouseService.MOUSE_GENDER_MALE),
					utils.dataSetCount(GenotypeDictionary.HETEROZYGOUS,MouseService.MOUSE_GENDER_MALE),
					utils.dataSetCount(GenotypeDictionary.HOMOZYGOUS,MouseService.MOUSE_GENDER_MALE),
					utils.fetchLineData(g.isTimeAxis(),GenotypeDictionary.WILDTYPE, MouseService.MOUSE_GENDER_MALE,onlyAverageDataLine),
					utils.fetchLineData(g.isTimeAxis(),GenotypeDictionary.HETEROZYGOUS, MouseService.MOUSE_GENDER_MALE,onlyAverageDataLine),
					utils.fetchLineData(g.isTimeAxis(),GenotypeDictionary.HOMOZYGOUS, MouseService.MOUSE_GENDER_MALE,onlyAverageDataLine),
					utils.fetchLineRangeData(g.isTimeAxis(), MouseService.MOUSE_GENDER_MALE ),
					null, null, null,
					g.isXPadding(), g.isTimeAxis(), g.isScientificYAxis(),g.isXAxisAsLabels(), utils.getMaxY(),utils.getMinY())
			);




		}else if(displayMode == DISPLAY_MODE.TOTAL){
			chart = new MultiChart(560, 480);
			// make a total chart.
			//chart.addChart();
		}
	}



	public XYChart createLineChart(String title, String xAxis, String yAxis, String[] xLabels,
			String numWT, String numHet, String numHom,
			HashMap<String,double[]> wt2, HashMap<String,double[]> het2, HashMap<String,double[]> hom2,
			ArrayList<double[]> refRanges, ArrayList<double[]> wtError, ArrayList<double[]> hetError, ArrayList<double[]> homError,
			boolean addPadding, boolean timeAxis, boolean scientificYaxis, boolean useXAxisLabels, double maxYVal, double minYVal)
	{


		String legend_axis1 = "WT (n="+numWT+")";
		String legend_axis2 = "Het (n="+numHet+")";
		String legend_axis3 = "Hom (n="+numHom+")";


		double[] xDataFromLabels = null;
		if(!timeAxis) {
			xDataFromLabels = getXDataFromLabels(xLabels);
		}


		// create chart, grey background.
		XYChart c = new XYChart(460, 430, 0xffffff,0x004869);

		// Set the search path for images
		c.setSearchPath3(servletContext,null, "/images");


		// set drawing area, white background, grey axis lines.
		c.setPlotArea(65, 80, 325, 300, 0xffffff, -1, 0xbdbdbd, 0xbdbdbd, Chart.Transparent);

		// Add legend. white background, raised edges. Fake legend entries.
		c.addScatterLayer(new double[]{}, new double[]{}, legend_axis1, Chart.SquareSymbol, 7, GraphColourMap.WILDTYPE_COLOUR);
		c.addScatterLayer(new double[]{}, new double[]{}, legend_axis2, Chart.TriangleSymbol, 7, GraphColourMap.HETROZYGOUS_COLOUR);
		c.addScatterLayer(new double[]{}, new double[]{}, legend_axis3, Chart.DiamondSymbol, 8, GraphColourMap.HOMOZYGOUS_COLOUR);
		c.addLegend(75, 35, false, "Arial", 10).setBackground(0xffffff, 0x000000,1);

		// Add title, white text, black glass effect background.
		c.addTitle(title, "Arial", 15, 0xffffff).setBackground(0x004869);

		// Add sanger image to top left corner.
		c.addText(2, 1, "<*block,valign=absmiddle*><*img=/sangerdna.png*>");

		// add X axis title
		c.xAxis().setTitle(xAxis, "Arial", 10);


		if(addPadding) {
			// use this only to indicate that the xAxis need not include zero.(3rd arg)
			c.xAxis().setAutoScale(0, 0, 0);
			// override the 1st/2nd args above to set left and right margins to 70px
			c.xAxis().setMargin(20, 20);
		}

		// add y axis title
		c.yAxis().setTitle(yAxis,"Arial", 10);



		if(scientificYaxis) {
			c.yAxis().setLabelFormat("{value|G}");
		}

		// set line widths and colors of the axis.
		c.xAxis().setWidth(2);
		c.yAxis().setWidth(2);
		c.xAxis().setColors(0x000000,GraphColourMap.AXIS_LABEL_COLOUR,0X000000,GraphColourMap.AXIS_LABEL_COLOUR);
		c.yAxis().setColors(0x000000,GraphColourMap.AXIS_LABEL_COLOUR,0X000000,GraphColourMap.AXIS_LABEL_COLOUR);

		c.yAxis().setAutoScale(0,0,0);
		c.yAxis().setMargin(10,10);
		c.yAxis().setLinearScale(minYVal,maxYVal);

		// Clip to drawing area.
		c.setClipping();

		// set the X axis labels.
		if(useXAxisLabels) {
			if(!timeAxis) {
				c.xAxis().setLabels(generateXAxisLabels(xLabels));
			}else{
				c.xAxis().setLabels(parseIndexFromLabel(xLabels));
				if(xLabels.length > 10) {
					c.xAxis().setLabelStyle("normal",7,0x000000,45.0);
					int tickSpace = xLabels.length / 10;
					c.xAxis().setLabelStep(tickSpace);
				}
			}
		}

		// add data lines, dont include them on the legend or we'll end up with multiples.
		// legend entries are faked above.
		if(wt2 != null) {
			for(String mouse : wt2.keySet()) {
				LineLayer layer1 = c.addLineLayer();
				layer1.addDataSet(wt2.get(mouse), GraphColourMap.WILDTYPE_COLOUR,legend_axis1).setDataSymbol(Chart.SquareSymbol, 7);
				if(!timeAxis) {layer1.setXData(xDataFromLabels);}
				layer1.setGapColor(GraphColourMap.WILDTYPE_COLOUR);
				layer1.setLegend(Chart.NoLegend);
				layer1.addExtraField(getExtraLabels(mouse,xLabels.length));// adds the mouse name for the image map.
			}
		}
		if(het2 != null) {
			for(String mouse :  het2.keySet()) {
				LineLayer layer2 = c.addLineLayer();
				layer2.addDataSet(het2.get(mouse), GraphColourMap.HETROZYGOUS_COLOUR,legend_axis2).setDataSymbol(Chart.TriangleSymbol, 7);
				if(!timeAxis) {layer2.setXData(xDataFromLabels);}
				layer2.setGapColor(GraphColourMap.HETROZYGOUS_COLOUR);
				layer2.setLegend(Chart.NoLegend);
				layer2.addExtraField(getExtraLabels(mouse,xLabels.length));// adds the mouse name for the image map.
			}
		}
		if(hom2 != null) {
			for(String mouse :  hom2.keySet()) {
				LineLayer layer3 = c.addLineLayer();
				layer3.addDataSet(hom2.get(mouse), GraphColourMap.HOMOZYGOUS_COLOUR,legend_axis3).setDataSymbol(Chart.DiamondSymbol, 8);
				if(!timeAxis) {layer3.setXData(xDataFromLabels);}
				layer3.setGapColor(GraphColourMap.HOMOZYGOUS_COLOUR);
				layer3.setLegend(Chart.NoLegend);
				layer3.addExtraField(getExtraLabels(mouse,xLabels.length));// adds the mouse name for the image map.
			}
		}

		if(refRanges != null && refRanges.size() != 0) {

		//	if(!timeAxis) {
				// whisker error bars.
				if(wtError != null && wtError.size() >0) {
					addWhiskerLayer(c,xLabels,wtError.get(0),wtError.get(1),GraphColourMap.WILDTYPE_COLOUR,timeAxis);
				}
				if(hetError != null && hetError.size() >0) {
					addWhiskerLayer(c,xLabels,hetError.get(0),hetError.get(1),GraphColourMap.HETROZYGOUS_COLOUR,timeAxis);
				}
				if(homError != null && homError.size() >0) {
					addWhiskerLayer(c,xLabels,homError.get(0),homError.get(1), GraphColourMap.HOMOZYGOUS_COLOUR,timeAxis);
				}
		//	}
			// add dashed lines for mean.
			LineLayer meanlayer = c.addLineLayer(refRanges.get(2),c.dashLineColor(GraphColourMap.REFRANGE_LINE, Chart.DashLine));
			if(!timeAxis) {meanlayer.setXData(xDataFromLabels);}

			// Add a new line layer to the chart
			LineLayer layer = c.addLineLayer2();

			if(!timeAxis) {layer.setXData(xDataFromLabels);}
			// Add the upper border of the percentile zone
			layer.addDataSet(refRanges.get(3), c.dashLineColor(GraphColourMap.REFRANGE_LINE, Chart.DashLine), "+1sd");

			// Add the lower border of the percentile zone
			layer.addDataSet(refRanges.get(1), c.dashLineColor(GraphColourMap.REFRANGE_LINE, Chart.DashLine), "-1sd");

			// Color the region between the percentile zone lines
			c.addInterLineLayer(layer.getLine(0), layer.getLine(1), GraphColourMap.REFRANGE_INNER);

			// Add the upper border of the outer 2.5% percentile zone
			layer.addDataSet(refRanges.get(4), c.dashLineColor(GraphColourMap.REFRANGE_LINE, Chart.DashLine), "+2sd");

			// Add the lower border of the outer 2.5% percentile zone
			layer.addDataSet(refRanges.get(0), c.dashLineColor(GraphColourMap.REFRANGE_LINE, Chart.DashLine), "-2sd");

			// Color the region between the percentile zone lines
			c.addInterLineLayer(layer.getLine(1), layer.getLine(3), GraphColourMap.REFRANGE_OUTER);

			// Color the region between the percentile zone lines
			c.addInterLineLayer(layer.getLine(0), layer.getLine(2), GraphColourMap.REFRANGE_OUTER);

			// dont show layer in legend box
			layer.setLegend(Chart.NoLegend);


		}


		return c;

	}

	/**
	 * Method to generate mouseName for image map. One String array with the same mouse name mapped
	 * for every xAxis point.
	 *
	 * @param mouseName
	 * @param len
	 * @return String[]
	 */
	private String[] getExtraLabels(String mouseName, int len) {
		String[] ret = new String[len];
		for(int i = 0; i<len; i++) {
			ret[i] = mouseName;
		}
		return ret;
	}

	private boolean isListed(int i, String[] labels) {
		String test = new String(i+"");

		for(int j= 0; j<labels.length; j++) {
			if(labels[j].equals(test)) {
				return true;
			}
		}
		return false;

	}

	/**
	 * Draw the SEM whiskers.
	 */
	private void addWhiskerLayer(XYChart c, String[] labels, double[] high, double[]low, int color, boolean timeAxis) {
		if(high != null && low != null) {
			BoxWhiskerLayer errLayer = c.addBoxWhiskerLayer(null, null, high, low, null,
					Chart.Transparent, color);
			errLayer.setLineWidth(2);
			errLayer.setDataGap(0.80);

			if(!timeAxis) {
				errLayer.setXData(getXDataFromLabels(labels));
			}
		}
	}

	/**
	 *  gets the the xAxis data for the labels,
	 *
	 *  Used for setXData so i can put the labels at specific points insted of chart director
	 *  working it out itself.
	 *
	 */
	private double[] getXDataFromLabels(String[] labels) {

		double[] xData = new double[labels.length];

		double offset = Double.valueOf(labels[0]);

		for(int i=0; i<labels.length;i++) {
			Double d;
			try {
				d = Double.valueOf(labels[i]);
				if(d != null) {
					double val = d.doubleValue();
					xData[i] = val - offset;
				}
			} catch (NumberFormatException e) {
			}
		}
		return xData;
	}

	/**
	 * Creates the xAxis labels, uses isListed to see if its a label we want to see.
	 * eg. in the case of ipGTT, we only want to see 0,15,30,60 & 120 on the axis.. but to space
	 * appropriately, the labels array contains the strings 0..120, i just choose the ones
	 * needed to be seen.
	 *
	 * @param labels
	 * @return
	 */
	private String[] generateXAxisLabels(String[] labels) {

		int labelLen = labels.length;

		int first = 0;
		int last = 0;
		try {
			first = Integer.parseInt(labels[0]);
			last = Integer.parseInt(labels[labelLen-1]);
		} catch (NumberFormatException e) {
			return null;
		}

		ArrayList<String> newLabels = new ArrayList<String>();

		for(int i = first; i<=last; i++) {
			if(isListed(i,labels)) {
				newLabels.add(new String(i+"")); // valid and i want to see it.
			} else {
				newLabels.add(new String("")); // ignore it.
			}
		}

		return newLabels.toArray(new String[newLabels.size()]);

	}



	private String[] parseIndexFromLabel(String[] labels) {
		String[] newLabels = new String[labels.length];
		int i = 0;
		for(String label : labels) {
			newLabels[i++] = label.substring(label.indexOf(" "));
		}
		return newLabels;
	}

}

