package uk.ac.sanger.mig.reporting.views;
/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


import java.math.BigDecimal;
import java.text.NumberFormat;
import java.util.ArrayList;

import javax.servlet.ServletContext;

import ChartDirector.ArrayMath;
import ChartDirector.Axis;
import ChartDirector.BoxWhiskerLayer;
import ChartDirector.Chart;
import ChartDirector.Mark;
import ChartDirector.MultiChart;
import ChartDirector.ScatterLayer;
import ChartDirector.XYChart;

import uk.ac.sanger.mig.mousetracking.GenotypeDictionary;
import uk.ac.sanger.mig.mousetracking.services.MouseService;
import uk.ac.sanger.mig.reporting.ChartDisplay;
import uk.ac.sanger.mig.reporting.GraphColourMap;
import uk.ac.sanger.mig.reporting.Scatter;
import uk.ac.sanger.mig.reporting.services.ChartUtils;


public class ScatterChart {

	// Display totals or male/female split.
	private enum DISPLAY_MODE {
		TOTAL,
		SPLIT
	};

	private DISPLAY_MODE displayMode =  DISPLAY_MODE.SPLIT;


	private double[] refRange = new double[]{2,4,6,8,10};


	private double[] wtIndex;
	private double[] hetIndex;
	private double[] homIndex;

	private ServletContext servletContext;

	private MultiChart chart;


	public MultiChart getChart() {
		return chart;
	}

	public ScatterChart(ServletContext servletContext, ChartDisplay displayData) {

		ChartUtils utils = new ChartUtils(displayData);
		this.servletContext = servletContext;
		if(displayMode ==  DISPLAY_MODE.SPLIT) {
			chart = new MultiChart(940, 460);

			chart.setBackground(0x0f0f0f);
			chart.setTransparentColor(0x0f0f0f);


			// make a male chart.
			// make a female chart.
			chart.addChart(0, 0, createScatterChart(displayData.getTitle()+"-Female",displayData.getXAxisTitle(), displayData.getYAxisTitle(),
					utils.fetchScatterData2(GenotypeDictionary.WILDTYPE, MouseService.MOUSE_GENDER_FEMALE),
					utils.fetchScatterData2(GenotypeDictionary.HETEROZYGOUS, MouseService.MOUSE_GENDER_FEMALE),
					utils.fetchScatterData2(GenotypeDictionary.HOMOZYGOUS, MouseService.MOUSE_GENDER_FEMALE),
					utils.getRefRangeByGenderId(MouseService.MOUSE_GENDER_FEMALE)));

			chart.addChart(480, 0, createScatterChart(displayData.getTitle()+"-Male",displayData.getXAxisTitle(), displayData.getYAxisTitle(),
					utils.fetchScatterData2(GenotypeDictionary.WILDTYPE, MouseService.MOUSE_GENDER_MALE ),
					utils.fetchScatterData2(GenotypeDictionary.HETEROZYGOUS, MouseService.MOUSE_GENDER_MALE),
					utils.fetchScatterData2(GenotypeDictionary.HOMOZYGOUS, MouseService.MOUSE_GENDER_MALE),
					utils.getRefRangeByGenderId(MouseService.MOUSE_GENDER_MALE)));

		}else if(displayMode == DISPLAY_MODE.TOTAL){
			chart = new MultiChart(460, 480);
			// make a total chart.
			chart.addChart(0, 0, createScatterChart(displayData.getTitle(),displayData.getXAxisTitle(), displayData.getYAxisTitle(),
					utils.fetchScatterData2(GenotypeDictionary.WILDTYPE, null),
					utils.fetchScatterData2(GenotypeDictionary.HETEROZYGOUS, null),
					utils.fetchScatterData2(GenotypeDictionary.HOMOZYGOUS, null),
					refRange));
		}
	}



	public XYChart createScatterChart(String title, String xAxis, String yAxis,
		//	double[] wt, double[] het, double[] hom, double[] refRange)
			ArrayList<Scatter> wtData, ArrayList<Scatter> hetData, ArrayList<Scatter> homData, double[] refRange)
	{

		XYChart c = new XYChart(460, 430, 0xffffff,0x004869);

		// Set the search path for images
		c.setSearchPath3(servletContext,null, "/images");

		// Add title
		c.addTitle(title, "Arial", 15, 0xffffff).setBackground(0x004869);

		// Add sanger image to top left corner.
		c.addText(2, 1, "<*block,valign=absmiddle*><*img=/sangerdna.png*>");

		double[] wt = toPrimitive(wtData);
		double[] het = toPrimitive(hetData);
		double[] hom = toPrimitive(homData);

		if(wt.length == 0 && het.length == 0 && hom.length == 0) {
			c.addText(180, 210, "No Data For Display");
		}else{


		// The XY points for the scatter chart
		wtIndex  = createIndex(1, wt);
		hetIndex = createIndex(3, het);
		homIndex = createIndex(5, hom);

		// set drawing area, white background, grey axis lines.
		c.setPlotArea(65, 80, 325, 300, 0xffffff, -1, 0xbdbdbd, 0xbdbdbd, -1);

		// Add legend. white background, raised edges. Add fake scatter layers so we get the correct labels in the legend.
		c.addScatterLayer(null, null, "WT", Chart.SquareSymbol, 7, GraphColourMap.WILDTYPE_COLOUR);
		c.addScatterLayer(null, null, "Het", Chart.TriangleSymbol, 7, GraphColourMap.HETROZYGOUS_COLOUR);
		c.addScatterLayer(null, null, "Hom", Chart.DiamondSymbol, 8, GraphColourMap.HOMOZYGOUS_COLOUR );
		c.addLegend(140, 35, false, "Arial", 10).setBackground(0xffffff, 0x000000,1);



		// add X axis title
		c.xAxis().setTitle(xAxis, "Arial", 10);

		// add Y axis title
		c.yAxis().setTitle(yAxis, "Arial", 10);

		// set 10px margin with no preference to zero on axis.
		c.yAxis().setAutoScale(0,0,0);
		c.yAxis().setMargin(10,10);

		// set line widths and colors of the axis.
		c.xAxis().setWidth(2);
		c.yAxis().setWidth(2);
		c.xAxis().setColors(0x000000,GraphColourMap.AXIS_LABEL_COLOUR,0X000000,GraphColourMap.AXIS_LABEL_COLOUR);
		c.yAxis().setColors(0x000000,GraphColourMap.AXIS_LABEL_COLOUR,0X000000,GraphColourMap.AXIS_LABEL_COLOUR);

		// add scatter data to plot. first arg will be the index of the xaxis label times data length.
		// this way they all draw in vertical line.
		ScatterLayer wtLayer = c.addScatterLayer(wtIndex, wt, "WT (n="+wt.length+")", Chart.SquareSymbol, 7, GraphColourMap.WILDTYPE_COLOUR);
		wtLayer.setLegend(Chart.NoLegend);
		wtLayer.addExtraField(getExtraLabels(wtData));

		ScatterLayer hetLayer =c.addScatterLayer(hetIndex, het, "Het (n="+het.length+")", Chart.TriangleSymbol, 7, GraphColourMap.HETROZYGOUS_COLOUR);
		hetLayer.setLegend(Chart.NoLegend);
		hetLayer.addExtraField(getExtraLabels(hetData));

		ScatterLayer homLayer =c.addScatterLayer(homIndex, hom, "Hom (n="+hom.length+")", Chart.DiamondSymbol, 8, GraphColourMap.HOMOZYGOUS_COLOUR);
		homLayer.setLegend(Chart.NoLegend);
		homLayer.addExtraField(getExtraLabels(homData));



		// five ticks, equally spaced, making each major indicator, 1,3 & 5 respectively
		String[] labels = {"","WT (n="+wt.length+")","","Het (n="+het.length+")","","Hom (n="+hom.length+")",""};

		// set the X axis labels.
		c.xAxis().setLabels(labels);

		// Add some marks and zones for reference ranges.

		//Create another yAxis on the right hand side. Add the marks and zones for the reference ranges.
		Axis y = c.yAxis2();
		// copy the main yAxis (left-hand) so that they draw at the right position.
		y.copyAxis(c.yAxis());
		// ..cant work this out... sooo.... set the axis labels to any old font but importantly,
		// set them to be transparent. This way, the marks drawn below override and are the only ones
		// shown (in black)
		y.setLabelStyle("Arial",8,Chart.Transparent);
		c.yAxis2().setTitle("All Wildtype Mice", "Arial", 10);

		if(refRange != null) {
			int rangeLen = refRange.length;
			if(rangeLen==5) {  //Standard Deviation
				drawSDRangeBackground(c,y,refRange);
			}else if(rangeLen == 3) {  //Percentiles
				drawPCTBackground(c,y,refRange);
			}
		}

		// Add an invisible scatter layer to the yaxis, plot the reference ranges on this so that the
		// chart is scaled to always show these ranges. It wont scale just on the marks added above.
		ScatterLayer sl = c.addScatterLayer(new double[]{0,0,0,0,0},refRange,"refRanges",Chart.CrossShape(),0,0x000000);
		// .... and don't add it to the legend.
		sl.setLegend(Chart.NoLegend);


		addBoxWhiskerForDatSet(c,0,wt);
		addBoxWhiskerForDatSet(c,2,het);
		addBoxWhiskerForDatSet(c,4,hom);

		// call layout so that getXCoor/getYCoor works...
		c.layout();

		int mWidth = 460;
		int lWidth = c.getLegend().getWidth();
		c.getLegend().setPos(mWidth/2 - lWidth/2, 30);

		// Draw mean indicator through scatter and b&w plots.
		addMeanIndicator(c,1,wt);
		addMeanIndicator(c,3,het);
		addMeanIndicator(c,5,hom);
		}

		return c;

	}


	//Hack. check whether range labels are all at zero and so overwrite.
	private boolean checkRangeLabelsOverwrite(double[] refRange) {

		for(double rangeVal : refRange) {
			if(rangeVal != 0) {
				return false;
			}
		}
		return true;
	}


	private void drawSDRangeBackground(XYChart c, Axis y, double[] refRange) {

		if(!checkRangeLabelsOverwrite(refRange)) {
			Mark m1 = y.addMark(refRange[0], c.dashLineColor(GraphColourMap.REFRANGE_LINE, Chart.DashLine),"-2SD");
			c.yAxis().addZone(refRange[0], refRange[1], GraphColourMap.REFRANGE_OUTER);
			m1.setFontColor(0x000000);
			m1.setDrawOnTop(false);
			Mark m2 = y.addMark(refRange[1], c.dashLineColor(GraphColourMap.REFRANGE_LINE, Chart.DashLine),"-1SD");
			c.yAxis().addZone(refRange[1], refRange[2], GraphColourMap.REFRANGE_INNER);
			m2.setFontColor(0x000000);
			m2.setDrawOnTop(false);
			Mark m3 = y.addMark(refRange[2], c.dashLineColor(GraphColourMap.REFRANGE_LINE, Chart.DashLine),"Mean");
			c.yAxis().addZone(refRange[2], refRange[3], GraphColourMap.REFRANGE_INNER);
			m3.setFontColor(0x000000);
			m3.setDrawOnTop(false);
			Mark m4 = y.addMark(refRange[3], c.dashLineColor(GraphColourMap.REFRANGE_LINE, Chart.DashLine),"+1SD");
			c.yAxis().addZone(refRange[3], refRange[4], GraphColourMap.REFRANGE_OUTER);
			m4.setFontColor(0x000000);
			m4.setDrawOnTop(false);
			Mark m5 = y.addMark(refRange[4], c.dashLineColor(GraphColourMap.REFRANGE_LINE, Chart.DashLine),"+2SD");
			m5.setFontColor(0x000000);
			m5.setDrawOnTop(false);
		}
	}

	private void drawPCTBackground(XYChart c, Axis y, double[] refRange) {


		Mark m2 = y.addMark(refRange[0], c.dashLineColor(GraphColourMap.REFRANGE_LINE, Chart.DashLine),"2.5%");
		c.yAxis().addZone(refRange[0], refRange[1], GraphColourMap.REFRANGE_INNER);
		m2.setFontColor(0x000000);
		m2.setDrawOnTop(false);
		Mark m3 = y.addMark(refRange[1], c.dashLineColor(GraphColourMap.REFRANGE_LINE, Chart.DashLine),"Mean");
		m3.setFontColor(0x000000);
		m3.setDrawOnTop(false);
		Mark m4 = y.addMark(refRange[2], c.dashLineColor(GraphColourMap.REFRANGE_LINE, Chart.DashLine),"97.5%");
		c.yAxis().addZone(refRange[1], refRange[2], GraphColourMap.REFRANGE_OUTER);
		m4.setFontColor(0x000000);
		m4.setDrawOnTop(false);

	}

	private void addBoxWhiskerForDatSet(XYChart chart, int index , double[] dataSet) {

		if(dataSet == null || dataSet.length == 0) {
			return;
		}

		double mean = getMean(dataSet);
		double sd = new ArrayMath(dataSet).stdDev();
		double upper = mean + sd;
		double lower = mean - sd;
		double boxTop = mean + (sd / Math.sqrt(dataSet.length));
		double boxBot = mean - (sd / Math.sqrt(dataSet.length));

		BoxWhiskerLayer errLayer = null;
		// cant be bothered to do anything clever here....

		switch(index) {
		case 0:
			errLayer = chart.addBoxWhiskerLayer(
					new double[] {boxTop,Chart.NoValue,Chart.NoValue,Chart.NoValue,Chart.NoValue,Chart.NoValue},
					new double[] {boxBot,Chart.NoValue,Chart.NoValue,Chart.NoValue,Chart.NoValue,Chart.NoValue},
					new double[] {upper,Chart.NoValue,Chart.NoValue,Chart.NoValue,Chart.NoValue,Chart.NoValue},
					new double[] {lower,Chart.NoValue,Chart.NoValue,Chart.NoValue,Chart.NoValue,Chart.NoValue},
					new double[] {mean,Chart.NoValue,Chart.NoValue,Chart.NoValue,Chart.NoValue,Chart.NoValue},
					GraphColourMap.WILDTYPE_COLOUR
			);

			break;
		case 2:
			errLayer = chart.addBoxWhiskerLayer(
					new double[] {Chart.NoValue,Chart.NoValue,boxTop,Chart.NoValue,Chart.NoValue,Chart.NoValue},
					new double[] {Chart.NoValue,Chart.NoValue,boxBot,Chart.NoValue,Chart.NoValue,Chart.NoValue},
					new double[] {Chart.NoValue,Chart.NoValue,upper,Chart.NoValue,Chart.NoValue,Chart.NoValue},
					new double[] {Chart.NoValue,Chart.NoValue,lower,Chart.NoValue,Chart.NoValue,Chart.NoValue},
					new double[] {Chart.NoValue,Chart.NoValue,mean,Chart.NoValue,Chart.NoValue,Chart.NoValue},
					GraphColourMap.HETROZYGOUS_COLOUR);

			break;
		case 4:
			errLayer = chart.addBoxWhiskerLayer(
					new double[] {Chart.NoValue,Chart.NoValue,Chart.NoValue,Chart.NoValue,boxTop,Chart.NoValue},
					new double[] {Chart.NoValue,Chart.NoValue,Chart.NoValue,Chart.NoValue,boxBot,Chart.NoValue},
					new double[] {Chart.NoValue,Chart.NoValue,Chart.NoValue,Chart.NoValue,upper,Chart.NoValue},
					new double[] {Chart.NoValue,Chart.NoValue,Chart.NoValue,Chart.NoValue,lower,Chart.NoValue},
					new double[] {Chart.NoValue,Chart.NoValue,Chart.NoValue,Chart.NoValue,mean,Chart.NoValue},
					GraphColourMap.HOMOZYGOUS_COLOUR);

			break;
		}

		errLayer.setLineWidth(2);
		errLayer.setDataWidth(10);

		// clever, offset the b&w by a set amount so that it is close to the data.
		// set min and max to the same values, in this case, the data index + 0.7.
		// the scatter layer is at index + 1 so this will align the  b&w 0.3 to the left.
		errLayer.setXData2(index + 0.7,index + 0.7);
	}
	/**
	 *
	 * @param data
	 * @return median value of the data points.
	 */
	private double getMean(double[] data) {

		double total = 0.0;
		for(int i=0; i<data.length; i++) {
			total += data[i];
		}
		//return total/data.length;

		int decimalPlace = 4;
		BigDecimal bd = new BigDecimal(total / data.length);
		bd = bd.setScale(decimalPlace,BigDecimal.ROUND_UP);
		return (bd.doubleValue());
	}
	/**
	 * display mean line for the data set displayed.
	 */
	private void addMeanIndicator(XYChart c, int index, double[] dataSet) {

		double mean = 0.0;
		int xpos = 0;
		int ypos = 0;

		if(dataSet.length > 0) {
			mean = getMean(dataSet);

			int fractional = (mean < 0.1) ? 3 : 2;

			xpos = c.getXCoor(index);
			ypos = c.getYCoor(mean);
			c.addLine(xpos-24, ypos, xpos+8,ypos, 0x000000,2);

			NumberFormat df=NumberFormat.getNumberInstance();
			df.setMaximumFractionDigits(fractional);
			c.addText(xpos+10, ypos-6, df.format(mean),"Arial", 8);
		}
	}


	/**
	 *
	 * @param labelIndex
	 * @param data
	 * @return  double[] of the labelIndex that has the same number of elements
	 *          as the data array. Allows us to draw the points in a vertical line.
	 */
	private double[] createIndex(int labelIndex, double[] data) {

		double[] retData = new double[data.length];
		for(int i=0; i<data.length;i++) {
			retData[i] = labelIndex;
		}
		return retData;
	}


	/**
	 *
	 * @param data
	 * @return  double[]
	 */
	private double[] toPrimitive(ArrayList<Scatter> data) {
		int len = data.size();
		double[] ret = new double[len];
		int i = 0;
		for(Scatter d : data) {
			ret[i++] = Double.parseDouble(d.getValue());
		}
		return ret;
	}

	/**
	 *
	 * @param data
	 * @return  String[]
	 */
	private String[] getExtraLabels(ArrayList<Scatter> data) {
		int len = data.size();
		String[] ret = new String[len];
		int i = 0;
		for(Scatter d : data) {
			ret[i++] = d.getMouseName();
		}
		return ret;
	}

}


