package uk.ac.sanger.mig.reporting.views;

import java.util.Collection;

import uk.ac.sanger.mig.reporting.BaselineQCRange;
import uk.ac.sanger.mig.reporting.GraphColourMap;
import uk.ac.sanger.mig.reporting.services.GraphMetaDataService;

import ChartDirector.Axis;
import ChartDirector.Chart;
import ChartDirector.LineLayer;
import ChartDirector.Mark;
import ChartDirector.RanTable;
import ChartDirector.XYChart;

public class WildtypeBaselineChart {


	private double[] plus2SD;
	private double[] plus1SD;
	private double[] mean;
	private double[] minus1SD;
	private double[] minus2SD;

	private double[] pct975;
	private double[] median;
	private double[] pct025;

	private String[] labels;

	private Long rangeType;

	private String[] generateAxisLabels(BaselineQCRange[] rangeArray) {
		int len = rangeArray.length;
		String[] labels = new String[len];
		for(int i=0; i<len; i++) {
			labels[i] = rangeArray[i].getBucketDate().toString();
		}
		return labels;
	}

	public WildtypeBaselineChart(Collection<BaselineQCRange> ranges, Long refrangeType) {
		rangeType = refrangeType;
		BaselineQCRange[] rangeArray =  (BaselineQCRange[])ranges.toArray(new BaselineQCRange[0]);
		labels = generateAxisLabels(rangeArray);
		int size = rangeArray.length;
		int numRanges = size + (size - 1); // account for the the gaps we'll leave between the groups.
		if(refrangeType.equals(GraphMetaDataService.REFRANGE_PERCENTILE)) {
			pct975 = new double[numRanges];
			median = new double[numRanges];
			pct025 = new double[numRanges];
			for(int i=0; i<numRanges; i++) {
				BaselineQCRange r = rangeArray[i];
				pct975[i] = r.getPercentile975();
				median[i] = r.getMedian();
				pct025[i] = r.getPercentile25();
				pct975[++i] = Chart.NoValue;
				median[++i] = Chart.NoValue;
				pct025[++i] = Chart.NoValue;
			}
		}
		if(refrangeType.equals(GraphMetaDataService.REFRANGE_SD)) {
			plus2SD = new double[numRanges];
			plus1SD = new double[numRanges];
			mean 	= new double[numRanges];
			minus1SD = new double[numRanges];
			minus2SD = new double[numRanges];
			for(int i=0; i<numRanges; i++) {
				BaselineQCRange r = rangeArray[i];
				plus2SD[i] 	= r.getPlus2Sd();
				plus1SD[i]	= r.getPlus1Sd();
				mean[i] 	= r.getMean();
				minus1SD[i] = r.getMinus1Sd();
				minus2SD[i] = r.getMinus2Sd();
				plus2SD[++i] 	= Chart.NoValue;
				plus1SD[++i]	= Chart.NoValue;
				mean[++i] 	= Chart.NoValue;
				minus1SD[++i] = Chart.NoValue;
				minus2SD[++i] = Chart.NoValue;
			}
		}
	}

	public  XYChart createWildtypeBaselineChart() {



//		===================================================================
//		Now we have the data ready. Actually drawing the chart.
//		===================================================================

//		Create a XYChart object of size 600 x 220 pixels
		XYChart c = new XYChart(1200, 500);

//		Set the plot area at (100, 25) and of size 450 x 150 pixels. Enabled both vertical
//		and horizontal grids by setting their colors to light grey (0xc0c0c0)
		c.setPlotArea(100, 25, 1000, 400).setGridColor(0xc0c0c0, 0xc0c0c0);

//		Add a legend box (92, 0) (top of plot area) using horizontal layout. Use 8 pts
//		Arial font. Disable bounding box (set border to transparent).
		c.addLegend(92, 0, false, "", 8).setBackground(Chart.Transparent);



//		Use manually scaling of y axis from 0 to 100, with ticks every 10 units
		c.yAxis().setLinearScale(0, 100, 10);

//		Set the labels on the x axis
		c.xAxis().setLabels(labels);


//		Add x axis (vertical) zones to indicate Saturdays and Sundays
		for (int i = 0; i < 29; i += 7) {
			c.xAxis().addZone(i, i + 2, 0xc0c0c0);
		}

//		Add a line layer to the chart
		LineLayer layer = c.addLineLayer();

		layer.setLegend(Chart.NoLegend);

//		Set the default line width to 2 pixels
		layer.setLineWidth(2);

//		Add the data sets to the line layer
		if(rangeType.equals(GraphMetaDataService.REFRANGE_PERCENTILE)) {
			layer.addDataSet(pct975, c.dashLineColor(GraphColourMap.REFRANGE_LINE, Chart.DashLine), "97.5%");
			layer.addDataSet(median, c.dashLineColor(GraphColourMap.REFRANGE_LINE, Chart.DashLine), "Median");
			layer.addDataSet(pct025, c.dashLineColor(GraphColourMap.REFRANGE_LINE, Chart.DashLine), "2.5%");
		}else if (rangeType.equals(GraphMetaDataService.REFRANGE_SD)) {
			layer.addDataSet(plus2SD, c.dashLineColor(GraphColourMap.REFRANGE_LINE, Chart.DashLine),"+2SD");
			layer.addDataSet(plus1SD, c.dashLineColor(GraphColourMap.REFRANGE_LINE, Chart.DashLine),"+1SD");
			layer.addDataSet(mean, c.dashLineColor(GraphColourMap.REFRANGE_LINE, Chart.DashLine),"Mean");
			layer.addDataSet(minus1SD, c.dashLineColor(GraphColourMap.REFRANGE_LINE, Chart.DashLine),"-1SD");
			layer.addDataSet(minus1SD, c.dashLineColor(GraphColourMap.REFRANGE_LINE, Chart.DashLine),"-2SD");
		}
//		Layout the chart to fix the y axis scaling. We can then use getXCoor and getYCoor
//		to determine the position of custom objects.
		c.layout();



//		Add the "week n" custom text boxes at the top of the plot area.
		for (int i = 0; i < labels.length; ++i) {
			// Add the "week n" text box using 8 pt Arial font with top center alignment.
			ChartDirector.TextBox textbox = c.addText(layer.getXCoor(i * 7 + 2), 25, ""+i, "Arial Bold", 8, 0x000000, Chart.TopCenter);

			// Set the box width to cover five days
			textbox.setSize(layer.getXCoor(i * 7 + 7) - layer.getXCoor(i * 7 + 2) + 1, 0);

			// Set box background to pale yellow 0xffff80, with a 1 pixel 3D border
			textbox.setBackground(0xffff80, Chart.Transparent, 1);
		}

		return c;

	}

	private void drawSDRangeBackground(XYChart c, Axis y, double[] refRange) {


			Mark m1 = y.addMark(refRange[0], c.dashLineColor(GraphColourMap.REFRANGE_LINE, Chart.DashLine),"-2SD");
			c.yAxis().addZone(refRange[0], refRange[1], GraphColourMap.REFRANGE_OUTER);
			m1.setFontColor(0x000000);
			m1.setDrawOnTop(false);
			Mark m2 = y.addMark(refRange[1], c.dashLineColor(GraphColourMap.REFRANGE_LINE, Chart.DashLine),"-1SD");
			c.yAxis().addZone(refRange[1], refRange[2], GraphColourMap.REFRANGE_INNER);
			m2.setFontColor(0x000000);
			m2.setDrawOnTop(false);
			Mark m3 = y.addMark(refRange[2], c.dashLineColor(GraphColourMap.REFRANGE_LINE, Chart.DashLine),"Mean");
			c.yAxis().addZone(refRange[2], refRange[3], GraphColourMap.REFRANGE_INNER);
			m3.setFontColor(0x000000);
			m3.setDrawOnTop(false);
			Mark m4 = y.addMark(refRange[3], c.dashLineColor(GraphColourMap.REFRANGE_LINE, Chart.DashLine),"+1SD");
			c.yAxis().addZone(refRange[3], refRange[4], GraphColourMap.REFRANGE_OUTER);
			m4.setFontColor(0x000000);
			m4.setDrawOnTop(false);
			Mark m5 = y.addMark(refRange[4], c.dashLineColor(GraphColourMap.REFRANGE_LINE, Chart.DashLine),"+2SD");
			m5.setFontColor(0x000000);
			m5.setDrawOnTop(false);

	}

	private void drawPCTBackground(XYChart c, Axis y, double[] refRange) {


		Mark m2 = y.addMark(refRange[0], c.dashLineColor(GraphColourMap.REFRANGE_LINE, Chart.DashLine),"2.5%");
		c.yAxis().addZone(refRange[0], refRange[1], GraphColourMap.REFRANGE_INNER);
		m2.setFontColor(0x000000);
		m2.setDrawOnTop(false);
		Mark m3 = y.addMark(refRange[1], c.dashLineColor(GraphColourMap.REFRANGE_LINE, Chart.DashLine),"Mean");
		m3.setFontColor(0x000000);
		m3.setDrawOnTop(false);
		Mark m4 = y.addMark(refRange[2], c.dashLineColor(GraphColourMap.REFRANGE_LINE, Chart.DashLine),"97.5%");
		c.yAxis().addZone(refRange[1], refRange[2], GraphColourMap.REFRANGE_OUTER);
		m4.setFontColor(0x000000);
		m4.setDrawOnTop(false);

	}
}
