/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.reservations.controllers;

import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.ParameterizableViewController;
import uk.ac.sanger.mig.mousetracking.MouseSearchBean;
import uk.ac.sanger.mig.mousetracking.services.MouseService;
import uk.ac.sanger.mig.mousetracking.views.MouseListView;
import uk.ac.sanger.mig.reservations.services.ReservationService;
import uk.ac.sanger.mig.reservations.Reservation;
import uk.ac.sanger.mig.common.services.ComponentMapService;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.Collection;
import java.util.LinkedList;
import java.util.Map;
import java.util.HashMap;

public class UpdateSuccessController extends ParameterizableViewController {

    private MouseService mouseService;
    private ReservationService reservationService;
    private ComponentMapService componentMapService;

    @Override
    protected ModelAndView handleRequestInternal(HttpServletRequest request,
                                                 HttpServletResponse response) throws Exception {
        Collection<MouseListView> mice = new LinkedList<MouseListView>();

        long[] ids = ServletRequestUtils.getRequiredLongParameters(request, "mouseId");
        long reservationId = ServletRequestUtils.getLongParameter(request, "reservationId", 0);

        Map<String,Object> model = new HashMap<String,Object>();

        MouseSearchBean msb = new MouseSearchBean();
        msb.setPaginated(false);

        for (long id : ids) {
            msb.setId(id);
            mice.addAll(mouseService.search(msb));
        }

        Reservation reservation = null;
        if(reservationId != 0) {
            reservation = reservationService.fetchById(
                    reservationId, componentMapService.getComponentMap("reservation")
            );
        }

        model.put("mice",mice);
        model.put("reservation",reservation);

        return new ModelAndView(getViewName(), model);
    }


    public MouseService getMouseService() {
        return mouseService;
    }


    public void setMouseService(MouseService mouseService) {
        this.mouseService = mouseService;
    }


    public void setReservationService(ReservationService reservationService) {
        this.reservationService = reservationService;
    }


    public void setComponentMapService(ComponentMapService componentMapService) {
        this.componentMapService = componentMapService;
    }
}
