/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.reservations.dao;

import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;

import uk.ac.sanger.mig.mousetracking.services.MouseService;
import uk.ac.sanger.mig.reservations.MouseReservation;

public class MouseReservationDaoSpringImpl extends AbstractDaoSpringImpl<MouseReservation> implements
		MouseReservationDao {

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, MouseReservation mouseReservation) {
		sql.addLongParam(mouseReservation.getMouseId(), "MOUSE_ID");
		sql.addLongParam(mouseReservation.getReservationId(), "RESERVATION_ID");
		sql.addBooleanParam(mouseReservation.getNotificationSent(), "NOTIFICATION_SENT");
		sql.addDateParam(mouseReservation.getEditDate(), "EDIT_DATE");
		sql.addStringParam(mouseReservation.getEditedBy(), "EDITED_BY");
		sql.addDateParam(mouseReservation.getCreatedDate(), "CREATED_DATE");
		sql.addLongParam(mouseReservation.getCreatorId(), "CREATOR_ID");
		sql.addLongParam(mouseReservation.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(mouseReservation.getId(), "ID");
	}


	public Collection<MouseReservation> fetchByReservation(Long reservationId) {
		String sql = "select * from " + getTableName() + " where reservation_id = ?";
		return fetchCollection(sql, reservationId);
	}


	public MouseReservation fetchForMouse(Long mouseId) {
		String sql = "select * from " + getTableName() + " where mouse_id = ?";
		return fetchOne(sql, mouseId);
	}


	public Collection<MouseReservation> fetchForDeathNotification() {
		String sql = "select mr.* from res_reservation r"
				+ " join res_mouse_reservation mr on r.id = mr.reservation_id"
				+ " join mts_mouse m on mr.mouse_id = m.id"
				+ " join per_person p on r.reserver_id = p.person_id"
				+ " where r.notify = 1"
				+ " and mr.notification_sent = 0"
				+ " and m.death_date is not null"
				+ " and m.cause_of_death_dict_id not in (?,?)";

		return fetchCollection(sql,MouseService.CAUSE_OF_DEATH_CULLED,MouseService.CAUSE_OF_DEATH_TO_CULL);
	}

}