/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.reservations.dao;

import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;

import uk.ac.sanger.mig.reservations.Purpose;

public class PurposeDaoSpringImpl extends AbstractDaoSpringImpl<Purpose> implements PurposeDao {



	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, Purpose purpose) {
		sql.addStringParam(purpose.getName(), "NAME");
		sql.addLongParam(purpose.getCategoryId(), "CATEGORY_ID");
		sql.addDateParam(purpose.getEditDate(), "EDIT_DATE");
		sql.addStringParam(purpose.getEditedBy(), "EDITED_BY");
		sql.addDateParam(purpose.getCreatedDate(), "CREATED_DATE");
		sql.addLongParam(purpose.getCreatorId(), "CREATOR_ID");
		sql.addLongParam(purpose.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(purpose.getId(), "ID");
	}

  public Collection<Purpose> fetchByCategory(Long categoryId) {
    String sql = "select * from res_purpose where category_id = ? order by lower(name)";
    return fetchCollection(sql, categoryId);
  }
  public Collection<Purpose> fetchAll() {
    String sql = "select * from res_purpose order by lower(name)";
    return fetchCollection(sql);
  }

}