/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.reservations.dao;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;

import uk.ac.sanger.mig.reservations.Reservation;

public class ReservationDaoSpringImpl extends AbstractDaoSpringImpl<Reservation> implements ReservationDao {

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, Reservation reservation) {
		sql.addLongParam(reservation.getPurposeId(), "PURPOSE_ID");
		sql.addLongParam(reservation.getReserverId(), "RESERVER_ID");
		sql.addLongParam(reservation.getTeamId(), "TEAM_ID");
		sql.addBooleanParam(reservation.isNotify(), "NOTIFY");
		sql.addDateParam(reservation.getEditDate(), "EDIT_DATE");
		sql.addStringParam(reservation.getEditedBy(), "EDITED_BY");
		sql.addDateParam(reservation.getCreatedDate(), "CREATED_DATE");
		sql.addLongParam(reservation.getCreatorId(), "CREATOR_ID");
		sql.addLongParam(reservation.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(reservation.getId(), "ID");
	}


	/**
	 * Finds the reservation associated with the passed mouse id, or null if no reservation exists.
	 *
	 * @param mouseId -
	 *            the id of the mouse to find a reservation for.
	 * @return reservation - the found reservation or null if nothing found.
	 */
	public Reservation fetchForMouse(Long mouseId) {
		String sql = "select r.* from res_reservation r" + " join res_mouse_reservation mr on r.id = mr.reservation_id"
				+ " where mr.mouse_id = ?";
		return fetchOne(sql, mouseId);
	}
}