/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.reservations.services;

import java.util.Collection;

import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.reservations.MouseReservation;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.services.CommonServices;

public interface MouseReservationService extends CommonServices<MouseReservation>{
  public MouseReservation fetchForMouse(Long mouseId,ComponentMap componentMap);
  public Collection<MouseReservation> fetchByReservation(Long reservationId,ComponentMap componentMap);

  /**
   * Delete the mouse reservation record.
   * After using this you should use ReservationService.deleteReservationIfEmpty
   * to ensure that we don't have redundant records.
   * @see ReservationService.deleteReservationIfEmpty
   * @param mouseReservation
   * @param user
   */
  public void delete(MouseReservation mouseReservation, Person user);
  public void sendAlertEmails(Person user);

  /**
   * Remove the mice listed from any reservation
   * @param mouseIds
   * @param user
   */
  public void deleteReservationForMice(Collection<Long> mouseIds, Person user);


}