/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.tecniplast;

import java.util.Collection;

import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.ComponentEnum;
import uk.ac.sanger.mig.common.LookupListElement;
import uk.ac.sanger.mig.common.LookupListUtil;
import uk.ac.sanger.mig.mousetracking.BarcodedObject;
import uk.ac.sanger.mig.mousetracking.Rack;


public class AirHandlingUnit extends AuthenticatedDataObject implements LookupListElement, BarcodedObject  {

	public enum Component implements ComponentEnum {
		ALL_COMPONENTS,
		RACKS
	}

    private String name;
    private String radioAddress;
    private Long roomId;
    private Collection<Rack> racks;

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Long getRoomId() {
        return roomId;
    }

    public void setRoomId(Long roomId) {
        this.roomId = roomId;
    }

	public String getRadioAddress() {
		return radioAddress;
	}

	public void setRadioAddress(String radioAddress) {
		this.radioAddress = radioAddress;
	}


	public Collection<Rack> getRacks() {
		return racks;
	}

	public void setRacks(Collection<Rack> racks) {
		this.racks = racks;
	}

	public String getDisplayText() {
		return name;
	}

	public String getElementData() {
		return
		LookupListUtil.format("airHandlingUnitId", getId()) +
		LookupListUtil.format("airHandlingUnitName", getName());
	}

	public void setDisplayText(String displayText) {
		// TODO Auto-generated method stub

	}

	public void setElementData(String elementData) {
		// TODO Auto-generated method stub

	}

	public String getBarcode() {
		return getName();
	}

	public String getBarcodeDescription() {
		return getDisplayText();
	}

	public BarcodeType getBarcodeType() {
		return BarcodeType.AHU;
	}

	public void generateBarcode() {
		// implementation is not applicable (AHUs don't really have barcodes)
	}
}