/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.tecniplast.dao;

import java.util.Collection;
import java.util.Date;

import uk.ac.sanger.mig.charting.ChartData;
import uk.ac.sanger.mig.database.TypedDao;
import uk.ac.sanger.mig.tecniplast.AhuMeasurement;
import uk.ac.sanger.mig.tecniplast.AhuMeasurementSearchBean;
																
	/**
	 * Takes search bean and returns a Collection of AhuMeasurement OBJECTS
	 * based on set fields in bean *and* (THIS IS IMPORTANT) your implementation
	 * of search method in Dao layer -- eg, are you testing for equality? 
	 * Greater than/less than, etc?
	 * @param ahuMeasurementSearchBean
	 * @return
	 */
	 
	public interface AhuMeasurementDao extends TypedDao<AhuMeasurement> {
		
	/**
	 * Return the set of AirHandlingUnit data measuements that confrom to the criteria specified
	 * in the search bean.
	 * 
	 * @param ahuMeasurementSearchBean
	 * @return
	 */
	public Collection<AhuMeasurement> search(AhuMeasurementSearchBean ahuMeasurementSearchBean);

	/**
	 * Get the last Date (as a date and time) when we have a recorded measurement for the Air Handling Unit
	 * identified by the supplied AirHandlingUnit identifier.
	 * 
	 * @param id
	 * @return
	 */
	public Date getLastCollectionDateByAhuId(Long id);
	
	/** fetch data for chart director package */
	public ChartData fetchChartData(AhuMeasurementSearchBean ahuMeasurementSearchBean);
	
}