/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.tecniplast.dao;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Date;

import org.springframework.dao.EmptyResultDataAccessException;

import uk.ac.sanger.mig.charting.ChartData;
import uk.ac.sanger.mig.charting.DatabaseChartData;
import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.common.PaginatedSearchUtils;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.tecniplast.AhuMeasurement;
import uk.ac.sanger.mig.tecniplast.AhuMeasurementSearchBean;

public class AhuMeasurementDaoSpringImpl extends AbstractDaoSpringImpl<AhuMeasurement> implements AhuMeasurementDao {

	private PaginatedSearchUtils<AhuMeasurement> paginator;

	public void setPaginator(PaginatedSearchUtils<AhuMeasurement> paginator) {
		this.paginator = paginator;
	}

	@Override
	protected Long insert(AhuMeasurement ahuMeasurement) {
		ahuMeasurement.setId(getPk());
		ParameterizedSqlUpdate sql = new ParameterizedSqlUpdate(getJdbcTemplate());
		bindVariables(sql,ahuMeasurement);
		sql.executeInsert(getTableName());
		return ahuMeasurement.getId();
	}

	@Override
	protected Long update(AhuMeasurement ahuMeasurement) {
		ParameterizedSqlUpdate sql = new ParameterizedSqlUpdate(getJdbcTemplate());
		bindVariables(sql,ahuMeasurement);
		sql.executeUpdate(getTableName());
		return ahuMeasurement.getId();
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, AhuMeasurement ahuMeasurement) {
		sql.addLongParam(ahuMeasurement.getAirHandlingUnitId(), "AIR_HANDLING_UNIT_ID");
		sql.addDateParam(ahuMeasurement.getCollectionDate(), "COLLECTION_DATE");
		sql.addIntParam(ahuMeasurement.getTemperature(), "TEMPERATURE");
		sql.addIntParam(ahuMeasurement.getRelativeHumidity(), "RELATIVE_HUMIDITY");
		sql.addIntParam(ahuMeasurement.getAirChangesPerHour(), "AIR_CHANGES_PER_HOUR");
		sql.addIntParam(ahuMeasurement.getRelativePressure(), "RELATIVE_PRESSURE");
		sql.addIntParam(ahuMeasurement.getErrorCode(), "ERROR_CODE");
		sql.addLongParam(ahuMeasurement.getCheckNumber(), "CHECK_NUMBER");
		sql.addStringParam(ahuMeasurement.getEditedBy(), "EDITED_BY");
		sql.addDateParam(ahuMeasurement.getEditDate(), "EDIT_DATE");
		sql.addDateParam(ahuMeasurement.getCreatedDate(), "CREATED_DATE");
		sql.addLongParam(ahuMeasurement.getId(), "ID");
	}

	public ChartData fetchChartData(AhuMeasurementSearchBean ahuMeasurementSearchBean) {

		Collection<Object> bindVariables = new ArrayList<Object>();

		String selectSql = "select a.collection_date label, a.temperature data0, a.relative_humidity data1, a.air_changes_per_hour data2, a.relative_pressure data3 ";
		String fromSql = " from " + getTableName() + " a ";

		String whereSql = " where 1=1 ";

		if (ahuMeasurementSearchBean.getAirHandlingUnitId() != null) {
			whereSql += " and a.AIR_HANDLING_UNIT_ID = ? ";
			bindVariables.add(ahuMeasurementSearchBean.getAirHandlingUnitId());
		}

		if (ahuMeasurementSearchBean.getMeasurementDateFrom() != null) {
			whereSql += " and trunc(a.collection_date) >= ? ";
			bindVariables.add(defaultDateFormat.format(ahuMeasurementSearchBean.getMeasurementDateFrom()));
		}

		if (ahuMeasurementSearchBean.getMeasurementDateTo() != null) {
			whereSql += " and trunc(a.collection_date) <= ? ";
			bindVariables.add(defaultDateFormat.format(ahuMeasurementSearchBean.getMeasurementDateTo()));
		}

		String orderBySql = "order by collection_date";

		String sql = selectSql + fromSql + whereSql + orderBySql;

		DatabaseChartData data = new DatabaseChartData(4);

		getJdbcTemplate().query(sql, bindVariables.toArray(),data);

		if(data.getLabels().length == 0) {
			return null;
		}else {
		 return data;
		}
	}


	/* (non-Javadoc)
	 * @see uk.ac.sanger.mig.tecniplast.dao.AhuMeasurementDao#search(uk.ac.sanger.mig.tecniplast.AhuMeasurementSearchBean)
	 */
	public Collection<AhuMeasurement> search(AhuMeasurementSearchBean ahuMeasurementSearchBean) {
		Collection<Object> bindVariables = new ArrayList<Object>();

		String selectSql = "select a.* ";
		String fromSql = " from " + getTableName() + " a ";

		String whereSql = " where 1=1 ";

		if (ahuMeasurementSearchBean.getAirHandlingUnitId() != null) {
			whereSql += " and a.AIR_HANDLING_UNIT_ID = ? ";
			bindVariables.add(ahuMeasurementSearchBean.getAirHandlingUnitId());
		}

		if (ahuMeasurementSearchBean.getMeasurementDateFrom() != null) {
			whereSql += " and a.collection_date >= ? ";
			bindVariables.add(defaultDateFormat.format(ahuMeasurementSearchBean.getMeasurementDateFrom()));
		}

		if (ahuMeasurementSearchBean.getMeasurementDateTo() != null) {
			whereSql += " and a.collection_date <= ? ";
			bindVariables.add(defaultDateFormat.format(ahuMeasurementSearchBean.getMeasurementDateTo()));
		}

		String orderBySql = "";

		if (ahuMeasurementSearchBean.getOrderBy() != null && ahuMeasurementSearchBean.getOrderBy().length() > 0) {
			orderBySql += " order by " + ahuMeasurementSearchBean.getOrderBy();
			if (ahuMeasurementSearchBean.isOrderDesc()) {
				orderBySql += " desc ";
			}
		}

		String sql = selectSql + fromSql + whereSql + orderBySql;

		for(Object obj : bindVariables) {
			logger.debug(obj);
		}
		logger.debug(sql);
		return paginator.fetchSearchResults(sql, bindVariables,
				ahuMeasurementSearchBean, getRowMapper());
	}

	/* (non-Javadoc)
	 * @see uk.ac.sanger.mig.tecniplast.dao.AhuMeasurementDao#getLastCollectionDateByAhuId(java.lang.Long)
	 */
	public Date getLastCollectionDateByAhuId(Long id) {
		String sql = " SELECT MAX(COLLECTION_DATE) FROM MTS_AIR_HANDLING_DATA WHERE AIR_HANDLING_UNIT_ID = ?";

		Date lastCollection = null;
		try {
			lastCollection = getSimpleJdbcTemplate().queryForObject(sql, Date.class, id);
		} catch(EmptyResultDataAccessException e){
			; // do nothing, will return a null by default.
		}

		return lastCollection;
	}

}