/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.tecniplast.dao;

import java.util.ArrayList;
import java.util.Collection;

import org.springframework.dao.EmptyResultDataAccessException;
import org.springframework.dao.IncorrectResultSizeDataAccessException;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.common.PaginatedSearchUtils;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.tecniplast.AirHandlingUnit;
import uk.ac.sanger.mig.tecniplast.AirHandlingUnitSearchBean;

public class AirHandlingUnitDaoSpringImpl extends AbstractDaoSpringImpl<AirHandlingUnit> implements AirHandlingUnitDao {

	private PaginatedSearchUtils<AirHandlingUnit> paginator;

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, AirHandlingUnit airHandlingUnit) {
		sql.addStringParam(airHandlingUnit.getName(), "NAME");
		sql.addStringParam(airHandlingUnit.getRadioAddress(), "RADIO_ADDRESS");
		sql.addLongParam(airHandlingUnit.getRoomId(), "ROOM_ID");
		sql.addLongParam(airHandlingUnit.getCheckNumber(), "CHECK_NUMBER");
		sql.addStringParam(airHandlingUnit.getEditedBy(), "EDITED_BY");
		sql.addDateParam(airHandlingUnit.getEditDate(), "EDIT_DATE");
		sql.addDateParam(airHandlingUnit.getCreatedDate(), "CREATED_DATE");
		sql.addLongParam(airHandlingUnit.getId(), "ID");
	}

	public AirHandlingUnit fetchByBarcode(String barcode) {
		String sql = " select * from mts_air_handling_unit where upper(name) = upper(?) or upper(radio_address) = upper(?) ";

		AirHandlingUnit airHandlingUnit = null;
		try {
			airHandlingUnit = getSimpleJdbcTemplate().queryForObject(sql, getRowMapper(), barcode, barcode);
		}
		catch(IncorrectResultSizeDataAccessException e) {

		}

		return airHandlingUnit;
	}


	/* (non-Javadoc)
	 * @see uk.ac.sanger.mig.tecniplast.dao.AirHandlingUnitDao#search(uk.ac.sanger.mig.tecniplast.AirHandlingUnitSearchBean)
	 */
	public Collection<AirHandlingUnit> search(AirHandlingUnitSearchBean airHandlingUnitSearchBean) {
		Collection<Object> bindVariables = new ArrayList<Object>();

		String selectSql = "select ahu.* ";
		String fromSql = " from " + getTableName() + " ahu ";

		String whereSql = " where 1=1 ";

		if (airHandlingUnitSearchBean.getCreatedDateFrom() != null) {
			whereSql += " and ahu.created_date >= ? ";
			bindVariables.add(defaultDateFormat.format(airHandlingUnitSearchBean.getCreatedDateFrom()));
		}

		if (airHandlingUnitSearchBean.getCreatedDateTo() != null) {
			whereSql += " and ahu.created_date <= ? ";
			bindVariables.add(defaultDateFormat.format(airHandlingUnitSearchBean.getCreatedDateTo()));
		}

		if (airHandlingUnitSearchBean.getName() != null) {
			whereSql += " and ahu.name = ? ";
			bindVariables.add(airHandlingUnitSearchBean.getName());
		}

		if (airHandlingUnitSearchBean.getRadioAddress() != null) {
			whereSql += " and ahu.radio_address = ? ";
			bindVariables.add(airHandlingUnitSearchBean.getName());
		}

		if (airHandlingUnitSearchBean.getSerialNumber() != null) {
			whereSql += " and ahu.serial_number <= ? ";
			bindVariables.add(airHandlingUnitSearchBean.getSerialNumber());
		}

		String orderBySql = "";

		if (airHandlingUnitSearchBean.getOrderBy() != null && airHandlingUnitSearchBean.getOrderBy().length() > 0) {
			orderBySql += " order by " + airHandlingUnitSearchBean.getOrderBy();
			if (airHandlingUnitSearchBean.isOrderDesc()) {
				orderBySql += " desc ";
			}
		}

		String sql = selectSql + fromSql + whereSql + orderBySql;

		return paginator.fetchSearchResults(sql, bindVariables,
				airHandlingUnitSearchBean, getRowMapper());
	}

	/* (non-Javadoc)
	 * @see uk.ac.sanger.mig.tecniplast.dao.AirHandlingUnitDao#fetchBySerialNumber(java.lang.String)
	 */
	public AirHandlingUnit fetchByRadioAddress(String radioAddress) {
		String sql = " SELECT * FROM MTS_AIR_HANDLING_UNIT WHERE RADIO_ADDRESS = ?";

		AirHandlingUnit ahu = null;
		try {
			ahu = getSimpleJdbcTemplate().queryForObject(sql, getRowMapper(), radioAddress);
		} catch(EmptyResultDataAccessException e){
			; // do nothing, will return a null by default.
		}

		return ahu;
	}

	/* (non-Javadoc)
	 * @see uk.ac.sanger.mig.tecniplast.dao.AirHandlingUnitDao#fetchByRoomId(Long)
	 */
	public Collection<AirHandlingUnit> fetchByRoomId(Long roomId) {
		String sql = "select a.* from mts_air_handling_unit a where a.room_id = ? order by (select min(r.name) from mts_rack r where r.air_handling_unit_id = a.id)";
		Collection<AirHandlingUnit> units = getSimpleJdbcTemplate().query(sql, getRowMapper(), roomId);
		return (units == null) ? new ArrayList<AirHandlingUnit>() : units;
	}


}