/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.tecniplast.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.tecniplast.AhuMeasurement;

public class AhuMeasurementRowMapper implements ParameterizedRowMapper<AhuMeasurement> {

	public AhuMeasurement mapRow(ResultSet rs, int rowNum) throws SQLException {
		
		AhuMeasurement ahuMeasurement = new AhuMeasurement();
		
		ahuMeasurement.setId(rs.getLong("ID"));
		ahuMeasurement.setAirHandlingUnitId(rs.getLong("AIR_HANDLING_UNIT_ID"));
		if(rs.wasNull()) ahuMeasurement.setAirHandlingUnitId(null);		
		ahuMeasurement.setCollectionDate(rs.getTimestamp("COLLECTION_DATE"));
		ahuMeasurement.setTemperature(rs.getInt("TEMPERATURE"));
		ahuMeasurement.setRelativeHumidity(rs.getInt("RELATIVE_HUMIDITY"));
		ahuMeasurement.setAirChangesPerHour(rs.getInt("AIR_CHANGES_PER_HOUR"));
		ahuMeasurement.setRelativePressure(rs.getInt("RELATIVE_PRESSURE"));
		ahuMeasurement.setErrorCode(rs.getInt("ERROR_CODE"));
		ahuMeasurement.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) ahuMeasurement.setCheckNumber(null);		
		ahuMeasurement.setEditedBy(rs.getString("EDITED_BY"));
		ahuMeasurement.setEditDate(rs.getDate("EDIT_DATE"));
		ahuMeasurement.setCreatedDate(rs.getDate("CREATED_DATE"));
		
		return ahuMeasurement;
		
	}
}