/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.tecniplast.services;

import java.util.Collection;
import java.util.Date;

import uk.ac.sanger.mig.charting.ChartData;
import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.tecniplast.AhuMeasurement;
import uk.ac.sanger.mig.tecniplast.AhuMeasurementSearchBean;
import uk.ac.sanger.mig.tecniplast.dao.AhuMeasurementDao;

public class AhuMeasurementServiceImpl extends AbstractServiceImpl<AhuMeasurement> implements AhuMeasurementService {
	
	private AhuMeasurementDao ahuMeasurementDao;
	
	//IMPORTANT: add other dependencies here: Should be other services *not* dao typically
	/**
	 * eg 	private AhuMeasurementDao ahuMeasurementDao;
	 *    private MouseService mouseService
	 *    private PersonService personService; 
	 */
	
	public void setAhuMeasurementDao(AhuMeasurementDao ahuMeasurementDao) {
		this.ahuMeasurementDao = ahuMeasurementDao;
	}


	public Long store(AhuMeasurement ahuMeasurement, Person user) {
		if(ahuMeasurement == null) {
			throw new RuntimeException("Cannot save a null ahuMeasurement");
		}
		
		return ahuMeasurementDao.store(ahuMeasurement, user);
	}
	
	public AhuMeasurement fetchById(Long ahuMeasurementId, ComponentMap requiredComponents) {
		AhuMeasurement ahuMeasurement = ahuMeasurementDao.fetchById(ahuMeasurementId);
		
		if(ahuMeasurement != null)
			attachComponents(ahuMeasurement, requiredComponents);
		
		return ahuMeasurement;
	}

	@Override
	protected void attachComponents(AhuMeasurement ahuMeasurement, ComponentMap requiredComponents) {
		if(ahuMeasurement == null) {
			throw new RuntimeException("Cannot attach components to null ahuMeasurement");
		}
	}


	/* (non-Javadoc)
	 * @see uk.ac.sanger.mig.tecniplast.services.AhuMeasurementService#getLastCollectionDateByAhuId(java.lang.Long)
	 */
	public Date getLastCollectionDateByAhuId(Long id) {
		return ahuMeasurementDao.getLastCollectionDateByAhuId(id);
	}


	/* (non-Javadoc)
	 * @see uk.ac.sanger.mig.tecniplast.services.AhuMeasurementService#search(uk.ac.sanger.mig.tecniplast.AhuMeasurementSearchBean)
	 */
	public Collection<AhuMeasurement> search(AhuMeasurementSearchBean bean) {
		return ahuMeasurementDao.search(bean);
	}
	
	public ChartData fetchChartData(AhuMeasurementSearchBean ahuMeasurementSearchBean) {
		return ahuMeasurementDao.fetchChartData(ahuMeasurementSearchBean);
	}
	
}
								