/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.tecniplast.services;

import java.util.Collection;
import java.util.Date;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.mousetracking.Rack;
import uk.ac.sanger.mig.mousetracking.Room;
import uk.ac.sanger.mig.mousetracking.services.RackService;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.tecniplast.AirHandlingUnit;
import uk.ac.sanger.mig.tecniplast.dao.AirHandlingUnitDao;

public class AirHandlingUnitServiceImpl extends AbstractServiceImpl<AirHandlingUnit> implements AirHandlingUnitService {

	private AirHandlingUnitDao airHandlingUnitDao;

	private AhuMeasurementService ahuMeasurementService;
	private RackService rackService;

	public void setAhuMeasurementService(AhuMeasurementService ahuMeasurementService) {
		this.ahuMeasurementService = ahuMeasurementService;
	}

	public void setAirHandlingUnitDao(AirHandlingUnitDao airHandlingUnitDao) {
		this.airHandlingUnitDao = airHandlingUnitDao;
	}

	public void setRackService(RackService rackService) {
		this.rackService = rackService;
	}

	public AirHandlingUnit fetchByBarcode(String barcode, ComponentMap componentMap) {
		AirHandlingUnit airHandlingUnit = airHandlingUnitDao.fetchByBarcode(barcode);

		if(airHandlingUnit != null) {
			attachComponents(airHandlingUnit, componentMap);
		}

		return airHandlingUnit;
	}

	public Long store(AirHandlingUnit airHandlingUnit, Person user) {
		if(airHandlingUnit == null) {
			throw new RuntimeException("Cannot save a null airHandlingUnit");
		}

		return airHandlingUnitDao.store(airHandlingUnit, user);
	}

	public AirHandlingUnit fetchById(Long airHandlingUnitId, ComponentMap requiredComponents) {
		AirHandlingUnit airHandlingUnit = airHandlingUnitDao.fetchById(airHandlingUnitId);

		if(airHandlingUnit != null)
			attachComponents(airHandlingUnit, requiredComponents);

		return airHandlingUnit;
	}

	@Override
	protected void attachComponents(AirHandlingUnit airHandlingUnit, ComponentMap requiredComponents) {
		if(airHandlingUnit == null) {
			throw new RuntimeException("Cannot attach components to null airHandlingUnit");
		}

		boolean fetchAll = false;

		if(requiredComponents != null) {

			if(requiredComponents.containsKey(AirHandlingUnit.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}

			if(fetchAll || requiredComponents.containsKey(AirHandlingUnit.Component.RACKS)) {
				airHandlingUnit.setRacks(fetchRacks(airHandlingUnit.getId(), requiredComponents.get(AirHandlingUnit.Component.RACKS)));
			}
		}
	}

	public Collection<Rack> fetchRacks(Long airHandlingUnitId, ComponentMap requiredComponents) {
		return rackService.fetchByAHUId(airHandlingUnitId, requiredComponents);
	}

	/* (non-Javadoc)
	 * @see uk.ac.sanger.mig.tecniplast.services.AirHandlingUnitService#fetchBySerialNumber(java.lang.String, uk.ac.sanger.mig.common.ComponentMap)
	 */
	public AirHandlingUnit fetchByRadioAddress(String radioAddress, ComponentMap componentMap) {
		AirHandlingUnit airHandlingUnit = airHandlingUnitDao.fetchByRadioAddress(radioAddress);

		if(airHandlingUnit != null)
			attachComponents(airHandlingUnit, componentMap);

		return airHandlingUnit;
	}


	/* (non-Javadoc)
	 * @see uk.ac.sanger.mig.tecniplast.services.AirHandlingUnitService#getLastCollectionDateByAhuId(java.lang.Long)
	 */
	public Date getLastCollectionDateByAhuId(Long id) {
		return ahuMeasurementService.getLastCollectionDateByAhuId(id);
	}

	public Collection<AirHandlingUnit> fetchByRoomId(Long roomId, ComponentMap requiredComponents) {
		Collection<AirHandlingUnit> units =  airHandlingUnitDao.fetchByRoomId(roomId);

		attachComponents(units, requiredComponents);

		return units;

	}

}
