/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.tecniplast.views;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;

import uk.ac.sanger.mig.charting.ChartData;
import ChartDirector.Axis;
import ChartDirector.Chart;
import ChartDirector.SplineLayer;
import ChartDirector.XYChart;

public class AHUChart extends XYChart{


	public AHUChart(int width, int height, ChartData data) {
		super(width, height, 0xeeeeff, 0x000000, 1);

		this.setRoundedFrame();


		this.setPlotArea(130, 70, 750, 400, this.linearGradientColor(0, 55, 0, 335, 0xf9fcff,
				0xaaccff),-1, -1, 0xcccccc, 0xcccccc);

//		Add a legend box at (250, 30) (top of the chart) with horizontal layout. Use 9 pts
//		Arial Bold font. Set the background and border color to Transparent.
		this.addLegend(250, 30, false, "Arial Bold", 9).setBackground(Chart.Transparent);


//		Add a title on top of the primary (left) y axis.
		this.yAxis().setTitle("Temp oC").setAlignment(Chart.TopLeft2);
//		Set the axis, label and title colors for the primary y axis to red (ff0000) to
//		match the first data set
		this.yAxis().setColors(0xff0000, 0xff0000, 0xff0000);
		
		
//		Add a title on top of the secondary (right) y axis.
		this.yAxis2().setTitle("Humidity").setAlignment(Chart.TopRight2);
//		Set the axis, label and title colors for the secondary y axis to green (00cc00)
//		to match the second data set
		this.yAxis2().setColors(0x00cc00, 0x00cc00, 0x00cc00);
		
//		Add the third y-axis at 50 pixels to the left of the plot area
		Axis leftAxis = this.addAxis(Chart.Left, 50);
//		Add a title on top of the third y axis.
		leftAxis.setTitle("Air Changes \nper Hour").setAlignment(Chart.TopLeft2);
//		Set the axis, label and title colors for the third y axis to blue (0000ff) to
//		match the third data set
		leftAxis.setColors(0x0000ff, 0x0000ff, 0x0000ff);
		
//		Add the fouth y-axis at 50 pixels to the right of the plot area
		Axis rightAxis = this.addAxis(Chart.Right, 50);
//		Add a title on top of the fourth y axis.
		rightAxis.setTitle("Relative\n Pressure").setAlignment(Chart.TopRight2);
//		Set the axis, label and title colors for the fourth y axis to black (0f0f0f) to
//		match the fourth data set
		rightAxis.setColors(0x0f0f0f, 0x0f0f0f, 0x0f0f0f);
	
// To use MultiFormat, the axis must be a date, parse the String[] to Date[]
		Date[] newLabels = parseLabelToDate(data.getLabels());
		this.xAxis().setLabels(newLabels);
		this.xAxis().setLabelStyle().setFontAngle(45.0); // andgled on 45 degrees
		if(data.getLabels().length > 10000) {	
			this.xAxis().setMultiFormat(Chart.StartOfMonthFilter(1,0.01), "<*font=bold*>{value|mmm}");
		}else{
			this.xAxis().setMultiFormat(Chart.StartOfDayFilter(1,0.01), "<*font=bold*>{value|mmm-dd}", Chart.AllPassFilter(), "<*font=small*>{value|hh:nn}");
		}
// work out the tick spacing.
		int tickSpace = data.getData(0).length / 50;
		this.xAxis().setLabelStep(tickSpace);
		
		
//		Add a title to the x axis
		this.xAxis().setTitle("Air Handling Unit Data Capture Date","Arial Bold", 9);


		SplineLayer layer1 = this.addSplineLayer();
		layer1.addDataSet(data.getData(0), 0xff0000, "Temperature");//.setDataSymbol(Chart.SquareSymbol);
		layer1.setLineWidth(1);
		
		//this.addSplineLayer(new ArrayMath(data.getData(0)).lowess().result(), 0xff0000).setLineWidth(2);

		SplineLayer layer2 = this.addSplineLayer();
		layer2.addDataSet(data.getData(1), 0x00cc00, "Relative Humidity");//.setDataSymbol(Chart.CircleSymbol);
		layer2.setLineWidth(1);
		layer2.setUseYAxis2();
	
		//this.addSplineLayer(new ArrayMath(data.getData(1)).lowess().result(), 0x00cc00).setLineWidth(2);

		SplineLayer layer3 = this.addSplineLayer();
		layer3.addDataSet(data.getData(2), 0x0000ff, "Air Changes Per Hour");//.setDataSymbol(Chart.DiamondSymbol);
		layer3.setLineWidth(1);
		layer3.setUseYAxis(leftAxis);
		
		//this.addSplineLayer(new ArrayMath(data.getData(2)).lowess().result(), 0x0000ff).setLineWidth(2);

		SplineLayer layer4 = this.addSplineLayer();
		layer4.addDataSet(data.getData(3), 0x0f0f0f, "Relative Pressure");//.setDataSymbol(Chart.TriangleSymbol);
		layer4.setLineWidth(1);
		layer4.setUseYAxis(rightAxis);
		
		//this.addSplineLayer(new ArrayMath(data.getData(3)).lowess().result(), 0x0f0f0f).setLineWidth(2);

		
	}

	// Translate the String[] into Date[] so that we can use xAxis date formats.
	private Date[] parseLabelToDate(String[] labels) {
		Date[] newLabels = new Date[labels.length];

		int i = 0;
		for(String label : labels) {
			try {
				newLabels[i++] = new SimpleDateFormat("yyyy-MM-dd hh:mm:ss").parse(label);
			} catch (ParseException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}

		return newLabels;
	}

//	Add a title box to the chart using 15 pts Times Bold Italic font, on a light blue
//	(CCCCFF) background with glass effect. 
	public void setTitle(String fromDate, String toDate) {
		this.addTitle("AHU Measurements "+fromDate+" - "+toDate, "Times New Roman Bold Italic", 15
		).setBackground(0xccccff, 0x000000, Chart.glassEffect());
	}


}
