package uk.ac.sanger.mig.testing;

import java.awt.Color;
import java.awt.Graphics;
import java.awt.Point;
import java.awt.Rectangle;
import java.awt.image.BufferedImage;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Iterator;

import javax.imageio.ImageIO;
import javax.imageio.ImageReadParam;
import javax.imageio.ImageReader;
import javax.imageio.stream.ImageInputStream;

import uk.ac.sanger.mig.histology.SweepScanException;


public class TestStreamStripJava2D {
	
	public static void main(String[] args) throws Exception {
		
		try {
			
			//System.out.println("Free mem:" + Runtime.getRuntime().freeMemory());
			
			int width = 5904, height = 4941, zoomRadix = 2, tileExponent = 8; 
			
			Long cropId = 137L;
			
			int tileEdge = (int)Math.pow(zoomRadix, tileExponent);
			
			int maxZoom = getMaxZoom( width, height, tileExponent, zoomRadix );
				
			File[] zoomDirs = initTempDirectories( maxZoom, cropId );
			
			Iterator<ImageReader> imageReaders = ImageIO.getImageReadersByFormatName("tif"); 
			
			ImageReader imageReader = imageReaders.next();
			
			ImageReadParam  imageReadParam = imageReader.getDefaultReadParam();
			
			File file = new File("c137.tif");
								
			int xTiles = getxTiles(width, tileEdge);
			int yTiles = getyTiles(height, tileEdge);
			
			System.out.println("xTiles" + xTiles);	
			System.out.println("yTiles" + yTiles);	
			
			for(int y = 0; y < yTiles; y++) {
				
				ImageInputStream iis = ImageIO.createImageInputStream( file );	
				
				imageReader.setInput( iis );

				//fetch strip 
				imageReadParam.setSourceRegion(new Rectangle(0,y*tileEdge,width,tileEdge));
				
				System.out.println("processing strip " + y);	
				
				BufferedImage img1 = imageReader.read(0, imageReadParam);  
				
				//grab and resize tiles
				for(int x = 0; x < xTiles; x++) {
					
					int tileWidth = tileEdge;
					int tileHeight = tileEdge;
					
					if( (x*tileEdge + tileEdge) > width ) { //handle x overflow
						tileWidth = width - x*tileEdge;
					}
					
					if( (y*tileEdge + tileEdge) > height ) { //handle y overflow
						tileHeight = height - y*tileEdge;
					}
					
					BufferedImage imgToRescale = img1.getSubimage(x*tileEdge, 0, tileWidth, tileHeight); 
						
					if(tileWidth < tileEdge || tileHeight < tileEdge) {
					//place under-sized tile in full tile sized image w/BG overflow	
						BufferedImage tile2 = new BufferedImage(tileEdge, tileEdge, BufferedImage.TYPE_INT_RGB);
						Graphics g = tile2.createGraphics();
						g.setColor(Color.BLACK);
						g.fillRect(0, 0, tileEdge, tileEdge);
						g.drawImage(imgToRescale, 0, 0, null);
						imgToRescale = tile2;
					}
							
					for(int z = 0; z <= maxZoom; z++) {
	
						TileCoordinate tc = mapImageDestination(x + y*xTiles, xTiles, (int)Math.pow(zoomRadix, z));
						
						ImageIO.write(imgToRescale, "jpg", new FileOutputStream( zoomDirs[ z ] +
							File.separator + tc +".jpg") );
						
						System.out.println("Zoom "+z+"," + tc);
						
						int scaledTileEdge = (int)(tileEdge/(Math.pow(zoomRadix, z)));
						
						BufferedImage resizedTile = new BufferedImage(scaledTileEdge, scaledTileEdge, BufferedImage.TYPE_INT_RGB);
						
						Graphics g = resizedTile.createGraphics();
						
						g.drawImage(imgToRescale, 0, 0, scaledTileEdge, scaledTileEdge, null);
							
						imgToRescale = resizedTile;
						
					}
					
				}

				iis.close();
				
				imageReader.dispose();
				
			}
						
			stitchAndStore(zoomDirs, maxZoom, width, height, zoomRadix, tileExponent);			
		
		} catch(Exception e) {e.printStackTrace();}
		
	}
	
	private static void stitchAndStore( File[] zoomDirs,  int maxZoom, int origWidth,
			int origHeight, int zoomRadix, int tileExponent ) throws IOException {
		
		buildZoomLevel(zoomDirs,  0, maxZoom, origWidth, origHeight, zoomRadix, tileExponent);
			
	}
	
	private static void buildZoomLevel(File[] zoomDirs, int zoomLevel, int maxZoom, 
			int resizedWidth, int resizedHeight,
			int zoomRadix, int tileExponent) throws IOException {
		
		if( zoomLevel < maxZoom ) {
					
			buildZoomLevel(zoomDirs, zoomLevel + 1, maxZoom, 
					(int) (resizedWidth  / zoomRadix ), 
					(int) (resizedHeight / zoomRadix ), 
					zoomRadix, tileExponent);
		}
		
		System.out.println("building tiles at zoom level " + zoomLevel);
		
		
		
		int tileEdge = (int)Math.pow( zoomRadix , tileExponent );
		
		int xTiles = getxTiles(resizedWidth, tileEdge);
		int yTiles = getyTiles(resizedHeight, tileEdge);
		
		for(int tileIndex = 0; tileIndex < xTiles * yTiles; tileIndex++  ) {
			
			BufferedImage tile = new BufferedImage(tileEdge, tileEdge, BufferedImage.TYPE_INT_RGB);
			Graphics g = tile.createGraphics();
			
			for(int y = 0; y < Math.pow(zoomRadix, zoomLevel); y++) {
				
				for(int x = 0; x < Math.pow(zoomRadix, zoomLevel); x++) {
					
					File file = new File(zoomDirs[zoomLevel] + File.separator + tileIndex + "_" + x + "_" + y + ".jpg");
					
					//System.out.println("reading file..." + file);
									
					if( file.exists() ) {
						
						BufferedImage img = ImageIO.read( file );  
						g.drawImage(img, x, y, null);
					}
					
				}
			}
			
			//store tile (tmp in same dir)
			ImageIO.write(tile, "jpg", new File(zoomDirs[zoomLevel] + File.separator + "tile_"+tileIndex+".jpg"));
		}		
		
	}
	
	private static byte[] getTileAsByteArray(BufferedImage bufferedImage) 
			throws SweepScanException {
		
		byte[] bytes = null;
		
		try {
	   
		    ByteArrayOutputStream output = new ByteArrayOutputStream();
		    
		    ImageIO.write(bufferedImage, "jpg" , output);
		    
		    bytes = output.toByteArray();
		    
		} catch(IOException e) {
			 
			throw new SweepScanException("IO problems flipping thumnail image: " + e );
		
		}	
	
		return bytes;
	}
	
	private static File[] initTempDirectories(int maxZoom, Long cropId) {
		
		File cropDir = new File( cropId+"" );
		if(!cropDir.exists()) cropDir.mkdir();
		
		File[] dirs = new File[ maxZoom + 1 ];
		
		for(int z = 0; z <= maxZoom; z++) {
			File dir = new File( cropDir + File.separator + Integer.toString( z ) );
			if( !dir.exists() )  dir.mkdir();
			dirs[ z ] = dir;
		}
		
		return dirs;
	}
	
	private static TileCoordinate mapImageDestination(int imageIndex, int xImages, int imagesPerTileEdge) {		
		
		int imgY = imageIndex / xImages;	
		
		int tileY = imgY / imagesPerTileEdge;
			
		int ySpillDownIntoTile = imgY - tileY * imagesPerTileEdge;
		
		int imgX = imageIndex - (imgY * xImages) ;
		
		int tileX = imgX / imagesPerTileEdge; 
		
		int xSpillRightIntoTile = imgX - tileX * imagesPerTileEdge;
		
		return new TileCoordinate(tileX + tileY*(int)Math.ceil(xImages/(double)imagesPerTileEdge), 
				new Point(xSpillRightIntoTile, ySpillDownIntoTile));
	}
	
	private static class TileCoordinate {
		
		private int index;
		private Point xy;
		
		private TileCoordinate(int index, Point xy) {
			
			this.index = index;
			this.xy = xy;
			
		}
		
		@Override
		public String toString() {
		
			return index + "_" + xy.x + "_" + xy.y;
		}
	}
	
	
	
	private static int getxTiles(int width, int tileEdge) {
		
		 return (int)Math.ceil( width / (double)tileEdge); 
		
	}
	
	private static int getyTiles(int height, int tileEdge) {
		
		 return (int)Math.ceil( height / (double)tileEdge);
		
	}
	
    public static int getMaxZoom(int cropWidth, int cropHeight, int tileExponent, int zoomRadix ) {
    	
    	if( cropWidth < 1 || cropHeight < 1 || tileExponent < 1 || zoomRadix < 1)
    		throw new IllegalArgumentException("One of cropWidth, cropHeight, tileExponent, zoomRadix is not > 0!");
    	
    	int tileEdge = (int)Math.pow(zoomRadix, tileExponent);
    	
    	int largerOfWxH = (cropWidth > cropHeight) ? cropWidth : cropHeight;
    	
    	//how many times must you multiply tile edge by radix to cover full image?
    	double log = Math.log( largerOfWxH / (double) tileEdge) / Math.log( zoomRadix );
    	
    	int maxZoom = (int)Math.ceil( log );
    	
    	int pixelDictatedLimit = tileExponent;
    	
    	return (int)Math.min(maxZoom, pixelDictatedLimit);
    }
	
}
