/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.testing.geneset.dao;

import java.text.SimpleDateFormat;
import java.util.Collection;
import java.util.Date;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.test.AbstractTransactionalSpringContextTests;

import uk.ac.sanger.mig.common.OperationNotSupported;
import uk.ac.sanger.mig.geneset.MigGeneSet;
import uk.ac.sanger.mig.geneset.MigGeneSetSearchBean;
import uk.ac.sanger.mig.geneset.dao.MigGeneSetDao;
import uk.ac.sanger.mig.geneset.views.MigGeneSetListView;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.personnel.dao.PersonDao;

public class GeneSetDaoSpringImplTest extends AbstractTransactionalSpringContextTests {
	
	private static final SimpleDateFormat simpleDateFormat = new SimpleDateFormat("dd-MMM-yyyy hh:mm:ss");

	public static final Log logger = LogFactory.getLog(GeneSetDaoSpringImplTest.class);

	private MigGeneSetDao geneSetDao;
	public void setMigGeneSetDaoSpringImpl(MigGeneSetDao miggenesetdaospringimpl) {
		this.geneSetDao = miggenesetdaospringimpl;
	}
	
	private PersonDao personDao;
	public void setPersonDao(PersonDao personDao) {
		this.personDao = personDao;
	}

	public void testSearch() {
		//TODO: add the body of your test
	}

	public void testFetchById() {

		MigGeneSet migGeneSet = new MigGeneSet();
		migGeneSet = geneSetDao.fetchById(121L);
		
		assertTrue(migGeneSet != null);
		logger.info("FetchById:" + migGeneSet);
	}

	/**
	 * Attempt to perform a full round-trip of a POJO. Create a new one, write it to the database and retrieve
	 * its contents using search.
	 *
	 */
	public void testStoreAuthenticated() {
		
		
		MigGeneSet miggeneset = new MigGeneSet();
		
		Date timestamp = new Date();
		
		miggeneset.setName("test-name");
		//miggeneset.setSize(0);
		miggeneset.setDescription("test-description");
		miggeneset.setEditDate(timestamp);
		miggeneset.setCreatorId(1L);
		miggeneset.setCreatedDate(timestamp);
		
		Long id = null;
		try {
			
			Person person = personDao.fetchById(1L);
			logger.info("Got Person:" + person.getFullName());
			
			miggeneset.setCreator(person);
			id = geneSetDao.store(miggeneset, person);

			MigGeneSetSearchBean searchBean = new MigGeneSetSearchBean();
			searchBean.setPaginated(false);
			searchBean.setName("test-name");
			//searchBean.setId(id);
			Collection<MigGeneSetListView> geneSets = null;//geneSetDao.search(searchBean);
			
			// We get a result back which matches by primary key.
			assertTrue(geneSets.size() == 1);
			MigGeneSetListView res = (MigGeneSetListView) geneSets.toArray()[0];
			
			assertTrue("test-name".equals(res.getName()));
			assertTrue(res.getGeneCount() == 0);
			assertTrue("test-description".equals(res.getDescription()));
			
			assertTrue(res.getCreatorId() == 1L);
			assertTrue(res.getCreatedDate() != null);
			
			String timestampStr = simpleDateFormat.format(timestamp);
			assertTrue(res.getEditDate() != null);
			assertTrue(timestampStr.equals(simpleDateFormat.format(res.getEditDate())));
			
			assertTrue(res.getCreatedDate() != null);
			assertTrue(timestampStr.equals(simpleDateFormat.format(res.getCreatedDate())));
			
			
			logger.info("StoreAtutenticated followed by FetchById:" + geneSets.toArray()[0]);
			
		} catch (OperationNotSupported e) {
			id = -1L;
		}

		assertTrue(id != null);
		logger.info("StoreAuthenticated:" + miggeneset);
	}

	public void testDelete() {
		//TODO: add the body of your test
	}

	protected String[] getConfigLocations() {
		return new String[] {
				"file:WebRoot/WEB-INF/conf/personnel.xml",
				"file:WebRoot/WEB-INF/conf/licensing.xml",
				"file:WebRoot/WEB-INF/conf/common.xml",
				"file:WebRoot/WEB-INF/conf/debug-database.xml",
				"file:WebRoot/WEB-INF/conf/mig-gene-set.xml" };
	}
}
