/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.tools;


import java.io.FileWriter;
import java.io.StringWriter;
import java.lang.reflect.Method;
import java.util.ArrayList;
import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.velocity.VelocityContext;
import org.apache.velocity.app.Velocity;

import uk.ac.sanger.mig.tools.classgenerator.Utils;

public class JunitGenerator {
	
	public static final Log logger = LogFactory.getLog(JunitGenerator.class);
	private String daoImplclassName;
	private String packageName;
	
	
	public String getDaoImplclassName() {
		return daoImplclassName;
	}

	public String getPackageName() {
		return packageName;
	}

	public String getImplInstance() {
		return Utils.toCamelCase(daoImplclassName, false);
	}
	
	public String getPojoInstance() {
		return Utils.toCamelCase(getPojoClassName(), false);
	}
	public String getPojoClassName(){
		return Utils.toPojo(daoImplclassName);
	}
	
	public String getPojoInstanceUpperCase() {
		
		String className = getPojoClassName();
		return Utils.allUpperCase(className);
	}
	
	public JunitGenerator(String className,String packageName) {
	
		// TODO Auto-generated constructor stub
		this.daoImplclassName = className;
		this.packageName = packageName;
	}
	
	
	/**
	 * @param args
	 */
	public static void main(String[] args) throws Exception {
		String daoImplClassName = args[0];//AuthorDaoSpringImp
		String packageName = args[1];//pubmedsorter
		
		//String daoImplClassName = "AuthorDaoSpringImpl";//AuthorDaoSpringImp
		//String packageName = "pubmedsorter";//pubmedsorter
		
		
		String outputFileName = "src/uk/ac/sanger/mig/testing/"+daoImplClassName+"Test.java";
		String template = "src/uk/ac/sanger/mig/tools/junitgenerator/Junit.vm";
		
		JunitGenerator generator = new JunitGenerator(daoImplClassName, packageName);
		String pojo = "uk.ac.sanger.mig."+generator.getPackageName()+"."+generator.getPojoClassName();
		String dao = "uk.ac.sanger.mig."+generator.getPackageName()+".dao."+generator.getPojoClassName()+"Dao";
			
		Class daoClass = Class.forName(dao);
		//Method[] methods = daoClass.getMethods();
		List<String> methodNames = new ArrayList<String>();
		for(int i=0; i< daoClass.getMethods().length; i++) {
			methodNames.add(Utils.startWithUpperCase(daoClass.getMethods()[i].getName()));
		}		
				
		Class pojoClass = Class.forName(pojo);
		Method[] pojoFields = pojoClass.getMethods();
		List<String> setMethods = new ArrayList<String>();
		
		for(int i = 0; i<pojoFields.length;i++){
			if(pojoFields[i].getName().substring(0,3).equals("set")){
				setMethods.add(pojoFields[i].getName());			
			}
		}
		
		Velocity.init();
		VelocityContext context = new VelocityContext();
		context.put("class",generator);
		context.put("methods",methodNames);
		context.put("setPojo",setMethods);
		
		StringWriter writer = new StringWriter();
		
		FileWriter output = new FileWriter(outputFileName);
		Velocity.mergeTemplate(template, "UTF-8", context, writer);
		output.write(writer.toString());
		output.close();
		logger.info("Output file for Junit test is: "+outputFileName);
	}


	
}
