/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.tools;

import java.text.SimpleDateFormat;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.ServletContext;
import javax.servlet.http.HttpSessionAttributeListener;
import javax.servlet.http.HttpSessionBindingEvent;
import javax.servlet.http.HttpSessionEvent;
import javax.servlet.http.HttpSessionListener;
import javax.sql.DataSource;

import org.springframework.context.ApplicationContext;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.web.context.support.WebApplicationContextUtils;

import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.personnel.Person;

public class SessionListener extends JdbcTemplate implements HttpSessionAttributeListener, HttpSessionListener {

	private final SimpleDateFormat sdf = new SimpleDateFormat("dd-MMM-yyyy HH:mm");

	private final String USER_BEAN = "user";
	private final String USER_LIST = "user_list";

	private boolean dataSourceLoaded = false;

	public void attributeAdded(HttpSessionBindingEvent be) {
		if(!dataSourceLoaded)
			loadDataSource(be);

		if(be.getName().equals(USER_BEAN) && be.getValue() != null) {

			Person user = (Person)be.getValue();
			Map<String, String> userList = getUserList(be.getSession().getServletContext());

			String sessionId = be.getSession().getId();
			userList.put(sessionId,getUserString(user));
			//userList.put(sessionId,getUserString(be.getValue()));
			//setUserList(be.getSession().getServletContext(),userList);

			try {
				String sql = "insert into per_user_log(user_name,person_name,event,log_date) values (?,?,'Logon',sysdate)";

				ParameterizedSqlUpdate insert = new ParameterizedSqlUpdate(this);
				insert.addStringParam(user.getUserName());
				insert.addStringParam(user.getFullName());
				insert.execute(sql);
			}
			catch(Exception e) {
				logger.warn("Failed to insert into per_user_log(logon): " + e);
			}
		}
	}

	@SuppressWarnings(value = "unchecked")
	public void attributeRemoved(HttpSessionBindingEvent be) {
		if(!dataSourceLoaded)
			loadDataSource(be);

		if(be.getName().equals(USER_BEAN)) {
			Person user = (Person)be.getValue();

			try {
				String sql = "insert into per_user_log(user_name,person_name,event,log_date) values (?,?,'Logoff',sysdate)";

				ParameterizedSqlUpdate insert = new ParameterizedSqlUpdate(this);
				insert.addStringParam(user.getUserName());
				insert.addStringParam(user.getFullName());
				insert.execute(sql);
			}
			catch(Exception e) {
				logger.warn("Failed to insert into per_user_log(logoff): " + e);
			}

			String sessionId = be.getSession().getId();

			try {
				String sql = "delete from app_user_searches where session_id = ?";

				ParameterizedSqlUpdate delete = new ParameterizedSqlUpdate(this);
				delete.addStringParam(sessionId);
				delete.execute(sql);
			}
			catch(Exception e) {
				logger.warn("Failed to delete from app_user_searches for session ID " + sessionId + ": " + e);
			}

			Map userList = getUserList(be.getSession().getServletContext());


			if(userList.containsKey(sessionId)) {
				userList.remove(sessionId);
			}
			setUserList(be.getSession().getServletContext(),userList);
		}
	}

	public void attributeReplaced(HttpSessionBindingEvent be) {

	}

	public void sessionCreated(HttpSessionEvent se) {

	}

	public void sessionDestroyed(HttpSessionEvent se) {
		Map userList = getUserList(se.getSession().getServletContext());

		String sessionId = se.getSession().getId();
		if(userList.containsKey(sessionId)) {
			userList.remove(sessionId);
		}
		//setUserList(se.getSession().getServletContext(),userList);
	}

	private void loadDataSource(HttpSessionBindingEvent be) {
		ApplicationContext springContext =
			WebApplicationContextUtils.getWebApplicationContext(be.getSession().getServletContext());

		setDataSource((DataSource)springContext.getBean("migDataSource"));
		dataSourceLoaded = true;
	}

	@SuppressWarnings(value = "unchecked")
	private Map<String, String> getUserList(ServletContext servletContext) {
		if(servletContext.getAttribute(USER_LIST) == null) {
			Map<String, String> map = new HashMap<String, String>();
			servletContext.setAttribute(USER_LIST,map);
		}
		return (Map<String, String>)servletContext.getAttribute(USER_LIST);
	}

	private void setUserList(ServletContext servletContext, Map<String, String> map) {
		servletContext.setAttribute(USER_LIST,map);
	}

	private String getUserString(Object userObject) {
		Person user = (Person)userObject;
		StringBuffer sb = new StringBuffer();
		sb.append("Login Time:");
		sb.append(sdf.format(new java.util.Date()));
		sb.append(" ");
		sb.append(user.getFullName());
		sb.append("(");
		sb.append(user.getUserName());
		sb.append(")");
		return sb.toString();
	}
}