/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.tools.classgenerator;

public class Column {
	
	private String name;
	private String type;
	private String sqlType;
	private String resultSetAccessor; // Which getter function to use
	private boolean foreignKey;
	
	public String getName() {
		return name;
	}
	public void setName(String name) {
		this.name = name;
	}
	public String getType() {
		return type;
	}
	public void setType(String type) {
		this.type = type;
	}	
	
	public String getUpperType()  {
		return Utils.toCamelCase(type, true);
	}
	
	public String getLowerType() {
		return Utils.toCamelCase(type, false);		
	}	
	
	public String getUpperName()  {
		return Utils.toCamelCase(name, true);
	}
	
	public String getLowerName() {
		return Utils.toCamelCase(name, false);		
	}
	
	public String getSqlType() {
		return sqlType;
	}
	
	public void setSqlType(String sqlType) {
		this.sqlType = sqlType;
	}
	
	public boolean isForeignKey() {
		return foreignKey;
	}
	
	public void setForeignKey(boolean foreignKey) {
		this.foreignKey = foreignKey;
	}
	
	/**
	 * Return the name of the result set getter function in camel case.
	 * @return
	 */
	public String getUpperResultSetAccessor() {
		return Utils.toCamelCase(resultSetAccessor, true);	
	}
	
	public String getResultSetAccessor() {
		return resultSetAccessor;
	}
	
	/**
	 * Set the name of the accessor method that should be used when fetching this column out of
	 * a result set. Typically this is the same as the Type but in the case of Date this could also be
	 * a Timestamp. The return value from this accessor must match the Type.
	 *  
	 * @param resultSetAccessor is the String representing the result set getter method that should be 
	 *     called to fetch the data from a result set.
	 */
	public void setResultSetAccessor(String resultSetAccessor) {
		this.resultSetAccessor = resultSetAccessor;
	}
	
}
