/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.tools.classgenerator;
import java.util.Collection;

public class Table {
	
	private String name;
	private String type;
	private Collection<Column> columns;
	private Column primaryKey;
	
	public Collection<Column> getColumns() {
		return columns;
	}
	
	public void setColumns(Collection<Column> columns) {
		this.columns = columns;
	}
	
	public boolean hasPrimaryKey() {
		return (primaryKey != null) ? true : false;
	}
	
	public String getName() {
		return name;
	}
	
	public String getLowerCaseName() {
		return name.toLowerCase();
	}	
	
	
	public void setName(String name) {
		this.name = name;
	}
	
	public Column getPrimaryKey() {
		return primaryKey;
	}
	
	public void setPrimaryKey(Column primaryKey) {
		this.primaryKey = primaryKey;
	}
	
	public String getType() {
		return type;
	}
	
	public void setType(String type) {
		this.type = type;
	}
	
	public boolean hasDateField() {
		for(Column column : this.getColumns()) {			
			if(column.getSqlType().equals("DATE")) {
				return true;
			}			
		}
		return false;
	}
	
	public boolean isColumnPk(String columnName) {		
		if(!hasPrimaryKey()) 
			return false;
		else		
			return (primaryKey.getName().equals(columnName));
	}
	
	public String insertStatement() throws Exception {		 
		
		if(!this.getType().equals("TABLE")) {
			throw new RuntimeException("Can only create INSERT statements for tables");
		}
		
		String sql = "insert into " + this.getName()  + "(";
		String bindVariables = "";
		
		for(Column column : this.getColumns()) {
			
			if(!this.isColumnPk(column.getName())) {
				sql += column.getName() +  ", ";
				bindVariables += "?, ";
			}
			
		}
		
		//add pk column to end of list
		if(this.hasPrimaryKey()) {
			sql += this.getPrimaryKey().getName();
			bindVariables += "?";
		}
		else {
			//remove trailing comma
			sql = sql.substring(0, sql.lastIndexOf(","));	
			bindVariables = bindVariables.substring(0,bindVariables.lastIndexOf(","));	
		}
		
		sql += ") values (" + bindVariables + ")";
		
		return sql;
	}	
	
	public String updateStatement() throws Exception {
		if(!this.getType().equals("TABLE")) {
			throw new RuntimeException("Can only create UPDATE statements for tables");
		}		
		else if(!this.hasPrimaryKey()) {
			throw new RuntimeException("Cannot create UPDATE statement without primary key");
		}
		
		String sql = "update " + this.getName() + " set ";

		for(Column column : this.getColumns()) {
			
			if(!this.isColumnPk(column.getName())) {
				sql += column.getName() +  "=?, ";
			}
		}

		//remove trailing comma
		sql = sql.substring(0, sql.lastIndexOf(","));
		
		sql += " where " + this.getPrimaryKey().getName() + "=?";
		
		return sql;
	}
	
}
