/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.tools.classgenerator;
import java.io.IOException;
import java.util.Collection;
import java.util.Properties;
import java.util.regex.Pattern;

import javax.sql.DataSource;

import org.springframework.core.io.ClassPathResource;
import org.springframework.core.io.support.PropertiesLoaderUtils;
import org.springframework.dao.IncorrectResultSizeDataAccessException;
import org.springframework.jdbc.core.simple.SimpleJdbcDaoSupport;
import org.springframework.jdbc.core.simple.SimpleJdbcTemplate;

public class Utils extends SimpleJdbcDaoSupport {
	
	private Properties sqlQueries;
	private SimpleJdbcTemplate template;
	
	public Utils(DataSource dataSource ) {
		
		template = new SimpleJdbcTemplate(dataSource);
		
		
		try  {
			sqlQueries = new Properties();
			PropertiesLoaderUtils.fillProperties(sqlQueries,new ClassPathResource("uk/ac/sanger/mig/tools/classgenerator/ClassGeneratorSql.properties"));
		}
		catch(IOException e) {
			throw new RuntimeException(e);
		}
		
		setDataSource(dataSource);
	}
		
	public static String toCamelCase(String inputName, boolean startWithUppercase) {
		
		boolean uppercase = startWithUppercase;
				
		String camelName = "";
		
		for (int i=0; i<inputName.length(); i++) {
			if(inputName.charAt(i) == '_') {
				uppercase = true;
			}
			else {
				if(uppercase)
					camelName += (inputName.substring(i,i+1).toUpperCase());
				else
					camelName += (inputName.substring(i,i+1).toLowerCase());
				uppercase = false;
			}
		}//for
		
		return camelName;
	}
	
	public static String startWithUpperCase(String inputString) {
		String returnString = inputString.substring(0, 1).toUpperCase();
		
		if(inputString.length() > 1) {		
			returnString +=inputString.substring(1);
		}
		
		return returnString;
	}
	
	public static String allUpperCase(String inputString) {
		String returnString = inputString.toUpperCase();
		
		return returnString;
	}
	
	public static String toPojo(String className) {
		
		String pojoName = "";
		// Create a pattern to match breaks
		Pattern p = Pattern.compile("Dao");
		// Split input with the pattern
		String[] result = p.split(className);
		pojoName = result[0];
		return pojoName;
	}

	public Table fetchTable(String tableName) throws Exception {
		
		Table table = 
			template.queryForObject(sqlQueries.getProperty("FETCH_TABLE"), new  DatabaseTableRowMapper(), tableName);
		
		table.setColumns(fetchColumns(tableName));
		table.setPrimaryKey(fetchPrimaryKey(tableName));
		
		return table;		
	}
	
	private Collection<Column> fetchColumns(String tableName) throws Exception {
		Collection<Column> columns = 
			template.query(
					sqlQueries.getProperty("FETCH_COLUMNS"), new  DatabaseColumnRowMapper(), tableName);	
		
		return columns;
	}
	
	private Column fetchPrimaryKey(String tableName) throws Exception {
		Column primaryKey;
		try {
			primaryKey = template.queryForObject(sqlQueries.getProperty("FETCH_PK"), new DatabaseColumnRowMapper(), tableName);
		}
		catch(IncorrectResultSizeDataAccessException e) {
			primaryKey  = null;
		}
		return primaryKey;
	}	
}
