/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.tools.datafix;

import java.io.File;
import java.util.Date;

import org.springframework.beans.factory.BeanFactory;
import org.springframework.context.support.ClassPathXmlApplicationContext;

import uk.ac.sanger.mig.histology.Crop;
import uk.ac.sanger.mig.histology.Scan;
import uk.ac.sanger.mig.histology.services.CropService;
import uk.ac.sanger.mig.histology.services.ScanService;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.personnel.services.PersonService;

public class BatchHistologyPathsUpdate {
	
	public static void main(String[] args) throws Exception {
		
		ClassPathXmlApplicationContext appContext =
			new ClassPathXmlApplicationContext(
					new String[] {
							"file:WebRoot"+File.separator+"WEB-INF"
							+File.separator+"conf"+File.separator+"application-context.xml"
					});

		BeanFactory factory = (BeanFactory)appContext;

		ScanService scanService = (ScanService)factory.getBean("scanService");
		CropService cropService = (CropService)factory.getBean("cropService");	
		PersonService personService = (PersonService)factory.getBean("personService");
		
		Person user = personService.fetchByUserName("ae1", null);
	
//getResizedImagePath=C:\nfs\mig_data\dmetrix_slides\viewable\ind_0\S000000179\scan166\crop98\resized\c98.jpg
		int recs = 0;
		
		for(Long pk = 5L; pk < 3755L; pk++) {
			
			Crop crop = cropService.fetchById(pk, null);
			
			if( crop == null ) continue;
			
			recs++;
			
			String NEW_VIEWABLE_ROOT = "/nfs/mig_data/dmi_viewable/prod";
			
			File newF1 = null;
			
			File f1 = crop.getFullImagePath();
			
			boolean updatingFullPath = false;
			
			if(f1 != null )  {
				String p1 = f1.toString();
				String[] s =  p1.split("viewable", 2);
				
				if(s != null && s.length == 2) {
					
					String suffix1 = s[1];
					newF1 = new File(NEW_VIEWABLE_ROOT + suffix1);
					System.out.println("Crop " + crop.getId() + " old full path: " + f1 );
					System.out.println("Crop " + crop.getId() + " new full path: " + newF1 );	
					crop.setFullImagePath( newF1 );
					updatingFullPath = true;
				}
			}
			
			File newF2 = null;
			
			File f2 = crop.getResizedImagePath();
			
			boolean updatingResizedPath = false;
			
			if( f2 != null )  {
				String p2 = f2.toString();
				String[] s =  p2.split("viewable", 2);
				
				if(s != null && s.length == 2) {

					String suffix2 = s[1];
					newF2 = new File(NEW_VIEWABLE_ROOT + suffix2);
					System.out.println("Crop " + crop.getId() + " old resized path: " + f2 );
					System.out.println("Crop " + crop.getId() + " new resized path: " + newF2 );	
					crop.setResizedImagePath( newF2 );
					updatingResizedPath = true;
				}
			}
			
			crop.setEditedBy( user.getUserName() );
			crop.setEditDate( new Date() );
			
			if(updatingResizedPath || updatingFullPath)
				cropService.store(crop, user);
		}

		System.out.println("Tot Crop Recs: " + recs); 
		
		/////////////////////////////////////now do scan paths
		String NEW_ARCHIVE_ROOT = "/nfs/mig_data/dmi_archive/prod";
		
		recs = 0;
		
		for(Long pk = 105L; pk < 1475L; pk++) {
		
			Scan scan = scanService.fetchById(pk, null);
			
			if(scan == null) continue;

			
			
			File newF3 = null;
			
			File f3 = scan.getDmiFilePath();
			
			if(f3 != null )  {
				String p3 = f3.toString();
				String[] s =  p3.split("dmi", 2);
				
				if(s != null && s.length == 2) {
					String suffix3 = s[1];
					newF3 = new File(NEW_ARCHIVE_ROOT + suffix3);
					System.out.println("Scan " + scan.getId() + " old archive path: " + f3 );
					System.out.println("Scan " + scan.getId() + " new archive path: " + newF3 );	
					
					scan.setEditedBy( user.getUserName() );
					scan.setEditDate( new Date() );
					scan.setDmiFilePath( newF3 );
					
					recs++;
					
					scanService.store(scan, user);
				}
			}				
		}
	
		System.out.println("Tot Scan Recs updated: " + recs); 
		
		appContext.close();
		
	}	
}
