/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.vector.intermediatevector.dao;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.PaginatedSearchUtils;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.vector.intermediatevector.IntermediateVector;
import uk.ac.sanger.mig.vector.intermediatevector.IntermediateVectorSearchBean;
import uk.ac.sanger.mig.vector.intermediatevector.dao.rowmappers.IntermediateVectorListViewRowMapper;
import uk.ac.sanger.mig.vector.intermediatevector.views.IntermediateVectorListView;

public class IntermediateVectorDaoSpringImpl extends AbstractDaoSpringImpl<IntermediateVector> implements IntermediateVectorDao {

  private PaginatedSearchUtils<IntermediateVectorListView> paginator;
  private IntermediateVectorListViewRowMapper intermediateVectorListViewRowMapper;
  
	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, IntermediateVector intermediateVector) {
		sql.addLongParam(intermediateVector.getDesignInstanceId(), "DESIGN_INSTANCE_ID");
		sql.addIntParam(intermediateVector.getLastQcStatus(), "LAST_QC_STATUS");
		sql.addDateParam(intermediateVector.getLastStatusChange(), "LAST_STATUS_CHANGE");
		sql.addIntParam(intermediateVector.getCassetteDict(), "CASSETTE_DICT");
		sql.addStringParam(intermediateVector.getUrlToAllele(), "URL_TO_ALLELE");
		sql.addLongParam(intermediateVector.getId(), "ID");
	}

  public Collection<IntermediateVectorListView> search(IntermediateVectorSearchBean searchBean, ComponentMap requiredComponents) {
    
    Collection<Object> bindVariables = new ArrayList<Object>();
    IntermediateVector intermediateVector = searchBean.getIntermediateVector();
    
    StringBuffer sqlSelect = new StringBuffer();
    StringBuffer sqlFrom = new StringBuffer();
    StringBuffer sqlWhere = new StringBuffer();
    StringBuffer sqlOrderBy = new StringBuffer();
    sqlSelect.append("select v.* ");
    sqlFrom.append(" from vec_intermediate_vec_list_vw v ");
    sqlWhere.append(" where 1=1 ");
   
    if(searchBean.getSearchString()!=null && 
        !searchBean.getSearchString().equals("") && !searchBean.getSearchBy().equals("") && !searchBean.getSearchString().contains("Please enter")
    ){
      if(searchBean.getSearchBy().equals("DESIGN_NAME")){
        sqlWhere.append(" and upper(v.design_name) = ? ");
        bindVariables.add(searchBean.getSearchString().toUpperCase());
      }
      if(searchBean.getSearchBy().equals("VEGA_ID")){
        sqlWhere.append(" and upper(v.vega_id) = ? ");
        bindVariables.add(searchBean.getSearchString().toUpperCase());
      }
      if(searchBean.getSearchBy().equals("GENE_NAME")){
        sqlWhere.append(" and upper(v.gene_name) =? ");
        bindVariables.add(searchBean.getSearchString().toUpperCase());
      }
      

    }
    else{

      
      //      search by source id
      if(intermediateVector.getAlleleRequest().getSource() != null 
          && intermediateVector.getAlleleRequest().getSource().getId() != null
          && intermediateVector.getAlleleRequest().getSource().getId() > 0) {
        sqlFrom.append(",arq_allele_request r ");
        sqlWhere.append(" and r.gene_id = v.id ");
        sqlWhere.append(" and r.request_source_dict_id = ? ");
        bindVariables.add(intermediateVector.getAlleleRequest().getSource().getId());
      }
      
      if(searchBean.getOrderBy() != null && !searchBean.getOrderBy().equals("")) {
        sqlOrderBy.append(" order by v." + searchBean.getOrderBy());
        if(searchBean.isOrderDesc()) {
          sqlOrderBy.append(" desc ");
        }
      }
    }
    
    String sql = sqlSelect.toString() + sqlFrom.toString() + sqlWhere.toString() + sqlOrderBy.toString();
     
    return paginator.fetchSearchResults(sql, bindVariables, searchBean, intermediateVectorListViewRowMapper);
    
  }

  public void setPaginator(
      PaginatedSearchUtils<IntermediateVectorListView> paginator) {
    this.paginator = paginator;
  }

  public void setIntermediateVectorListViewRowMapper(
      IntermediateVectorListViewRowMapper intermediateVectorListViewRowMapper) {
    this.intermediateVectorListViewRowMapper = intermediateVectorListViewRowMapper;
  }
	
}