/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.vector.intermediatevector.services;

import java.util.Collection;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.vector.intermediatevector.IntermediateVector;
import uk.ac.sanger.mig.vector.intermediatevector.IntermediateVectorSearchBean;
import uk.ac.sanger.mig.vector.intermediatevector.views.IntermediateVectorListView;
																
public interface IntermediateVectorService {
	
	/**
	 * Stores IntermediateVector as record in database and returns the record's primary key
	 * @param intermediateVector
	 * @return
	 */
	//public Long storeAuthenticated(IntermediateVector intermediateVector, Person person);	
	
	/**
	 * Returns intermediateVector for a given id that maps to primary key
	 * of a record in a database table.
	 * @param id
	 * @return
	 */
	public IntermediateVector fetchById(Long id, ComponentMap componentMap);
	
	
	/**
	 * Takes search bean and returns a Collection of IntermediateVector objects
	 * based on set fields in bean *and* (this is important) your implementation
	 * of search method in Dao layer -- eg, are you testing for equality? 
	 * Greater than/less than, etc?
	 * @param intermediateVectorSearchBean
	 * @return
	 */
	public Collection<IntermediateVectorListView> search(IntermediateVectorSearchBean intermediateVectorSearchBean, ComponentMap requiredComponents);
	
	//YOU CAN ALTERNATIVELY RETURN COLLECTION OF VIEW BEANS INSTEAD OF DOMAIN OBJECT POJO. 
	//THIS IS SUITABLE FOR "FLAT" OBJECTS HAVING MOSTSLY OR ALL JUST PRIMITIVES & STRINGS.
	//HOWEVER, FOR COMPLEX OBJECTS HAVING SEVERAL SUB-OBJECTS (MAYBE HAVING SUB-SUB OBJECTS AS WELL) 
	//USING A VIEW BEAN TO TEST FOR NULLS AND "FLATTEN" OBJECT INTO PRIMITIVES & STRINGS, OR A 
	//VIEW BEAN POPULATED BY A FLAT DATABASE VIEW, MIGHT BE MORE APPROIPRIATE.
	
}