/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.vector.intermediatevector.services;

import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.eucomm.designinstance.DesignInstance;
import uk.ac.sanger.mig.eucomm.designinstance.services.DesignInstanceService;
import uk.ac.sanger.mig.vector.intermediatevector.IntermediateVector;
import uk.ac.sanger.mig.vector.intermediatevector.IntermediateVectorSearchBean;
import uk.ac.sanger.mig.vector.intermediatevector.dao.IntermediateVectorDao;
import uk.ac.sanger.mig.vector.intermediatevector.views.IntermediateVectorListView;

public class IntermediateVectorServiceImpl extends AbstractServiceImpl<IntermediateVectorListView> implements IntermediateVectorService {
	
	private IntermediateVectorDao intermediateVectorDao;
  private DesignInstanceService designInstanceService;
	
	//IMPORTANT: add other dependencies here: Should be other services *not* dao typically
	/**
	 * eg 	private IntermediateVectorDao intermediateVectorDao;
	 *    private MouseService mouseService
	 *    private PersonService personService; 
	 */
	
	public void setIntermediateVectorDao(IntermediateVectorDao intermediateVectorDao) {
		this.intermediateVectorDao = intermediateVectorDao;
	}

	/*public Long storeAuthenticated(IntermediateVector intermediateVector, Person user) {
		if(intermediateVector == null) {
			throw new RuntimeException("Cannot save a null intermediateVector");
		}
		
		return intermediateVectorDao.storeAuthenticated(intermediateVector, user);
	}*/
	
  public DesignInstance fetchDesignInstance(Long designInstanceId, ComponentMap requiredComponents){
    
    if(designInstanceId != null) {
      return designInstanceService.fetchById(designInstanceId, requiredComponents);
    }
    else {
      return null;
    }   
    
  }
	@Override
	protected void attachComponents(IntermediateVectorListView intermediateVectorListView, ComponentMap requiredComponents) {
		if(intermediateVectorListView == null) {
			throw new RuntimeException("Cannot attach components to null intermediateVector");
		}		
		
		boolean fetchAll = false;
		
		if(requiredComponents != null) {
			
			if(requiredComponents.containsKey(IntermediateVector.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}
			if(fetchAll || requiredComponents.containsKey(IntermediateVector.Component.DESIGN_INSTANCES)){
        intermediateVectorListView.setDesignInstance(fetchDesignInstance(intermediateVectorListView.getDesignInstanceId(), requiredComponents.get(IntermediateVector.Component.DESIGN_INSTANCES)));
      }
      
			// query required components map and fetch/attach sub-components as needed
			// ...........
			
		}
	}


  public Collection<IntermediateVectorListView> search(IntermediateVectorSearchBean intermediateVectorSearchBean, ComponentMap requiredComponents) {
    Collection<IntermediateVectorListView> intermediateVectorsList = intermediateVectorDao.search(intermediateVectorSearchBean, requiredComponents);
    
    attachComponents(intermediateVectorsList, requiredComponents);
    
    return intermediateVectorsList;
  }


  public void setDesignInstanceService(DesignInstanceService designInstanceService) {
    this.designInstanceService = designInstanceService;
  }


  public IntermediateVector fetchById(Long id, ComponentMap componentMap) {
    // TODO Auto-generated method stub
    return null;
  }
  //private helper methods--eg, fetchSomeSubComponent (REM: use service injection, not Dao!)
	
}
								