/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.vector.targetingvector;

import uk.ac.sanger.mig.allelerequest.AlleleRequest;
import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.common.PaginatedSearchBean;

/**
 * This class serves as wrapper around domain object POJO for searching on particular fields that are set.
 * It also inherits orderBy and sortOrder methods from SortableSearchBean enabling sort functionlity.
 *
 * If you also need pagination functionality, subclass PaginatedSearchBean which extends SortableSearchBean
 * 
 * NOTE: Using wrapper is just one appraoch to search bean. You could alternatively created a standalone
 * search bean that effectively mimics all of the fields with getters and setters of your domain object POJO.
 */

public class TargetingVectorSearchBean extends PaginatedSearchBean  {
  
  private TargetingVector targetingVector;
  private String searchBy;
  private String searchString;
    
  
  public TargetingVectorSearchBean(){
    targetingVector = new TargetingVector();  
    AlleleRequest alleleRequest = new AlleleRequest();
    alleleRequest.setSource(new DictionaryEntry());
    targetingVector.setAlleleRequest(alleleRequest);
  }
  public void setIntermediateVector(TargetingVector targetingVector) {
    this.targetingVector = targetingVector;
  }

  public String getSearchBy() {
    return searchBy;
  }

  public void setSearchBy(String searchBy) {
    this.searchBy = searchBy;
  }

  public String getSearchString() {
    return searchString;
  }

  public void setSearchString(String searchString) {
    this.searchString = searchString;
  }

  public TargetingVector getIntermediateVector() {
    return targetingVector;
  }
  public TargetingVector getTargetingVector() {
    return targetingVector;
  }
  public void setTargetingVector(TargetingVector targetingVector) {
    this.targetingVector = targetingVector;
  }
  

  
}