/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.vector.targetingvector.dao;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.PaginatedSearchUtils;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.vector.targetingvector.TargetingVector;
import uk.ac.sanger.mig.vector.targetingvector.TargetingVectorSearchBean;
import uk.ac.sanger.mig.vector.targetingvector.dao.rowmappers.TargetingVectorListViewRowMapper;
import uk.ac.sanger.mig.vector.targetingvector.views.TargetingVectorListView;

public class TargetingVectorDaoSpringImpl extends AbstractDaoSpringImpl<TargetingVector> implements TargetingVectorDao {

  private PaginatedSearchUtils<TargetingVectorListView> paginator;
  private TargetingVectorListViewRowMapper targetingVectorListViewRowMapper;
  
  @Override
  protected void bindVariables(ParameterizedSqlUpdate sql, TargetingVector targetingVector) {
    sql.addLongParam(targetingVector.getDesignInstanceId(), "DESIGN_INSTANCE_ID");
    sql.addIntParam(targetingVector.getLastQcStatus(), "LAST_QC_STATUS");
    sql.addDateParam(targetingVector.getLastStatusChange(), "LAST_STATUS_CHANGE");
    sql.addIntParam(targetingVector.getCassetteDict(), "CASSETTE_DICT");
    sql.addStringParam(targetingVector.getUrlToAllele(), "URL_TO_ALLELE");
    sql.addLongParam(targetingVector.getId(), "ID");
  }

  public Collection<TargetingVectorListView> search(TargetingVectorSearchBean searchBean, ComponentMap requiredComponents) {
    
    Collection<Object> bindVariables = new ArrayList<Object>();
    TargetingVector targetingVector = searchBean.getTargetingVector();
    
    StringBuffer sqlSelect = new StringBuffer();
    StringBuffer sqlFrom = new StringBuffer();
    StringBuffer sqlWhere = new StringBuffer();
    StringBuffer sqlOrderBy = new StringBuffer();
    sqlSelect.append("select v.* ");
    sqlFrom.append(" from vec_targeting_vec_list_vw v ");
    sqlWhere.append(" where 1=1 ");
   
    if(searchBean.getSearchString()!=null && 
        !searchBean.getSearchString().equals("") && !searchBean.getSearchBy().equals("") && !searchBean.getSearchString().contains("Please enter")
    ){
      if(searchBean.getSearchBy().equals("DESIGN_NAME")){
        sqlWhere.append(" and upper(v.design_name) = ? ");
        bindVariables.add(searchBean.getSearchString().toUpperCase());
      }
      if(searchBean.getSearchBy().equals("VEGA_ID")){
        sqlWhere.append(" and upper(v.vega_id) = ? ");
        bindVariables.add(searchBean.getSearchString().toUpperCase());
      }
      if(searchBean.getSearchBy().equals("GENE_NAME")){
        sqlWhere.append(" and upper(v.gene_name) =? ");
        bindVariables.add(searchBean.getSearchString().toUpperCase());
      }
      

    }
    else{

      
      //      search by source id
      if(targetingVector.getAlleleRequest().getSource() != null 
          && targetingVector.getAlleleRequest().getSource().getId() != null
          && targetingVector.getAlleleRequest().getSource().getId() > 0) {
        sqlFrom.append(",arq_allele_request r ");
        sqlWhere.append(" and r.gene_id = v.id ");
        sqlWhere.append(" and r.request_source_dict_id = ? ");
        bindVariables.add(targetingVector.getAlleleRequest().getSource().getId());
      }
      
      if(searchBean.getOrderBy() != null && !searchBean.getOrderBy().equals("")) {
        sqlOrderBy.append(" order by v." + searchBean.getOrderBy());
        if(searchBean.isOrderDesc()) {
          sqlOrderBy.append(" desc ");
        }
      }
    }
    
    String sql = sqlSelect.toString() + sqlFrom.toString() + sqlWhere.toString() + sqlOrderBy.toString();
     
    return paginator.fetchSearchResults(sql, bindVariables, searchBean, targetingVectorListViewRowMapper);
    
  }

  public void setPaginator(
      PaginatedSearchUtils<TargetingVectorListView> paginator) {
    this.paginator = paginator;
  }

  public void setTargetingVectorListViewRowMapper(
      TargetingVectorListViewRowMapper targetingVectorListViewRowMapper) {
    this.targetingVectorListViewRowMapper = targetingVectorListViewRowMapper;
  }

  /*public Long storeAuthenticated(TargetingVector dataObject, Person user) {
    // TODO Auto-generated method stub
    return null;
  }*/

  public int delete(TargetingVector object, Person user) {
    // TODO Auto-generated method stub
    return 0;
  }
  
}