package uk.ac.sanger.mig.abr.parser;

import java.io.ByteArrayInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStreamReader;
import java.text.ParseException;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

public class FileParserTestSetUp {

	List<File>	files;


	/**
	 * Sets up the test. Creates a new FileParser object and asks it to pass the project test file.
	 * Catches any exceptions thrown.
	 */
	public void setUp() {
		this.files = new ArrayList<File>();
		try {
			for (File f : new File(new File(".").getCanonicalPath() + "/test/uk/ac/sanger/mig/abr/parser/testFiles")
					.listFiles()) {
				if (f.getName().charAt(0) == '.')
					continue;
				this.files.add(f);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
	}


	/**
	 * Converts the passed file to bytes and then uses the
	 * <code>FileParser.parse(InputStreamReader)</code> to parse the file. This tests the file
	 * parser being used with a byte[] instead of a file name.
	 *
	 * @param byteFile -
	 *            the File to convert to a byte array and then to pass.
	 * @return byteFileParser - the FileParser that has passed the byte array.
	 * @throws FileNotFoundException -
	 *             no file found.
	 * @throws AttributeFormatException -
	 *             error with the attributes in a block of the file.
	 * @throws BlockAttributeAssociationException -
	 *             associating a block attribute to no block.
	 * @throws IOException -
	 *             in out error.
	 */
	private FileParser getByteFileParser(File byteFile) throws FileNotFoundException, AttributeFormatException,
			BlockAttributeAssociationException, IOException, ParseException, StartClickBlockMissingException,
			EndClickBlockMissingException, HeaderBlockMissingException {
		FileInputStream fis = null;
		byte[] b;
		try {
			fis = new FileInputStream(byteFile);
			int fileLength = new Long(byteFile.length()).intValue();
			b = new byte[fileLength];
			fis.read(b, 0, fileLength);
		} finally {
			fis.close();
		}
		FileParser byteFileParser = new FileParser();
		byteFileParser.parse(new InputStreamReader(new ByteArrayInputStream(b)));
		return byteFileParser;
	}


	/**
	 * Parses the passed file and returns the file parser for testing on.
	 *
	 * @param file -
	 *            the file to parse.
	 * @return the resulting file parser.
	 */
	public FileParser getFileParser(File file) {
		FileParser fp = null;
		try {
			fp = new FileParser();
			fp.parse(file);
		} catch (Exception e) {
			e.printStackTrace();
		}
		return fp;
	}


	/**
	 * The files found in the testFiles directory.
	 *
	 * @return files - collection of File objects.
	 */
	public Collection<File> getFiles() {
		return files;
	}

}
