/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.alleles.services;
import static org.easymock.EasyMock.expect;
import static org.easymock.EasyMock.verify;
import static org.junit.Assert.assertEquals;
import static org.unitils.easymock.EasyMockUnitils.replay;
import static org.unitils.reflectionassert.ReflectionAssert.assertRefEquals;

import org.junit.Before;
import org.junit.Test;
import org.unitils.UnitilsJUnit4;
import org.unitils.easymock.annotation.Mock;
import org.unitils.inject.annotation.InjectIntoByType;
import org.unitils.inject.annotation.TestedObject;

import uk.ac.sanger.mig.alleles.Allele;
import uk.ac.sanger.mig.alleles.dao.AlleleDao;
import uk.ac.sanger.mig.gene.MigGene;
import uk.ac.sanger.mig.gene.services.MigGeneService;
import uk.ac.sanger.mig.mirequest.InvalidTeam87InfoException;

public class AlleleServiceMockTest extends UnitilsJUnit4 {

	@TestedObject
	private AlleleServiceImpl alleleServiceImpl;

	@Mock @InjectIntoByType private AlleleDao alleleDaoMock;
	@Mock @InjectIntoByType private MigGeneService migGeneServiceMock;
	//private Allele testAllele;

	@Before
	public void setUp() {



	}


	//@Test
	public void deriveWorkingEpdAllele_mig_allele() throws InvalidTeam87InfoException{

		Allele expectedAllele = new Allele();
		expectedAllele.setId( 1L );
		expectedAllele.setMigGeneId( 10L );
		expectedAllele.setOfficialNameSuperscript("testOfficialName");

		expect( alleleDaoMock.fetchBySuperscriptAndGeneId(null, null) ).andReturn( expectedAllele );

		expect( migGeneServiceMock.fetchById(expectedAllele.getMigGeneId(), null) ).andReturn( new MigGene() );

		replay();

		Allele actualAllele = alleleServiceImpl.deriveEpdAllele( new Allele() );

		verify();

		assertEquals( expectedAllele.getId(), actualAllele.getId());
		assertEquals( expectedAllele.getMigGeneId(), actualAllele.getMigGeneId());
		assertEquals( expectedAllele.getOfficialNameSuperscript(), actualAllele.getOfficialNameSuperscript());

	}

	@Test
	public void deriveWorkingEpdAllele_Team87_allele() throws InvalidTeam87InfoException {

		Allele expectedAllele = new Allele();
		expectedAllele.setId( null );
		expectedAllele.setMigGeneId( 10L );
		expectedAllele.setOfficialNameSuperscript("testOfficialName");

		expect( alleleDaoMock.fetchBySuperscriptAndGeneId(null, null) ).andReturn( null );

		expect( migGeneServiceMock.fetchById(expectedAllele.getMigGeneId(), null) ).andReturn( new MigGene() );

		replay();

		Allele actualAllele = alleleServiceImpl.deriveEpdAllele( expectedAllele );

		verify();

		assertRefEquals( expectedAllele, actualAllele );

	}


	@Test(expected=InvalidTeam87InfoException.class)
	public void deriveWorkingEpdAllele_bad_gene() throws InvalidTeam87InfoException {

		Allele testAllele = new Allele();
		testAllele.setAlleleDescription( null );
		testAllele.setMigGeneId( 10L );
		expect( alleleDaoMock.fetchBySuperscriptAndGeneId(null, null) ).andReturn( null );

		expect( migGeneServiceMock.fetchById(testAllele.getMigGeneId(), null) ).andReturn( null );

		replay();

		alleleServiceImpl.deriveEpdAllele( testAllele );

		verify();
	}





}
