package uk.ac.sanger.mig.common;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

import org.junit.Test;
import org.unitils.UnitilsJUnit4;

public class DataObjectTest extends UnitilsJUnit4 {

	private DataObject testObjectA;
	private DataObject testObjectB;

	@Test
	public void testEquals() {
		testObjectA = new TestDataObjectType1();
		testObjectB = new TestDataObjectType1();

		testObjectA.setId(1L);
		testObjectB.setId(1L);

		assertEquals(testObjectA, testObjectB);
	}

	@Test
	public void testEquals_sameIdDifferentClass() {
		testObjectA = new TestDataObjectType1();
		testObjectB = new TestDataObjectType2();

		testObjectA.setId(2L);
		testObjectB.setId(2L);

		assertFalse(testObjectA.equals(testObjectB));
	}

	@Test
	public void testEquals_differentIdSameClass() {
		testObjectA = new TestDataObjectType1();
		testObjectB = new TestDataObjectType1();

		testObjectA.setId(1L);
		testObjectB.setId(2L);

		assertFalse(testObjectA.equals(testObjectB));
	}

	@Test
	public void testEquals_nullIdAndObjectsAreSame() {
		testObjectA = new TestDataObjectType1();
		testObjectB = testObjectA;

		testObjectA.setId(null);

		assertEquals(testObjectA, testObjectB);
	}

	@Test
	public void testEquals_nullIdAndObjectsAreDifferent() {
		testObjectA = new TestDataObjectType1();
		testObjectB = new TestDataObjectType1();

		testObjectA.setId(null);
		testObjectB.setId(null);

		assertFalse(testObjectA.equals(testObjectB));
	}

	@Test
	public void testHasId_idNotNull() {
		testObjectA = new TestDataObjectType1();

		testObjectA.setId(1L);

		assertTrue(testObjectA.hasId());
	}

	@Test
	public void testHasId_idNull() {
		testObjectA = new TestDataObjectType1();

		testObjectA.setId(null);

		assertFalse(testObjectA.hasId());

	}

	@Test
	public void testHashCode() {
		testObjectA = new TestDataObjectType1();

		testObjectA.setId(1L);
		Long testValue = new Long(1);

		assertTrue(testObjectA.hashCode() == testValue.hashCode());
	}

	@Test
	public void testHashCode_idNull() {
		testObjectA = new TestDataObjectType1();
		
		testObjectA.setId(null);
		
		assertTrue(testObjectA.hashCode() == 0);
	}

}

class TestDataObjectType1 extends DataObject {

}

class TestDataObjectType2 extends DataObject {

}