package uk.ac.sanger.mig.genotyping.controllers;

import static org.easymock.EasyMock.expect;
import static org.unitils.easymock.EasyMockUnitils.replay;
import static org.unitils.easymock.EasyMockUnitils.verify;

import java.util.ArrayList;
import java.util.Collection;

import junit.framework.Assert;

import org.junit.Before;
import org.junit.Test;
import org.springframework.validation.BindException;
import org.unitils.UnitilsJUnit4;
import org.unitils.easymock.annotation.Mock;
import org.unitils.inject.annotation.InjectIntoByType;
import org.unitils.inject.annotation.TestedObject;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.services.ComponentMapService;
import uk.ac.sanger.mig.database.TableMetadataEnum;
import uk.ac.sanger.mig.filesupport.BinaryFile;
import uk.ac.sanger.mig.filesupport.services.BinaryFileService;
import uk.ac.sanger.mig.genotyping.AssayPlate;
import uk.ac.sanger.mig.genotyping.forms.EditAssayForm;
import uk.ac.sanger.mig.genotyping.services.AssayPlateService;

public class EditAssayFormHelperTest extends UnitilsJUnit4 {

	@TestedObject
	private EditAssayFormHelper editAssayFormHelper;

	@Mock @InjectIntoByType private AssayPlateService assayPlateService;
	@Mock @InjectIntoByType private ComponentMapService componentMapService;
	@Mock @InjectIntoByType private BinaryFileService binaryFileService;

	private EditAssayForm form;
	private BindException bindErrors;
	private AssayPlate plate;

	@Before
	public void setup() {
		form = new EditAssayForm();
		bindErrors = new BindException(form, "form");
	}

	@Test
	public void scanBarcodeValid() {
		String barcode = "P00000001";
		ComponentMap plateComponents = ComponentMap.of(AssayPlate.Component.ALL_COMPONENTS);

		expect(
				componentMapService.getComponentMap("viewOneAssayPlate")
		)
		.andReturn(plateComponents)
		.once();

		Collection<BinaryFile> files = new ArrayList<BinaryFile>();
		expect(
				binaryFileService.fetchByTableRef(
						TableMetadataEnum.GTP_ASSAY_PLATE,
						null,
						false, null
				)
		)
		.andReturn(files);

		expect(
				assayPlateService.fetchByBarcode(barcode, plateComponents)
		)
		.andReturn(makeValidPlate())
		.once();

		replay();

		editAssayFormHelper.initForm(form, null, null);
		form.setBarcode(barcode);
		editAssayFormHelper.scanBarcode(form, bindErrors);

		verify();

		Assert.assertNotNull(plate);
		assertNullFormFields();
	}

	@Test
	public void scanBarcodeInvalid() {
		String barcode = "P00000002";
		ComponentMap plateComponents = new ComponentMap();

		expect(
				componentMapService.getComponentMap("viewOneAssayPlate")
		)
		.andReturn(plateComponents)
		.once();

		expect(
				assayPlateService.fetchByBarcode(barcode, plateComponents)
		)
		.andReturn(makeInvalidPlate())
		.once();

		replay();

		editAssayFormHelper.initForm(form, null, null);
		form.setBarcode(barcode);
		editAssayFormHelper.scanBarcode(form, bindErrors);

		verify();

		Assert.assertNull(plate);
		assertNullFormFields();
		Assert.assertTrue(bindErrors.hasErrors());
	}


	@Test
	public void scanBarcodeNull() {
		editAssayFormHelper.initForm(form, null, null);
		form.setBarcode(null);
		editAssayFormHelper.scanBarcode(form, bindErrors);

		Assert.assertNull(plate);
		assertNullFormFields();
	}

	private AssayPlate makeValidPlate() {
		plate = new AssayPlate(8,12);
		return plate;
	}

	private AssayPlate makeInvalidPlate() {
		plate = null;
		return plate;
	}

	private void assertNullFormFields() {
		Assert.assertNull("assay", form.getAssay());
		Assert.assertNull("assayDate", form.getAssayDate());
		Assert.assertNull("selectedAssay", form.getSelectedAssay());
		Assert.assertNull("selectedAssayTypeDictId", form.getSelectedAssayTypeDictId());
		Assert.assertNull("selectedAlleleId", form.getSelectedAlleleId());
		Assert.assertNull("selectedWells", form.getSelectedWells());
	}

}
