/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.genotyping.dao;

import static junit.framework.Assert.assertNotNull;
import static junit.framework.Assert.assertTrue;

import java.text.ParseException;
import java.util.Collection;

import org.junit.Test;
import org.unitils.dbunit.annotation.DataSet;
import org.unitils.spring.annotation.SpringApplicationContext;
import org.unitils.spring.annotation.SpringBean;

import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.database.TypedDaoTest;
import uk.ac.sanger.mig.genotyping.Assay;
import uk.ac.sanger.mig.genotyping.AssaySearchBean;

/*
 *
 *
 * @SpringApplicationContext loads the specified xml files,
 * these should be the minimum dependencies to make the dao work
 *
 * the unitils-test-database.xml sets the migDataSource to
 * use the db configured in unitils. It should be the last
 * thing in the config list, to override any other datasource
 * definition.
 */
@SpringApplicationContext({"genotyping-dao.xml","common.xml","test-config.xml","unitils-test-database.xml"})
@DataSet
public class AssayDaoTest extends TypedDaoTest<AssayDao, Assay> {


	@Override
	@SpringBean("assayDao")
	protected void setDao(AssayDao dao) {
		super.dao = dao;
	}

	@Override
	public void setUpTestObject() throws ParseException {
		testObject = new Assay();
		testObject.setAssayTypeDictId(2L);
		testObject.setAssayDate(sdf.parse("2008-01-01"));
		testObject.setAlleleId(3L);
		testObject.setAssayPlateId(4L);

		DictionaryEntry assayType = new DictionaryEntry();
		assayType.setId(2L);
		assayType.setName("LacZ");
		assayType.setActive(true);

		testObject.setAssayType(assayType);
	}

	/**
	 * Based on the contents of the dataset file, this should return 1 record
	 *
	 */
	@Test
	public void fetchPlateAssayTypes() {
		Collection<DictionaryEntry> assayTypes = dao.fetchPlateAssayTypes();
		assertTrue(assayTypes.size() == 1);
	}

	/**
	 * Based on the contents of the dataset file, this should return 2 records
	 *
	 */
	@Test
	public void fetchAlleleAssayTypes() {
		Collection<DictionaryEntry> assayTypes = dao.fetchAlleleAssayTypes();
		assertTrue(assayTypes.size() == 2);
	}

	/**
	 * Based on the contents of the dataset file, this should return 2 records
	 *
	 */
	@Test
	public void fetchByPlateId() {
		Collection<Assay> assays = dao.fetchByPlateId(4L);
		assertTrue(assays.size() == 2);
	}

	@Test
	public void fetchByPlateAlleleTypeAndDateWithAllele() throws ParseException {
		AssaySearchBean bean = new AssaySearchBean();
		bean.setAssayPlateId(4L);
		bean.setAlleleId(3L);
		bean.setAssayTypeDictId(2L);
		bean.setAssayDate(sdf.parse("2008-01-01"));

		Assay assay = dao.fetchByPlateAlleleTypeAndDate(bean);
		assertNotNull(assay);
	}

	@Test
	public void fetchByPlateAlleleTypeAndDateNullAllele() throws ParseException {
		AssaySearchBean bean = new AssaySearchBean();
		bean.setAssayPlateId(4L);
		bean.setAlleleId(null);
		bean.setAssayTypeDictId(1L);
		bean.setAssayDate(sdf.parse("2008-01-01"));

		Assay assay = dao.fetchByPlateAlleleTypeAndDate(bean);
		assertNotNull(assay);
	}
}
