/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.genotyping.dao;

import static junit.framework.Assert.*;

import org.apache.commons.lang.StringUtils;
import org.junit.Test;
import org.unitils.dbunit.annotation.DataSet;
import org.unitils.spring.annotation.SpringApplicationContext;
import org.unitils.spring.annotation.SpringBean;

import uk.ac.sanger.mig.database.TypedDaoTest;
import uk.ac.sanger.mig.genotyping.AssayPlate;
/*
 *
 *
 * @SpringApplicationContext loads the specified xml files,
 * these should be the minimum dependencies to make the dao work
 *
 * the unitils-test-database.xml sets the migDataSource to
 * use the db configured in unitils. It should be the last
 * thing in the config list, to override any other datasource
 * definition.
 */
@SpringApplicationContext({"genotyping-dao.xml","common.xml","test-config.xml","unitils-test-database.xml"})
@DataSet
public class AssayPlateDaoTest extends TypedDaoTest<AssayPlateDao, AssayPlate> {

	@Override
	@SpringBean("assayPlateDao")
	protected void setDao(AssayPlateDao dao) {
		super.dao = dao;
	}

	@Override
	protected void setUpTestObject() {
		testObject = new AssayPlate(8,12);
		testObject.setAutoPopulated(true);
		testObject.setCohortId(4L);
		testObject.setPlateBarcode("PLATE_BARCODE");
		testObject.setSheetBarcode("SHEET_BARCODE");
	}

	/**
	 * Assay Plate barcode starts with the letter 'P' and is generated on storing a new plate
	 */
	@Test
	public void generateBarcode() {
		AssayPlate assayPlate = new AssayPlate(8,12);
		dao.store(assayPlate, testUser);
		assertTrue(StringUtils.contains(assayPlate.getBarcode(), 'P'));
	}

	@Test
	public void fetchByBarcodeWithSheetBarcode() {
		AssayPlate plate = dao.fetchByBarcode("SHEET_BARCODE");
		assertNotNull(plate);
	}

	@Test
	public void fetchByBarcodeWithPlateBarcode() {
		AssayPlate plate = dao.fetchByBarcode("PLATE_BARCODE");
		assertNotNull(plate);
	}

	@Test
	public void fetchByBarcodeWithNullBarcode() {
		AssayPlate plate = dao.fetchByBarcode(null);
		assertNull(plate);
	}
}
