/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.genotyping.dao;

import static junit.framework.Assert.*;

import java.text.ParseException;
import java.util.Collection;

import org.junit.Test;
import org.unitils.dbunit.annotation.DataSet;
import org.unitils.spring.annotation.SpringApplicationContext;
import org.unitils.spring.annotation.SpringBean;

import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.database.TypedDaoTest;
import uk.ac.sanger.mig.genotyping.AssayResult;

/*
 *
 *
 * @SpringApplicationContext loads the specified xml files,
 * these should be the minimum dependencies to make the dao work
 *
 * the unitils-test-database.xml sets the migDataSource to
 * use the db configured in unitils. It should be the last
 * thing in the config list, to override any other datasource
 * definition.
 */
@SpringApplicationContext({"genotyping-dao.xml","common.xml","test-config.xml","unitils-test-database.xml"})
@DataSet
public class AssayResultDaoTest extends TypedDaoTest<AssayResultDao, AssayResult> {

	@Override
	@SpringBean("assayResultDao")
	protected void setDao(AssayResultDao dao) {
		super.dao = dao;
	}

	@Override
	public void setUpTestObject() throws ParseException {
		testObject = new AssayResult();
		testObject.setAssayResultDictId(2L);
		testObject.setAssayId(1L);
		testObject.setAssayPlateWellId(3L);

		DictionaryEntry assayResult = new DictionaryEntry();
		assayResult.setId(2L);
		assayResult.setName("test_result");
		assayResult.setActive(true);

		testObject.setAssayResult(assayResult);
	}

	@Test
	public void fetchByAssayId() {
		Collection<AssayResult> testResults1 = dao.fetchByAssayId(1L);
		assertTrue(testResults1.size() == 3);

		Collection<AssayResult> testResults2 = dao.fetchByAssayId(2L);
		assertTrue(testResults2.size() == 1);

		Collection<AssayResult> testResults3 = dao.fetchByAssayId(-1L);
		assertTrue(testResults3.isEmpty());
	}

	@Test
	@DataSet("AssayResultDaoTest_FetchLatestByMouseAlleleId.xml")
	public void fetchLatestByMouseAlleleIdValid() {
		Collection<AssayResult> dbResults = dao.fetchLatestByMouseAlleleId(1L);
		assertTrue("2 records for ID=1", dbResults.size() == 2);
	}

	@Test
	@DataSet("AssayResultDaoTest_FetchLatestByMouseAlleleId.xml")
	public void fetchLatestByMouseAlleleIdInvalid() {
		Collection<AssayResult> dbResults = dao.fetchLatestByMouseAlleleId(3L);
		assertTrue("Empty list for ID=3", dbResults.isEmpty());
	}

	@Test
	public void fetchLatestByMouseAlleleIdNull() {
		Collection<AssayResult> dbResults = dao.fetchLatestByMouseAlleleId(null);
		assertTrue("Empty list for ID=3", dbResults.isEmpty());
	}

	@Test
	@DataSet("AssayResultDaoTest_FetchByMouseAllele.xml")
	public void fetchByMouseAllele() {
		Collection<AssayResult> assayResults = dao.fetchByMouseAllele(1L, 2L);
		assertTrue(assayResults.size() == 4);
	}
}
