package uk.ac.sanger.mig.histology.dao;

import static org.junit.Assert.*;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Collection;

import org.junit.Before;
import org.junit.Test;
import org.unitils.UnitilsJUnit4;
import org.unitils.dbunit.annotation.DataSet;
import org.unitils.spring.annotation.SpringApplicationContext;
import org.unitils.spring.annotation.SpringBean;

import uk.ac.sanger.mig.histology.Block;
import uk.ac.sanger.mig.histology.CropJob;

@DataSet
@SpringApplicationContext({"histology-dao.xml",
	"test-config.xml","unitils-test-database.xml"})
public class CropJobDaoTest extends UnitilsJUnit4{

  @SpringBean("cropJobDao")
  private CropJobDao cropJobDao;

  private final int MAX_ATTEMPTS = 3;

  @Before
  public void setUp() {

  }

	/**
	 * Returns a Collection of CropJobs awaiting processing ordered
	 * by when the CropJob was created, newest jobs first.
	 * (This way when hash these CropJobs to Scan ID key, you
	 * get the oldest CropJob if multiple CropJobs share same Scan).
	 *
	 * A job 'awaiting processing' is defined as one that has not
	 * run successfully and actual attempts < maxAttempts.
	 * @param maxAttempts
	 * @return

	public Collection<CropJob> fetchAwaitProcessing(int maxAttempts);
  	 */

  @Test
  public void fetchAwaitProcessing() {

	  int expectedCount = 3;

	  Collection<CropJob> cropJobs
	  	= cropJobDao.fetchAwaitProcessing( MAX_ATTEMPTS );

	  assertEquals( expectedCount , cropJobs.size() );
  }

  @Test
  public void fetchAwaitProcessing_check_sorted_desc() {

	  Collection<CropJob> cropJobs
	  	= cropJobDao.fetchAwaitProcessing( MAX_ATTEMPTS );

	  CropJob prevCropJob = null;

	  for(CropJob cropJob : cropJobs) {

		  if( prevCropJob != null ) {

			  assertTrue(prevCropJob.getCreatedDate().equals(cropJob.getCreatedDate()) ||
					     prevCropJob.getCreatedDate().after(cropJob.getCreatedDate()));
		  }

		  prevCropJob = cropJob;

	  }

  }

}
