package uk.ac.sanger.mig.histology.services;

import java.lang.reflect.Method;
import java.util.Collection;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.histology.Crop;
import uk.ac.sanger.mig.histology.CropJob;
import uk.ac.sanger.mig.histology.Scan;
import uk.ac.sanger.mig.histology.views.SerializableScanView;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.testsupport.AbstractGenericServiceTest;

public class ScanServiceTest extends AbstractGenericServiceTest {
	
	private Person user;
	private CropJobService cropJobService;
	private CropService cropService;
	
	public ScanServiceTest() {
		
		user = new Person();
		user.setId( 121L);
		user.setUserName("ae1");
	}
	

	
	public CropJobService getCropJobService() {
		return this.cropJobService;
	}



	public void setCropJobService(CropJobService cropJobService) {
		this.cropJobService = cropJobService;
	}



	public CropService getCropService() {
		return this.cropService;
	}



	public void setCropService(CropService cropService) {
		this.cropService = cropService;
	}



	public void setScanService(ScanService service) {
		this.service = service;
	}

	public ScanService getScanService() {
		return (ScanService)service;
	}

	@Override
	protected boolean testFetchMethod(Method method) {
	   return !method.getName().equals("fetchSweepFiles");
	}
    /*
	public void testRemoveFromCropSelectionBin(){

		//TODO: need to fetch arbitrary Collection<Scans>
		Collection<Scan> scans = new ArrayList<Scan>();//getScanService().fetchCropSelectionBin();
		//Get first scan to test its removal from the bin
		Iterator<Scan> iter = scans.iterator();
		if(iter.hasNext()){
			Scan scan1 = (Scan)iter.next();
			Scan scan2 = getScanService().removeFromCropSelectionBin(scan1.getId());
			assertEquals("Scans should be the same when fetched by different methods", scan1, scan2);
			//assertTrue("The crop selection bin should no longer contain the relevant scan", !getScanService().fetchCropSelectionBin(null).contains(scan1));
		}
	}
 	*/

	public void testGentlyFail_NoChildCrops(){

		Scan scan = new Scan();
		
		scan.setStatusDictId( Scan.StatusDictEnum.AWAITING_THUMBNAIL_QC.getId() );
		
		Long id = getScanService().store( scan, user );
		
		scan = getScanService().fetchById(id, ComponentMap.of( Scan.Component.CROP_JOBS));
		
		assertTrue("Scan not set to a non-failed status for test.", 
				 scan.getStatusDictId() != null &&
				 !scan.getStatusDictId().equals( Scan.StatusDictEnum.THUMBNAIL_QC_FAIL_BAD_SCAN.getId() ) &&
				 !scan.getStatusDictId().equals( Scan.StatusDictEnum.THUMBNAIL_QC_FAIL_BAD_SLIDE.getId() ) 
			);

		assertTrue("Scan must have no chilren CropJobs for test.", scan.getCropJobs().size() == 0 );
			
		boolean ok = getScanService().gentlyFail(id, Scan.StatusDictEnum.THUMBNAIL_QC_FAIL_BAD_SCAN, user);
		
		assertTrue("gentlyFail() should always return true if it has no Crops.", ok );
	
		scan = getScanService().fetchById(id, null);
		
		assertTrue("If gentlyFail() returns true, Scan status must be failed as due to bad scan or bad slide.",
				scan.getStatusDictId() != null &&
				scan.getStatusDictId() == Scan.StatusDictEnum.THUMBNAIL_QC_FAIL_BAD_SCAN.getId() );
		
		
		ok = getScanService().gentlyFail(id, Scan.StatusDictEnum.THUMBNAIL_QC_FAIL_BAD_SLIDE, user);
		
		assertTrue("gentlyFail() should always return true if it has no Crops.", ok );
	
		scan = getScanService().fetchById(id, null);
		
		assertTrue("If gentlyFail() returns true, Scan status must be failed as due to bad scan or bad slide.",
				scan.getStatusDictId() != null && (
				scan.getStatusDictId() == Scan.StatusDictEnum.THUMBNAIL_QC_FAIL_BAD_SLIDE.getId() ||
				scan.getStatusDictId() == Scan.StatusDictEnum.THUMBNAIL_QC_FAIL_BAD_SLIDE.getId() ) );
				
	}
	
	public void testGentlyFail_HasChildCropsButNoneQcPassed(){

		Scan scan = new Scan();
		scan.setStatusDictId( Scan.StatusDictEnum.AWAITING_THUMBNAIL_QC.getId() );
		Long scanId = getScanService().store( scan, user );
			
		Scan fetchedScan1 = getScanService().fetchById(scanId, null);

		assertTrue("Scan must have a non-failed status for test.", 
				fetchedScan1.getStatusDictId() != null &&
			   !fetchedScan1.getStatusDictId().equals( Scan.StatusDictEnum.THUMBNAIL_QC_FAIL_BAD_SCAN.getId() ) &&
			   !fetchedScan1.getStatusDictId().equals( Scan.StatusDictEnum.THUMBNAIL_QC_FAIL_BAD_SLIDE.getId() ) 
			);
		
		CropJob cropJob = new CropJob();
		cropJob.setScanId( scanId );
		Long cropJobId = getCropJobService().store(cropJob, user);
		
		Crop crop1 = new Crop();
		crop1.setCropJobId(cropJobId);
		crop1.setQcPass( false ); //qc-failed 
		Crop crop2 = new Crop();
		crop2.setCropJobId(cropJobId);
		crop2.setQcPass( null ); //non-qc-ed
		getCropService().store(crop1, user);
		getCropService().store(crop2, user);
		
		ComponentMap cropJobMap = new ComponentMap();
		cropJobMap.put(CropJob.Component.CROPS, null);
		ComponentMap scanMap = new ComponentMap();
		scanMap.put(Crop.Component.CROP_JOB, cropJobMap);
		
		Scan fetchedScan2 = getScanService().fetchById(scanId, scanMap);
				
		boolean ok = getScanService().gentlyFail(fetchedScan2.getId(), Scan.StatusDictEnum.THUMBNAIL_QC_FAIL_BAD_SCAN, user);
		
		assertTrue("gentlyFail() should always return true if it has no QC-passed Crops.", ok );
	
		Scan fetchedScan3 = getScanService().fetchById(fetchedScan2.getId(), null);
		
		assertTrue("If gentlyFail() returns true, Scan status must be failed (as due to bad scan or bad slide).",
				fetchedScan3.getStatusDictId() != null && (
				fetchedScan3.getStatusDictId() == Scan.StatusDictEnum.THUMBNAIL_QC_FAIL_BAD_SCAN.getId() ||
				fetchedScan3.getStatusDictId() == Scan.StatusDictEnum.THUMBNAIL_QC_FAIL_BAD_SLIDE.getId()  ));
		
		
		boolean foundScanIdInCropSelectionBin = false;
		
		Collection<SerializableScanView> scanViews = getScanService().fetchCropSelectionBinSerialized();
		
		for(SerializableScanView scanView : scanViews) {
			if(scanView.getId().equals( fetchedScan1.getId() )) {
			
				foundScanIdInCropSelectionBin = true;
				break;
			}
			
		}
		
		assertTrue("Scan must not be in Crop Selection Bin.", !foundScanIdInCropSelectionBin );
		
	}

	public void testGentlyFail_AtLeastOneCropQcPassed(){

		Long statusIdBeforeFailAttempt =  Scan.StatusDictEnum.AWAITING_THUMBNAIL_QC.getId();

		Scan scan = new Scan();
		scan.setStatusDictId( statusIdBeforeFailAttempt );
		Long scanId = getScanService().store( scan, user );
		
		CropJob cropJob = new CropJob();
		cropJob.setScanId( scanId );
		Long cropJobId = getCropJobService().store(cropJob, user);
		
		Crop crop1 = new Crop();
		crop1.setCropJobId(cropJobId);
		crop1.setQcPass( false );
		Crop crop2 = new Crop();
		crop2.setCropJobId(cropJobId);
		crop2.setQcPass( true );	
		getCropService().store(crop1, user);
		getCropService().store(crop2, user);
		
		ComponentMap cropJobMap = new ComponentMap();
		cropJobMap.put(CropJob.Component.CROPS, null);
		ComponentMap scanMap = new ComponentMap();
		scanMap.put(Crop.Component.CROP_JOB, cropJobMap);
		
		Scan fetchedScan1 = getScanService().fetchById(scanId, scanMap);
				
		boolean ok = getScanService().gentlyFail(fetchedScan1.getId(), Scan.StatusDictEnum.THUMBNAIL_QC_FAIL_BAD_SCAN, user);
		
		assertTrue("gentlyFail() should always return false if it has at least 1 QC-passed Crop.", !ok );
	
		Scan fetchedScan2 = getScanService().fetchById(fetchedScan1.getId(), null);
		
		assertTrue("If gentlyFail() returns false, Scan status must *not* be changed.",
				fetchedScan2.getStatusDictId().equals( statusIdBeforeFailAttempt ) );
							
	}
	
}
