/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.miprocessing;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

import java.util.Calendar;
import java.util.Date;

import org.junit.Test;
import org.unitils.UnitilsJUnit4;
import org.unitils.inject.annotation.TestedObject;

import uk.ac.sanger.mig.miprocessing.workflow.Task;

public class ScheduledMiTaskTest extends UnitilsJUnit4 {

	@TestedObject
	private ScheduledMiTask scheduledMiTask;

	
	@Test
	public void isComplete(){
		
		scheduledMiTask.setActualCompletionDate( null );
		assertFalse( scheduledMiTask.isComplete() );
		scheduledMiTask.setActualCompletionDate( new Date() );
		assertTrue( scheduledMiTask.isComplete() );
	}

	
	@Test
	public void isPastDue_false_already_complete(){
		
		scheduledMiTask.setActualCompletionDate( new Date() );
		assertFalse( scheduledMiTask.isPastDue() );	
	}
	
	@Test
	public void isPastDue_false_not_complete_and_before_estCompletionDate(){
		
		Calendar c = Calendar.getInstance();
		c.add(Calendar.DAY_OF_YEAR, 1);//est date is tomorrow
		Date estimatedCompletionDate = c.getTime();
		scheduledMiTask.setEstimatedCompletionDate( estimatedCompletionDate );
		scheduledMiTask.setActualCompletionDate( null ); //not yet complete	
		assertFalse( scheduledMiTask.isPastDue() );	
	}	
	
	@Test
	public void isPastDue_true_not_complete_and_after_estCompletionDate(){
		
		Calendar c = Calendar.getInstance();
		c.add(Calendar.DAY_OF_YEAR, -1);//est date was yesterday
		Date estimatedCompletionDate = c.getTime();
		scheduledMiTask.setEstimatedCompletionDate( estimatedCompletionDate );//yesterday
		scheduledMiTask.setActualCompletionDate( null ); 
		assertTrue( scheduledMiTask.isPastDue() );	
	}
	
	@Test
	public void compareTo() {
		
		int sequenceNumber = 1;
		Task targetTask = new ScheduledMiTask();
		targetTask.setSequenceNumber( sequenceNumber );
		scheduledMiTask.setSequenceNumber( sequenceNumber );
		assertEquals( 0, scheduledMiTask.compareTo(targetTask) );//equal	to target
		targetTask.setSequenceNumber( sequenceNumber );
		scheduledMiTask.setSequenceNumber( sequenceNumber - 1 );//less than target
		assertTrue( scheduledMiTask.compareTo(targetTask) < 0);
		targetTask.setSequenceNumber( sequenceNumber );
		scheduledMiTask.setSequenceNumber( sequenceNumber + 1 );//greater than target
		assertTrue( scheduledMiTask.compareTo(targetTask) > 0);
			
	}	
	

	
	
}
