/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.miprocessing.dao;

/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

import static org.junit.Assert.assertEquals;

import java.util.List;

import org.junit.Before;
import org.junit.Test;
import org.unitils.UnitilsJUnit4;
import org.unitils.dbunit.annotation.DataSet;
import org.unitils.spring.annotation.SpringApplicationContext;
import org.unitils.spring.annotation.SpringBean;

import uk.ac.sanger.mig.miprocessing.workflow.TaskDao;
import uk.ac.sanger.mig.miprocessing.workflow.TaskTemplate;
import uk.ac.sanger.mig.mirequest.CellLine;
import uk.ac.sanger.mig.mirequest.MiRequest;

@SpringApplicationContext( { "microinject-processing-dao.xml", 
							 "test-config.xml", 
							 "unitils-test-database.xml" })
public class TaskDaoTest extends UnitilsJUnit4 {

	@SpringBean("taskDao")
	private TaskDao taskDao;

	private MiRequest miRequest;

	//actual dataset
	private final Long CELL_LINE_STRAIN_ID = 2L;
	private final Long CHIMERA_MATE_STRAIN_ID = 1L;
	@Before
	public void setUp() {

		miRequest = new MiRequest();
		miRequest.setCellLine( new CellLine() );

	}

	@Test
	@DataSet("taskDaoTest.f1Endpoint.xml")
	public void fetchTaskTemplates_f1_workflow_rule_found(){
		
		final Long EXPECTED_TASK_GROUP_ID = 10L;
		final int EXPECTED_TASK_TEMPLATE_COUNT = 5;
		
		miRequest.getCellLine().setCellLineStrainDictId( CELL_LINE_STRAIN_ID );
		miRequest.setEndpointDictId( MiRequest.EndpointEnum.F1.getId() );
		miRequest.setChimeraMateStrainDictId( CHIMERA_MATE_STRAIN_ID );
		
		List<TaskTemplate> taskTemplates = taskDao.fetchTaskTemplates( miRequest );
		
		assertEquals( EXPECTED_TASK_TEMPLATE_COUNT, taskTemplates.size() );
		
		for(TaskTemplate taskTemplate : taskTemplates) {

			assertEquals(EXPECTED_TASK_GROUP_ID, taskTemplate.getTaskGroupDictId());
			
		}
	}

	@Test
	@DataSet("taskDaoTest.f1Endpoint.xml")
	public void fetchTaskTemplates_f1_workflow_rule_not_found(){
		
		final Long EXPECTED_TASK_GROUP_ID = 11L;//expected default id 
		final int EXPECTED_TASK_TEMPLATE_COUNT = 3;
		
		miRequest.getCellLine().setCellLineStrainDictId( -1L );//set unknown id
		miRequest.setEndpointDictId( MiRequest.EndpointEnum.F1.getId() );
		miRequest.setChimeraMateStrainDictId( CHIMERA_MATE_STRAIN_ID );
		
		List<TaskTemplate> taskTemplates = taskDao.fetchTaskTemplates( miRequest );
		
		assertEquals( EXPECTED_TASK_TEMPLATE_COUNT, taskTemplates.size() );
		
		for(TaskTemplate taskTemplate : taskTemplates) {

			assertEquals(EXPECTED_TASK_GROUP_ID, taskTemplate.getTaskGroupDictId());
			
		}
	}

	@Test
	@DataSet("taskDaoTest.f0AdultEndpoint.xml")
	public void fetchTaskTemplates_f0_adult_default(){
		
		final Long EXPECTED_TASK_GROUP_ID = 12L;//expected default id 
		final int EXPECTED_TASK_TEMPLATE_COUNT = 10;
		
		miRequest.getCellLine().setCellLineStrainDictId( CELL_LINE_STRAIN_ID );
		miRequest.setEndpointDictId( MiRequest.EndpointEnum.F0.getId() );
		
		List<TaskTemplate> taskTemplates = taskDao.fetchTaskTemplates( miRequest );
		
		assertEquals( EXPECTED_TASK_TEMPLATE_COUNT, taskTemplates.size() );
		
		for(TaskTemplate taskTemplate : taskTemplates) {

			assertEquals(EXPECTED_TASK_GROUP_ID, taskTemplate.getTaskGroupDictId());
			
		}
	}

	@Test
	@DataSet("taskDaoTest.f0EmbryoEndpoint.xml")
	public void fetchTaskTemplates_f0_embryo_default(){
		
		final Long EXPECTED_TASK_GROUP_ID = 13L;//expected default id 
		final int EXPECTED_TASK_TEMPLATE_COUNT = 7;
		
		miRequest.getCellLine().setCellLineStrainDictId( CELL_LINE_STRAIN_ID );
		miRequest.setEndpointDictId( MiRequest.EndpointEnum.EMBRYONIC_CHIMERAS.getId() );
		
		List<TaskTemplate> taskTemplates = taskDao.fetchTaskTemplates( miRequest );
		
		assertEquals( EXPECTED_TASK_TEMPLATE_COUNT, taskTemplates.size() );
		
		for(TaskTemplate taskTemplate : taskTemplates) {

			assertEquals(EXPECTED_TASK_GROUP_ID, taskTemplate.getTaskGroupDictId());
			
		}
	}
	@Test(expected=IllegalArgumentException.class) 
	public void fetchTaskTemplates_null_mi_request(){
		
		taskDao.fetchTaskTemplates( null );
		
	}	
	
	@Test(expected=RuntimeException.class) 
	public void fetchTaskTemplates_null_endpoint_id(){
		
		miRequest.getCellLine().setCellLineStrainDictId( CELL_LINE_STRAIN_ID );
		miRequest.setEndpointDictId( null );
		miRequest.setChimeraMateStrainDictId( CHIMERA_MATE_STRAIN_ID );
		
		taskDao.fetchTaskTemplates( miRequest );
		
	}	
	
	@Test(expected=RuntimeException.class) 
	public void fetchTaskTemplates_f1_null_cell_line_strain(){
		
		miRequest.getCellLine().setCellLineStrainDictId( null );
		miRequest.setEndpointDictId( MiRequest.EndpointEnum.F1.getId() );
		miRequest.setChimeraMateStrainDictId( CHIMERA_MATE_STRAIN_ID );
		
		taskDao.fetchTaskTemplates( miRequest );
		
	}	
	
	
	
	@Test(expected=RuntimeException.class) 
	public void fetchTaskTemplates_f1_null_chimera_strain(){
		
		miRequest.getCellLine().setCellLineStrainDictId( CELL_LINE_STRAIN_ID );
		miRequest.setEndpointDictId( MiRequest.EndpointEnum.F1.getId() );
		miRequest.setChimeraMateStrainDictId( null );
		
		taskDao.fetchTaskTemplates( miRequest );
		
	}	
	
	@DataSet("taskDaoTest.noTasksFound.xml")
	@Test(expected=RuntimeException.class) 
	public void fetchTaskTemplates_no_tasks_found(){
		
		miRequest.getCellLine().setCellLineStrainDictId( CELL_LINE_STRAIN_ID );
		miRequest.setEndpointDictId( MiRequest.EndpointEnum.F1.getId() );
		miRequest.setChimeraMateStrainDictId( CHIMERA_MATE_STRAIN_ID );
		
		taskDao.fetchTaskTemplates( miRequest );
		
	}		
}
