/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.miprocessing.services;

import java.util.Calendar;
import java.util.Collection;
import java.util.GregorianCalendar;
import java.util.Map;

import uk.ac.sanger.mig.miprocessing.forms.BatchWildtypeRequestForm;
import uk.ac.sanger.mig.testsupport.AbstractGenericServiceTest;

public class BatchWildtypeRequestServiceTest extends AbstractGenericServiceTest {
	
	public void setBatchWildtypeRequestService(BatchWildtypeRequestService service) {
		this.service = service;
	}

	public BatchWildtypeRequestService getBatchWildtypeRequestService(){
		return (BatchWildtypeRequestService)service;
	}

	public void testProcessWildtypeRequests(){
		
		BatchWildtypeRequestForm batchWildtypeRequestForm = new BatchWildtypeRequestForm();
		
		batchWildtypeRequestForm.setAlbinoDonorCount(5);
		batchWildtypeRequestForm.setBlackDonorCount(5);
		batchWildtypeRequestForm.setRecipientCount(5);
			
		GregorianCalendar calendar = new GregorianCalendar();
		calendar.set(Calendar.DATE, calendar.get(Calendar.DATE) + 5);
		batchWildtypeRequestForm.setDateRequired(calendar.getTime());

		batchWildtypeRequestForm.setRequester(getFakeUser());
		batchWildtypeRequestForm.addDailyRequests(getFakeUser());
		
		Collection<String> recipients = getBatchWildtypeRequestService().processWildtypeRequests(batchWildtypeRequestForm);
		
		assertTrue("Method should produce a collection of strings containing requester email addresses", recipients.size() > 0);
	}
	
	public void testBuild(){

		BatchWildtypeRequestForm batchWildtypeRequestForm = new BatchWildtypeRequestForm();
		
		batchWildtypeRequestForm.setAlbinoDonorCount(5);
		batchWildtypeRequestForm.setBlackDonorCount(5);
		batchWildtypeRequestForm.setRecipientCount(5);
			
		GregorianCalendar calendar = new GregorianCalendar();
		calendar.set(Calendar.DATE, calendar.get(Calendar.DATE) + 5);
		batchWildtypeRequestForm.setDateRequired(calendar.getTime());

		batchWildtypeRequestForm.setRequester(getFakeUser());
		batchWildtypeRequestForm.addDailyRequests(getFakeUser());
		
		Map<String, Object> model = getBatchWildtypeRequestService().buildReport(batchWildtypeRequestForm);
						
		assertTrue("Method should produce a model containing details of the requests", model.size() > 0);
	}
}