/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.miprocessing.services;

import static org.unitils.reflectionassert.ReflectionAssert.assertRefEquals;

import java.util.Calendar;
import java.util.Date;

import uk.ac.sanger.mig.miprocessing.EmbryoHarvest;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.testsupport.AbstractGenericServiceTest;
public class EmbryoHarvestServiceTest extends AbstractGenericServiceTest {

	private Person testUser;
	private EmbryoHarvest expectedEmbryoHarvest;
	private EmbryoHarvestService embryoHarvestService;

	public void setEmbryoHarvestService(EmbryoHarvestService service) {
		this.service = service;
		embryoHarvestService = (EmbryoHarvestService)service;
	}

	public EmbryoHarvestServiceTest() {

		super();

		testUser = new Person();
		testUser.setId( 10L );

		expectedEmbryoHarvest = new EmbryoHarvest();
		expectedEmbryoHarvest.setTechnician( testUser );
		expectedEmbryoHarvest.setTechnicianId( testUser.getId() );
		expectedEmbryoHarvest.setUseBlastocysts( true );
		expectedEmbryoHarvest.setUseMoralae( true );
	}

	public void testBuildDefaultEmbryoHarvest() {

		EmbryoHarvest actualEmbryoHarvest
			= embryoHarvestService.buildDefaultEmbryoHarvest( testUser );

		assertRefEquals(expectedEmbryoHarvest, actualEmbryoHarvest);
	}

	public void testGetDefaultPlugDate_same_month() {

		Calendar calFlushDate = Calendar.getInstance();

		calFlushDate.set(2008, Calendar.FEBRUARY, 25);

		Calendar calExpectedPlugDate = Calendar.getInstance();

		calExpectedPlugDate.set(calFlushDate.get(Calendar.YEAR),
							   calFlushDate.get(Calendar.MONTH),
							   calFlushDate.get(Calendar.DAY_OF_MONTH)
							   + EmbryoHarvestService.DEFAULT_PLUG_DAY_OFFSET);

		Date actualPlugDate = embryoHarvestService.getDefaultPlugDate( calFlushDate.getTime() );

		Calendar calActualPlugDate = Calendar.getInstance();

		calActualPlugDate.setTime( actualPlugDate );

		assertRefEquals( calExpectedPlugDate.getTime(), calActualPlugDate.getTime() );

	}

	public void testGetDefaultPlugDate_different_month() {


		Calendar calFlushDate = Calendar.getInstance();

		calFlushDate.set(2008, Calendar.FEBRUARY, 1);

		Calendar calExpectedPlugDate = Calendar.getInstance();

		calExpectedPlugDate.set(calFlushDate.get(Calendar.YEAR),
							   calFlushDate.get(Calendar.MONTH),
							   calFlushDate.get(Calendar.DAY_OF_MONTH)
							   + EmbryoHarvestService.DEFAULT_PLUG_DAY_OFFSET);

		Date actualPlugDate = embryoHarvestService.getDefaultPlugDate( calFlushDate.getTime() );

		Calendar calActualPlugDate = Calendar.getInstance();

		calActualPlugDate.setTime( actualPlugDate );

		assertRefEquals( calExpectedPlugDate.getTime(), calActualPlugDate.getTime() );

	}

	public void testGetDefaultPlugDate_different_year() {


		Calendar calFlushDate = Calendar.getInstance();

		calFlushDate.set(2008, Calendar.JANUARY, 1);

		Calendar calExpectedPlugDate = Calendar.getInstance();

		calExpectedPlugDate.set(calFlushDate.get(Calendar.YEAR),
							   calFlushDate.get(Calendar.MONTH),
							   calFlushDate.get(Calendar.DAY_OF_MONTH)
							   + EmbryoHarvestService.DEFAULT_PLUG_DAY_OFFSET);

		EmbryoHarvestService embryoHarvestService = (EmbryoHarvestService)service;

		Date actualPlugDate = embryoHarvestService.getDefaultPlugDate( calFlushDate.getTime() );

		Calendar calActualPlugDate = Calendar.getInstance();

		calActualPlugDate.setTime( actualPlugDate );

		assertRefEquals( calExpectedPlugDate.getTime(), calActualPlugDate.getTime() );

	}

}
