/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.miprocessing.services;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.UnattachedComponentException;
import uk.ac.sanger.mig.miprocessing.ScheduledMicroInjectionJob;
import uk.ac.sanger.mig.mirequest.MiRequest;
import uk.ac.sanger.mig.testsupport.AbstractGenericServiceTest;
public class ScheduledMicroInjectionServiceTest extends AbstractGenericServiceTest {
	
	public void setScheduledMicroInjectionService(ScheduledMicroInjectionService service) {
		this.service = service;
	}

	public ScheduledMicroInjectionService getScheduledMicroInjectionService(){
		
		return (ScheduledMicroInjectionService)service;
	}

	
	
	public void testDeriveJobId_nonNullJobs(){
		ScheduledMicroInjectionJob scheduledMicroInjectionJob1 = new ScheduledMicroInjectionJob();
		ScheduledMicroInjectionJob scheduledMicroInjectionJob2 = new ScheduledMicroInjectionJob();
		ScheduledMicroInjectionJob scheduledMicroInjectionJob3 = new ScheduledMicroInjectionJob();
		
		Collection<ScheduledMicroInjectionJob> jobs = new ArrayList<ScheduledMicroInjectionJob>();
		jobs.add(scheduledMicroInjectionJob1);
		jobs.add(scheduledMicroInjectionJob2);
		jobs.add(scheduledMicroInjectionJob3);
		
		MiRequest miRequest = new MiRequest();
		miRequest.setScheduledMicroInjections(jobs);
		
		String jobId = getScheduledMicroInjectionService().deriveJobId(miRequest);
		assertTrue("Method should produce a jobId string starting with 'MIR_'", jobId.startsWith("MIR_"));
	}

	public void testDeriveJobId_nullJobs(){
		
		MiRequest miRequest = new MiRequest();
		
		try {
		
			getScheduledMicroInjectionService().deriveJobId(miRequest);
			
			assertTrue("Expected UnattachedComponentException", false);
		
		} catch(UnattachedComponentException e) {
			
			assertTrue( true );
		}	
	}

	public void testDeriveJobId_nullMiRequestArg(){
		
		try {
		
			getScheduledMicroInjectionService().deriveJobId( null );
			
			assertTrue("Expected IllegalArgumentException", false);
		
		} catch(IllegalArgumentException e) {
			
			assertTrue( true );
		}	
	}
	
	public void testCancelJob(){

		Long tryPK = 1L;
		int testRecords = 0;
		//fetch first three we find in 1-100
		while( testRecords < 2 && tryPK < 100 ) {
			
			ScheduledMicroInjectionJob smiJobTest
			 = getScheduledMicroInjectionService().fetchById(tryPK,null);
			
			if( smiJobTest != null ) {
				
				testRecords++;
				
				Long id = getScheduledMicroInjectionService().cancelJob(smiJobTest.getId(), 
						getFakeUser(), "test cancel");
				
				assertTrue("id should not be null ", (id != null) );
			
				
			}
			
			tryPK++;
		}
	}
	

	public void testFailJob(){

		Long tryPK = 1L;
		int testRecords = 0;
		//fetch first three we find in 1-100
		while( testRecords < 2 && tryPK < 100 ) {
			
			ScheduledMicroInjectionJob smiJobTest
			 = getScheduledMicroInjectionService().fetchById(tryPK,null);
			
			if( smiJobTest != null ) {
								
				Long id = getScheduledMicroInjectionService().cancelJob(smiJobTest.getId(), 
						getFakeUser(), "test fail");
				
				assertTrue("id should not be null ", (id != null) );
			
				testRecords++;
			}
			
			tryPK++;
		}
	}
		
}



