/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.mirequest.dao;

/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

import static org.junit.Assert.*;

import java.util.List;

import org.junit.Before;
import org.junit.Test;
import org.unitils.UnitilsJUnit4;
import org.unitils.dbunit.annotation.DataSet;
import org.unitils.spring.annotation.SpringApplicationContext;
import org.unitils.spring.annotation.SpringBean;

import uk.ac.sanger.mig.miprocessing.workflow.TaskDao;
import uk.ac.sanger.mig.miprocessing.workflow.TaskTemplate;
import uk.ac.sanger.mig.mirequest.CellLine;
import uk.ac.sanger.mig.mirequest.MiRequest;

import static org.unitils.reflectionassert.ReflectionAssert.assertRefEquals;

@SpringApplicationContext( { "cell-line-info-dao.xml",
							 "dictionary.xml",
							 "test-config.xml",
							 "unitils-test-database.xml" })

@DataSet("cellLineDaoTest.xml")
public class CellLineDaoTest extends UnitilsJUnit4 {

	@SpringBean("cellLineDao")
	private  CellLineDao  cellLineDao;


	@Before
	public void setUp() {

	}

	@Test
	public void existsByCellLineAndCloneName_true1(){

		assertTrue( cellLineDao.existsByCellLineAndCloneName("B", "b2") );

	}

	@Test
	public void existsByCellLineAndCloneName_true2(){

		assertTrue( cellLineDao.existsByCellLineAndCloneName("C", "c3") );

	}

	@Test
	public void existsByCellLineAndCloneName_true_case_insentitive(){

		assertTrue( cellLineDao.existsByCellLineAndCloneName("c", "C3") );

	}

	@Test
	public void existsByCellLineAndCloneName_false1(){

		assertFalse( cellLineDao.existsByCellLineAndCloneName("B", "") );

	}

	@Test
	public void existsByCellLineAndCloneName_false2(){

		assertFalse( cellLineDao.existsByCellLineAndCloneName("", "b2") );

	}

	@Test
	public void existsByCellLineAndCloneName_false_case_insensitive(){

		assertFalse( cellLineDao.existsByCellLineAndCloneName("", "B2") );

	}

	@Test
	public void existsByCellLineAndCloneName_false_null_args(){

		assertFalse( cellLineDao.existsByCellLineAndCloneName(null, null) );

	}

	@Test
	public void fetchByEpdId_found(){

		CellLine expectedCellLine = new CellLine();
		expectedCellLine.setId(4L);
		expectedCellLine.setCloneName("EPD_ID_123");

		CellLine actualCellLine = cellLineDao.fetchByEpdId("EPD_ID_123");

		assertEquals( expectedCellLine.getId(), actualCellLine.getId() );
	}

	@Test
	public void fetchByEpdId_none_found(){


		CellLine actualCellLine = cellLineDao.fetchByEpdId("invalidEpdId");

		assertNull( actualCellLine );
	}

	@Test
	public void fetchByEpdId_null_arg_none_found(){


		CellLine actualCellLine = cellLineDao.fetchByEpdId( null );

		assertNull( actualCellLine );
	}

	@Test
	public void fetchByEpdId_empty_arg_none_found(){


		CellLine actualCellLine = cellLineDao.fetchByEpdId( "" );

		assertNull( actualCellLine );
	}

}
