/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.dao;

import static junit.framework.Assert.assertTrue;

import java.text.ParseException;
import java.util.Collection;

import org.junit.Test;
import org.unitils.dbunit.annotation.DataSet;
import org.unitils.spring.annotation.SpringApplicationContext;
import org.unitils.spring.annotation.SpringBean;

import uk.ac.sanger.mig.common.DictionaryEntry;
import uk.ac.sanger.mig.database.TypedDaoTest;
import uk.ac.sanger.mig.mousetracking.GenotypeHistory;

/*
 *
 *
 * @SpringApplicationContext loads the specified xml files,
 * these should be the minimum dependencies to make the dao work
 *
 * the unitils-test-database.xml sets the migDataSource to
 * use the db configured in unitils. It should be the last
 * thing in the config list, to override any other datasource
 * definition.
 */
@SpringApplicationContext({"mouse-tracking-dao.xml","common.xml","test-config.xml","unitils-test-database.xml"})
@DataSet
public class GenotypeHistoryDaoTest extends TypedDaoTest<GenotypeHistoryDao, GenotypeHistory> {

	private static final Long DEFAULT_MOUSE_ALLELE_ID = 2L;

	@Override
	@SpringBean("genotypeHistoryDao")
	protected void setDao(GenotypeHistoryDao dao) {
		super.dao = dao;
	}

	@Override
	public void setUpTestObject() throws ParseException {
		testObject = new GenotypeHistory();
		testObject.setMouseAlleleId(DEFAULT_MOUSE_ALLELE_ID);
		testObject.setAssignmentDate(sdf.parse("2008-01-03"));
		testObject.setGenotypeDictId(3L);

		DictionaryEntry genotype = new DictionaryEntry();
		genotype.setId(3L);
		genotype.setName("Homozygous");
		genotype.setActive(true);

		testObject.setGenotype(genotype);
	}

	@Test
	public void fetchByMouseAlleleIdValid() {
		Collection<GenotypeHistory> dbRecords = dao.fetchByMouseAlleleId(DEFAULT_MOUSE_ALLELE_ID);
		assertTrue(dbRecords.size() == 3);

		GenotypeHistory[] asArray = dbRecords.toArray(new GenotypeHistory[0]);
		assertTrue("date 1 before date 0", asArray[1].getAssignmentDate().before(asArray[0].getAssignmentDate()));
		assertTrue("date 2 before date 1", asArray[2].getAssignmentDate().before(asArray[1].getAssignmentDate()));
	}

	@Test
	public void fetchByMouseAlleleIdInvalid() {
		Collection<GenotypeHistory> dbRecords = dao.fetchByMouseAlleleId(INVALID_ID);
		assertTrue(dbRecords.isEmpty());
	}
}
