package uk.ac.sanger.mig.mousetracking.dao;

import static org.junit.Assert.assertNull;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.unitils.UnitilsJUnit4;
import org.unitils.reflectionassert.ReflectionAssert;
import org.unitils.reflectionassert.ReflectionComparatorMode;
import org.unitils.spring.annotation.SpringApplicationContext;
import org.unitils.spring.annotation.SpringBean;

import uk.ac.sanger.mig.mousetracking.Mouse;
import uk.ac.sanger.mig.personnel.Person;

@SpringApplicationContext({"mouse-tracking-dao.xml","dictionary.xml","test-config.xml","unitils-test-database.xml"})

public class MouseDaoTest extends UnitilsJUnit4 {

	@SpringBean("mouseDao")
	private MouseDao mouseDao;
	private Mouse mouse = null;
	private Person user = null;

	@Before
	public void setUp() {
		user = new Person();
		user.setId(275L);
		user.setUserName("dg6");

		mouse = new Mouse();
		mouseDao.store(mouse, user);
		mouse.setName(mouse.getBarcode());
		mouseDao.store(mouse, user);
	}


	@Test
	public void testFetchById_validId() {
		Mouse testMouse = mouseDao.fetchById(mouse.getId());
		ReflectionAssert.assertRefEquals(mouse, testMouse, ReflectionComparatorMode.LENIENT_DATES);
	}

	@Test
	public void testFetchById_invalidId() {
		Mouse testMouse = mouseDao.fetchById(Long.MAX_VALUE);
		assertNull(testMouse);
	}

	@Test
	public void testFetchByBarcode() {
		Mouse testMouse = mouseDao.fetchByBarcode(mouse.getBarcode());
		ReflectionAssert.assertRefEquals(mouse, testMouse, ReflectionComparatorMode.LENIENT_DATES);
	}

	@Test
	public void testFetchByName() {
		Mouse testMouse = mouseDao.fetchByName(mouse.getName());
		ReflectionAssert.assertRefEquals(mouse, testMouse, ReflectionComparatorMode.LENIENT_DATES);
	}


	@After
	public void cleanUp() {
		mouseDao.deleteMouse(mouse, user);
	}

}
