/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.services;

import static junit.framework.Assert.assertNotNull;
import static org.unitils.easymock.EasyMockUnitils.*;

import org.junit.Before;
import org.junit.Test;
import org.unitils.UnitilsJUnit4;
import org.unitils.easymock.annotation.Mock;
import org.unitils.inject.annotation.InjectIntoByType;
import org.unitils.inject.annotation.TestedObject;

import uk.ac.sanger.mig.mousetracking.Mouse;

public class MouseServiceTest extends UnitilsJUnit4  {

	@TestedObject MouseServiceImpl mouseService;

	@Mock @InjectIntoByType MouseProcedureService mouseProcedureService;

	private Mouse mouse;

	@Before
	public void setUp() {
		mouse = new Mouse();
	}

	@Test
	public void testInflateComponents() {

		mouseProcedureService.inflateComponents(mouse.getCurrentLicencedProcedure());

		replay();

		mouseService.inflateMouseComponents(mouse);

		verify();

		assertNotNull("alleles", mouse.getAlleles());
		assertNotNull("cage", mouse.getCage());
		assertNotNull("colony", mouse.getColonyInfo());
		assertNotNull("owner", mouse.getCurrentOwner());
		assertNotNull("location", mouse.getLocation());
		assertNotNull("litter", mouse.getLitter());
		assertNotNull("strain", mouse.getStrain());
		assertNotNull("procedure", mouse.getCurrentLicencedProcedure());
		assertNotNull("chimeric", mouse.getChimericData());
		assertNotNull("weight", mouse.getCurrentWeight());
		assertNotNull("latest breeding", mouse.getLatestBreeding());
	}

}
