/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.mousetracking.services;

import static junit.framework.Assert.assertNull;

import java.util.ArrayList;

import org.junit.Before;
import org.junit.Test;
import org.unitils.UnitilsJUnit4;
import org.unitils.inject.annotation.TestedObject;

import uk.ac.sanger.mig.mousetracking.ChimericMouseData;
import uk.ac.sanger.mig.mousetracking.Mouse;
import uk.ac.sanger.mig.mousetracking.MouseAllele;
import uk.ac.sanger.mig.mousetracking.MouseProcedure;
import uk.ac.sanger.mig.mousetracking.MouseWeight;

public class MouseServiceTest_resetIdFields extends UnitilsJUnit4  {

	@TestedObject MouseServiceImpl mouseService;

	private Mouse mouse;

	@Before
	public void setUp() {
		Long mouseId = 1L;

		mouse = new Mouse();
		mouse.setId(mouseId);

		mouse.setAlleles(new ArrayList<MouseAllele>());
		MouseAllele alleleA = new MouseAllele();
		alleleA.setId(5L);
		alleleA.setMouseId(mouseId);
		mouse.getAlleles().add(alleleA);

		mouse.setCurrentWeight(new MouseWeight());
		mouse.getCurrentWeight().setId(2L);
		mouse.getCurrentWeight().setMouseId(mouseId);

		mouse.setCurrentLicencedProcedure(new MouseProcedure());
		mouse.getCurrentLicencedProcedure().setId(3L);
		mouse.getCurrentLicencedProcedure().setMouseId(mouseId);

		mouse.setChimericData(new ChimericMouseData());
		mouse.getChimericData().setId(4L);
		mouse.getChimericData().setMouseId(mouseId);
	}

	@Test
	public void testResetIdFields() {
		mouseService.resetIdFields(mouse);

		assertNull("mouse.getId", mouse.getId());
		assertNull("allele.getId", mouse.getAlleles().iterator().next().getId());
		assertNull("allele.getMouseId", mouse.getAlleles().iterator().next().getMouseId());
		assertNull("weight.getId", mouse.getCurrentWeight().getId());
		assertNull("weight.getMouseId", mouse.getCurrentWeight().getMouseId());
		assertNull("proc.getId", mouse.getCurrentLicencedProcedure().getId());
		assertNull("proc.getMouseId", mouse.getCurrentLicencedProcedure().getMouseId());
		assertNull("chimeric.getId", mouse.getChimericData().getId());
		assertNull("chimeric.getMouseId", mouse.getChimericData().getMouseId());
	}
}
