/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.personnel.services;

import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.testsupport.AbstractGenericServiceTest;
public class PersonServiceTest extends AbstractGenericServiceTest {
  @Override
  public void setPersonService(PersonService service) {
    this.service = service;
    super.setPersonService(service);
  }

  private PersonService personService() {
    return (PersonService)service;
  }

  @Override
  protected void onSetUpInTransaction(){
    Person testUser = personService().fetchByUserName("test", null);

    if (testUser == null) {
      testUser = new Person();
      testUser.setUserName("test");
    }

    assertNotNull("Test user is required",testUser);
    testUser.setActive(true);
    // makes sure the password is set to 'test'
    testUser.setPasswordHash("a94a8fe5ccb19ba61c4c0873d391e987982fbbd3");
    personService().store(testUser, getFakeUser());
  }



  public void testAuthenticateGood() {
    Person person = personService().authenticate("test", "test");

    assertNotNull("Person object should be returned",person);
    assertNotNull("Person object should have a username",person.getUserName());
    assertEquals("Person should have expected username", "test", person.getUserName());
  }

  public void testAuthenticateBadPassword() {
    Person person = personService().authenticate("test", "thisisnotthepassword");
    assertNull("Person object should not be returned", person);
  }

  public void testAuthenticateEmptyPassword() {
    Person person = personService().authenticate("test", "");
    assertNull("Person object should not be returned", person);
  }


  public void testAuthenticateNullPassword() {
    Person person = null;
    IllegalArgumentException iae = null;
    try {
      person = personService().authenticate("test", null);
    }
    catch (IllegalArgumentException e) {
      iae = e;
    }
    assertNull("Person object should not be returned", person);
    assertNotNull("IllegalArgumentException expected", iae);
  }

  public void testAuthenticateEmptyUsername() {
    Person person = personService().authenticate("", "");

    assertNull("Person object should not be returned", person);
  }

  public void testAuthenticateNullUser() {
    Person person = null;
    IllegalArgumentException iae = null;
    try {
      person = personService().authenticate(null, "meh");
    }
    catch (IllegalArgumentException e) {
      iae = e;
    }
    assertNull("Person object should not be returned", person);
    assertNotNull("IllegalArgumentException expected", iae);
  }

  public void testAuthenticateFakeUser() {
    Person person = personService().authenticate("therewillneverbeausernamelikethisbecauseitwouldtakefartoolongtotypeinandwhohasthepatienceforthissortofnonsenseasausername,imeanyou'dgocrazytypingthisineverydayandourusersarentthatcrazy", "password");
    assertNull("Person object should not be returned", person);
  }

}
