package uk.ac.sanger.mig.phenotyping.calorimetry.parser;

import static org.junit.Assert.*;

import java.text.ParseException;
import java.util.Collection;

import org.junit.Test;

import uk.ac.sanger.mig.phenotyping.calorimetry.parser.BoxData;
import uk.ac.sanger.mig.phenotyping.calorimetry.parser.CalorimetryData;
import uk.ac.sanger.mig.phenotyping.calorimetry.parser.MalformedCalorimetryFileException;
import uk.ac.sanger.mig.phenotyping.calorimetry.parser.Parser;
import uk.ac.sanger.mig.phenotyping.calorimetry.parser.Sample;

public class ParserTest {

  private CalorimetryData data;


  public void loadFromFile() {
    Parser parser = new Parser();

    try {
      data = parser.loadFromFile(ParserTestUtil.getAbsoluteFilePath());
    }
    catch (Exception e) {
      fail("Threw exception "+e);
    }

    assertNotNull("Parser should return file",data);
  }


  /**
   * Buffer the test data into a byte array before passing to the parser.
   *
   * This is to emulate the situation where a file has been uploaded
   * to the server, rather than loaded from disc
   *
   * @return
   */
  public void loadViaByteBuffer() {
    byte[] testData = ParserTestUtil.getTestData();

    try {
      Parser parser= new Parser();
      data = parser.loadFromBytes(testData);
    } catch (MalformedCalorimetryFileException e) {
      fail("Exception thrown: "+e);
    } catch (ParseException e) {
      fail("Exception thrown: "+e);
    }
  }

  @Test
  public void  boxCountFile() {
    loadFromFile();

    Collection<BoxData> boxes = data.getBoxes();

    assertNotNull(boxes);
    assertEquals(11, boxes.size());
  }

  @Test
  public void sampleCountFile() {
    loadFromFile();

    Collection<Sample> samples = data.getSamples();

    assertNotNull(samples);
    assertEquals(836,samples.size());
  }

  @Test
  public void boxCountBytes() {
    loadViaByteBuffer();

    Collection<BoxData> boxes = data.getBoxes();

    assertNotNull(boxes);
    assertEquals(11, boxes.size());
  }

  @Test
  public void sampleCountBytes() {
    loadViaByteBuffer();

    Collection<Sample> samples = data.getSamples();

    assertNotNull(samples);
    assertEquals(836,samples.size());
  }




}
