package uk.ac.sanger.mig.phenotyping.calorimetry.parser;

import static org.junit.Assert.*;

import java.util.Date;

import org.apache.commons.lang.time.DateUtils;
import org.junit.Test;

public class SampleTest {

  @Test
  public void testGetFeedInFirstInterval() {
    float feedAmount = 10.10f;

    Sample s = new Sample();
    s.setFeed(feedAmount);

    assertEquals(feedAmount, s.getFeedInInterval(),0);
  }

  @Test
  public void testGetFeedInInterval() {
    float previousFeedAmount = 10f;
    float feedAmount = 10.10f;

    Sample previousSample = new Sample();
    previousSample.setFeed(previousFeedAmount);

    Sample s = new Sample();
    s.setFeed(feedAmount);

    s.setPreviousSample(previousSample);

    assertEquals(feedAmount - previousFeedAmount, s.getFeedInInterval(),0);
  }

  @Test
  public void testGetTimeElapsedSinceLastSample() {
    Sample s = getSamplesOneDayApart();

    assertEquals(DateUtils.MILLIS_PER_DAY, s.getTimeElapsedSinceLastSample().longValue());
  }

  @Test
  public void testGetHoursElapsedSinceLastSample() {
    Sample s = getSamplesOneDayApart();

    assertEquals(24, s.getHoursElapsedSinceLastSample().intValue());
  }

  @Test
  public void testCalculateRate() {
    Sample s = getSamplesOneDayApart();

    int measure = 48;

    assertEquals(2f, s.calculateRate(measure),0) ;
  }

  private Sample getSamplesOneDayApart() {
    Sample s = new Sample();
    Sample previous = new Sample();
    Date now = new Date();
    Date then = new Date(now.getTime() - DateUtils.MILLIS_PER_DAY);

    s.setDate(now);
    previous.setDate(then);
    s.setPreviousSample(previous);

    return s;
  }

}
