/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.datacapture.dao;

import static org.junit.Assert.*;
import static org.unitils.reflectionassert.ReflectionAssert.*;

import java.util.Collection;
import java.util.LinkedList;

import org.junit.Test;
import org.unitils.UnitilsJUnit4;
import org.unitils.dbunit.annotation.DataSet;
import org.unitils.spring.annotation.SpringApplicationContext;
import org.unitils.spring.annotation.SpringBean;

import uk.ac.sanger.mig.common.Pair;
import uk.ac.sanger.mig.phenotyping.datacapture.UploadMapping;
import uk.ac.sanger.mig.phenotyping.datacapture.services.UploadMappingService;
import uk.ac.sanger.mig.phenotyping.datacapture.services.UploadMappingService.Type;

/**
 *
 */
@SpringApplicationContext({"data-capture-dao.xml","dictionary.xml","common.xml","test-config.xml","unitils-test-database.xml"})
@DataSet
public class UploadMappingDaoTest extends UnitilsJUnit4{

  private Long activeSopId  = 10L;

  @SpringBean("uploadMappingDao")
  private UploadMappingDao uploadMappingDao;

  @Test
  public void testFetchActiveSopIdForUploadType() {
    Long sopId = uploadMappingDao.fetchActiveSopIdForUploadType(UploadMappingService.Type.MGP_CALORIMETRY);

    assertNotNull(sopId);
    assertEquals(activeSopId, sopId);
  }

  @Test
  public void testFetchBySopId() {
    Collection<UploadMapping> mappings = uploadMappingDao.fetchBySopId(activeSopId);

    assertEquals(2, mappings.size());
  }

  @Test
  public void testFetchSopsToUploadType() {
    Collection<Pair<Long,Type>> sopsToTypes = uploadMappingDao.fetchSopsToUploadType();

    Collection<Pair<Long,Type>> expected = new LinkedList<Pair<Long,Type>>();
    expected.add(new Pair<Long, Type>(10L,Type.MGP_CALORIMETRY));
    expected.add(new Pair<Long, Type>(11L,Type.MGP_CALORIMETRY));

    assertRefEquals(expected, sopsToTypes);
  }



}
