/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.phenotyping.datacapture.services;

import java.util.Collection;
import java.util.Date;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.phenotyping.datacapture.Experiment;
import uk.ac.sanger.mig.phenotyping.datacapture.ExperimentSet;
import uk.ac.sanger.mig.phenotyping.datacapture.ExperimentSetSearchBean;
import uk.ac.sanger.mig.phenotyping.datacapture.views.ExperimentSetListView;
import uk.ac.sanger.mig.testsupport.AbstractGenericServiceTest;

public class ExperimentServiceTest extends AbstractGenericServiceTest {
  private ExperimentSetService experimentSetService;
  
  public void setExperimentSetService(ExperimentSetService experimentSetService) {
    this.experimentSetService = experimentSetService;
  }
  
	public void setExperimentService(ExperimentService service) {
		this.service = service;
	}
	
	public void testDateChange() {
	  Experiment preTest = getExperimentForTest();
	  
	  Date testDate = new Date();
	  
	  Experiment postTest = ((ExperimentService)service).changeExperimentStart(preTest.getId(), testDate, getFakeUser());
	  
	  assertNotNull("Experiment should be returned", postTest);
	  assertNotNull("Procedure should be populated", postTest.getProcedure());
	  assertNotNull("Procedure should have a start date", postTest.getProcedure().getStartDate());
	  
	  assertEquals("Date in procedure should equal parameter on return", testDate, postTest.getProcedure().getStartDate());
	  
	  Experiment postStore = ((ExperimentService)service).fetchById(
	      preTest.getId(),
	      ComponentMap.of(Experiment.Component.PROCEDURE)
	  );
	  
	  assertNotNull("Experiment should be fetched", postStore);
    assertNotNull("Procedure should be populated on retrieval", postStore.getProcedure());
    assertNotNull("Procedure should have a start date on retrieval", postStore.getProcedure().getStartDate());
    
    // Lose some precision during storage, but this is acceptable
    long millisecondsDifference = postStore.getProcedure().getStartDate().getTime() - testDate.getTime();
    
    assertTrue("Date in procedure should be within a second of parameter on retrieval", (Math.abs(millisecondsDifference) < 1000)); 
	}
	
	public void testDateChangeFailsProperly() {
	  Experiment e = ((ExperimentService)service).changeExperimentStart(-1L, new Date(), getFakeUser());
	  
	  assertNull("Calling change date with a silly ID should cause it to return null",e);
	}

	
  private Experiment getExperimentForTest() {
    Experiment exp = null;
	  
	  ExperimentSetSearchBean esb = new ExperimentSetSearchBean();
	  esb.setPaginated(false);
	  esb.setRecordSetLength(1);
	  
	  Collection<ExperimentSetListView> listView = experimentSetService.search(esb);
	  
	  OUTER: for (ExperimentSetListView view : listView) {
	    ExperimentSet es = experimentSetService.fetchById(view.getId(), ComponentMap.of(ExperimentSet.Component.EXPERIMENTS));
	    
	    for (Experiment e : es.getExperiments()) {
	      exp = e;
	      break OUTER;
	    }
	  }
	  
	  assertNotNull("Require experiment for test, but did not get one", exp);
    return exp;
  }
	
}
