package uk.ac.sanger.mig.reservations.dao;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;

import org.junit.Before;
import org.junit.Test;
import org.unitils.UnitilsJUnit4;
import org.unitils.dbunit.annotation.DataSet;
import org.unitils.spring.annotation.SpringApplicationContext;
import org.unitils.spring.annotation.SpringBean;

import uk.ac.sanger.mig.reservations.Reservation;

@SpringApplicationContext( { "reservations-dao.xml", "common.xml", "test-config.xml", "unitils-test-database.xml" })
@DataSet
public class ReservationDaoSpringImplTest extends UnitilsJUnit4 {

	@SpringBean("reservationDao")
	private ReservationDao	reservationDao;

	private Long			mouseId1;
	private Long			mouseId2;


	@Before
	public void setUp() throws Exception {
		mouseId1 = 1L;
		mouseId2 = 2L;
	}


	/**
	 * Tests the the fetchForMouse() method returns a Reservation object, which it should because the data set defines
	 * one to satisfy the query being used.
	 *
	 */
	@Test
	public void fetchForMouseSingleMouse() {
		Reservation reservation = reservationDao.fetchForMouse(mouseId1);
		assertNotNull(reservation);
	}


	/**
	 * Tests that the fetchForMouse() method will return the same reservation when passed two mice attached to the same
	 * reservation.
	 *
	 */
	@Test
	public void fetchForMouseMultipleMice() {
		Reservation reservation1 = reservationDao.fetchForMouse(mouseId1);
		Reservation reservation2 = reservationDao.fetchForMouse(mouseId2);
		assertNotNull(reservation1);
		assertNotNull(reservation2);
		assertEquals(reservation1.getId(), reservation2.getId());
	}
}
