package uk.ac.sanger.mig.reservations.services;

import static org.easymock.EasyMock.expect;
import static org.unitils.easymock.EasyMockUnitils.replay;
import static org.unitils.easymock.EasyMockUnitils.verify;
import static org.unitils.reflectionassert.ReflectionAssert.assertRefEquals;

import java.util.Collection;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.Map;

import org.junit.Before;
import org.junit.Test;
import org.unitils.UnitilsJUnit4;
import org.unitils.easymock.annotation.Mock;
import org.unitils.inject.annotation.InjectIntoByType;
import org.unitils.inject.annotation.TestedObject;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.MailHelper;
import uk.ac.sanger.mig.mousetracking.Mouse;
import uk.ac.sanger.mig.mousetracking.services.MouseService;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.personnel.Team;
import uk.ac.sanger.mig.reservations.MouseReservation;
import uk.ac.sanger.mig.reservations.Purpose;
import uk.ac.sanger.mig.reservations.Reservation;
import uk.ac.sanger.mig.reservations.dao.MouseReservationDao;

public class MouseReservationServiceImplTest extends UnitilsJUnit4 {
	@TestedObject
	private MouseReservationServiceImpl		mouseReservationService;

	@Mock
	@InjectIntoByType
	private MailHelper						mockMailHelper;
	@Mock
	@InjectIntoByType
	private MouseService					mockMouseService;
	@Mock
	@InjectIntoByType
	private ReservationService				mockReservationService;
	@Mock
	@InjectIntoByType
	private MouseReservationDao				mockMouseReservationDao;

	private Person							user;
	private Person							reserver;
	private Team							team;
	private Purpose							purpose;
	private MouseReservation				mouseReservation;
	private MouseReservation				mouseReservationAtMail;
	private MouseReservation				mouseReservationAtStore;
	private MouseReservation				mouseReservationAttached;
	private Reservation						reservation;
	private Mouse							mouse;
	private Collection<MouseReservation>	mouseReservations;
	private Collection<MouseReservation>	mouseReservationsAtMail;
	private Collection<MouseReservation>	mouseReservationsAtStore;
	private Map<String, Object>				templateModel;
	private Collection<Long>				mouseIds;

	private String							email					= "test@test.com";
	private Long							personId				= 2L;
	private Long							mouseReservationId		= 3L;
	private Long							reservationId			= 5L;
	private Long							mouseId					= 7L;
	private Long							teamId					= 11L;
	private Long							purposeId				= 13L;
	private Long							reserverId				= 17L;

	private String							reservationTemplateKey	= "reservation_alert";


	@Before
	public void setUp() {
		user = new Person();
		user.setId(personId);

		reserver = new Person();
		reserver.setId(reserverId);
		reserver.setEmail(email);

		team = new Team();
		team.setId(teamId);

		purpose = new Purpose();
		purpose.setId(purposeId);

		mouse = new Mouse();
		mouse.setId(mouseId);
		mouseIds = new LinkedList<Long>();
		mouseIds.add(mouseId);

		reservation = new Reservation();
		reservation.setId(reservationId);
		reservation.setReserverId(reserverId);
		reservation.setTeamId(teamId);
		reservation.setPurposeId(purposeId);
		reservation.setReserver(reserver);
		reservation.setTeam(team);
		reservation.setPurpose(purpose);

		mouseReservation = new MouseReservation();
		mouseReservation.setId(mouseReservationId);
		mouseReservation.setMouseId(mouseId);
		mouseReservation.setReservationId(reservationId);
		mouseReservation.setNotificationSent(false);

		mouseReservationAtMail = new MouseReservation();
		mouseReservationAtMail.setId(mouseReservationId);
		mouseReservationAtMail.setMouseId(mouseId);
		mouseReservationAtMail.setReservationId(reservationId);
		mouseReservationAtMail.setMouse(mouse);

		mouseReservationAtStore = new MouseReservation();
		mouseReservationAtStore.setId(mouseReservationId);
		mouseReservationAtStore.setMouseId(mouseId);
		mouseReservationAtStore.setReservationId(reservationId);
		mouseReservationAtStore.setMouse(mouse);
		// set notification sent in the test, it varies

		mouseReservationAttached = new MouseReservation();
		mouseReservationAttached.setId(mouseReservationId);
		mouseReservationAttached.setMouseId(mouseId);
		mouseReservationAttached.setReservationId(reservationId);
		mouseReservationAttached.setMouse(mouse);
		mouseReservationAttached.setReservation(reservation);

		mouseReservations = new LinkedList<MouseReservation>();
		mouseReservations.add(mouseReservation);

		mouseReservationsAtMail = new LinkedList<MouseReservation>();
		mouseReservationsAtMail.add(mouseReservationAtMail);

		mouseReservationsAtStore = new LinkedList<MouseReservation>();
		mouseReservationsAtStore.add(mouseReservationAtStore);

		templateModel = new HashMap<String, Object>();
		templateModel.put("reservation", reservation);
		templateModel.put("mouseReservations", mouseReservationsAtMail);
	}


	@Test
	public void sendAlertEmailsSuccess() {
		mouseReservationAtStore.setNotificationSent(true);

		expect(mockMouseReservationDao.fetchForDeathNotification()).andReturn(mouseReservations);
		expect(
				mockReservationService.fetchById(reservationId, ComponentMap.of(Reservation.Component.PURPOSE,
						Reservation.Component.RESERVER, Reservation.Component.TEAM))).andReturn(reservation);
		expect(mockMouseService.fetchById(mouseId, null)).andReturn(mouse);
		expect(mockMailHelper.sendMail(reservationTemplateKey, templateModel, new String[] { email })).andReturn(true);
		expect(mockMouseReservationDao.store(mouseReservationAtStore, user)).andReturn(mouseReservationId);

		replay();

		mouseReservationService.sendAlertEmails(user);

		verify();

	}


	@Test
	public void sendAlertEmailsFailMail() {
		mouseReservationAtStore.setNotificationSent(false);

		expect(mockMouseReservationDao.fetchForDeathNotification()).andReturn(mouseReservations);
		expect(
				mockReservationService.fetchById(reservationId, ComponentMap.of(Reservation.Component.PURPOSE,
						Reservation.Component.RESERVER, Reservation.Component.TEAM))).andReturn(reservation);
		expect(mockMouseService.fetchById(mouseId, null)).andReturn(mouse);
		expect(mockMailHelper.sendMail(reservationTemplateKey, templateModel, new String[] { email })).andReturn(false);
		expect(mockMouseReservationDao.store(mouseReservationAtStore, user)).andReturn(mouseReservationId);

		replay();

		mouseReservationService.sendAlertEmails(user);

		verify();

	}

	/**
	 * 
	 *
	 */
	@Test
	public void testFetchAndAttach() {
		expect(mockMouseReservationDao.fetchById(mouseReservationId)).andReturn(mouseReservation);
		expect(mockMouseService.fetchById(mouseId, null)).andReturn(mouse);
		expect(mockReservationService.fetchById(reservationId, null)).andReturn(reservation);
		replay();
		MouseReservation testResult = mouseReservationService.fetchById(mouseReservationId, ComponentMap
				.of(MouseReservation.Component.ALL_COMPONENTS));
		verify();
		assertRefEquals(mouseReservationAttached, testResult);
	}


	/**
	 * Tests that the deleteReservationForMice() method correctly fetches the Mouse objects for each of the mouse ids
	 * passed in to it and then deletes their associated mouse reservations. Finally, the method should delete the
	 * reservation if it no longer contains any mouse reservations.
	 * 
	 */
	@Test
	public void testDelete() {
		expect(mockMouseReservationDao.fetchForMouse(mouseId)).andReturn(mouseReservation);
		expect(mockMouseReservationDao.delete(mouseReservation, user)).andReturn(1);
		mockReservationService.deleteReservationIfEmpty(reservationId, user);
		replay();
		mouseReservationService.deleteReservationForMice(mouseIds, user);
		verify();
	}


	/**
	 * Explicitly tests the delete service method that should delete a single mouse reservation and then call the
	 * reservation services method to delete the reservation if it's empty.
	 * 
	 */
	@Test
	public void delete() {
		expect(mockMouseReservationDao.delete(mouseReservation, user)).andReturn(1);
		mockReservationService.deleteReservationIfEmpty(reservationId, user);
		replay();
		mouseReservationService.delete(mouseReservation, user);
		verify();
	}

}
