/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.testsupport;

import java.util.Set;

import org.unitils.core.dbsupport.OracleDbSupport;
import org.unitils.core.dbsupport.SQLHandler;

public class MigOracleDbSupport extends OracleDbSupport {

  /**
   * Removes the table with the given name from the database.
   * Note: the table name is surrounded with quotes, making it case-sensitive.
   *
   * Differs from parent as it checks if the tableName is really a materialized view and uses the correct syntax to drop it.
   *
   * @param tableName The table to drop (case-sensitive), not null
   */
  @Override
  public void dropTable(String tableName) {
    Set mvCheck = getSQLHandler().getItemsAsStringSet("select TABLE_NAME from USER_SNAPSHOTS where TABLE_NAME = '"+tableName+"'");
    String dropSql;

    if (!mvCheck.isEmpty()) {
      dropSql = "drop materialized view " + qualified(tableName);
    }
    else {
      dropSql = "drop table " + qualified(tableName) + " cascade constraints" + (supportsPurge() ? " purge" : "");
    }


    getSQLHandler().executeUpdate(dropSql);
  }

  /**
   * Removes all constraints on the specified table
   *
   * Differs from parent as it does not attempt to disable unique constraints
   *
   * @param tableName The table with the column, not null
   */
  //@Override
  public void disableConstraints(String tableName) {
      SQLHandler sqlHandler = getSQLHandler();
      Set<String> constraintNames = sqlHandler.getItemsAsStringSet("select CONSTRAINT_NAME from USER_CONSTRAINTS where TABLE_NAME = '" + tableName + "' and CONSTRAINT_TYPE not in ('U','P') and STATUS = 'ENABLED'");
      for (String constraintName : constraintNames) {
          sqlHandler.executeUpdate("alter table " + qualified(tableName) + " disable constraint " + quoted(constraintName));
      }
  }

}
