package uk.ac.sanger.mig.testsupport;

import java.sql.SQLException;

import org.dbunit.dataset.CompositeTable;
import org.dbunit.dataset.DataSetException;
import org.dbunit.dataset.DefaultDataSet;
import org.dbunit.dataset.FilteredDataSet;
import org.dbunit.dataset.FilteredTableMetaData;
import org.dbunit.dataset.IDataSet;
import org.dbunit.dataset.ITable;
import org.dbunit.dataset.ITableIterator;
import org.dbunit.dataset.filter.IColumnFilter;
import org.dbunit.dataset.filter.IncludeTableFilter;
import org.unitils.core.UnitilsException;
import org.unitils.dbunit.util.DbUnitAssert;
import org.unitils.dbunit.util.DbUnitDatabaseConnection;

/**
 * Assertion class
 */
public class MigUnitTestAssert extends DbUnitAssert{
  /**
   *
   * @param expectedDataSet
   * @param dbUnitDatabaseConnection
   * @param columnFilter
   */
  public static void assertDbContentAsExpected(
      IDataSet expectedDataSet,
      DbUnitDatabaseConnection dbUnitDatabaseConnection,
      IColumnFilter columnFilter) {
    if (expectedDataSet == null) {
      // no data set should be compared
      return;
    }
    try {
      // get the actual data set
      IDataSet actualDataSet = dbUnitDatabaseConnection.createDataSet();
      IDataSet filteredActualDataSet = new FilteredDataSet(new IncludeTableFilter(expectedDataSet.getTableNames()), actualDataSet);
      assertEqualsDataSet(expectedDataSet, filteredActualDataSet, columnFilter);

    } catch (SQLException e) {
      throw new UnitilsException("Unable to assert whether db content is as expected.", e);
    } catch (DataSetException e) {
      throw new UnitilsException("Unable to assert whether db content is as expected", e);

    }
  }

  public static void assertEqualsDataSet(IDataSet expectedDataSet, IDataSet actualDataSet, IColumnFilter columnFilter) {
    IDataSet filteredExpectedDataSet = filterColumnsInDataSet(expectedDataSet, columnFilter);
    IDataSet filteredActualDataSet = filterColumnsInDataSet(actualDataSet, columnFilter);
    DbUnitAssert.assertEqualsDataSet(filteredExpectedDataSet, filteredActualDataSet);
  }

  private static IDataSet filterColumnsInDataSet(IDataSet dataSet, IColumnFilter columnFilter) {
    if (columnFilter == null) {
      return dataSet;
    }


    DefaultDataSet replacementDataSet = new DefaultDataSet();

    try {
      ITableIterator iterator = dataSet.iterator();
      while (iterator.next()){
        ITable table = iterator.getTable();
        ITable filteredTable = filterColumns(table, columnFilter);

        replacementDataSet.addTable(filteredTable);
      }
    }
    catch (DataSetException e) {
      // wrap and throw
      throw new RuntimeException(e);
    }

    return replacementDataSet;
  }

  private static ITable filterColumns(ITable table, IColumnFilter columnFilter) throws DataSetException {
    FilteredTableMetaData metaData = new FilteredTableMetaData(
        table.getTableMetaData(), columnFilter);
    return new CompositeTable(metaData, table);
  }

}


