/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

create synonym mts_mouse_audit for mig_audit.mts_mouse_audit;

create synonym mts_cage_audit for mig_audit.mts_cage_audit;

create synonym mts_mouse_health_audit for mig_audit.mts_mouse_health_audit;

create synonym mts_air_handling_unit_audit for mig_audit.mts_air_handling_unit_audit;

create synonym mts_litter_audit for mig_audit.mts_litter_audit;

create synonym mts_room_audit for mig_audit.mts_room_audit;

create synonym mts_rack_audit for mig_audit.mts_rack_audit;

create synonym mts_breeding_audit for mig_audit.mts_breeding_audit;

drop trigger req_animal_request_trig;

CREATE TABLE CRQ_CRYO_REQUEST_STRAIN_DICT
(
  ID           INTEGER,
  NAME         VARCHAR2(64 CHAR)                NOT NULL,
  DESCRIPTION  VARCHAR2(2048 CHAR),
  ACTIVE       NUMBER(1)                        NOT NULL,
  ORDER_BY     NUMBER
)
TABLESPACE DATA_02
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;


CREATE UNIQUE INDEX CRQ_CRYO_REQUEST_STRAIN_DICTPK ON CRQ_CRYO_REQUEST_STRAIN_DICT
(ID)
LOGGING
TABLESPACE INDEX_02
NOPARALLEL;


ALTER TABLE CRQ_CRYO_REQUEST_STRAIN_DICT ADD (
  CONSTRAINT CRQ_CRYO_REQUEST_STRAIN_DICTPK
 PRIMARY KEY
 (ID)
    USING INDEX 
    TABLESPACE INDEX_02);

INSERT INTO CRQ_CRYO_REQUEST_STRAIN_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
1, 'Albino B6', NULL, 1, 1); 
INSERT INTO CRQ_CRYO_REQUEST_STRAIN_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
2, 'B6', NULL, 1, 2); 
INSERT INTO CRQ_CRYO_REQUEST_STRAIN_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
3, '129Sv5', NULL, 1, 3); 
INSERT INTO CRQ_CRYO_REQUEST_STRAIN_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
4, 'CBA', NULL, 1, 4); 
INSERT INTO CRQ_CRYO_REQUEST_STRAIN_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
5, 'Other', NULL, 1, 5); 
COMMIT;



create table crq_cryo_request_old 
as select * from crq_cryo_request;

drop table crq_cryo_request purge;

create table crq_cryo_request
(
  id                  integer,
  person_id           integer,
  project_licence_id  integer,
  colony_id           integer,
  strain_dict_id      integer,
  creator_id          integer,
  created_date        date,
  edited_by           varchar2(128 char),
  edit_date           date,
  check_number        number,
  status_dict_id      integer
)
tablespace data_02
;

create unique index crq_cryo_request_pk1 on crq_cryo_request
(id)
logging
tablespace index_02
noparallel;

alter table crq_cryo_request add (
  constraint crq_cryo_request_pk
 primary key
 (id)
    using index 
    tablespace index_02);

alter table crq_cryo_request add (
  constraint crq_cryo_request_r06 
 foreign key (strain_dict_id) 
 references typ_strain (id));

alter table crq_cryo_request add (
  constraint crq_cryo_request_r05 
 foreign key (status_dict_id) 
 references crq_cryo_request_status_dict (id));

alter table crq_cryo_request add (
  constraint crq_cryo_request_r04 
 foreign key (creator_id) 
 references per_person (person_id));

alter table crq_cryo_request add (
  constraint crq_cryo_request_r03 
 foreign key (colony_id) 
 references mts_colony_info (id));

alter table crq_cryo_request add (
  constraint crq_cryo_request_r02 
 foreign key (project_licence_id) 
 references lic_project_licence (project_licence_id));

alter table crq_cryo_request add (
  constraint crq_cryo_request_r01 
 foreign key (person_id) 
 references per_person (person_id));
  
insert into mts_colony_info(id,colony_name,colony_prefix)
select mts_colony_info_seq.nextval, upper(c.colony_prefix), upper(c.colony_prefix)
from crq_cryo_request_old c where upper(c.colony_prefix) 
not in (select upper(i.colony_prefix) from mts_colony_info i);

insert into crq_cryo_request
select 
  o.id,
  p.person_id,
  l.project_licence_id,
  c.id colony_info_id,
  d1.id female_strain_id,
  p.person_id creator_id,
  o.created_date,
  o.edited_by,
  o.edit_date,
  0 check_number,
  o.status_dict_id
from
  crq_cryo_request_old o,
  per_person p,
  lic_project_licence l,
  mts_colony_info c,
  crq_cryo_request_strain_dict d1 
where
  lower(o.requestor_name) = lower(p.first_name||' '||p.last_name) and
  l.licence_number = o.ppl and
  upper(o.colony_prefix) = upper(c.colony_prefix(+)) and
  d1.name = o.female_strain;
  
commit;

alter table arq_design_request add retrieval_primer_offset_3p integer;

alter table arq_design_request rename column retrieval_primer_offset to retrieval_primer_offset_5p;
 
alter table arq_design_request add retrieval_primer_length_3p integer;

alter table arq_design_request rename column retrieval_primer_length to retrieval_primer_length_5p;

alter table arq_design_request add critical_exon_contains_atg number(1);

alter table arq_design_request add score integer default null;

-- alter the trigger on arq_design_request table

create or replace trigger arq_design_request_ta
before update or delete on arq_design_request for each row

/* this trigger was autogenerated by dbms_mig.make_audit_trigger */

begin

if deleting or updating then 

 insert into arq_design_request_audit(
    id,
    allele_request_id,
    status_dict_id,
    created_date,
    edited_date,
    created_by,
    comments,
    edited_by,
    vega_id,
    promoter_inclusion,
    gene_build_id,
    gene_build_gene_id,
    start_exon_id,
    end_exon_id,
    target_start,
    target_end,
    min_5p_exon_flanks,
    min_3p_exon_flanks,
    split_target_seq_length,
    multi_region_offset_shim,
    primer_length,
    retrieval_primer_offset_3p,	
	retrieval_primer_offset_5p,	
    retrieval_primer_length_3p,	
	retrieval_primer_length_5p,
	critical_exon_contains_atg,
	score,	
    conserved_elements,
    creator_id)
 values (
    :old.id,
    :old.allele_request_id,
    :old.status_dict_id,
    :old.created_date,
    :old.edited_date,
    :old.created_by,
    :old.comments,
    :old.edited_by,
    :old.vega_id,
    :old.promoter_inclusion,
    :old.gene_build_id,
    :old.gene_build_gene_id,
    :old.start_exon_id,
    :old.end_exon_id,
    :old.target_start,
    :old.target_end,
    :old.min_5p_exon_flanks,
    :old.min_3p_exon_flanks,
    :old.split_target_seq_length,
    :old.multi_region_offset_shim,
    :old.primer_length,
    :old.retrieval_primer_offset_3p,	
	:old.retrieval_primer_offset_5p,
    :old.retrieval_primer_length_3p,	
	:old.retrieval_primer_length_5p,
	:old.critical_exon_contains_atg,
	:old.score,
    :old.conserved_elements,
    :old.creator_id);
end if;

end;
/

update arq_design_request set retrieval_primer_offset_3p = retrieval_primer_offset_5p;

update arq_design_request set retrieval_primer_length_3p = retrieval_primer_length_5p;

--update the score field in arq_design_request

update arq_design_request set score = 1 where comments like '%SCORE_1%';

update arq_design_request set score = 2 where comments like '%SCORE_2%';

update arq_design_request set score = 3 where comments like '%SCORE_3%';
	
commit;

--view on design_status_dict table 

create or replace view arq_design_status_vw (id,
                                             name,
                                             description,
                                             order_by,
                                             is_active
                                            )
as
   select design_status_id id, description name, '' description, 0 order_by,
          1 is_active
     from eucomm_vector.design_status_dict;




--view on design_instance_status_dict table

create or replace view arq_des_instance_status_vw (id,
                                                   name,
                                                   description,
                                                   order_by,
                                                   active
                                                  )
as
   select design_instance_status_id id, description name, '' description,
          0 order_by, 1 active
     from eucomm_vector.design_instance_status_dict;



--view on clone lib dict

/* formatted on 2007/03/05 17:48 (formatter plus v4.8.7) */
create or replace view arq_clone_lib_dict_vw (id,
                                              name,
                                              description,
                                              order_by,
                                              active
                                             )
as
   select clone_lib_id as id, library as name, '' as description, 0 order_by,
          1 active
     from eucomm_vector.clone_lib_dict;


--change design request list view (right join on havana request)

create or replace view arq_design_request_list_vw (id,
                                                   status_dict_id,
                                                   allele_request_id,
                                                   comments,
                                                   created_by,
                                                   edited_date,
                                                   status,
                                                   created_date,
                                                   edited_by,
                                                   primary_name,
                                                   vega_id,
                                                   build_name,
                                                   havana_request_id,
                                                   gene_build_gene_primary_name
                                                  )
as
   select v.id, v.status_dict_id, v.allele_request_id, v.comments,
          v.created_by, v.edited_date, d.name status, v.created_date,
          v.edited_by, g.primary_name, ah.vega_id, g.build_name, ah.id,
          g.gene_build_gene_primary_name
     from arq_design_request v,
          arq_allele_request a,
          arq_havana_request ah,
          gnm_gene_vw g,
          arq_design_req_status_dict_vw d,
          arq_allele_request_source_dict s
    where a.id = v.allele_request_id
      and ah.allele_request_id(+) = a.id
      and a.gene_id = g.gene_id
      and a.request_source_dict_id = s.id
      and v.status_dict_id = d.id;


DROP TABLE MIR_MICRO_INJ_REQ_AUDIT_OLD CASCADE CONSTRAINTS purge;

DROP TABLE MIR_MICRO_INJECTION_REQ_OLD CASCADE CONSTRAINTS purge;

CREATE SEQUENCE MIR_EMBRYO_HARVEST_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE MIR_EMBRYO_TRANSFER_PROC_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE MIR_MICRO_INJECTION_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE MIR_SCHEDULED_MI_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE MIR_SCHEDULED_MI_TASK_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE TABLE MIR_ANAESTHETIC_DICT
(
  ID           INTEGER,
  NAME         VARCHAR2(256 CHAR),
  DESCRIPTION  VARCHAR2(2048 CHAR),
  ACTIVE       NUMBER(1)                        DEFAULT 1,
  ORDER_BY     NUMBER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MIR_ANALGESIA_DICT
(
  ID           INTEGER,
  NAME         VARCHAR2(256 CHAR),
  DESCRIPTION  VARCHAR2(2048 CHAR),
  ACTIVE       NUMBER(1)                        DEFAULT 1,
  ORDER_BY     NUMBER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

ALTER TABLE MIR_CELL_LINE
MODIFY(CREATED_DATE  DEFAULT sysdate);

ALTER TABLE MIR_CELL_LINE
MODIFY(EDIT_DATE  DEFAULT sysdate);

ALTER TABLE MIR_CELL_LINE
 ADD (CELL_LINE_PROVIDER_ID  NUMBER);
 
update mir_cell_line set cell_line_provider_id = creator_id;

CREATE TABLE MIR_EMBRYO_HARVEST
(
  ID                         NUMBER,
  EDITED_DATE                DATE               DEFAULT sysdate,
  EDITED_BY                  VARCHAR2(128 BYTE),
  CREATED_DATE               DATE               DEFAULT sysdate,
  CREATOR_ID                 NUMBER,
  CHECK_NUMBER               NUMBER,
  COMMENTS                   VARCHAR2(4000 BYTE),
  BLASTOCYST_COUNT           NUMBER,
  MORALAE_COUNT              NUMBER,
  EIGHT_CELL_COMP_COUNT      NUMBER,
  EIGHT_CELL_NON_COMP_COUNT  NUMBER,
  FOUR_CELL_COUNT            NUMBER,
  HATCHED_COUNT              NUMBER,
  DEAD_OR_FRAGMENTED_COUNT   NUMBER,
  OTHER_EMBRYO_TYPE_COUNT    INTEGER,
  FLUSH_DATE                 DATE,
  OVERNIGHT_INCUBATION       NUMBER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MIR_EMBRYO_TRANSFER_PROCEDURE
(
  ID                            INTEGER,
  CREATED_DATE                  DATE            DEFAULT sysdate,
  EDITED_BY                     VARCHAR2(128 CHAR),
  EDIT_DATE                     DATE            DEFAULT sysdate,
  CHECK_NUMBER                  INTEGER,
  MOUSE_WEIGHT                  NUMBER,
  NUMBER_RIGHT                  INTEGER,
  NUMBER_LEFT                   INTEGER,
  ANAESTHETIC_DICT_ID           INTEGER,
  DOSE_ANESTHETIC               NUMBER,
  ANALGESIA_DICT_ID             INTEGER,
  DOSE_ANALGESIA                NUMBER,
  TRANSFER_TYPE_DICT_ID         INTEGER,
  STUFFER_STRAIN_ID             INTEGER,
  NUMBER_RIGHT_STUFFERS         INTEGER,
  NUMBER_LEFT_STUFFERS          INTEGER,
  CREATOR_ID                    INTEGER,
  COMMENTS                      VARCHAR2(4000 BYTE),
  SCHEDULED_MICRO_INJECTION_ID  NUMBER,
  MOUSE_ID                      NUMBER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MIR_INTERNAL_STATUS_DICT
(
  ID           NUMBER,
  NAME         VARCHAR2(128 CHAR),
  DESCRIPTION  VARCHAR2(2048 CHAR),
  ACTIVE       NUMBER(1),
  ORDER_BY     NUMBER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MIR_MICRO_INJECTION
(
  ID                            INTEGER,
  CREATED_DATE                  DATE            DEFAULT sysdate,
  EDITED_BY                     VARCHAR2(128 CHAR) DEFAULT NULL,
  EDIT_DATE                     DATE            DEFAULT sysdate,
  CHECK_NUMBER                  INTEGER,
  EMBRYO_STAGE_DICT_ID          INTEGER,
  EMBRYO_COUNT                  INTEGER,
  ES_CELL_PER_EMBRYO            INTEGER,
  CELL_LINE_ID                  INTEGER,
  DATE_COMPLETED                DATE,
  COMMENTS                      VARCHAR2(4000 CHAR),
  CREATOR_ID                    INTEGER,
  SCHEDULED_MICRO_INJECTION_ID  NUMBER,
  EMBRYO_HARVEST_ID             INTEGER,
  ES_CELLS_PER_EMBRYO_FROM      INTEGER,
  ES_CELLS_PER_EMBRYO_TO        INTEGER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

ALTER TABLE MIR_MICRO_INJECTION_REQUEST
MODIFY(EDIT_DATE  DEFAULT sysdate);

ALTER TABLE MIR_MICRO_INJECTION_REQUEST
MODIFY(STATUS_COMMENTS VARCHAR2(4000 BYTE));


ALTER TABLE MIR_MICRO_INJECTION_REQUEST
 ADD (CHECK_NUMBER  INTEGER);

CREATE TABLE MIR_MI_129_TASK_TEMPLATE
(
  ID               INTEGER,
  NAME             VARCHAR2(128 CHAR),
  DESCRIPTION      VARCHAR2(4000 CHAR),
  SEQUENCE_NUMBER  INTEGER,
  TIME_OFFSET      NUMBER,
  TIME_UNIT        VARCHAR2(255 BYTE),
  IS_MILESTONE     NUMBER(1)
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MIR_MI_B6_TASK_TEMPLATE
(
  ID               INTEGER,
  NAME             VARCHAR2(128 CHAR),
  DESCRIPTION      VARCHAR2(4000 CHAR),
  SEQUENCE_NUMBER  INTEGER,
  TIME_OFFSET      NUMBER,
  TIME_UNIT        VARCHAR2(255 BYTE),
  IS_MILESTONE     NUMBER(1)
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MIR_MI_F0_EMBRYO_TASK_TEMPLATE
(
  ID               INTEGER,
  NAME             VARCHAR2(128 CHAR),
  DESCRIPTION      VARCHAR2(4000 CHAR),
  SEQUENCE_NUMBER  INTEGER,
  TIME_OFFSET      NUMBER,
  TIME_UNIT        VARCHAR2(255 BYTE),
  IS_MILESTONE     NUMBER(1)
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MIR_SCHEDULED_MICRO_INJECTION
(
  ID                             NUMBER,
  CREATOR_ID                     NUMBER,
  CREATED_DATE                   DATE           DEFAULT SYSDATE,
  EDITED_BY                      VARCHAR2(128 BYTE),
  EDITED_DATE                    DATE           DEFAULT SYSDATE,
  CHECK_NUMBER                   NUMBER,
  TARGET_SCHEDULE_DATE           DATE,
  MICRO_INJECTION_REQUEST_ID     NUMBER,
  DONOR_ANIMAL_REQUEST_ID        NUMBER,
  RECIPIENT_ANIMAL_REQUEST_ID    NUMBER,
  COMMENTS                       VARCHAR2(4000 BYTE),
  INTERNAL_STATUS_DICT_ID        NUMBER,
  SUPPLEMENTAL_RECIPIENT_REQ_ID  NUMBER,
  CANCEL_OR_FAIL_REASONS         VARCHAR2(4000 BYTE),
  CELL_LINE_PROVIDER_ID          NUMBER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MIR_SCHEDULED_MI_TASK
(
  ID                            NUMBER,
  ESTIMATED_COMPLETION_DATE     DATE,
  ACTUAL_COMPLETION_DATE        DATE,
  DESCRIPTION                   VARCHAR2(4000 BYTE),
  SCHEDULED_MICRO_INJECTION_ID  INTEGER,
  NAME                          VARCHAR2(255 BYTE),
  SEQUENCE_NUMBER               INTEGER,
  IS_MILESTONE                  INTEGER,
  CREATOR_ID                    NUMBER,
  CREATED_DATE                  DATE,
  EDITED_BY                     VARCHAR2(128 BYTE),
  EDITED_DATE                   DATE,
  CHECK_NUMBER                  NUMBER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MIR_TRANSFER_TYPE_DICT
(
  ID           INTEGER,
  NAME         VARCHAR2(128 CHAR),
  DESCRIPTION  VARCHAR2(4000 CHAR),
  ORDER_BY     INTEGER,
  ACTIVE       INTEGER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE UNIQUE INDEX MIR_MI_TASK_B6_TEMPLATE_PK ON MIR_MI_B6_TASK_TEMPLATE
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MIR_MI_TASK_B6_TEMPLATE_U01 ON MIR_MI_B6_TASK_TEMPLATE
(NAME)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MIR_INTERNAL_STATUS_DICT_U01 ON MIR_INTERNAL_STATUS_DICT
(NAME)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MIR_MI_F0_DICT_R02 ON MIR_MI_F0_EMBRYO_TASK_TEMPLATE
(NAME)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MIR_MI_TASK_B6_TEMPLATE_R01 ON MIR_MI_B6_TASK_TEMPLATE
(SEQUENCE_NUMBER)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MIR_TRANSFER_TYPE_DICT_PK ON MIR_TRANSFER_TYPE_DICT
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MIR_MICRO_INJECTION_PROCEDU_PK ON MIR_MICRO_INJECTION
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MIR_MI_F0_DICT_R04 ON MIR_MI_F0_EMBRYO_TASK_TEMPLATE
(SEQUENCE_NUMBER)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MIR_EMBRYO_HARVEST_PK ON MIR_EMBRYO_HARVEST
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MIR_EMBRYO_TRANSFER_PK ON MIR_EMBRYO_TRANSFER_PROCEDURE
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MIR_MICRO_INJECTION_U01 ON MIR_MICRO_INJECTION
(SCHEDULED_MICRO_INJECTION_ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MIR_SCHEDULED_MICRO_INJECTI_PK ON MIR_SCHEDULED_MICRO_INJECTION
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MIR_MI_F0_DICT_R01 ON MIR_MI_F0_EMBRYO_TASK_TEMPLATE
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MIR_SCHEDULED_MI_TASK_PK ON MIR_SCHEDULED_MI_TASK
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MIR_CHIMERA_MATE_STRAIN_DICTPK ON MIR_CHIMERA_MATE_STRAIN_DICT
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MIR_ANAESTHETIC_DICT_R01 ON MIR_ANAESTHETIC_DICT
(NAME)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MIR_ANALGESIC_DICT_R01 ON MIR_ANALGESIA_DICT
(NAME)
LOGGING
NOPARALLEL;

alter table mir_request_status_dict drop constraint MIR_REQUEST_STATUS_DICT_PK;

DROP INDEX MIR_REQUEST_STATUS_DICT_PK;

CREATE UNIQUE INDEX MIR_REQUEST_STATUS_DICT_PK ON MIR_INTERNAL_STATUS_DICT
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MIR_MI_TASK_DICT_R04 ON MIR_MI_129_TASK_TEMPLATE
(SEQUENCE_NUMBER)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MIR_MI_TASK_DICT_R01 ON MIR_MI_129_TASK_TEMPLATE
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MIR_MI_TASK_DICT_R02 ON MIR_MI_129_TASK_TEMPLATE
(NAME)
LOGGING
NOPARALLEL;

CREATE INDEX MIR_SCHEDULED_MI_TASK_IND1 ON MIR_SCHEDULED_MI_TASK
(SCHEDULED_MICRO_INJECTION_ID)
LOGGING
NOPARALLEL;

-- No action taken.  This is a column of a view.  
-- Changes should be made in underlying objects of the view, not the view itself.

CREATE OR REPLACE FORCE VIEW MIR_CELL_LINE_LIST_VW
(ID, CREATED_BY, CELL_LINE_PROVIDER_NAME_NO, CREATOR_ID, CREATED_DATE, 
 CELL_LINE_NAME, GENE_ID, GENE_NAME, ALLELE_NAME, MODIFIED_ALLELE_ID, 
 CELL_LINE_SOURCE, CELL_LINE_SOURCE_ID, CLONE_NAME, COAT_COLOR_NAME, COAT_COLOR_ID, 
 STRAIN_NAME, STRAIN_ID, GENOTYPE, GENOTYPE_ID, WILDTYPE_PRIMER_FORWARD, 
 WILDTYPE_PRIMER_REVERSE, WILDTYPE_EXPECTED_SIZE, ALLELE_PRIMER_FORWARD, ALLELE_PRIMER_REVERSE, ALLELE_EXPECTED_SIZE, 
 EDIT_DATE, EDITED_BY)
AS 
SELECT c.ID, p.first_name || ' ' || p.last_name created_by,
       DECODE (cp.phone_number,
               '', cp.first_name || ' ' || cp.last_name,
                  cp.first_name
               || ' '
               || cp.last_name
               || '('
               || cp.phone_number
               || ')'
              ) cell_line_provider_name_no,
       c.creator_id, c.created_date, c.cell_line_name, mod_allele.gene_id,
       mod_allele.gene_name, mod_allele.allele_name,
       mod_allele.ID modified_allele_id, cs.NAME cell_line_source,
       cs.ID cell_line_source_id, c.clone_name, cc.NAME coat_color_name,
       cc.ID coat_color_id, st.NAME strain_name, st.ID strain_id,
       gd.NAME genotype, gd.ID genotype_id,
       mod_allele.wildtype_primer_forward, mod_allele.wildtype_primer_reverse,
       mod_allele.wildtype_expected_size, mod_allele.allele_primer_forward,
       mod_allele.allele_primer_reverse, mod_allele.allele_expected_size,
       c.edit_date, c.edited_by
  FROM mir_cell_line c,
       per_person p,
       per_person cp,
       mts_coat_colour_dict cc,
       mir_cell_line_strain_dict st,
       mir_es_cell_line_source_dict cs,
       mts_genotype_dict gd,
       (SELECT a.ID, a.gene_id, g.primary_name gene_name,
               a.official_name_superscript allele_name,
               a.ID modified_allele_id, gt_test.wildtype_primer_forward,
               gt_test.wildtype_primer_reverse,
               gt_test.wildtype_expected_size, gt_test.allele_primer_forward,
               gt_test.allele_primer_reverse, gt_test.allele_expected_size
          FROM typ_modified_allele a,
               gnm_gene g,
               (SELECT gt.modified_allele_id,
                       gpp1.five_primer_forward wildtype_primer_forward,
                       gpp1.three_primer_reverse wildtype_primer_reverse,
                       gpp1.expected_size wildtype_expected_size,
                       gpp2.five_primer_forward allele_primer_forward,
                       gpp2.three_primer_reverse allele_primer_reverse,
                       gpp2.expected_size allele_expected_size
                  FROM typ_genotype_test gt,
                       typ_genotyping_primer_pair gpp1,
                       typ_genotyping_primer_pair gpp2
                 WHERE gpp1.genotype_test_id = gt.ID
                   AND gpp1.primer_pair_type_id = 1
                   AND gpp2.genotype_test_id = gt.ID
                   AND gpp2.primer_pair_type_id = 2) gt_test
         WHERE a.gene_id = g.gene_id(+) AND gt_test.modified_allele_id(+) =
                                                                          a.ID) mod_allele
 WHERE c.creator_id = p.person_id
   AND c.modified_allele_id = mod_allele.ID(+)
   AND c.expected_coat_color_dict_id = cc.ID(+)
   AND c.genotype_dict_id = gd.ID(+)
   AND c.cell_line_strain_dict_id = st.ID(+)
   AND c.cell_line_source_dict_id = cs.ID(+)
   AND c.cell_line_provider_id = cp.person_id(+);

CREATE OR REPLACE FORCE VIEW MIR_REQUEST_LIST_VW
(ID, REQUESTER_NAME, TEAM_NUMBER, CHIMERA_MATE_STRAIN_NAME, CHIMERA_MATE_STRAIN_ID, 
 STRAIN_NAME, STRAIN_ID, CELL_LINE_NAME, CELL_LINE_ID, CLONE_NAME, 
 ENDPOINT_NAME, ENDPOINT_ID, EMBRYO_STAGE_NAME, EMBRYO_STAGE_ID, EDIT_DATE, 
 CREATED_DATE, PROJECT_LICENCE, WORKFLOW_PIPELINE, WORKFLOW_PIPELINE_ID, REQUESTER_ID, 
 EXTERNAL_STATUS_DICT_ID, EXTERNAL_STATUS_NAME, SMI_COUNT, TARGET_DATE, INTERNAL_STATUS_DICT_ID)
AS 
select 
  mir.id, 
  per.requester_name, 
  per.team_number, 
  cms.name chimera_mate_strain_name, 
  cms.id chimera_mate_strain_id, 
  esline.name strain_name, 
  esline.id strain_id, 
  cl.cell_line_name, 
  cl.id cell_line_id, 
  cl.clone_name, 
  ed.name endpoint_name, 
  ed.id endpoint_id, 
  sd.name embryo_stage_name, 
  sd.id embryo_stage_id, 
  mir.edit_date, 
  mir.created_date, 
  pl.ppl project_licence, 
  aw.name workflow_pipeline, 
  aw.id workflow_pipeline_id, 
  mir.requester_id requester_id, 
  esd.id external_status_dict_id,
  esd.name external_status_name,
  smi_table.smi_count smi_count,
  smi_table2.target_schedule_date target_date,
  smi_table2. internal_status_dict_id  internal_status_dict_id
from 
  mir_micro_injection_request mir, 
  app_workflow_pipeline_dict aw, 
  mir_chimera_mate_strain_dict cms, 
  mir_cell_line_strain_dict esline, 
  mir_target_endpoint_dict ed, 
  (
   select micro_injection_request_id, count(*) smi_count
   from MIR_scheduled_micro_injection
   group by micro_injection_request_id  
  ) smi_table,  
   (
   select micro_injection_request_id, target_schedule_date, internal_status_dict_id
   from MIR_scheduled_micro_injection smi
   where 
      not (smi.internal_status_dict_id in (9,10,13))  
  ) smi_table2,  
  (select 
    p.person_id, 
    p.first_name || ' ' || p.last_name requester_name, 
 tm.team_number 
  from 
    per_person p, 
    per_team tm 
  where 
    p.team_id = tm.id(+)
 ) per, 
  mir_cell_line cl, 
  mir_embryo_stage_dict sd, 
  lic_project_licence pl,
  mir_external_status_dict esd
where 
  mir.endpoint_dict_id = ed.id(+) AND 
  aw.id(+) = mir.WORKFLOW_PIPELINE_DICT_ID AND 
  mir.donor_embryo_stage_dict_id = sd.id(+) AND 
  mir.chimera_mate_strain_dict_id = cms.id(+) AND 
  mir.requester_id = per.person_id(+) AND 
  mir.cell_line_id = cl.id(+) AND 
  mir.project_licence_id = pl.project_licence_id(+) AND 
  cl.cell_line_strain_dict_id = esline.id(+)  AND
  smi_table.micro_injection_request_id(+) = mir.id AND
  mir.external_status_dict_id = esd.id(+) and 
  mir.id = smi_table2.micro_injection_request_id (+)
;

CREATE OR REPLACE FORCE VIEW MIR_SCHEDULED_MI_LIST_VW
(ID, MICRO_INJECTION_REQUEST_ID, INTERNAL_STATUS_ID, INTERNAL_STATUS_NAME, ENDPOINT_ID, 
 ENDPOINT_NAME, TARGET_SCHEDULE_DATE, DONOR_ANIMAL_REQUEST_ID, RECIPIENT_ANIMAL_REQUEST_ID, SUPPLEMENTAL_RECIPIENT_REQ_ID, 
 MI_ACTUAL_COMPLETION_DATE, ET_ACTUAL_COMPLETION_DATE, F0_ACTUAL_COMPLETION_DATE, F1_ACTUAL_COMPLETION_DATE, RECIPIENT_MOUSE_COUNT, 
 DONOR_MOUSE_COUNT, SUPPLEMENTAL_MOUSE_COUNT, REQUESTER_NAME, CELL_LINE_PROVIDER_NAME_NO, MICRO_INJECTION_ID)
AS 
SELECT smi.ID, smi.micro_injection_request_id, isd.ID internal_status_id,
       isd.NAME internal_status_name, med.ID endpoint_id,
       med.NAME endpoint_name, smi.target_schedule_date,
       smi.donor_animal_request_id, smi.recipient_animal_request_id,
       smi.supplemental_recipient_req_id,       
       --mi.id micro_injection_id,
       --mi.date_completed micro_injection_completed_date
       smt_mi.actual_completion_date mi_actual_completion_date,
       smt_et.actual_completion_date et_actual_completion_date,
       smt_f0.actual_completion_date f0_actual_completion_date,
       smt_f1.actual_completion_date f1_actual_completion_date,
       res_recipient.reserved_mouse_count recipient_mouse_count,
       res_donor.reserved_mouse_count donor_mouse_count,
       res_supplemental.reserved_mouse_count supplemental_mouse_count,
       per_r.first_name || ' ' || per_r.last_name requester_name,
       DECODE (per_cl.phone_number,
               '', per_cl.first_name|| ' '|| per_cl.last_name,
               per_cl.first_name || ' ' || per_cl.last_name || ' ('
                || per_cl.phone_number || ')'
              ) cell_line_provider_name_no,
       mi.ID micro_injection_id
  FROM mir_scheduled_micro_injection smi,
       mir_internal_status_dict isd,
       mir_micro_injection_request mir,
       mir_target_endpoint_dict med,
       (SELECT   foreign_key_id animal_request_id,
                 COUNT (*) reserved_mouse_count
            FROM mts_reserved_mouse rm,
                 mts_reservation res,
                 req_animal_request req
           WHERE rm.reservation_id = res.ID
             AND res.foreign_key_id = req.ID
             AND res.table_metadata_id = 2
        GROUP BY foreign_key_id) res_recipient,
       (SELECT   foreign_key_id animal_request_id,
                 COUNT (*) reserved_mouse_count
            FROM mts_reserved_mouse rm,
                 mts_reservation res,
                 req_animal_request req
           WHERE rm.reservation_id = res.ID
             AND res.foreign_key_id = req.ID
             AND res.table_metadata_id = 2
        GROUP BY foreign_key_id) res_donor,
       (SELECT   foreign_key_id animal_request_id,
                 COUNT (*) reserved_mouse_count
            FROM mts_reserved_mouse rm,
                 mts_reservation res,
                 req_animal_request req
           WHERE rm.reservation_id = res.ID
             AND res.foreign_key_id = req.ID
             AND res.table_metadata_id = 2
        GROUP BY foreign_key_id) res_supplemental,       
       -- mir_micro_injection mi
       (SELECT smt.*
          FROM mir_scheduled_mi_task smt, mir_scheduled_micro_injection smi
         WHERE smi.ID = smt.scheduled_micro_injection_id(+)
               AND smt.NAME = 'Microinjection Completed') smt_mi,
       (SELECT smt.*
          FROM mir_scheduled_mi_task smt, mir_scheduled_micro_injection smi
         WHERE smi.ID = smt.scheduled_micro_injection_id(+)
               AND smt.NAME = 'Embryo Transfer Completed') smt_et,
       (SELECT smt.*
          FROM mir_scheduled_mi_task smt, mir_scheduled_micro_injection smi
         WHERE smi.ID = smt.scheduled_micro_injection_id(+)
               AND smt.NAME = 'F0s Weaned') smt_f0,
       (SELECT smt.*
          FROM mir_scheduled_mi_task smt, mir_scheduled_micro_injection smi
         WHERE smi.ID = smt.scheduled_micro_injection_id(+)
               AND smt.NAME = 'F1s Genotyped') smt_f1,
       per_person per_r,
       per_person per_cl,
       mir_micro_injection mi
 WHERE smi.internal_status_dict_id = isd.ID
   AND mir.ID = smi.micro_injection_request_id
   AND mir.endpoint_dict_id = med.ID
   AND smt_mi.scheduled_micro_injection_id(+) = smi.ID
   AND smt_et.scheduled_micro_injection_id(+) = smi.ID
   AND smt_f0.scheduled_micro_injection_id(+) = smi.ID
   AND smt_f1.scheduled_micro_injection_id(+) = smi.ID
   AND smi.recipient_animal_request_id = res_recipient.animal_request_id(+)
   AND smi.donor_animal_request_id = res_donor.animal_request_id(+)
   AND smi.supplemental_recipient_req_id = res_supplemental.animal_request_id(+)
   AND mir.requester_id = per_r.person_id
   AND smi.cell_line_provider_id = per_cl.person_id
   AND smi.ID = mi.scheduled_micro_injection_id(+);

alter table req_animal_request 
 rename column age_or_weight_vs_embryo_age to development_endpoint;

alter table req_animal_request
 add (pseudo_pregnant_female  number(1));
 
alter table req_animal_request drop column age_matched_litermates;

alter table req_animal_request drop column identification;


alter table mir_micro_injection_request
 add (funding_source  varchar2(256 byte));
 
CREATE OR REPLACE TRIGGER MIR_MICRO_INJECTION_REQUEST_ta
before update or delete on MIR_MICRO_INJECTION_REQUEST for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
begin

if deleting or updating then 
 insert into MIR_MICRO_INJECTION_REQ_AUDIT(
    ID,
    CELL_LINE_ID,
    ENDPOINT_DICT_ID,
    EDIT_DATE,
    EDITED_BY,
    CREATED_DATE,
    REQUESTER_ID,
    PROJECT_LICENCE_ID,
    DONOR_PLUG_COUNT,
    CHIMERA_MATE_STRAIN_DICT_ID,
    GENOTYPING_REQUIRED,
    DONOR_EMBRYO_STAGE_DICT_ID,
    WORKFLOW_PIPELINE_DICT_ID,
    EXTERNAL_STATUS_DICT_ID,
    STATUS_COMMENTS)
 values (
    :old.ID,
    :old.CELL_LINE_ID,
    :old.ENDPOINT_DICT_ID,
    :old.EDIT_DATE,
    :old.EDITED_BY,
    :old.CREATED_DATE,
    :old.REQUESTER_ID,
    :old.PROJECT_LICENCE_ID,
    :old.DONOR_PLUG_COUNT,
    :old.CHIMERA_MATE_STRAIN_DICT_ID,
    :old.GENOTYPING_REQUIRED,
    :old.DONOR_EMBRYO_STAGE_DICT_ID,
    :old.WORKFLOW_PIPELINE_DICT_ID,
    :old.EXTERNAL_STATUS_DICT_ID,
    :old.STATUS_COMMENTS);
end if;
end;
/ 
 
update mir_micro_injection_request set external_status_dict_id = old_status_dict_id where external_status_dict_id is null; 
 
alter table mir_micro_injection_request drop column old_status_dict_id;

drop sequence mir_request_status_id_seq;

alter table arq_design_2_design_request drop column comments;


create or replace force view mir_cell_line_list_vw
(id, created_by, cell_line_provider_name_no, creator_id, created_date, 
 cell_line_name, gene_id, gene_name, allele_name, modified_allele_id, 
 cell_line_source, cell_line_source_id, clone_name, coat_color_name, coat_color_id, 
 strain_name, strain_id, genotype, genotype_id, wildtype_primer_forward, 
 wildtype_primer_reverse, wildtype_expected_size, allele_primer_forward, allele_primer_reverse, allele_expected_size, 
 edit_date, edited_by)
as 
select c.id, p.first_name || ' ' || p.last_name created_by,
       decode (cp.phone_number,
               '', cp.first_name || ' ' || cp.last_name,
                  cp.first_name
               || ' '
               || cp.last_name
               || '('
               || cp.phone_number
               || ')'
              ) cell_line_provider_name_no,
       c.creator_id, c.created_date, c.cell_line_name, mod_allele.gene_id,
       mod_allele.gene_name, mod_allele.allele_name,
       mod_allele.id modified_allele_id, cs.name cell_line_source,
       cs.id cell_line_source_id, c.clone_name, cc.name coat_color_name,
       cc.id coat_color_id, st.name strain_name, st.id strain_id,
       gd.name genotype, gd.id genotype_id,
       mod_allele.wildtype_primer_forward, mod_allele.wildtype_primer_reverse,
       mod_allele.wildtype_expected_size, mod_allele.allele_primer_forward,
       mod_allele.allele_primer_reverse, mod_allele.allele_expected_size,
       c.edit_date, c.edited_by
  from mir_cell_line c,
       per_person p,
       per_person cp,
       mts_coat_colour_dict cc,
       mir_cell_line_strain_dict st,
       mir_es_cell_line_source_dict cs,
       mts_genotype_dict gd,
       (select a.id, a.gene_id, g.primary_name gene_name,
               a.official_name_superscript allele_name,
               a.id modified_allele_id, gt_test.wildtype_primer_forward,
               gt_test.wildtype_primer_reverse,
               gt_test.wildtype_expected_size, gt_test.allele_primer_forward,
               gt_test.allele_primer_reverse, gt_test.allele_expected_size
          from typ_modified_allele a,
               gnm_gene g,
               (select gt.modified_allele_id,
                       gpp1.five_primer_forward wildtype_primer_forward,
                       gpp1.three_primer_reverse wildtype_primer_reverse,
                       gpp1.expected_size wildtype_expected_size,
                       gpp2.five_primer_forward allele_primer_forward,
                       gpp2.three_primer_reverse allele_primer_reverse,
                       gpp2.expected_size allele_expected_size
                  from typ_genotype_test gt,
                       typ_genotyping_primer_pair gpp1,
                       typ_genotyping_primer_pair gpp2
                 where gpp1.genotype_test_id = gt.id
                   and gpp1.primer_pair_type_id = 1
                   and gpp2.genotype_test_id = gt.id
                   and gpp2.primer_pair_type_id = 2) gt_test
         where a.gene_id = g.gene_id(+) and gt_test.modified_allele_id(+) =
                                                                          a.id) mod_allele
 where c.creator_id = p.person_id
   and c.modified_allele_id = mod_allele.id(+)
   and c.expected_coat_color_dict_id = cc.id(+)
   and c.genotype_dict_id = gd.id(+)
   and c.cell_line_strain_dict_id = st.id(+)
   and c.cell_line_source_dict_id = cs.id(+)
   and c.cell_line_provider_id = cp.person_id(+);

create or replace force view mir_request_list_vw
(id, requester_name, team_number, chimera_mate_strain_name, chimera_mate_strain_id, 
 strain_name, strain_id, cell_line_name, cell_line_id, clone_name, 
 endpoint_name, endpoint_id, embryo_stage_name, embryo_stage_id, edit_date, 
 created_date, project_licence, workflow_pipeline, workflow_pipeline_id, requester_id, 
 external_status_dict_id, external_status_name, smi_count, target_date, internal_status_dict_id)
as 
select 
  mir.id, 
  per.requester_name, 
  per.team_number, 
  cms.name chimera_mate_strain_name, 
  cms.id chimera_mate_strain_id, 
  esline.name strain_name, 
  esline.id strain_id, 
  cl.cell_line_name, 
  cl.id cell_line_id, 
  cl.clone_name, 
  ed.name endpoint_name, 
  ed.id endpoint_id, 
  sd.name embryo_stage_name, 
  sd.id embryo_stage_id, 
  mir.edit_date, 
  mir.created_date, 
  pl.ppl project_licence, 
  aw.name workflow_pipeline, 
  aw.id workflow_pipeline_id, 
  mir.requester_id requester_id, 
  esd.id external_status_dict_id,
  esd.name external_status_name,
  smi_table.smi_count smi_count,
  smi_table2.target_schedule_date target_date,
  smi_table2. internal_status_dict_id  internal_status_dict_id
from 
  mir_micro_injection_request mir, 
  app_workflow_pipeline_dict aw, 
  mir_chimera_mate_strain_dict cms, 
  mir_cell_line_strain_dict esline, 
  mir_target_endpoint_dict ed, 
  (
   select micro_injection_request_id, count(*) smi_count
   from mir_scheduled_micro_injection
   group by micro_injection_request_id  
  ) smi_table,  
   (
   select micro_injection_request_id, target_schedule_date, internal_status_dict_id
   from mir_scheduled_micro_injection smi
   where 
      not (smi.internal_status_dict_id in (9,10,13))  
  ) smi_table2,  
  (select 
    p.person_id, 
    p.first_name || ' ' || p.last_name requester_name, 
 tm.team_number 
  from 
    per_person p, 
    per_team tm 
  where 
    p.team_id = tm.id(+)
 ) per, 
  mir_cell_line cl, 
  mir_embryo_stage_dict sd, 
  lic_project_licence pl,
  mir_external_status_dict esd
where 
  mir.endpoint_dict_id = ed.id(+) and 
  aw.id(+) = mir.workflow_pipeline_dict_id and 
  mir.donor_embryo_stage_dict_id = sd.id(+) and 
  mir.chimera_mate_strain_dict_id = cms.id(+) and 
  mir.requester_id = per.person_id(+) and 
  mir.cell_line_id = cl.id(+) and 
  mir.project_licence_id = pl.project_licence_id(+) and 
  cl.cell_line_strain_dict_id = esline.id(+)  and
  smi_table.micro_injection_request_id(+) = mir.id and
  mir.external_status_dict_id = esd.id(+) and 
  mir.id = smi_table2.micro_injection_request_id (+)
;

create or replace force view arq_havana_req_historical_vw
(id, allele_request_id, status_dict_id, status, created_by, 
 created_date, edited_by, edited_date, comments, vega_id, 
 updated_gene_name, updated_chromosome_name, start_not_found, end_not_found, critical_exon_id, 
 primary_name, gene_build_gene_primary_name, chromosome_name, chromosome_start, chromosome_end, 
 build_name, build_version, request_source_dict_id, source, unique_exon_count, 
 total_exon_count, requester_person_id)
as 
select 
  v.id, 
  v.allele_request_id, 
  v.status_dict_id, 
  d.name status, 
  v.created_by, 
  v.created_date, 
  v.edited_by, 
  v.edited_date, 
  v.comments, 
  v.vega_id, 
  v.updated_gene_name, 
  v.updated_chromosome_name, 
  v.start_not_found, 
  v.end_not_found, 
  v.critical_exon_id, 
  g.primary_name, 
  g.gene_build_gene_primary_name, 
  g.chromosome_name, 
  g.chromosome_start, 
  g.chromosome_end, 
  g.build_name, 
  g.build_version, 
  a.request_source_dict_id, 
  s.name source, 
  g.unique_exon_count, 
  g.total_exon_count, 
  a.requester_person_id 
from 
  arq_havana_request_audit v, 
  arq_allele_request a, 
  gnm_gene_vw g, 
  arq_havana_req_status_dict_vw d, 
  arq_allele_request_source_dict s 
where 
  a.id = v.allele_request_id and 
  a.gene_id = g.gene_id and 
  a.request_source_dict_id =  s.id and 
  v.status_dict_id = d.id;
  
CREATE SEQUENCE MTS_AIR_HANDLING_DATA_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE MTS_AIR_HANDLING_UNIT_SEQ
  START WITH 482
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE MTS_BIOPSY_PLATE_SEQ
  START WITH 9
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE MTS_BIOPSY_PLATE_WELL_SEQ
  START WITH 11
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE MTS_BOOKING_ID_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE MTS_BREEDING_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE MTS_CAGED_MOUSE_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE MTS_CAGE_DETAIL_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE MTS_CAGE_HEADER_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE MTS_CAGE_RACK_HISTORY_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE MTS_CAGE_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE MTS_CHIMERIC_MOUSE_DATA_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE MTS_COHORT_2_MOUSE_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  CACHE 20
  NOORDER;

CREATE SEQUENCE MTS_COHORT_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  CACHE 20
  NOORDER;

CREATE SEQUENCE MTS_EMBRYO_TRANSFER_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE MTS_ENVIRONMENT_REPORT_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE MTS_ES_CLONE_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE MTS_LITTER_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE MTS_MOUSE_ALLELE_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE MTS_MOUSE_CAGE_HISTORY_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 0
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE MTS_MOUSE_HEALTH_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE MTS_MOUSE_PROCEDURE_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE MTS_MOUSE_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE MTS_PRINT_JOB_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE MTS_RACKED_CAGE_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE MTS_RACK_ROOM_HISTORY_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 0
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE MTS_RACK_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE MTS_RESERVATION_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE MTS_RESERVED_MOUSE_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE SEQUENCE MTS_ROOMED_RACK_SEQ
  START WITH 1
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE TABLE MTS_AIR_HANDLING_DATA
(
  ID                    INTEGER,
  AIR_HANDLING_UNIT_ID  NUMBER,
  COLLECTION_DATE       DATE,
  TEMPERATURE           NUMBER,
  RELATIVE_HUMIDITY     NUMBER,
  AIR_CHANGES_PER_HOUR  NUMBER,
  RELATIVE_PRESSURE     NUMBER,
  ERROR_CODE            NUMBER,
  CHECK_NUMBER          INTEGER,
  EDITED_BY             VARCHAR2(128 CHAR),
  EDIT_DATE             DATE,
  CREATED_DATE          DATE
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_AIR_HANDLING_UNIT
(
  ID             NUMBER,
  NAME           VARCHAR2(100 CHAR),
  ROOM_ID        NUMBER,
  CHECK_NUMBER   NUMBER,
  RADIO_ADDRESS  VARCHAR2(100 CHAR),
  EDITED_BY      VARCHAR2(128 CHAR),
  EDIT_DATE      DATE,
  CREATED_DATE   DATE
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_BIOPSY_PLATE
(
  ID             INTEGER,
  CREATED_DATE   DATE,
  CREATOR_ID     INTEGER,
  EDITED_BY      VARCHAR2(128 CHAR),
  EDIT_DATE      DATE,
  DESCRIPTION    VARCHAR2(512 CHAR),
  BARCODE        VARCHAR2(128 CHAR),
  PLATE_ROWS     INTEGER,
  PLATE_COLUMNS  INTEGER,
  CHECK_NUMBER   INTEGER,
  STATUS         VARCHAR2(20 CHAR)
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_BIOPSY_PLATE_WELL
(
  ID               INTEGER,
  BIOPSY_PLATE_ID  INTEGER,
  MOUSE_ID         INTEGER,
  ARRAY_ROW        INTEGER,
  ARRAY_COLUMN     INTEGER,
  CREATED_DATE     DATE,
  CREATOR_ID       INTEGER,
  EDIT_DATE        DATE,
  EDITED_BY        VARCHAR2(128 CHAR),
  CHECK_NUMBER     INTEGER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_BODY_SUBSYSTEM_DICT
(
  ID                   NUMBER,
  NAME                 VARCHAR2(256 CHAR),
  ORDER_BY             INTEGER,
  DESCRIPTION          VARCHAR2(2048 CHAR),
  ACTIVE               NUMBER,
  BODY_SYSTEM_DICT_ID  INTEGER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_BODY_SYSTEM_DICT
(
  ID           NUMBER,
  NAME         VARCHAR2(256 CHAR),
  ORDER_BY     INTEGER,
  DESCRIPTION  VARCHAR2(2048 CHAR),
  ACTIVE       NUMBER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_BREEDING
(
  ID                   INTEGER,
  EVENT_START          DATE                     DEFAULT SYSDATE,
  EVENT_END            DATE,
  CHECK_NUMBER         INTEGER,
  EDITED_BY            VARCHAR2(128 CHAR),
  EDIT_DATE            DATE,
  COMMENTS             VARCHAR2(4000 CHAR),
  RESERVATION_ID       INTEGER,
  CREATOR_ID           INTEGER,
  CREATED_DATE         DATE,
  MALE_ID              INTEGER,
  FEMALE_ID            NUMBER,
  STATUS               VARCHAR2(32 CHAR),
  BREEDING_NAME        VARCHAR2(32 CHAR),
  OFFSPRING_COLONY_ID  INTEGER,
  PSEUDO_BREEDING      NUMBER(1),
  EMBRYO_TRANSFER_ID   INTEGER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_BREEDING_OFFSET
(
  COLONY_INFO_ID  INTEGER,
  OFFSET          INTEGER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_CAGE
(
  ID                 INTEGER,
  RACK_ID            INTEGER,
  STATUS             VARCHAR2(20 CHAR),
  CHECK_NUMBER       INTEGER,
  COMMENTS           VARCHAR2(4000 CHAR),
  EDITED_BY          VARCHAR2(128 CHAR),
  EDIT_DATE          DATE,
  CREATOR_ID         INTEGER,
  CREATED_DATE       DATE,
  BARCODE            VARCHAR2(128 CHAR),
  NAME               INTEGER,
  LAST_CLEANED_DATE  DATE
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_CAGE_LABEL_DETAIL
(
  ID                    INTEGER,
  CAGE_LABEL_HEADER_ID  INTEGER,
  MOUSE_ID              INTEGER,
  ALLELE                VARCHAR2(256 CHAR)
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_CAGE_LABEL_HEADER
(
  ID                    NUMBER,
  PRINT_JOB_ID          NUMBER,
  ROOM_NAME             VARCHAR2(20 CHAR),
  STRAIN                VARCHAR2(100 CHAR),
  PROJECT_LICENCE       VARCHAR2(20 CHAR),
  PROTOCOL_CODE         VARCHAR2(20 CHAR),
  PERSON_NAME           VARCHAR2(100 CHAR),
  RACK_NAME             VARCHAR2(20 CHAR),
  CAGE_NAME             VARCHAR2(20 CHAR),
  EXTRA_INFO_1          VARCHAR2(1000 CHAR),
  CAGE_BARCODE          VARCHAR2(256 CHAR),
  COLONY_NAME           VARCHAR2(256 CHAR),
  CREATED_DATE          DATE                    DEFAULT sysdate,
  MALE_COUNT            INTEGER,
  FEMALE_COUNT          INTEGER,
  UNKNOWN_GENDER_COUNT  INTEGER,
  LABEL_TYPE            VARCHAR2(100 CHAR)
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_CAGE_RACK_HISTORY
(
  ID          NUMBER,
  CAGE_ID     NUMBER,
  RACK_ID     NUMBER,
  START_DATE  DATE,
  END_DATE    DATE
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_CAUSE_OF_DEATH_DICT
(
  ID           NUMBER,
  NAME         VARCHAR2(256 CHAR),
  ORDER_BY     INTEGER,
  DESCRIPTION  VARCHAR2(2048 CHAR),
  ACTIVE       NUMBER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_CHIMERIC_MOUSE_DATA
(
  ID                INTEGER,
  MOUSE_ID          INTEGER,
  PERCENT_CHIMERIC  INTEGER,
  CREATOR_ID        INTEGER,
  CREATED_DATE      DATE,
  EDITED_BY         VARCHAR2(128 CHAR),
  EDIT_DATE         DATE,
  CHECK_NUMBER      INTEGER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_COHORT
(
  ID            INTEGER,
  NAME          VARCHAR2(64 CHAR),
  EDIT_DATE     DATE,
  EDITED_BY     VARCHAR2(128 CHAR),
  CREATOR_ID    INTEGER,
  CREATED_DATE  DATE,
  CHECK_NUMBER  INTEGER,
  DESCRIPTION   VARCHAR2(4000 CHAR)
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_EARMARK_DICT
(
  ID           NUMBER,
  NAME         VARCHAR2(256 CHAR),
  ORDER_BY     INTEGER,
  DESCRIPTION  VARCHAR2(2048 CHAR),
  ACTIVE       NUMBER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_EMBRYO_TRANSFER
(
  ID               INTEGER,
  FEMALE_MOUSE_ID  INTEGER,
  ES_CLONE_ID      INTEGER,
  TIMESTAMP        DATE                         DEFAULT SYSDATE
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_ENVIRONMENT_REPORT
(
  ID                 INTEGER,
  DESCRIPTION        VARCHAR2(4000 CHAR),
  REPORTED_DATE      DATE,
  RESOLVED_DATE      DATE,
  FOREIGN_KEY_ID     INTEGER,
  TABLE_METADATA_ID  INTEGER,
  CREATED_DATE       DATE,
  CREATOR_ID         INTEGER,
  EDIT_DATE          DATE,
  EDITED_BY          VARCHAR2(128 CHAR),
  CHECK_NUMBER       NUMBER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_ES_CLONE
(
  ID                  INTEGER,
  MODIFIED_ALLELE_ID  INTEGER,
  TIMESTAMP           DATE                      DEFAULT SYSDATE,
  NAME                VARCHAR2(1024 CHAR)
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_EYE_COLOUR_DICT
(
  ID           NUMBER,
  NAME         VARCHAR2(256 CHAR),
  ORDER_BY     INTEGER,
  DESCRIPTION  VARCHAR2(2048 CHAR),
  ACTIVE       NUMBER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_GENDER_DICT
(
  ID           NUMBER,
  NAME         VARCHAR2(256 CHAR),
  ORDER_BY     INTEGER,
  DESCRIPTION  VARCHAR2(2048 CHAR),
  ACTIVE       NUMBER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_HEALTH_CONCERN_DICT
(
  ID                      NUMBER,
  NAME                    VARCHAR2(256 CHAR),
  ORDER_BY                INTEGER,
  DESCRIPTION             VARCHAR2(2048 CHAR),
  ACTIVE                  NUMBER,
  BODY_SUBSYSTEM_DICT_ID  INTEGER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_LITTER
(
  ID                INTEGER,
  LITTER_SOURCE     VARCHAR2(32 CHAR),
  BREEDING_ID       INTEGER,
  BIRTH_DATE        DATE                        DEFAULT NULL,
  CHECK_NUMBER      NUMBER,
  EDITED_BY         VARCHAR2(128 CHAR),
  EDIT_DATE         DATE,
  CREATOR_ID        INTEGER,
  CREATED_DATE      DATE,
  PLUG_CHECK_DATE   DATE,
  FOSTER_MOTHER_ID  INTEGER,
  NUMBER_BORN       INTEGER,
  NUMBER_WEANED     INTEGER,
  NUMBER_USED       INTEGER,
  COMMENTS          VARCHAR2(4000 CHAR),
  NUMBER_DIED       INTEGER,
  STATUS            VARCHAR2(32 CHAR),
  LITTER_NAME       VARCHAR2(32 CHAR),
  NUMBER_HARVESTED  INTEGER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_MOUSE
(
  ID                          INTEGER,
  LITTER_ID                   INTEGER,
  NAME                        VARCHAR2(64 CHAR),
  EDIT_DATE                   DATE              DEFAULT SYSDATE,
  RFID_TAG                    VARCHAR2(256 CHAR),
  COAT_COLOUR_DICT_ID         NUMBER,
  EYE_COLOUR_DICT_ID          NUMBER,
  EARMARK_DICT_ID             NUMBER,
  BIRTH_DATE                  DATE,
  DEATH_DATE                  DATE,
  CAUSE_OF_DEATH_DICT_ID      NUMBER,
  EDITED_BY                   VARCHAR2(128 CHAR),
  WEAN_DATE                   DATE,
  CAGE_ID                     NUMBER,
  CURRENT_OWNER_ID            NUMBER,
  CURRENT_PROJECT_LICENCE_ID  NUMBER,
  CHECK_NUMBER                NUMBER,
  GENDER_DICT_ID              NUMBER,
  MOUSE_STRAIN_DICT_ID        INTEGER,
  STATUS                      VARCHAR2(20 CHAR),
  CREATOR_ID                  INTEGER,
  CREATED_DATE                DATE,
  BARCODE                     VARCHAR2(128 CHAR),
  COMMENTS                    VARCHAR2(4000 CHAR),
  CURRENT_PROTOCOL_ID         INTEGER,
  SUPPLIER_DICT_ID            INTEGER,
  IS_NON_BREEDER              NUMBER(1),
  IS_SENTINEL                 NUMBER(1),
  RESERVATION_ID              INTEGER,
  GENERATION                  VARCHAR2(128 CHAR),
  COLONY_INFO_ID              INTEGER,
  COHORT_ID                   INTEGER,
  ARRIVAL_DATE                DATE,
  FATHER_ID                   INTEGER,
  MOTHER_ID                   INTEGER,
  EARMARK_LEFT                INTEGER,
  EARMARK_RIGHT               INTEGER,
  IS_STERILE                  NUMBER(1),
  LATEST_PLUG_DATE            DATE
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_MOUSE_ALLELE
(
  ID                INTEGER,
  MOUSE_ID          INTEGER,
  ALLELE_ID         INTEGER,
  GENOTYPE_DICT_ID  INTEGER,
  CREATOR_ID        INTEGER,
  CREATED_DATE      DATE,
  EDITED_BY         VARCHAR2(128 BYTE),
  EDIT_DATE         DATE,
  CHECK_NUMBER      INTEGER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_MOUSE_CAGE_HISTORY
(
  ID          NUMBER,
  MOUSE_ID    NUMBER,
  CAGE_ID     NUMBER,
  START_DATE  DATE,
  END_DATE    DATE
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_MOUSE_HEALTH
(
  ID                      NUMBER,
  MOUSE_ID                NUMBER,
  START_DATE              DATE,
  END_DATE                DATE,
  EDIT_DATE               DATE,
  EDITED_BY               VARCHAR2(100 CHAR),
  CREATOR_ID              INTEGER,
  CREATED_DATE            DATE,
  COMMENTS                VARCHAR2(4000 CHAR),
  STATUS                  VARCHAR2(20 CHAR),
  BODY_SUBSYSTEM_DICT_ID  NUMBER,
  BODY_SYSTEM_DICT_ID     NUMBER,
  HEALTH_CONCERN_DICT_ID  NUMBER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_MOUSE_PROCEDURE
(
  ID                   INTEGER,
  MOUSE_ID             INTEGER,
  PROTOCOL_ID          INTEGER,
  PERSONAL_LICENCE_ID  INTEGER,
  START_DATE           DATE,
  END_DATE             DATE,
  TABLE_METADATA_ID    INTEGER,
  FOREIGN_KEY_ID       INTEGER,
  EDIT_DATE            DATE,
  EDITED_BY            VARCHAR2(128 BYTE),
  CREATED_DATE         DATE,
  CREATOR_ID           INTEGER,
  CHECK_NUMBER         INTEGER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_MOUSE_SUPPLIER_DICT
(
  ID           NUMBER,
  NAME         VARCHAR2(256 CHAR),
  ORDER_BY     INTEGER,
  DESCRIPTION  VARCHAR2(2048 CHAR),
  ACTIVE       NUMBER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_PROCEDURE_DICT
(
  ID           INTEGER,
  NAME         VARCHAR2(64 CHAR),
  DESCRIPTION  VARCHAR2(2048 CHAR),
  ACTIVE       NUMBER(1)                        DEFAULT 1,
  ORDER_BY     NUMBER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_RACK
(
  ID                    INTEGER,
  AIR_HANDLING_UNIT_ID  INTEGER,
  ROOM_ID               INTEGER,
  STATUS                VARCHAR2(20 CHAR),
  TECHNOPLAST_NAME      VARCHAR2(128 CHAR),
  CHECK_NUMBER          INTEGER,
  EDITED_BY             VARCHAR2(128 CHAR),
  EDIT_DATE             DATE,
  CREATOR_ID            INTEGER,
  CREATED_DATE          DATE,
  BARCODE               VARCHAR2(128 CHAR),
  MAX_CAPACITY          INTEGER,
  NAME                  INTEGER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_RACK_ROOM_HISTORY
(
  ID          NUMBER,
  RACK_ID     NUMBER,
  ROOM_ID     NUMBER,
  START_DATE  DATE,
  END_DATE    DATE
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_RESERVATION
(
  ID                 INTEGER,
  CREATED_DATE       DATE,
  CREATOR_ID         INTEGER,
  EDITED_BY          VARCHAR2(128 CHAR),
  EDIT_DATE          DATE,
  CHECK_NUMBER       NUMBER,
  START_DATE         DATE,
  END_DATE           DATE,
  COMMENTS           VARCHAR2(4000 CHAR),
  RESERVATION_TYPE   VARCHAR2(30 BYTE),
  RESERVED_FOR_ID    INTEGER,
  TABLE_METADATA_ID  INTEGER,
  FOREIGN_KEY_ID     INTEGER,
  REASON             VARCHAR2(4000 CHAR)
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE MTS_RESERVED_MOUSE
(
  ID              INTEGER,
  RESERVATION_ID  INTEGER,
  MOUSE_ID        INTEGER,
  STATUS          VARCHAR2(20 CHAR),
  STATUS_DATE     DATE,
  CREATED_DATE    DATE,
  CREATOR_ID      INTEGER,
  EDITED_BY       VARCHAR2(128 CHAR),
  EDIT_DATE       DATE,
  CHECK_NUMBER    INTEGER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

ALTER TABLE MTS_ROOM
MODIFY(OFFICIAL_ROOM_NUMBER VARCHAR2(4000 CHAR));


CREATE TABLE MTS_TISSUE_SAMPLE
(
  ID            INTEGER,
  SAMPLE_TYPE   VARCHAR2(128 CHAR),
  SAMPLE_DATE   DATE,
  MOUSE_ID      INTEGER,
  CREATED_DATE  DATE,
  CREATOR_ID    INTEGER,
  EDIT_DATE     DATE,
  EDITED_BY     VARCHAR2(32 CHAR),
  REUSABLE      NUMBER(1)
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE UNIQUE INDEX MTS_PROCEDURE_DICT_PK ON MTS_PROCEDURE_DICT
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_BIOPSY_PLATE_WELL_PK ON MTS_BIOPSY_PLATE_WELL
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_ENVIRONMENT_REPORT_PK ON MTS_ENVIRONMENT_REPORT
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_CHIMERIC_MOUSE_DATA_U01 ON MTS_CHIMERIC_MOUSE_DATA
(MOUSE_ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_CHIMERIC_MOUSE_DATA_PK ON MTS_CHIMERIC_MOUSE_DATA
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_MOUSE_ALLELE_PK ON MTS_MOUSE_ALLELE
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_AIR_HANDLING_DATA_PK ON MTS_AIR_HANDLING_DATA
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_RESERVATION_PK ON MTS_RESERVATION
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_BIOPSY_PLATE_PK ON MTS_BIOPSY_PLATE
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_MOUSE_HEALTH_PK ON MTS_MOUSE_HEALTH
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_TISSUE_SAMPLE_PK ON MTS_TISSUE_SAMPLE
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_BIOPSY_PLATE_U01 ON MTS_BIOPSY_PLATE
(BARCODE)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_MOUSE_PROTOCOL_PK ON MTS_MOUSE_PROCEDURE
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_RESERVED_MOUSE_PK ON MTS_RESERVED_MOUSE
(ID)
LOGGING
NOPARALLEL;

CREATE INDEX MTS_HEALTH_CONCERN_DICT_IND1 ON MTS_HEALTH_CONCERN_DICT
(BODY_SUBSYSTEM_DICT_ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_RACK_ROOM_HISTORY_PK ON MTS_RACK_ROOM_HISTORY
(ID)
LOGGING
NOPARALLEL;

CREATE INDEX MTS_LITTER_IND2 ON MTS_LITTER
(CREATOR_ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_EMBRYO_TRANSFER_PK ON MTS_EMBRYO_TRANSFER
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_CAGE_U01 ON MTS_CAGE
(BARCODE)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_MOUSE_SUPPLIER_DICT_PK ON MTS_MOUSE_SUPPLIER_DICT
(ID)
LOGGING
NOPARALLEL;

CREATE INDEX MTS_MOUSE_IND4 ON MTS_MOUSE
(CREATOR_ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_MOUSE_FN1 ON MTS_MOUSE
(LOWER("NAME"))
LOGGING
NOPARALLEL;

CREATE INDEX MTS_BREEDING_IND2 ON MTS_BREEDING
(CREATOR_ID)
LOGGING
NOPARALLEL;

CREATE INDEX MTS_COLONY_COAT_COLOUR_IND2 ON MTS_COLONY_COAT_COLOUR
(COAT_COLOUR_DICT_ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_CAUSE_OF_DEATH_DICT_PK ON MTS_CAUSE_OF_DEATH_DICT
(ID)
LOGGING
NOPARALLEL;

CREATE INDEX MTS_RACK_IND1 ON MTS_RACK
(CREATOR_ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_EARMARK_DICT_PK ON MTS_EARMARK_DICT
(ID)
LOGGING
NOPARALLEL;

CREATE INDEX MTS_CAGE_LABEL_DETAIL_IND1 ON MTS_CAGE_LABEL_DETAIL
(CAGE_LABEL_HEADER_ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_LITTER_PK ON MTS_LITTER
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_AIR_HANDLING_UNIT_PK ON MTS_AIR_HANDLING_UNIT
(ID)
LOGGING
NOPARALLEL;

CREATE INDEX MTS_ES_CLONE_IND59 ON MTS_ES_CLONE
(MODIFIED_ALLELE_ID)
LOGGING
NOPARALLEL;

CREATE INDEX MTS_MOUSE_ALLELE_IND2 ON MTS_MOUSE_ALLELE
(ALLELE_ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_MOUSE_CAGE_HISTORY_PK ON MTS_MOUSE_CAGE_HISTORY
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_HEALTH_CONCERN_DICT_PK ON MTS_HEALTH_CONCERN_DICT
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_BODY_SUBSYSTEM_DICT_PK ON MTS_BODY_SUBSYSTEM_DICT
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_BODY_SYSTEM_DICT_PK ON MTS_BODY_SYSTEM_DICT
(ID)
LOGGING
NOPARALLEL;

CREATE INDEX MTS_MOUSE_HEALTH_IND1 ON MTS_MOUSE_HEALTH
(CREATOR_ID)
LOGGING
NOPARALLEL;

CREATE INDEX MTS_MOUSE_ALLELE_IND1 ON MTS_MOUSE_ALLELE
(MOUSE_ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_MOUSE_PK ON MTS_MOUSE
(ID)
LOGGING
NOPARALLEL;

CREATE INDEX MTS_MOUSE_IND3 ON MTS_MOUSE
(RESERVATION_ID)
LOGGING
NOPARALLEL;

CREATE INDEX MTS_LITTER_IND1 ON MTS_LITTER
(FOSTER_MOTHER_ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_RACK_U01 ON MTS_RACK
(BARCODE)
LOGGING
NOPARALLEL;

CREATE INDEX MTS_RESERVED_IND1 ON MTS_RESERVATION
(TABLE_METADATA_ID, FOREIGN_KEY_ID)
LOGGING
NOPARALLEL;

CREATE INDEX MTS_CAGE_LABEL_HEADER_IND3 ON MTS_CAGE_LABEL_HEADER
(PRINT_JOB_ID)
LOGGING
NOPARALLEL;

CREATE INDEX MTS_CAGE_IND1 ON MTS_CAGE
(CREATOR_ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_MOUSE_U01 ON MTS_MOUSE
(NAME)
LOGGING
NOPARALLEL;

CREATE INDEX MTS_COLONY_INFO_IND1 ON MTS_COLONY_INFO
(CARD_COLOUR_DICT_ID)
LOGGING
NOPARALLEL;

CREATE INDEX MTS_COHORT_IND1 ON MTS_COHORT
(CREATOR_ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_EYE_COLOUR_DICT_PK ON MTS_EYE_COLOUR_DICT
(ID)
LOGGING
NOPARALLEL;

CREATE INDEX MTS_BODY_SUBSYSTEM_DICT_IND1 ON MTS_BODY_SUBSYSTEM_DICT
(BODY_SYSTEM_DICT_ID)
LOGGING
NOPARALLEL;

CREATE INDEX MTS_TISSUE_SAMPLE_IND1 ON MTS_TISSUE_SAMPLE
(CREATOR_ID)
LOGGING
NOPARALLEL;

CREATE INDEX MTS_BREEDING_IND1 ON MTS_BREEDING
(RESERVATION_ID)
LOGGING
NOPARALLEL;

CREATE INDEX MTS_COLONY_COAT_COLOUR_IND1 ON MTS_COLONY_COAT_COLOUR
(COLONY_ID)
LOGGING
NOPARALLEL;

CREATE INDEX MTS_EMBRYO_TRANSFER_IND48 ON MTS_EMBRYO_TRANSFER
(ES_CLONE_ID)
LOGGING
NOPARALLEL;

CREATE INDEX MTS_MOUSE_IND1 ON MTS_MOUSE
(CAGE_ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_GENDER_DICT_PK ON MTS_GENDER_DICT
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_ES_CLONE_PK ON MTS_ES_CLONE
(ID)
LOGGING
NOPARALLEL;

CREATE INDEX MTS_RESERVED_MOUSE_IND1 ON MTS_RESERVED_MOUSE
(RESERVATION_ID)
LOGGING
NOPARALLEL;

CREATE INDEX MTS_EMBRYO_TRANSFER_IND49 ON MTS_EMBRYO_TRANSFER
(FEMALE_MOUSE_ID)
LOGGING
NOPARALLEL;

CREATE INDEX MTS_BREEDING_IND3 ON MTS_BREEDING
(MALE_ID)
LOGGING
NOPARALLEL;

CREATE INDEX MTS_BREEDING_IND4 ON MTS_BREEDING
(FEMALE_ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_CAGE_RACK_HISTORY_PK ON MTS_CAGE_RACK_HISTORY
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX MTS_MOUSE_U02 ON MTS_MOUSE
(BARCODE)
LOGGING
NOPARALLEL;

CREATE INDEX MTS_CAGE_LABEL_DETAIL_IND2 ON MTS_CAGE_LABEL_DETAIL
(MOUSE_ID)
LOGGING
NOPARALLEL;

CREATE INDEX MTS_MOUSE_IND2 ON MTS_MOUSE
(CURRENT_PROTOCOL_ID)
LOGGING
NOPARALLEL;

CREATE OR REPLACE FORCE VIEW MTS_CAGE_VW
(CAGE_ID, CAGE_NAME, CAGE_BARCODE, RACK_ID, RACK_NAME, 
 RACK_BARCODE, ROOM_ID, ROOM_NAME)
AS 
select 
  c.id cage_id, 
  c.name cage_name, 
  c.barcode cage_barcode, 
  r.id rack_id, 
  r.name rack_name, 
  r.barcode rack_barcode, 
  m.id room_id, 
  m.room_number room_name 
from 
  mts_cage c, 
  mts_rack r, 
  mts_room m 
where 
  c.rack_id = r.id and 
  r.room_id = m.id;

CREATE OR REPLACE FORCE VIEW MTS_MOUSE_VW
(ID, LITTER_ID, NAME, EDIT_DATE, COAT_COLOUR_DICT_ID, 
 COAT_COLOUR, EYE_COLOUR_DICT_ID, EYE_COLOUR, EARMARK_DICT_ID, EARMARK, 
 EARMARK_LEFT, EARMARK_RIGHT, BIRTH_DATE, AGE_IN_WEEKS, DEATH_DATE, 
 AGE_AT_DEATH, CAUSE_OF_DEATH_DICT_ID, CAUSE_OF_DEATH, EDITED_BY, WEAN_DATE, 
 CAGE_ID, CAGE_NAME, CAGE_BARCODE, RACK_ID, RACK_NAME, 
 ROOM_ID, ROOM_NAME, CURRENT_OWNER_ID, CURRENT_OWNER, CURRENT_PROJECT_LICENCE_ID, 
 CURRENT_PROJECT_LICENCE, CURRENT_PROTOCOL_ID, CURRENT_PROTOCOL_CODE, CHECK_NUMBER, GENDER_DICT_ID, 
 GENDER, MOUSE_STRAIN_DICT_ID, STRAIN, STATUS, CREATOR_ID, 
 CREATED_DATE, BARCODE, COMMENTS, SUPPLIER_DICT_ID, SUPPLIER, 
 IS_NON_BREEDER, IS_SENTINEL, GENERATION, COLONY_NAME, COLONY_INFO_ID, 
 COHORT_ID, ARRIVAL_DATE, FATHER_ID, MOTHER_ID, LATEST_PLUG_DATE)
AS 
select 
  m.id, 
  m.litter_id, 
  m.name, 
  m.edit_date, 
  m.coat_colour_dict_id, 
  c.name coat_colour, 
  m.eye_colour_dict_id, 
  e.name eye_colour, 
  m.earmark_dict_id, 
  ear.name earmark, 
  m.earmark_left, 
  m.earmark_right, 
  m.birth_date, 
  round((sysdate - m.birth_date)/7,1) age_in_weeks, 
  m.death_date, 
  round((m.death_date - m.birth_date)/7,1) age_at_death, 
  m.cause_of_death_dict_id, 
  d.name cause_of_death, 
  m.edited_by, 
  m.wean_date, 
  m.cage_id, 
  l.cage_name, 
  l.cage_barcode, 
  l.rack_id, 
  l.rack_name, 
  l.room_id, 
  l.room_name, 
  m.current_owner_id, 
  owner.first_name||' '||owner.last_name current_owner, 
  m.current_project_licence_id, 
  l.licence_number current_project_licence, 
  m.current_protocol_id, 
  r.protocol_code current_protocol_code, 
  m.check_number, 
  m.gender_dict_id, 
  s.name gender, 
  m.mouse_strain_dict_id, 
  t.name strain, 
  m.status, 
  m.creator_id, 
  m.created_date, 
  m.barcode, 
  m.comments, 
  m.supplier_dict_id, 
  sup.name supplier, 
  m.is_non_breeder, 
  m.is_sentinel, 
  m.generation, 
  colony.colony_name, 
  m.colony_info_id, 
  m.cohort_id, 
  m.arrival_date, 
  m.father_id, 
  m.mother_id, 
  m.latest_plug_date 
from 
  mts_mouse m, 
  mts_coat_colour_dict c, 
  mts_eye_colour_dict e, 
  mts_earmark_dict ear, 
  mts_cause_of_death_dict d, 
  mts_mouse_supplier_dict sup, 
  per_person owner, 
  lic_project_licence l, 
  mts_gender_dict s, 
  mts_cage_vw l, 
  typ_strain t, 
  lic_protocol_19b r, 
  mts_colony_info colony 
where 
  m.coat_colour_dict_id = c.id(+) and 
  m.eye_colour_dict_id = e.id(+) and 
  m.earmark_dict_id = ear.id(+) and 
  m.supplier_dict_id = sup.id(+) and 
  m.cause_of_death_dict_id = d.id(+) and 
  m.current_owner_id = owner.person_id(+) and 
  m.current_project_licence_id = l.project_licence_id(+) and 
  m.gender_dict_id = s.id(+) and 
  m.cage_id = l.cage_id(+) and 
  m.mouse_strain_dict_id = t.id(+) and 
  m.current_protocol_id = r.id(+) and 
  m.colony_info_id = colony.id(+);

CREATE OR REPLACE FORCE VIEW MTS_BIOPSY_PLATE_VW
(ID, CREATED_DATE, CREATOR_ID, CREATOR_NAME, EDITED_BY, 
 EDIT_DATE, DESCRIPTION, BARCODE, PLATE_ROWS, PLATE_COLUMNS, 
 CHECK_NUMBER, OCCUPIED_WELLS)
AS 
select 
  p.id, 
  p.created_date, 
  p.creator_id, 
  u.first_name||' '||u.last_name creator_name, 
  p.edited_by, 
  p.edit_date, 
  p.description, 
  p.barcode, 
  p.plate_rows, 
  p.plate_columns, 
  p.check_number, 
  count(w.id) occupied_wells 
from 
  mts_biopsy_plate p, 
  per_person u, 
  mts_biopsy_plate_well w 
where 
  p.creator_id = u.person_id and 
  p.id = w.biopsy_plate_id(+) 
group by 
  p.id, 
  p.created_date, 
  p.creator_id, 
  u.first_name||' '||u.last_name, 
  p.edited_by, 
  p.edit_date, 
  p.description, 
  p.barcode, 
  p.plate_rows, 
  p.plate_columns, 
  p.check_number;

CREATE OR REPLACE FORCE VIEW MTS_MOUSE_HEALTH_VW
(ID, START_DATE, END_DATE, MOUSE_ID, MOUSE_NAME, 
 MOUSE_BARCODE, ROOM_NAME, ROOM_ID, RACK_NAME, RACK_ID, 
 CAGE_NAME, CAGE_ID, BODY_SYSTEM, BODY_SYSTEM_DICT_ID, BODY_SUBSYSTEM, 
 BODY_SUBSYSTEM_DICT_ID, HEALTH_CONCERN, HEALTH_CONCERN_DICT_ID, STATUS, EDIT_DATE, 
 MOUSE_STATUS)
AS 
select 
  h.id, 
  h.start_date, 
  h.end_date, 
  m.id mouse_id, 
  m.name mouse_name, 
  m.barcode mouse_barcode, 
  c.room_name, 
  c.room_id, 
  c.rack_name, 
  c.rack_id, 
  c.cage_name, 
  c.cage_id, 
  d1.name body_system, 
  h.body_system_dict_id, 
  d2.name body_subsystem, 
  h.body_subsystem_dict_id, 
  d3.name health_concern, 
  h.health_concern_dict_id, 
  h.status, 
  h.edit_date, 
  m.status mouse_status 
from 
  mts_mouse_health h, 
  mts_mouse m, 
  mts_cage_vw c, 
  mts_body_system_dict d1, 
  mts_body_subsystem_dict d2, 
  mts_health_concern_dict d3 
where 
  h.mouse_id = m.id and 
  m.cage_id = c.cage_id(+) and 
  h.body_system_dict_id = d1.id and 
  h.body_subsystem_dict_id = d2.id and 
  h.health_concern_dict_id = d3.id;

CREATE OR REPLACE FORCE VIEW MTS_LITTER_LIST_VW
(ID, LITTER_NAME, BIRTH_DATE, LITTER_SOURCE, PLUG_CHECK_DATE, 
 FOSTER_MOTHER_ID, FOSTER_MOTHER_NAME, NUMBER_BORN, NUMBER_WEANED, NUMBER_USED, 
 NUMBER_DIED, NUMBER_HARVESTED, NUMBER_TO_WEAN, EMBRYO_AGE, LITTER_COMMENTS, 
 LITTER_STATUS, BREEDING_ID, EMBRYO_TRANSFER_ID, MOTHER_ID, MOTHER_NAME, 
 MOTHER_COLONY_ID, MOTHER_COLONY_NAME, MOTHER_COHORT_ID, MOTHER_COHORT_NAME, MOTHER_CAGE_ID, 
 MOTHER_CAGE_NAME, MOTHER_CAGE_BARCODE, MOTHER_RACK_ID, MOTHER_RACK_NAME, MOTHER_RACK_BARCODE, 
 MOTHER_ROOM_ID, MOTHER_ROOM_NAME, FATHER_ID, FATHER_NAME, FATHER_COLONY_ID, 
 FATHER_COLONY_NAME, FATHER_COHORT_ID, FATHER_COHORT_NAME, FATHER_CAGE_ID, FATHER_CAGE_NAME, 
 FATHER_CAGE_BARCODE, FATHER_RACK_ID, FATHER_RACK_NAME, FATHER_RACK_BARCODE, FATHER_ROOM_ID, 
 FATHER_ROOM_NAME)
AS 
select 
  lt.id, 
  lt.litter_name, 
  lt.birth_date, 
  lt.litter_source, 
  lt.plug_check_date, 
  lt.foster_mother_id, 
  stepmom.name foster_mother_name, 
  lt.number_born, 
  lt.number_weaned, 
  lt.number_used, 
  lt.number_died, 
  lt.number_harvested, 
  (nvl(lt.number_born,0) - (nvl(lt.number_weaned,0) + nvl(lt.number_died,0) + nvl(lt.number_used,0))) number_to_wean, 
  decode(lt.birth_date, null, (sysdate - lt.plug_check_date), null) embryo_age, 
  lt.comments litter_comments, 
  lt.status litter_status, 
  br.id breeding_id, 
  br.embryo_transfer_id, 
  mother.id mother_id, 
  mother.name mother_name, 
  mother.colony_info_id mother_colony_id, 
  mother_colony.colony_name mother_colony_name, 
  mother.cohort_id mother_cohort_id, 
  mother_cohort.name mother_cohort_name, 
  mother_cage.cage_id mother_cage_id, 
  mother_cage.cage_name mother_cage_name, 
  mother_cage.cage_barcode mother_cage_barcode, 
  mother_cage.rack_id mother_rack_id, 
  mother_cage.rack_name mother_rack_name, 
  mother_cage.rack_barcode mother_rack_barcode, 
  mother_cage.room_id mother_room_id, 
  mother_cage.room_name mother_room_name, 
  father.id father_id, 
  father.name father_name, 
  father.colony_info_id father_colony_id, 
  father_colony.colony_name father_colony_name, 
  father.cohort_id father_cohort_id, 
  father_cohort.name father_cohort_name, 
  father_cage.cage_id father_cage_id, 
  father_cage.cage_name father_cage_name, 
  father_cage.cage_barcode father_cage_barcode, 
  father_cage.rack_id father_rack_id, 
  father_cage.rack_name father_rack_name, 
  father_cage.rack_barcode father_rack_barcode, 
  father_cage.room_id father_room_id, 
  father_cage.room_name father_room_name 
from 
  mts_litter lt, 
  mts_breeding br, 
  mts_mouse mother, 
  mts_mouse father, 
  mts_mouse stepmom, 
  mts_cage_vw mother_cage, 
  mts_cage_vw father_cage, 
  mts_colony_info mother_colony, 
  mts_colony_info father_colony, 
  mts_cohort mother_cohort, 
  mts_cohort father_cohort 
where 
  lt.breeding_id = br.id and 
  br.male_id = father.id and 
  father.cage_id = father_cage.cage_id(+) and 
  father.colony_info_id = father_colony.id(+) and 
  father.cohort_id = father_cohort.id(+) and 
  br.female_id = mother.id and 
  mother.cage_id = mother_cage.cage_id(+) and 
  mother.colony_info_id = mother_colony.id(+) and 
  mother.cohort_id = mother_cohort.id(+) and 
  lt.foster_mother_id = stepmom.id(+);



CREATE TABLE APP_PRINTER
(
  PRINTER_MODEL  VARCHAR2(4000 CHAR),
  ID             NUMBER,
  LOADED_MEDIA   VARCHAR2(4000 CHAR),
  SYS_NAME       VARCHAR2(4000 CHAR),
  ROOM_ID        NUMBER,
  DESCRIPTION    VARCHAR2(128 CHAR)
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE APP_COLUMN_PREFS
(
  ID             INTEGER,
  TABLE_NAME     VARCHAR2(30 CHAR),
  COLUMN_NAME    VARCHAR2(30 CHAR),
  COLUMN_TITLE   VARCHAR2(128 CHAR),
  GETTER_METHOD  VARCHAR2(30 CHAR),
  ORDER_BY       INTEGER,
  DATATYPE       VARCHAR2(30 CHAR)
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE APP_SERVER_ALERT_DICT
(
  ID           INTEGER,
  NAME         VARCHAR2(512 CHAR),
  DESCRIPTION  VARCHAR2(4000 CHAR),
  ORDER_BY     INTEGER,
  ACTIVE       NUMBER(1)
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

create or replace view app_server_alert_dict_vw
as
select 
  id,
  name,
  description,
  order_by,
  active
from 
  app_server_alert_dict
union
select
  0,
  'Database Information' name,
  'This is a '||decode(property_value,'MIGP.WORLD','production','MIGT.WORLD','test','MIGD.WORLD','development','unknown')||' server ('||user||'@'||property_value||')' description,
  0 order_by,
  decode(property_value,'MIGP.WORLD',0,1) active
from
  database_properties
where
  property_name='GLOBAL_DB_NAME';

CREATE OR REPLACE PACKAGE dbms_mig AS

  PROCEDURE make_audit_trigger(in_table_name in varchar2);
  
  PROCEDURE make_all_audit_triggers;

END dbms_mig;
/

SHOW ERRORS;

CREATE OR REPLACE package body dbms_mig as

  procedure make_all_audit_triggers is
  
 cursor c_audit_tables is
 select table_name
 from app_audit_tables
 ;
  
 begin
  
    for t in c_audit_tables loop
     make_audit_trigger(t.table_name);
    end loop;
  
  end make_all_audit_triggers;

  procedure make_audit_trigger(in_table_name in varchar2) is
  
    cr varchar2(2) := chr(13);
 
 cursor c_table_columns is
 select column_name
 from user_tab_columns
 where table_name = upper(in_table_name)
 order by column_id;
 
 cursor c_audit_table is
 select audit_table 
 from app_audit_tables
 where table_name = upper(in_table_name);
 
 v_audit_table varchar2(30);
 
 v_trigger_text varchar2(10000); 
 
 v_insert_sql varchar2(4000) := ' insert into ';
 v_values_sql varchar2(4000) := ' values (';
 
 user_error varchar2(4000);
 user_exception exception;
 
  begin
  
    v_trigger_text := 'create or replace trigger '||in_table_name||'_ta'||cr;
 v_trigger_text := v_trigger_text ||'before update or delete on '||in_table_name||' for each row'||cr;
 v_trigger_text := v_trigger_text ||'/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */'||cr||cr;
 v_trigger_text := v_trigger_text ||'begin'||cr;
 v_trigger_text := v_trigger_text ||cr;
 v_trigger_text := v_trigger_text ||'if deleting or updating then '||cr;
    
 open c_audit_table;
 fetch c_audit_table into v_audit_table; 
 if c_audit_table%notfound then
    close c_audit_table;    
    user_error := 'No audit table found in app_audit_tables for "'||in_table_name||'"';
    raise user_exception;
 end if;
 close c_audit_table;
 
 v_insert_sql := v_insert_sql || v_audit_table || '(';
 
 for x in c_table_columns loop
 
  v_insert_sql := v_insert_sql || cr ||'    ' || x.column_name ||',';
  v_values_sql := v_values_sql || cr ||'    :old.'||x.column_name ||',';
  
 end loop;
 
 v_insert_sql := substr(v_insert_sql,1,length(v_insert_sql)-1);
 v_values_sql := substr(v_values_sql,1,length(v_values_sql)-1);
 
 v_insert_sql := v_insert_sql ||')'||cr;
 v_values_sql := v_values_sql ||');'||cr;
 
 v_insert_sql := v_insert_sql || v_values_sql;
 
 v_trigger_text := v_trigger_text || v_insert_sql;
 
 v_trigger_text := v_trigger_text ||'end if;'||cr;
 v_trigger_text := v_trigger_text ||'end;'||cr;
 v_trigger_text := v_trigger_text ||'/'||cr;
 
 dbms_output.put_line(v_trigger_text);
 --begin
 --  execute immediate(v_trigger_text);
 --  exception when others then null;
 --end;
  
exception
  when user_exception then
    raise_application_error(-20001,user_error);
end;

end dbms_mig;
/

SHOW ERRORS;

CREATE OR REPLACE PACKAGE MIG_LABEL AS
/******************************************************************************
   NAME:       MIG_LABEL
   PURPOSE:

   REVISIONS:
   Ver        Date        Author           Description
   ---------  ----------  ---------------  ------------------------------------
   1.0        13/10/2006             1. Created this package.
******************************************************************************/

  procedure create_label_print_job(in_list_type IN varchar2, in_list_values IN varchar2, print_job_id OUT integer);
  
  procedure create_cage_labels(cage_list in integer_list, print_job_id out number);
  
END MIG_LABEL;
/

SHOW ERRORS;

CREATE OR REPLACE PACKAGE BODY MIG_LABEL AS
/******************************************************************************
   NAME:       MIG_LABEL
   PURPOSE:

   REVISIONS:
   Ver        Date        Author           Description
   ---------  ----------  ---------------  ------------------------------------
   1.0        13/10/2006             1. Created this package body.
******************************************************************************/

procedure create_label_print_job(in_list_type IN varchar2, in_list_values IN varchar2, print_job_id OUT integer)
is
/*
  in_list_type valid values are 'PROCEDURE', 'RACK', 'CAGE_LIST', 'CAGE',' COHORT_ID', 'LITTER_ID'.

  for PROCEDURE, in_list_values must be a single integer corresponding to an experiment ID.
  for RACK, in_list_values must be a sinle integer corresponding to a rack ID.
  for CAGE_LIST, in_list_values may be a list of numbers comma separated or hyphenated for a range of number
         corresponding to valid cage IDs.
  for CAGE, in_list_values must be a single integer corresponding to a cage ID.
  for COHORT_ID, in_list_values must be a non-null string corresponding to the COHORT_ID column in the animal table. 
  for LITTER_ID in_list_values must be a single integer corresponding to a litter ID.

  the procedure returns the print_job_id generated by the called procedure CREATE_CAGE_LABELS
  this print_job_id is then used to run a report to generate the cage labels
*/

-- cage_list will hold the list of cages to be passed into the next procedure
cage_list integer_list := integer_list();

-- search_cursor is a weak ref cursor used to run different queries based on in_list_type
type ref_cursor is ref cursor;
search_cursor ref_cursor;

-- cage_id is a temp variable to fetch records from search_cursor
cage_id integer;

-- i is a counter used to insert into the cage_list array.
i integer :=1;

BEGIN
  /*
      PROCEDURE
 ============================
  */
--   if in_list_type = 'PROCEDURE' then
--    -- for experiments, find distinct not null cages for all animals booked under the experiment.
--  --NOTE: ANIMAL.BOOKING_ID is not used as this is a transient field and may be null at the time
--  --      labels are being printed.
--     open search_cursor for
--    select distinct a.cage_id
--    from animal a,
--        experiment_animal e
--    where e.animal_id = a.id and
--      a.cage_number is not null and
--    a.cage_id is not null and
--      e.experiment_id = to_number(in_list_values);

  /*
      RACK 
 ============================
  */
  if in_list_type = 'RACK' then
   open search_cursor for
   select id
   from mts_cage
   where rack_id = to_number(in_list_values);

  /*
      CAGE 
 ============================
  */
  elsif in_list_type = 'CAGE' then
   open search_cursor for
   select id
   from mts_cage
   where id = to_number(in_list_values);
  /*
      COHORT_ID 
 ============================
  */   
  elsif in_list_type = 'COHORT_ID' then
    open search_cursor for
   select distinct cage_id
   from mts_mouse
   where cohort_id = in_list_values 
   and cage_id is not null;
  /*
      LITTER_ID 
 ============================
  */   
  elsif in_list_type = 'LITTER_ID' then
    open search_cursor for
   select distinct cage_id
   from mts_mouse
   where litter_id = in_list_values 
   and cage_id is not null;   
  else
    raise_application_error(-20000,'Invalid List Type ('||in_list_type||')');
  end if;

  -- if the search_cursor has been opened okay, then get the cage IDs.
  if search_cursor%ISOPEN then

   loop
     fetch search_cursor into cage_id;
     exit when search_cursor%NOTFOUND;
     cage_list.extend;
     cage_list(i) := cage_id;
     i := i + 1;
  
  --dbms_output.put_line('cage id = '||cage_id);
   end loop;

   close search_cursor;

  end if;

  if(cage_list.count > 0) then
    --dbms_output.put_line('cage count = '||cage_list.count);
    create_cage_labels(cage_list, print_job_id);
  else
    print_job_id := -1;
  end if;
end create_label_print_job;

procedure create_cage_labels(cage_list in integer_list, print_job_id out number) is
/*
  This procedure is used to generate cage labels to be printed by an external application.
  (e.g. Oracle Reports).

  This procedure receives an array of cage IDs and for each cage, creates a record in the
  MTS_CAGE_LABEL_HEADER table containing header information for the label. Child records are also
  added for every animal in the cage to the MTS_CAGE_LABEL_DETAIL table.

  A unique print_job_id is generated and stored in the CAGE_LABEL_HEADER table. This number
  is returned from the procedure and can be used to find all labels generated by the
  execution of this procedure.
*/

  v_cage_label_header_id    number; -- primary key for CAGE_LABEL_HEADER table
  v_cage_label_detail_id  number; -- primary key for CAGE_LABEL_DETAIL table
  v_cage_id     number; -- temp variable to store current cage ID being processed
  v_extra_info_1   varchar2(1000);  -- variable to hold additional header details.
  v_label_type              varchar2(100); -- Stock, Breeding, etc...

  -- this is used to determine if <>1 value exists for header columns
  -- later, this will determine if the column will be displayed as 'NULL','MULTIPLE' or data.
  cursor count_header_details(in_cage_id number) is
  select
    count(distinct m.mouse_strain_dict_id),
 count(distinct m.current_owner_id),
 count(distinct m.current_project_licence_id),
 count(distinct m.current_protocol_id),
 count(decode(m.gender_dict_id,2,2,null)) males,
 count(decode(m.gender_dict_id,1,1,null)) females,
 count(decode(m.gender_dict_id,3,1,null)) unknowns,
 count(distinct m.colony_info_id)
  from
    mts_mouse m
  where
    cage_id = in_cage_id;

  -- these varables will hold the values from count_header_details cursor
  c_strain       number;
  c_current_owner   number;
  c_project_licence   number;
  c_protocol_code   number;
  c_males     number;
  c_females     number;
  c_unknowns    number;
  c_colony_info    number;

  -- this cursor will retrieve the actual data for the header
  cursor get_header_details(in_cage_id number) is
  select
    distinct
    m.strain,
 m.current_owner,
 m.room_name,
 m.rack_name,
 m.cage_name,
 m.cage_barcode,
 m.current_project_licence,
 m.current_protocol_code,
 m.colony_name
  from
    mts_mouse_vw m
  where
    m.cage_id = in_cage_id;

  -- these variables will hold the data from get_header_details cursor.
  v_strain         mts_mouse_vw.strain%type;
  v_current_owner     mts_mouse_vw.current_owner%type;
  v_room_name      mts_mouse_vw.room_name%type;
  v_rack_name     mts_mouse_vw.rack_name%type;
  v_cage_name         mts_mouse_vw.rack_name%type;
  v_cage_barcode     mts_mouse_vw.cage_barcode%type;
  v_project_licence    mts_mouse_vw.current_project_licence%type;
  v_protocol_code    mts_mouse_vw.current_protocol_code%type;
  v_colony_name     mts_mouse_vw.colony_name%type;

  -- this cursor returns the animal ids from a given cage.
  cursor get_animals_in_cage(in_cage_id number) is
  select
    *
  from
    mts_mouse
  where
    cage_id = in_cage_id;

  -- this variable will hold the data from get_animals_in_cage cursor.
  v_animal_id number;

  -- this cursor return the allele information for a given colony_id
  cursor get_allele(in_mouse_id number) is
  select 
    a.official_name_superscript,
 g.description genotype 
  from
    typ_modified_allele a,
 mts_mouse_allele m,
 mts_genotype_dict g
  where
    m.allele_id = a.id and
 m.mouse_id = in_mouse_id and
 m.genotype_dict_id = g.id(+);
 
  -- this variable will hold the data from get_allele.
  v_allele varchar2(4000); 
  v_genotype varchar2(30);
  
  -- this cursor is used to see if female in the current cage is in breeding,
  -- if so, the breeding name will be added to the header information.
   cursor breedingDetails(in_cage_id number) is
   select 
     'Mating '||breeding_name 
   from 
     mts_breeding b
   where 
     event_end is null and exists 
     (select null from mts_mouse female where female.id = b.female_id and female.cage_id = in_cage_id);

  -- this cursor is used to see if a female in the cage has an unweaned litter
  -- if so, the litter info will be added to the header information.
  -- (prewean animals have no records in the MOUSE table).
   cursor litterDetails(in_cage_id number) is
   select
     distinct
  chr(13)||chr(10)||'Birth Date: '||l.birth_date||
  chr(13)||chr(10)||' Pups: '||(l.number_born - (l.number_used + l.number_died))
   from
     mts_litter l,
   mts_breeding b
   where
     b.id = l.breeding_id and
  (exists (select null from mts_mouse f where f.id = b.female_id and f.cage_id = in_cage_id) or
   exists (select null from mts_mouse m where m.id = l.foster_mother_id and m.cage_id = in_cage_id)) and
  not exists (select null from mts_mouse a where a.litter_id = l.id);

  -- this variable is used to append text to the v_extra_info_1 variable.
  v_temp_string varchar2(1000);

begin
  --firstly get a print job ID from the sequence
  select mts_print_job_seq.nextval into print_job_id from dual;

  -- loop through the array of cages passed to the procedure.
  for i in cage_list.FIRST .. cage_list.LAST loop
      --reset variables for this iteration of the loop.
     v_temp_string := '';
   v_extra_info_1 := '';
   v_label_type := '';

     -- fetch header information for the current cage.
     open count_header_details(cage_list(i));
     fetch count_header_details into
      c_strain,
    c_current_owner,
    c_project_licence,
    c_protocol_code,
    c_males,
    c_females,
    c_unknowns,
    c_colony_info;
   close count_header_details;

   open get_header_details(cage_list(i));
     fetch get_header_details into
      v_strain,
    v_current_owner,
    v_room_name,
    v_rack_name,
    v_cage_name,
    v_cage_barcode,
    v_project_licence,
    v_protocol_code,
    v_colony_name;
   close get_header_details;

   -- if any header information has <>1 record then ammend the field as appropriate
   if c_strain = 0 then v_strain := 'NULL';
   elsif c_strain > 1 then v_strain := 'MULTIPLE';
   end if;

   if c_current_owner = 0 then v_current_owner := 'NULL';
   elsif c_current_owner > 1 then v_current_owner := 'MULTIPLE';
   end if;

   if c_project_licence = 0 then v_project_licence := 'NULL';
   elsif c_project_licence > 1 then v_project_licence := 'MULTIPLE';
   end if;

   if c_protocol_code = 0 then v_protocol_code := 'NULL';
   elsif c_protocol_code > 1 then v_protocol_code := 'MULTI';
   end if;
   
   if c_colony_info = 0 then v_colony_name := 'NULL';
   elsif c_colony_info > 1 then v_colony_name := 'MULTIPLE';
   end if;   
   
   v_temp_string := '';

    open breedingDetails(cage_list(i));
    fetch breedingDetails into v_label_type;
   if breedingDetails%NOTFOUND then
     v_label_type := 'STOCK';
   end if;
    close breedingDetails;

    open litterDetails(cage_list(i));
    fetch litterDetails into v_temp_string;
    close litterDetails;
 
    v_extra_info_1 := v_extra_info_1||v_temp_string;
    v_temp_string := '';

   -- generate the PK for the CAGE_LABEL_HEADER table
   -- need to do this as it's used as a foreign key on the CAGE_LABEL_DETAIL table.
   select mts_cage_header_seq.nextval into v_cage_label_header_id from dual;

   -- add parent record to CAGE_LABEL_HEADER table
   insert into mts_cage_label_header
     (id, print_job_id, room_name, rack_name, cage_name, cage_barcode,
   strain, project_licence, protocol_code, person_name, extra_info_1, 
   male_count, female_count, unknown_gender_count, colony_name, label_type)
     values
  (v_cage_label_header_id,
   print_job_id,
   v_room_name,
   v_rack_name,
   v_cage_name,
   v_cage_barcode,
   v_strain,
   v_project_licence,
   v_protocol_code,
   v_current_owner,
   v_extra_info_1,
   c_males,
   c_females,
   c_unknowns,
   v_colony_name,
   v_label_type);

    -- fetch animals for current cage and insert into child table CAGE_LABEL_DETAIL.
    for a in get_animals_in_cage(cage_list(i)) loop
      select mts_cage_detail_seq.nextval into v_cage_label_detail_id from dual;
   
   v_allele := '';
   v_genotype := '';
   open get_allele(a.id);
   fetch get_allele into v_allele, v_genotype;
   close get_allele;

      insert into mts_cage_label_detail(id, cage_label_header_id, mouse_id, allele)
    values
    (v_cage_label_detail_id,
     v_cage_label_header_id,
     a.id,
     v_allele||' '||v_genotype);
    end loop; --for a...

  end loop; --for i...
end create_cage_labels;

END MIG_LABEL;
/


SHOW ERRORS;

CREATE TABLE PER_PERSON_PREFS
(
  ID               NUMBER,
  PERSON_ID        NUMBER,
  DEFAULT_ROOM_ID  NUMBER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE PER_PERSON_COLUMN_PREFS
(
  ID              INTEGER,
  PERSON_ID       INTEGER,
  ORDER_BY        INTEGER,
  COLUMN_PREF_ID  INTEGER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE TABLE APP_TABLE_METADATA
(
  ID                  INTEGER,
  TABLE_NAME          VARCHAR2(30 BYTE),
  PRIMARY_KEY_COLUMN  VARCHAR2(30 BYTE)
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

CREATE SEQUENCE PER_PERSON_COL_PREF_SEQ
  START WITH 3434
  MAXVALUE 999999999999999999999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  NOORDER;

CREATE TABLE LIC_PROCEDURE_2_PROTOCOL
(
  ID                 INTEGER,
  PROCEDURE_DICT_ID  INTEGER,
  PROTOCOL_ID        INTEGER
)
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;


CREATE SYNONYM DESIGN_INSTANCE FOR EUCOMM_VECTOR.DESIGN_INSTANCE;

CREATE SYNONYM S_DESIGN_INSTANCE FOR EUCOMM_VECTOR.S_DESIGN_INSTANCE;


CREATE OR REPLACE FORCE VIEW REQ_ANIMAL_REQUEST_LIST_VW
(ID, PROJECT_LICENCE_ID, PPL_HOLDER, REQUEST_REASON, STRAIN_ID, 
 STRAIN, NUM_MALES_NEEDED, NUM_FEMALES_NEEDED, DATE_REQUIRED, DESTINATION_ROOM_ID, 
 DESTINATION_ROOM, STANDING_ORDER_FREQ, STANDING_ORDER_DAY, NUMBER_IN_CAGE, REDERIVATION_REQUESTED, 
 COMMENTS, EMBRYO_AGE_NEEDED, AGE_OR_WEIGHT_UNITS, AGE_OR_WEIGHT, FUNDING_SOURCE, 
 STATUS_DICT_ID, STATUS, DEVELOPMENT_ENDPOINT, CREATED_DATE, EDITED_BY, 
 EDIT_DATE, REQUEST_ORIGINATOR_ID, REQUESTER, TEAM_NUMBER, CREATOR_ID, 
 CHECK_NUMBER, PSEUDO_PREGNANT_FEMALE, END_DATE)
AS 
select 
  r.id, 
  r.project_licence_id, 
  h.first_name||' '||h.last_name ppl_holder, 
  r.request_reason, 
  r.strain_id, 
  s.name strain, 
  r.num_males_needed, 
  r.num_females_needed, 
  r.date_required, 
  r.destination_room_id, 
  m.room_number destination_room, 
  r.standing_order_freq, 
  r.standing_order_day, 
  r.number_in_cage, 
  r.rederivation_requested, 
  r.comments, 
  r.embryo_age_needed, 
  r.age_or_weight_units, 
  r.age_or_weight, 
  r.funding_source, 
  r.status_dict_id, 
  d.name status, 
  r.development_endpoint, 
  r.created_date, 
  r.edited_by, 
  r.edit_date, 
  r.request_originator_id, 
  p.first_name||' '||p.last_name requester, 
  t.team_number, 
  r.creator_id, 
  r.check_number, 
  r.pseudo_pregnant_female, 
  r.end_date 
from 
  req_animal_request r, 
  per_person p, 
  typ_strain s, 
  req_animal_request_status_dict d, 
  mts_room m, 
  lic_project_licence l, 
  per_person h, 
  per_team t 
where 
  r.status_dict_id = d.id and 
  r.strain_id = s.id and 
  r.request_originator_id = p.person_id and 
  r.destination_room_id = m.id(+) and 
  r.project_licence_id = l.project_licence_id and 
  l.responsible_person_id = h.person_id and 
  p.team_id = t.id(+);

CREATE OR REPLACE FORCE VIEW ARQ_DESIGN_STATUS_VW
(ID, NAME, DESCRIPTION, ORDER_BY, IS_ACTIVE)
AS 
select design_status_id id, description name, '' description, 0 order_by, 1 is_active from 
eucomm_vector.design_status_dict;

ALTER TABLE LIC_PROTOCOL_19B
 ADD (EDITED_BY  VARCHAR2(128 CHAR));

ALTER TABLE LIC_PROTOCOL_19B
 ADD (EDIT_DATE  DATE);

ALTER TABLE LIC_PROTOCOL_19B
 ADD (CHECK_NUMBER  INTEGER                         DEFAULT 0);

CREATE UNIQUE INDEX APP_COLUMN_PREFS_PK ON APP_COLUMN_PREFS
(ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX APP_TABLE_METADATA_PK ON APP_TABLE_METADATA
(ID)
LOGGING
NOPARALLEL;

ALTER TABLE LIC_PROTOCOL_19B
 ADD (PROTOCOL_CODE  VARCHAR2(32 CHAR));

ALTER TABLE LIC_PROTOCOL_19B
 ADD (TITLE  VARCHAR2(512 CHAR));

ALTER TABLE LIC_PROTOCOL_19B
 ADD (CREATOR_ID  INTEGER);

ALTER TABLE LIC_PROTOCOL_19B
 ADD (CREATED_DATE  DATE);

ALTER TABLE TYP_MODIFIED_ALLELE
 ADD (ALLELE_MAKER_ID  NUMBER);

CREATE UNIQUE INDEX PER_PERSON_COLUMN_PREFS_PK ON PER_PERSON_COLUMN_PREFS
(ID)
LOGGING
NOPARALLEL;

CREATE OR REPLACE FORCE VIEW PER_PERSON_COLUMN_PREFS_VW
(PERSON_ID, ORDER_BY, TABLE_NAME, COLUMN_NAME, COLUMN_TITLE, 
 GETTER_METHOD, COLUMN_PREF_ID, DATATYPE)
AS 
select 
  p.person_id, 
  p.order_by, 
  a.table_name, 
  a.column_name, 
  a.column_title, 
  a.getter_method, 
  p.column_pref_id, 
  a.datatype 
from 
  per_person_column_prefs p, 
  app_column_prefs a 
where 
  a.id = p.column_pref_id;
  

CREATE OR REPLACE TRIGGER MTS_COLONY_INFO_ta
before update or delete on MTS_COLONY_INFO for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
begin

if deleting or updating then 
 insert into MTS_COLONY_INFO_AUDIT(
    ID,
    COLONY_NAME,
    PROJECT_LICENCE_ID,
    CARD_COLOUR_DICT_ID,
    COLONY_MANAGEMENT,
    AVERAGE_LITTER_SIZE,
    BREEDING_LIFESPAN_WEEKS,
    IMMUNE_STATUS,
    OTHER_ABNORMALITIES,
    WELFARE_ASSESSMENT,
    HUSBANDRY_RECOMMENDATIONS,
    DIET,
    HOUSING_SYSTEM,
    ENVIRONMENTAL_ENRICHMENT,
    MISC_NOTES,
    COLONY_ORIGIN,
    PLACE_OF_ORIGIN,
    DATE_OF_IMPORT,
    DATE_OF_REDERIVATION,
    REDERIVATION_METHOD,
    EDITED_BY,
    EDIT_DATE,
    WELFARE_ASSESSMENT_PERFORMED,
    WTSI_ORIGIN,
    COLONY_PREFIX,
    MODE_OF_INHERITANCE,
    ASSESSING_PHENOTYPE,
    CHECK_NUMBER,
    CREATED_BY,
    CREATED_DATE)
 values (
    :old.ID,
    :old.COLONY_NAME,
    :old.PROJECT_LICENCE_ID,
    :old.CARD_COLOUR_DICT_ID,
    :old.COLONY_MANAGEMENT,
    :old.AVERAGE_LITTER_SIZE,
    :old.BREEDING_LIFESPAN_WEEKS,
    :old.IMMUNE_STATUS,
    :old.OTHER_ABNORMALITIES,
    :old.WELFARE_ASSESSMENT,
    :old.HUSBANDRY_RECOMMENDATIONS,
    :old.DIET,
    :old.HOUSING_SYSTEM,
    :old.ENVIRONMENTAL_ENRICHMENT,
    :old.MISC_NOTES,
    :old.COLONY_ORIGIN,
    :old.PLACE_OF_ORIGIN,
    :old.DATE_OF_IMPORT,
    :old.DATE_OF_REDERIVATION,
    :old.REDERIVATION_METHOD,
    :old.EDITED_BY,
    :old.EDIT_DATE,
    :old.WELFARE_ASSESSMENT_PERFORMED,
    :old.WTSI_ORIGIN,
    :old.COLONY_PREFIX,
    :old.MODE_OF_INHERITANCE,
    :old.ASSESSING_PHENOTYPE,
    :old.CHECK_NUMBER,
    :old.CREATED_BY,
    :old.CREATED_DATE);
end if;
end;
/
SHOW ERRORS;


CREATE OR REPLACE TRIGGER MTS_COHORT_TRIG
BEFORE INSERT
ON MTS_COHORT
FOR EACH ROW
BEGIN
  IF :NEW.ID IS NULL THEN
     SELECT MTS_COHORT_SEQ.NEXTVAL INTO :NEW.ID FROM dual;
  END IF;   
END;
/
SHOW ERRORS;


CREATE OR REPLACE TRIGGER MTS_ES_CLONE_TRIG
BEFORE INSERT
ON MTS_ES_CLONE
REFERENCING NEW AS New OLD AS Old
FOR EACH ROW
BEGIN
  IF(:NEW.ID IS NULL) THEN
    SELECT MTS_ES_CLONE_SEQ.NEXTVAL INTO :NEW.ID FROM DUAL;
  END IF;
END;
/
SHOW ERRORS;


/* This object may not be sorted properly in the script due to cirular references */
CREATE OR REPLACE TRIGGER mts_breeding_ts
before insert on mts_breeding for each row
begin
  if :new.id is null then
    select mts_breeding_seq.nextval into :new.id from dual;
  end if;
end;
/
SHOW ERRORS;


/* This object may not be sorted properly in the script due to cirular references */
CREATE OR REPLACE TRIGGER MTS_BREEDING_ta
before update or delete on MTS_BREEDING for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
begin

if deleting or updating then 
 insert into MTS_BREEDING_AUDIT(
    ID,
    EVENT_START,
    EVENT_END,
    CHECK_NUMBER,
    EDITED_BY,
    EDIT_DATE,
    COMMENTS,
    RESERVATION_ID,
    CREATOR_ID,
    CREATED_DATE,
    MALE_ID,
    FEMALE_ID,
    STATUS,
    BREEDING_NAME,
    OFFSPRING_COLONY_ID,
    PSEUDO_BREEDING,
    EMBRYO_TRANSFER_ID)
 values (
    :old.ID,
    :old.EVENT_START,
    :old.EVENT_END,
    :old.CHECK_NUMBER,
    :old.EDITED_BY,
    :old.EDIT_DATE,
    :old.COMMENTS,
    :old.RESERVATION_ID,
    :old.CREATOR_ID,
    :old.CREATED_DATE,
    :old.MALE_ID,
    :old.FEMALE_ID,
    :old.STATUS,
    :old.BREEDING_NAME,
    :old.OFFSPRING_COLONY_ID,
    :old.PSEUDO_BREEDING,
    :old.EMBRYO_TRANSFER_ID);
end if;
end;
/
SHOW ERRORS;


/* This object may not be sorted properly in the script due to cirular references */
CREATE OR REPLACE TRIGGER mts_mouse_t2
after insert or update on mts_mouse
for each row
WHEN (
nvl(old.cage_id,-1) != nvl(new.cage_id,-2)
      )
declare

/*
  Find the previous history record (if any). 
  This will be updated with an end date corresponding to current timestamp.
*/
cursor previous_history_record(in_mouse_id number) is
select id from mts_mouse_cage_history where mouse_id = in_mouse_id and end_date is null;

previous_history_id number;

now_timestamp date := systimestamp;
	  
begin

  open previous_history_record(:new.id);
  fetch previous_history_record into previous_history_id;
  close previous_history_record;

  -- Insert a new history record for the current cage (if not null)
  if :new.cage_id is not null then
	  insert into mts_mouse_cage_history(id,mouse_id,cage_id,start_date)
	  select 
	    mts_mouse_cage_history_seq.nextval,
		:new.id,
		:new.cage_id,
		now_timestamp 
	  from dual;
  end if;
  
  -- Update previous history record with a new end date
  update mts_mouse_cage_history
  set end_date = now_timestamp
  where id = previous_history_id;

end;
/
SHOW ERRORS;


/* This object may not be sorted properly in the script due to cirular references */
CREATE OR REPLACE TRIGGER mts_mouse_ts
before insert or update on mts_mouse for each row
begin
  if(:new.id is null) then
    select mts_mouse_seq.nextval into :new.id from dual;
  end if;
  
  :new.barcode := 'M'||lpad(:new.id,8,'0');
  
  if :new.death_date is null then
    :new.status := 'Alive';
  else
    :new.status := 'Deceased';
  end if;
	
end;
/
SHOW ERRORS;


CREATE OR REPLACE TRIGGER MTS_MOUSE_ta
before update or delete on MTS_MOUSE for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
begin

if deleting or updating then 
 insert into MTS_MOUSE_AUDIT(
    ID,
    LITTER_ID,
    NAME,
    EDIT_DATE,
    RFID_TAG,
    COAT_COLOUR_DICT_ID,
    EYE_COLOUR_DICT_ID,
    EARMARK_DICT_ID,
    BIRTH_DATE,
    DEATH_DATE,
    CAUSE_OF_DEATH_DICT_ID,
    EDITED_BY,
    WEAN_DATE,
    CAGE_ID,
    CURRENT_OWNER_ID,
    CURRENT_PROJECT_LICENCE_ID,
    CHECK_NUMBER,
    GENDER_DICT_ID,
    MOUSE_STRAIN_DICT_ID,
    STATUS,
    CREATOR_ID,
    CREATED_DATE,
    BARCODE,
    COMMENTS,
    CURRENT_PROTOCOL_ID,
    SUPPLIER_DICT_ID,
    IS_NON_BREEDER,
    IS_SENTINEL,
    RESERVATION_ID,
    GENERATION,
    COLONY_INFO_ID,
    COHORT_ID,
    ARRIVAL_DATE,
    FATHER_ID,
    MOTHER_ID,
    EARMARK_LEFT,
    EARMARK_RIGHT)
 values (
    :old.ID,
    :old.LITTER_ID,
    :old.NAME,
    :old.EDIT_DATE,
    :old.RFID_TAG,
    :old.COAT_COLOUR_DICT_ID,
    :old.EYE_COLOUR_DICT_ID,
    :old.EARMARK_DICT_ID,
    :old.BIRTH_DATE,
    :old.DEATH_DATE,
    :old.CAUSE_OF_DEATH_DICT_ID,
    :old.EDITED_BY,
    :old.WEAN_DATE,
    :old.CAGE_ID,
    :old.CURRENT_OWNER_ID,
    :old.CURRENT_PROJECT_LICENCE_ID,
    :old.CHECK_NUMBER,
    :old.GENDER_DICT_ID,
    :old.MOUSE_STRAIN_DICT_ID,
    :old.STATUS,
    :old.CREATOR_ID,
    :old.CREATED_DATE,
    :old.BARCODE,
    :old.COMMENTS,
    :old.CURRENT_PROTOCOL_ID,
    :old.SUPPLIER_DICT_ID,
    :old.IS_NON_BREEDER,
    :old.IS_SENTINEL,
    :old.RESERVATION_ID,
    :old.GENERATION,
    :old.COLONY_INFO_ID,
    :old.COHORT_ID,
    :old.ARRIVAL_DATE,
    :old.FATHER_ID,
    :old.MOTHER_ID,
    :old.EARMARK_LEFT,
    :old.EARMARK_RIGHT);
end if;
end;
/
SHOW ERRORS;



/* This object may not be sorted properly in the script due to cirular references */
CREATE OR REPLACE TRIGGER mts_mouse_procedure_t1 
 before insert or update or delete on mts_mouse_procedure
for each row
declare

cursor get_table_metadata(in_table_metadata_id integer) is
select
  *
from
  app_table_metadata
where
  id = in_table_metadata_id;
  
user_exception exception;
exception_message varchar2(4000);

v_table_metadata app_table_metadata%rowtype;

begin

	 -- updated records cannot change the table metadata (doesn't make sense to do so)
	 if updating then
	   if :new.table_metadata_id != :old.table_metadata_id then
	      exception_message := 'TABLE_METADATA_ID reference cannot be updated';
	   	  raise user_exception;
	   end if;	 	
	 end if;
	 
	 -- inserted record must contain a valid table name
	 if inserting then
	 	open get_table_metadata(:new.table_metadata_id);
		fetch get_table_metadata into v_table_metadata;
		if get_table_metadata%notfound then
		  close get_table_metadata;
		  exception_message := 'TABLE_METADATA_ID ('||:new.table_metadata_id||') is not a valid reference';
	   	  raise user_exception;
		end if;
		close get_table_metadata;
	 end if; 
	 
	 -- if deleting, ensure foreign key does not exist
	 if deleting then
	 	open get_table_metadata(:old.table_metadata_id);
		fetch get_table_metadata into v_table_metadata;
		if get_table_metadata%notfound then
		  close get_table_metadata;
		  exception_message := 'TABLE_METADATA_ID ('||:old.table_metadata_id||') is not a valid reference';
	   	  raise user_exception;
		end if;
		close get_table_metadata;
	    execute immediate 'select * from '||v_table_metadata.table_name||' where '||v_table_metadata.primary_key_column||'=:1' using :old.foreign_key_id;
		if sql%rowcount > 0 then
		  exception_message := 'Cannot delete MTS_MOUSE_PROCEDURE (ID='||:old.id||') because foreign key exists.';
	   	  raise user_exception;
		  
		end if;
	end if;
	 

exception
  when user_exception then raise_application_error(-20001, exception_message);
  	 
end mts_mouse_procedure_t1;
/
SHOW ERRORS;


CREATE OR REPLACE TRIGGER MTS_RACK_ta
before update or delete on MTS_RACK for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
begin

if deleting or updating then 
 insert into MTS_RACK_AUDIT(
    ID,
    AIR_HANDLING_UNIT_ID,
    ROOM_ID,
    STATUS,
    TECHNOPLAST_NAME,
    CHECK_NUMBER,
    EDITED_BY,
    EDIT_DATE,
    CREATOR_ID,
    CREATED_DATE,
    BARCODE,
    MAX_CAPACITY,
    NAME)
 values (
    :old.ID,
    :old.AIR_HANDLING_UNIT_ID,
    :old.ROOM_ID,
    :old.STATUS,
    :old.TECHNOPLAST_NAME,
    :old.CHECK_NUMBER,
    :old.EDITED_BY,
    :old.EDIT_DATE,
    :old.CREATOR_ID,
    :old.CREATED_DATE,
    :old.BARCODE,
    :old.MAX_CAPACITY,
    :old.NAME);
end if;
end;
/
SHOW ERRORS;


CREATE OR REPLACE TRIGGER MTS_AIR_HANDLING_UNIT_TRIG BEFORE INSERT ON MTS_AIR_HANDLING_UNIT
REFERENCING NEW AS New OLD AS Old
FOR EACH ROW
BEGIN
    IF(:NEW.ID IS NULL) THEN
      SELECT MTS_AIR_HANDLING_UNIT_SEQ.NEXTVAL INTO :NEW.ID FROM DUAL;
    END IF;
END;
/
SHOW ERRORS;


CREATE OR REPLACE TRIGGER MTS_AIR_HANDLING_UNIT_ta
before update or delete on MTS_AIR_HANDLING_UNIT for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
begin

if deleting or updating then 
 insert into MTS_AIR_HANDLING_UNIT_AUDIT(
    ID,
    NAME,
    ROOM_ID,
    CHECK_NUMBER,
    RADIO_ADDRESS,
    EDITED_BY,
    EDIT_DATE,
    CREATED_DATE)
 values (
    :old.ID,
    :old.NAME,
    :old.ROOM_ID,
    :old.CHECK_NUMBER,
    :old.RADIO_ADDRESS,
    :old.EDITED_BY,
    :old.EDIT_DATE,
    :old.CREATED_DATE);
end if;
end;
/
SHOW ERRORS;


CREATE OR REPLACE TRIGGER MTS_COLONY_CROSS_ta
before update or delete on MTS_COLONY_CROSS for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
begin

if deleting or updating then 
 insert into MTS_COLONY_CROSS_AUDIT(
    ID,
    PHENOTYPE_TEXT,
    GENOTYPE_TEXT,
    DELIMITED_ALLELE_IDS,
    COLONY_ID,
    IS_LETHAL,
    EDITED_BY,
    EDIT_DATE,
    CHECK_NUMBER)
 values (
    :old.ID,
    :old.PHENOTYPE_TEXT,
    :old.GENOTYPE_TEXT,
    :old.DELIMITED_ALLELE_IDS,
    :old.COLONY_ID,
    :old.IS_LETHAL,
    :old.EDITED_BY,
    :old.EDIT_DATE,
    :old.CHECK_NUMBER);
end if;
end;
/
SHOW ERRORS;


CREATE OR REPLACE TRIGGER MTS_COLONY_ALLELE_ta
before update or delete on MTS_COLONY_ALLELE for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
begin

if deleting or updating then 
 insert into MTS_COLONY_ALLELE_AUDIT(
    ID,
    COLONY_ID,
    MODIFIED_ALLELE_ID,
    EDITED_BY,
    EDIT_DATE,
    CHECK_NUMBER)
 values (
    :old.ID,
    :old.COLONY_ID,
    :old.MODIFIED_ALLELE_ID,
    :old.EDITED_BY,
    :old.EDIT_DATE,
    :old.CHECK_NUMBER);
end if;
end;
/
SHOW ERRORS;


CREATE OR REPLACE TRIGGER MTS_COLONY_BEHAVIOUR_ta
before update or delete on MTS_COLONY_BEHAVIOUR for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
begin

if deleting or updating then 
 insert into MTS_COLONY_BEHAVIOUR_AUDIT(
    ID,
    TRAIT,
    REMEDIAL_ACTION,
    COLONY_ID,
    EDITED_BY,
    EDIT_DATE,
    CHECK_NUMBER)
 values (
    :old.ID,
    :old.TRAIT,
    :old.REMEDIAL_ACTION,
    :old.COLONY_ID,
    :old.EDITED_BY,
    :old.EDIT_DATE,
    :old.CHECK_NUMBER);
end if;
end;
/
SHOW ERRORS;


CREATE OR REPLACE TRIGGER MTS_COLONY_COAT_COLOUR_ta
before update or delete on MTS_COLONY_COAT_COLOUR for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
begin

if deleting or updating then 
 insert into MTS_COLONY_COAT_COLOUR_AUDIT(
    ID,
    COLONY_ID,
    COAT_COLOUR_DICT_ID,
    EDITED_BY,
    EDIT_DATE,
    CHECK_NUMBER)
 values (
    :old.ID,
    :old.COLONY_ID,
    :old.COAT_COLOUR_DICT_ID,
    :old.EDITED_BY,
    :old.EDIT_DATE,
    :old.CHECK_NUMBER);
end if;
end;
/
SHOW ERRORS;


CREATE OR REPLACE TRIGGER MTS_COLONY_CONTACT_ta
before update or delete on MTS_COLONY_CONTACT for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
begin

if deleting or updating then 
 insert into MTS_COLONY_CONTACT_AUDIT(
    ID,
    PERSON_ID,
    COLONY_ID,
    REASON,
    EDITED_BY,
    EDIT_DATE,
    CHECK_NUMBER)
 values (
    :old.ID,
    :old.PERSON_ID,
    :old.COLONY_ID,
    :old.REASON,
    :old.EDITED_BY,
    :old.EDIT_DATE,
    :old.CHECK_NUMBER);
end if;
end;
/
SHOW ERRORS;


CREATE OR REPLACE TRIGGER MTS_COLONY_ROOM_ta
before update or delete on MTS_COLONY_ROOM for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
begin

if deleting or updating then 
 insert into MTS_COLONY_ROOM_AUDIT(
    ID,
    ROOM_ID,
    COLONY_ID,
    EDITED_BY,
    EDIT_DATE,
    CHECK_NUMBER)
 values (
    :old.ID,
    :old.ROOM_ID,
    :old.COLONY_ID,
    :old.EDITED_BY,
    :old.EDIT_DATE,
    :old.CHECK_NUMBER);
end if;
end;
/
SHOW ERRORS;


CREATE OR REPLACE TRIGGER MTS_COLONY_STRAIN_ta
before update or delete on MTS_COLONY_STRAIN for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
begin

if deleting or updating then 
 insert into MTS_COLONY_STRAIN_AUDIT(
    ID,
    STRAIN_ID,
    COLONY_ID,
    PERCENT,
    EDITED_BY,
    EDIT_DATE,
    CHECK_NUMBER)
 values (
    :old.ID,
    :old.STRAIN_ID,
    :old.COLONY_ID,
    :old.PERCENT,
    :old.EDITED_BY,
    :old.EDIT_DATE,
    :old.CHECK_NUMBER);
end if;
end;
/
SHOW ERRORS;


CREATE OR REPLACE TRIGGER MTS_ROOM_ta
before update or delete on MTS_ROOM for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
begin

if deleting or updating then 
 insert into MTS_ROOM_AUDIT(
    ID,
    ROOM_NUMBER,
    BUILDING_NAME,
    CORRIDOR,
    DESCRIPTION,
    CHECK_NUMBER,
    ACTIVE,
    OFFICIAL_ROOM_NUMBER)
 values (
    :old.ID,
    :old.ROOM_NUMBER,
    :old.BUILDING_NAME,
    :old.CORRIDOR,
    :old.DESCRIPTION,
    :old.CHECK_NUMBER,
    :old.ACTIVE,
    :old.OFFICIAL_ROOM_NUMBER);
end if;
end;
/
SHOW ERRORS;


CREATE OR REPLACE TRIGGER mts_cage_t2
after insert or update on mts_cage
for each row
WHEN (
nvl(old.rack_id,-1) != nvl(new.rack_id,-2)
      )
declare

/*
  Find the previous history record (if any). 
  This will be updated with an end date corresponding to current timestamp.
*/
cursor previous_history_record(in_cage_id number) is
select id from mts_cage_rack_history where cage_id = in_cage_id and end_date is null;

previous_history_id number;

now_timestamp date := systimestamp;
	  
begin

  open previous_history_record(:new.id);
  fetch previous_history_record into previous_history_id;
  close previous_history_record;

  -- Insert a new history record for the current cage (if not null)
  if :new.rack_id is not null then
	  insert into mts_cage_rack_history(id,cage_id,rack_id,start_date)
	  select 
	    mts_cage_rack_history_seq.nextval,
		:new.id,
		:new.rack_id,
		now_timestamp 
	  from dual;
  end if;
  
  -- Update previous history record with a new end date
  update mts_cage_rack_history
  set end_date = now_timestamp
  where id = previous_history_id;

end;
/
SHOW ERRORS;


CREATE OR REPLACE TRIGGER mts_cage_ts
before insert or update on mts_cage for each row
begin
  if(:new.id is null) then
    select mts_cage_seq.nextval into :new.id from dual;
  end if;
  
  :new.barcode := 'C'||lpad(:new.id,8,'0');
end;
/
SHOW ERRORS;


CREATE OR REPLACE TRIGGER MTS_CAGE_ta
before update or delete on MTS_CAGE for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
begin

if deleting or updating then 
 insert into MTS_CAGE_AUDIT(
    ID,
    RACK_ID,
    STATUS,
    CHECK_NUMBER,
    COMMENTS,
    EDITED_BY,
    EDIT_DATE,
    CREATOR_ID,
    CREATED_DATE,
    BARCODE,
    NAME,
    LAST_CLEANED_DATE)
 values (
    :old.ID,
    :old.RACK_ID,
    :old.STATUS,
    :old.CHECK_NUMBER,
    :old.COMMENTS,
    :old.EDITED_BY,
    :old.EDIT_DATE,
    :old.CREATOR_ID,
    :old.CREATED_DATE,
    :old.BARCODE,
    :old.NAME,
    :old.LAST_CLEANED_DATE);
end if;
end;
/
SHOW ERRORS;


CREATE OR REPLACE TRIGGER MTS_AIR_HANDLING_DATA_TRIG BEFORE INSERT ON MTS_AIR_HANDLING_DATA 
REFERENCING NEW AS New OLD AS Old
FOR EACH ROW
BEGIN
    IF(:NEW.ID IS NULL) THEN
      SELECT MTS_AIR_HANDLING_DATA_SEQ.NEXTVAL INTO :NEW.ID FROM DUAL;
    END IF;
END;
/
SHOW ERRORS;


/* This object may not be sorted properly in the script due to cirular references */
CREATE OR REPLACE TRIGGER MTS_EMBRYO_TRANSFER_TRIG
BEFORE INSERT
ON MTS_EMBRYO_TRANSFER
REFERENCING NEW AS New OLD AS Old
FOR EACH ROW
BEGIN
  IF(:NEW.ID IS NULL) THEN
    SELECT MTS_EMBRYO_TRANSFER_SEQ.NEXTVAL INTO :NEW.ID FROM DUAL;
  END IF;
END;
/
SHOW ERRORS;


/* This object may not be sorted properly in the script due to cirular references */
CREATE OR REPLACE TRIGGER mts_litter_ts
before insert on mts_litter for each row
begin
  if :new.id is null then
    select mts_litter_seq.nextval into :new.id from dual;
  end if;
end;
/
SHOW ERRORS;


/* This object may not be sorted properly in the script due to cirular references */
CREATE OR REPLACE TRIGGER MTS_LITTER_ta
before update or delete on MTS_LITTER for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
begin

if deleting or updating then 
 insert into MTS_LITTER_AUDIT(
    ID,
    LITTER_SOURCE,
    BREEDING_ID,
    BIRTH_DATE,
    CHECK_NUMBER,
    EDITED_BY,
    EDIT_DATE,
    CREATOR_ID,
    CREATED_DATE,
    PLUG_CHECK_DATE,
    FOSTER_MOTHER_ID,
    NUMBER_BORN,
    NUMBER_WEANED,
    NUMBER_USED,
    COMMENTS,
    NUMBER_DIED,
    STATUS,
    LITTER_NAME,
    NUMBER_HARVESTED)
 values (
    :old.ID,
    :old.LITTER_SOURCE,
    :old.BREEDING_ID,
    :old.BIRTH_DATE,
    :old.CHECK_NUMBER,
    :old.EDITED_BY,
    :old.EDIT_DATE,
    :old.CREATOR_ID,
    :old.CREATED_DATE,
    :old.PLUG_CHECK_DATE,
    :old.FOSTER_MOTHER_ID,
    :old.NUMBER_BORN,
    :old.NUMBER_WEANED,
    :old.NUMBER_USED,
    :old.COMMENTS,
    :old.NUMBER_DIED,
    :old.STATUS,
    :old.LITTER_NAME,
    :old.NUMBER_HARVESTED);
end if;
end;
/
SHOW ERRORS;


CREATE OR REPLACE TRIGGER mts_rack_t2
after insert or update on mts_rack
for each row
WHEN (
nvl(old.room_id,-1) != nvl(new.room_id,-2)
      )
declare

/*
  Find the previous history record (if any). 
  This will be updated with an end date corresponding to current timestamp.
*/
cursor previous_history_record(in_rack_id number) is
select id from mts_rack_room_history where rack_id = in_rack_id and end_date is null;

previous_history_id number;

now_timestamp date := systimestamp;
	  
begin

  open previous_history_record(:new.id);
  fetch previous_history_record into previous_history_id;
  close previous_history_record;

  -- Insert a new history record for the current rack (if not null)
  if :new.room_id is not null then
	  insert into mts_rack_room_history(id,rack_id,room_id,start_date)
	  select 
	    mts_rack_room_history_seq.nextval,
		:new.id,
		:new.room_id,
		now_timestamp 
	  from dual;
  end if;
  
  -- Update previous history record with a new end date
  update mts_rack_room_history
  set end_date = now_timestamp
  where id = previous_history_id;

end;
/
SHOW ERRORS;


/* This object may not be sorted properly in the script due to cirular references */
CREATE OR REPLACE TRIGGER mts_mouse_allele_ts
before insert or update on mts_mouse_allele for each row
begin
  if(:new.id is null) then
    select mts_mouse_allele_seq.nextval into :new.id from dual;
  end if; 
end;
/
SHOW ERRORS;


/* This object may not be sorted properly in the script due to cirular references */
CREATE OR REPLACE TRIGGER mts_chimeric_mouse_data_ts
before insert on mts_chimeric_mouse_data for each row
begin
  if :new.id is null then
    select mts_chimeric_mouse_data_seq.nextval into :new.id from dual;
  end if;
end;
/
SHOW ERRORS;


/* This object may not be sorted properly in the script due to cirular references */
CREATE OR REPLACE TRIGGER MTS_MOUSE_HEALTH_ta
before update or delete on MTS_MOUSE_HEALTH for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
begin

if deleting or updating then 
 insert into MTS_MOUSE_HEALTH_AUDIT(
    ID,
    MOUSE_ID,
    START_DATE,
    END_DATE,
    EDIT_DATE,
    EDITED_BY,
    CREATOR_ID,
    CREATED_DATE,
    COMMENTS,
    STATUS,
    BODY_SUBSYSTEM_DICT_ID,
    BODY_SYSTEM_DICT_ID,
    HEALTH_CONCERN_DICT_ID)
 values (
    :old.ID,
    :old.MOUSE_ID,
    :old.START_DATE,
    :old.END_DATE,
    :old.EDIT_DATE,
    :old.EDITED_BY,
    :old.CREATOR_ID,
    :old.CREATED_DATE,
    :old.COMMENTS,
    :old.STATUS,
    :old.BODY_SUBSYSTEM_DICT_ID,
    :old.BODY_SYSTEM_DICT_ID,
    :old.HEALTH_CONCERN_DICT_ID);
end if;
end;
/
SHOW ERRORS;

CREATE OR REPLACE TRIGGER REQ_ANIMAL_REQUEST_ta
before update or delete on REQ_ANIMAL_REQUEST for each row
/* THIS TRIGGER WAS AUTOGENERATED BY DBMS_MIG.MAKE_AUDIT_TRIGGER */
begin

if deleting or updating then 
 insert into REQ_ANIMAL_REQUEST_AUDIT(
    ID,
    PROJECT_LICENCE_ID,
    REQUEST_REASON,
    STRAIN_ID,
    NUM_MALES_NEEDED,
    NUM_FEMALES_NEEDED,
    DATE_REQUIRED,
 END_DATE,
    DESTINATION_ROOM_ID,
    STANDING_ORDER_FREQ,
    STANDING_ORDER_DAY,
    NUMBER_IN_CAGE,
    REDERIVATION_REQUESTED,
    COMMENTS,
    EMBRYO_AGE_NEEDED,
    AGE_OR_WEIGHT_UNITS,
    AGE_OR_WEIGHT,
    FUNDING_SOURCE,
    STATUS_DICT_ID,
    DEVELOPMENT_ENDPOINT,
    CREATED_DATE,
    EDITED_BY,
    EDIT_DATE,
    REQUEST_ORIGINATOR_ID,
    CREATOR_ID,
    CHECK_NUMBER)
 values (
    :old.ID,
    :old.PROJECT_LICENCE_ID,
    :old.REQUEST_REASON,
    :old.STRAIN_ID,
    :old.NUM_MALES_NEEDED,
    :old.NUM_FEMALES_NEEDED,
    :old.DATE_REQUIRED,
 :old.END_DATE,
    :old.DESTINATION_ROOM_ID,
    :old.STANDING_ORDER_FREQ,
    :old.STANDING_ORDER_DAY,
    :old.NUMBER_IN_CAGE,
    :old.REDERIVATION_REQUESTED,
    :old.COMMENTS,
    :old.EMBRYO_AGE_NEEDED,
    :old.AGE_OR_WEIGHT_UNITS,
    :old.AGE_OR_WEIGHT,
    :old.FUNDING_SOURCE,
    :old.STATUS_DICT_ID,
    :old.DEVELOPMENT_ENDPOINT,
    :old.CREATED_DATE,
    :old.EDITED_BY,
    :old.EDIT_DATE,
    :old.REQUEST_ORIGINATOR_ID,
    :old.CREATOR_ID,
    :old.CHECK_NUMBER);
end if;
end;
/


CREATE OR REPLACE TRIGGER mts_rack_ts
before insert or update on mts_rack for each row
begin
  if(:new.id is null) then
    select mts_rack_seq.nextval into :new.id from dual;
  end if;
  
  :new.barcode := 'R'||lpad(:new.id,8,'0');
end;
/
SHOW ERRORS;

ALTER TABLE MTS_RESERVATION
 ADD CONSTRAINT MTS_RESERVATION_PK
 PRIMARY KEY
 (ID);  
 

ALTER TABLE MIR_INTERNAL_STATUS_DICT
 ADD CONSTRAINT MIR_REQUEST_STATUS_DICT_PK
 PRIMARY KEY
 (ID); 
 
ALTER TABLE MTS_EYE_COLOUR_DICT
 ADD CONSTRAINT MTS_EYE_COLOUR_DICT_PK
 PRIMARY KEY
 (ID); 
 
ALTER TABLE MIR_SCHEDULED_MICRO_INJECTION
 ADD CONSTRAINT MIR_SCHEDULED_MICRO_INJECTI_PK
 PRIMARY KEY
 (ID); 
 
ALTER TABLE MTS_CAGE_RACK_HISTORY
 ADD CONSTRAINT MTS_CAGE_RACK_HISTORY_PK
 PRIMARY KEY
 (ID); 
 
ALTER TABLE MTS_MOUSE_ALLELE
 ADD CONSTRAINT MTS_MOUSE_ALLELE_PK
 PRIMARY KEY
 (ID); 
 
ALTER TABLE MTS_MOUSE_HEALTH
 ADD CONSTRAINT MTS_MOUSE_HEALTH_PK
 PRIMARY KEY
 (ID); 
 
ALTER TABLE MIR_TRANSFER_TYPE_DICT
 ADD CONSTRAINT MIR_TRANSFER_TYPE_DICT_PK
 PRIMARY KEY
 (ID);

ALTER TABLE MTS_BIOPSY_PLATE
 ADD CONSTRAINT MTS_BIOPSY_PLATE_PK
 PRIMARY KEY
 (ID); 
 
ALTER TABLE MTS_HEALTH_CONCERN_DICT
 ADD CONSTRAINT MTS_HEALTH_CONCERN_DICT_PK
 PRIMARY KEY
 (ID);

ALTER TABLE MTS_PROCEDURE_DICT
 ADD CONSTRAINT MTS_PROCEDURE_DICT_PK
 PRIMARY KEY
 (ID);

ALTER TABLE MTS_AIR_HANDLING_DATA
 ADD CONSTRAINT MTS_AIR_HANDLING_DATA_PK
 PRIMARY KEY
 (ID);
 
 
ALTER TABLE MIR_SCHEDULED_MI_TASK
 ADD CONSTRAINT MIR_SCHEDULED_MI_TASK_PK
 PRIMARY KEY
 (ID);

ALTER TABLE MTS_MOUSE_CAGE_HISTORY
 ADD CONSTRAINT MTS_MOUSE_CAGE_HISTORY_PK
 PRIMARY KEY
 (ID);
 
 
ALTER TABLE MIR_EMBRYO_TRANSFER_PROCEDURE
 ADD CONSTRAINT MIR_EMBRYO_TRANSFER_PK
 PRIMARY KEY
 (ID); 
 
ALTER TABLE MIR_MICRO_INJECTION
 ADD CONSTRAINT MIR_MICRO_INJECTION_PROCEDU_PK
 PRIMARY KEY
 (ID); 
 
ALTER TABLE MIR_EMBRYO_HARVEST
 ADD CONSTRAINT MIR_EMBRYO_HARVEST_PK
 PRIMARY KEY
 (ID); 
 
ALTER TABLE MTS_COHORT
 ADD PRIMARY KEY
 (ID);

ALTER TABLE APP_COLUMN_PREFS
 ADD CONSTRAINT APP_COLUMN_PREFS_PK
 PRIMARY KEY
 (ID);

ALTER TABLE MTS_AIR_HANDLING_UNIT
 ADD CONSTRAINT MTS_AIR_HANDLING_UNIT_PK
 PRIMARY KEY
 (ID); 
 
ALTER TABLE MTS_RACK
 ADD PRIMARY KEY
 (ID); 
 
ALTER TABLE MTS_RACK_ROOM_HISTORY
 ADD CONSTRAINT MTS_RACK_ROOM_HISTORY_PK
 PRIMARY KEY
 (ID); 
 
ALTER TABLE APP_TABLE_METADATA
 ADD CONSTRAINT APP_TABLE_METADATA_PK
 PRIMARY KEY
 (ID);

ALTER TABLE MTS_ES_CLONE
 ADD CONSTRAINT MTS_ES_CLONE_PK
 PRIMARY KEY
 (ID); 
 
ALTER TABLE MTS_ENVIRONMENT_REPORT
 ADD CONSTRAINT MTS_ENVIRONMENT_REPORT_PK
 PRIMARY KEY
 (ID);

ALTER TABLE MTS_BODY_SYSTEM_DICT
 ADD CONSTRAINT MTS_BODY_SYSTEM_DICT_PK
 PRIMARY KEY
 (ID); 
 
ALTER TABLE MTS_BODY_SUBSYSTEM_DICT
 ADD CONSTRAINT MTS_BODY_SUBSYSTEM_DICT_PK
 PRIMARY KEY
 (ID); 
 
ALTER TABLE MTS_GENDER_DICT
 ADD CONSTRAINT MTS_GENDER_DICT_PK
 PRIMARY KEY
 (ID);

ALTER TABLE MTS_MOUSE_SUPPLIER_DICT
 ADD CONSTRAINT MTS_MOUSE_SUPPLIER_DICT_PK
 PRIMARY KEY
 (ID); 


ALTER TABLE MTS_CAGE
 ADD PRIMARY KEY
 (ID); 
 
 
ALTER TABLE MTS_RESERVED_MOUSE
 ADD CONSTRAINT MTS_RESERVED_MOUSE_PK
 PRIMARY KEY
 (ID); 
 
ALTER TABLE MIR_MI_B6_TASK_TEMPLATE
 ADD CONSTRAINT MIR_MI_TASK_B6_TEMPLATE_PK
 PRIMARY KEY
 (ID);

ALTER TABLE MTS_CAUSE_OF_DEATH_DICT
 ADD CONSTRAINT MTS_CAUSE_OF_DEATH_DICT_PK
 PRIMARY KEY
 (ID); 
 
ALTER TABLE MIR_MI_129_TASK_TEMPLATE
 ADD CONSTRAINT MIR_MI_TASK_DICT_R01
 PRIMARY KEY
 (ID);
 
ALTER TABLE MIR_ANALGESIA_DICT
 ADD PRIMARY KEY
 (ID); 
 
ALTER TABLE MTS_LITTER
 ADD CONSTRAINT MTS_LITTER_PK
 PRIMARY KEY
 (ID); 
 
ALTER TABLE MTS_CHIMERIC_MOUSE_DATA
 ADD CONSTRAINT MTS_CHIMERIC_MOUSE_DATA_PK
 PRIMARY KEY
 (ID);

ALTER TABLE MTS_BREEDING
 ADD PRIMARY KEY
 (ID); 

ALTER TABLE MTS_EARMARK_DICT
 ADD CONSTRAINT MTS_EARMARK_DICT_PK
 PRIMARY KEY
 (ID); 

ALTER TABLE MIR_MI_F0_EMBRYO_TASK_TEMPLATE
 ADD CONSTRAINT MIR_MI_F0_DICT_R01
 PRIMARY KEY
 (ID);

ALTER TABLE MIR_ANAESTHETIC_DICT
 ADD PRIMARY KEY
 (ID);

ALTER TABLE APP_PRINTER
 ADD CONSTRAINT TABLE1_PK
 PRIMARY KEY
 (ID); 
 
ALTER TABLE MTS_BIOPSY_PLATE_WELL
 ADD CONSTRAINT MTS_BIOPSY_PLATE_WELL_PK
 PRIMARY KEY
 (ID);
 
ALTER TABLE MTS_MOUSE
 ADD CONSTRAINT MTS_MOUSE_PK
 PRIMARY KEY
 (ID);  

ALTER TABLE MTS_MOUSE_PROCEDURE
 ADD CONSTRAINT MTS_MOUSE_PROTOCOL_PK
 PRIMARY KEY
 (ID);

ALTER TABLE MTS_EMBRYO_TRANSFER
 ADD CONSTRAINT MTS_EMBRYO_TRANSFER_PK
 PRIMARY KEY
 (ID);

ALTER TABLE PER_PERSON_COLUMN_PREFS
 ADD CONSTRAINT PER_PERSON_COLUMN_PREFS_PK
 PRIMARY KEY
 (ID); 
 
ALTER TABLE MTS_MOUSE_PROCEDURE
 ADD CONSTRAINT MTS_MOUSE_PROCEDURE_R01 
 FOREIGN KEY (MOUSE_ID) 
 REFERENCES MTS_MOUSE (ID);

ALTER TABLE MTS_CAGE_RACK_HISTORY
 ADD CONSTRAINT MTS_CAGE_RACK_HISTORY_R02 
 FOREIGN KEY (CAGE_ID) 
 REFERENCES MTS_CAGE (ID);

ALTER TABLE MTS_RESERVATION
 ADD CONSTRAINT MTS_RESERVATION_R01 
 FOREIGN KEY (CREATOR_ID) 
 REFERENCES PER_PERSON (PERSON_ID);

ALTER TABLE PER_PERSON_COLUMN_PREFS
 ADD CONSTRAINT PER_PERSON_COLUMN_PREFS_R02 
 FOREIGN KEY (COLUMN_PREF_ID) 
 REFERENCES APP_COLUMN_PREFS (ID);

ALTER TABLE MIR_SCHEDULED_MICRO_INJECTION
 ADD FOREIGN KEY (INTERNAL_STATUS_DICT_ID) 
 REFERENCES MIR_INTERNAL_STATUS_DICT (ID);

ALTER TABLE MIR_MI_129_TASK_TEMPLATE
 ADD CONSTRAINT MIR_MI_TASK_DICT_R02
 UNIQUE (NAME);

ALTER TABLE LIC_PROCEDURE_2_PROTOCOL
 ADD CONSTRAINT LIC_PROCEDURE_2_PROTOCOL_R01 
 FOREIGN KEY (PROTOCOL_ID) 
 REFERENCES LIC_PROTOCOL_19B (ID);

ALTER TABLE MIR_MI_B6_TASK_TEMPLATE
 ADD CONSTRAINT MIR_MI_TASK_B6_TEMPLATE_U01
 UNIQUE (NAME);

ALTER TABLE MIR_MI_B6_TASK_TEMPLATE
 ADD CONSTRAINT MIR_MI_TASK_B6_TEMPLATE_R01
 UNIQUE (SEQUENCE_NUMBER);

ALTER TABLE CRQ_CRYO_REQUEST
 ADD CONSTRAINT CRQ_CRYO_REQUEST_R01A 
 FOREIGN KEY (PERSON_ID) 
 REFERENCES PER_PERSON (PERSON_ID);

ALTER TABLE MTS_RESERVED_MOUSE
 ADD CONSTRAINT MTS_RESERVED_MOUSE_R01 
 FOREIGN KEY (RESERVATION_ID) 
 REFERENCES MTS_RESERVATION (ID);

ALTER TABLE MTS_CAGE_RACK_HISTORY
 ADD CONSTRAINT MTS_CAGE_RACK_HISTORY_R01 
 FOREIGN KEY (RACK_ID) 
 REFERENCES MTS_RACK (ID);

ALTER TABLE MTS_MOUSE
 ADD CONSTRAINT MTS_MOUSE_R02 
 FOREIGN KEY (COAT_COLOUR_DICT_ID) 
 REFERENCES MTS_COAT_COLOUR_DICT (ID);

ALTER TABLE MTS_BREEDING
 ADD CONSTRAINT MTS_BREEDING_R03 
 FOREIGN KEY (OFFSPRING_COLONY_ID) 
 REFERENCES MTS_COLONY_INFO (ID);


ALTER TABLE MTS_BIOPSY_PLATE_WELL
 ADD CONSTRAINT MTS_BIOPSY_PLATE_WELL_R01 
 FOREIGN KEY (BIOPSY_PLATE_ID) 
 REFERENCES MTS_BIOPSY_PLATE (ID);

ALTER TABLE MTS_MOUSE
 ADD CONSTRAINT MTS_MOUSE_R14 
 FOREIGN KEY (COHORT_ID) 
 REFERENCES MTS_COHORT (ID);

ALTER TABLE MTS_TISSUE_SAMPLE
 ADD CONSTRAINT MTS_TISSUE_SAMPLE_R01 
 FOREIGN KEY (MOUSE_ID) 
 REFERENCES MTS_MOUSE (ID);

ALTER TABLE MTS_EMBRYO_TRANSFER
 ADD CONSTRAINT MTS_EMBRYO_TRANSFER_R01 
 FOREIGN KEY (FEMALE_MOUSE_ID) 
 REFERENCES MTS_MOUSE (ID);

ALTER TABLE MTS_RESERVED_MOUSE
 ADD CONSTRAINT MTS_RESERVED_MOUSE_R03 
 FOREIGN KEY (MOUSE_ID) 
 REFERENCES MTS_MOUSE (ID);

ALTER TABLE MTS_BIOPSY_PLATE_WELL
 ADD CONSTRAINT MTS_BIOPSY_PLATE_WELL_R02 
 FOREIGN KEY (MOUSE_ID) 
 REFERENCES MTS_MOUSE (ID);

ALTER TABLE MTS_BIOPSY_PLATE_WELL
 ADD CONSTRAINT MTS_BIOPSY_PLATE_WELL_R03 
 FOREIGN KEY (CREATOR_ID) 
 REFERENCES PER_PERSON (PERSON_ID);


ALTER TABLE MTS_MOUSE_PROCEDURE
 ADD CONSTRAINT MTS_MOUSE_PROCEDURE_R02 
 FOREIGN KEY (PROTOCOL_ID) 
 REFERENCES LIC_PROTOCOL_19B (ID);


ALTER TABLE MTS_MOUSE
 ADD CONSTRAINT MTS_MOUSE_R05 
 FOREIGN KEY (CAUSE_OF_DEATH_DICT_ID) 
 REFERENCES MTS_CAUSE_OF_DEATH_DICT (ID);



ALTER TABLE MIR_MI_F0_EMBRYO_TASK_TEMPLATE
 ADD CONSTRAINT MIR_MI_F0_DICT_R04
 UNIQUE (SEQUENCE_NUMBER);



ALTER TABLE MTS_MOUSE
 ADD CONSTRAINT MTS_MOUSE_R16 
 FOREIGN KEY (FATHER_ID) 
 REFERENCES MTS_MOUSE (ID);

ALTER TABLE MTS_MOUSE
 ADD CONSTRAINT MTS_MOUSE_R10 
 FOREIGN KEY (GENDER_DICT_ID) 
 REFERENCES MTS_GENDER_DICT (ID);

ALTER TABLE MTS_MOUSE
 ADD CONSTRAINT MTS_MOUSE_R01 
 FOREIGN KEY (LITTER_ID) 
 REFERENCES MTS_LITTER (ID);



ALTER TABLE MIR_ANALGESIA_DICT
 ADD CONSTRAINT MIR_ANALGESIC_DICT_R01
 UNIQUE (NAME);

ALTER TABLE MTS_MOUSE
 ADD CONSTRAINT MTS_MOUSE_R11 
 FOREIGN KEY (MOUSE_STRAIN_DICT_ID) 
 REFERENCES TYP_STRAIN (ID);



ALTER TABLE MTS_MOUSE_HEALTH
 ADD CONSTRAINT MTS_MOUSE_HEALTH_R01 
 FOREIGN KEY (MOUSE_ID) 
 REFERENCES MTS_MOUSE (ID);

 


ALTER TABLE MTS_CHIMERIC_MOUSE_DATA
 ADD CONSTRAINT MTS_CHIMERIC_MOUSE_DATA_R01 
 FOREIGN KEY (MOUSE_ID) 
 REFERENCES MTS_MOUSE (ID);

ALTER TABLE MTS_EMBRYO_TRANSFER
 ADD CONSTRAINT MTS_EMBRYO_TRANSFER_R02 
 FOREIGN KEY (ES_CLONE_ID) 
 REFERENCES MTS_ES_CLONE (ID);

ALTER TABLE MIR_SCHEDULED_MICRO_INJECTION
 ADD FOREIGN KEY (SUPPLEMENTAL_RECIPIENT_REQ_ID) 
 REFERENCES REQ_ANIMAL_REQUEST (ID);

ALTER TABLE MIR_MI_129_TASK_TEMPLATE
 ADD CONSTRAINT MIR_MI_TASK_DICT_R04
 UNIQUE (SEQUENCE_NUMBER);

ALTER TABLE MTS_BIOPSY_PLATE
 ADD CONSTRAINT MTS_BIOPSY_PLATE_R01 
 FOREIGN KEY (CREATOR_ID) 
 REFERENCES PER_PERSON (PERSON_ID);

ALTER TABLE MTS_BREEDING
 ADD CONSTRAINT MTS_BREEDING_R01 
 FOREIGN KEY (MALE_ID) 
 REFERENCES MTS_MOUSE (ID);


ALTER TABLE MIR_INTERNAL_STATUS_DICT
 ADD CONSTRAINT MIR_INTERNAL_STATUS_DICT_U01
 UNIQUE (NAME);



ALTER TABLE MTS_MOUSE
 ADD CONSTRAINT MTS_MOUSE_R09 
 FOREIGN KEY (CURRENT_PROJECT_LICENCE_ID) 
 REFERENCES LIC_PROJECT_LICENCE (PROJECT_LICENCE_ID);



ALTER TABLE MIR_MICRO_INJECTION_REQUEST
 ADD FOREIGN KEY (EXTERNAL_STATUS_DICT_ID) 
 REFERENCES MIR_EXTERNAL_STATUS_DICT (ID);

ALTER TABLE MTS_MOUSE_PROCEDURE
 ADD CONSTRAINT MTS_MOUSE_PROCEDURE_R03 
 FOREIGN KEY (PERSONAL_LICENCE_ID) 
 REFERENCES LIC_PERSONAL_LICENCE (PERSONAL_LICENCE_ID);



ALTER TABLE MTS_MOUSE_CAGE_HISTORY
 ADD CONSTRAINT MTS_MOUSE_CAGE_HISTORY_R02 
 FOREIGN KEY (MOUSE_ID) 
 REFERENCES MTS_MOUSE (ID);

ALTER TABLE MIR_SCHEDULED_MICRO_INJECTION
 ADD CONSTRAINT MIR_SCHEDULED_MICRO_INJECT_R01 
 FOREIGN KEY (CREATOR_ID) 
 REFERENCES PER_PERSON (PERSON_ID);

ALTER TABLE MIR_MI_F0_EMBRYO_TASK_TEMPLATE
 ADD CONSTRAINT MIR_MI_F0_DICT_R02
 UNIQUE (NAME);

ALTER TABLE MTS_MOUSE_CAGE_HISTORY
 ADD CONSTRAINT MTS_MOUSE_CAGE_HISTORY_R01 
 FOREIGN KEY (CAGE_ID) 
 REFERENCES MTS_CAGE (ID);

ALTER TABLE MTS_CHIMERIC_MOUSE_DATA
 ADD CONSTRAINT MTS_CHIMERIC_MOUSE_DATA_U01
 UNIQUE (MOUSE_ID);

ALTER TABLE PER_PERSON_COLUMN_PREFS
 ADD CONSTRAINT PER_PERSON_COLUMN_PREFS_R01 
 FOREIGN KEY (PERSON_ID) 
 REFERENCES PER_PERSON (PERSON_ID);

ALTER TABLE MTS_MOUSE_HEALTH
 ADD CONSTRAINT MTS_MOUSE_HEALTH_R02 
 FOREIGN KEY (BODY_SUBSYSTEM_DICT_ID) 
 REFERENCES MTS_BODY_SUBSYSTEM_DICT (ID);


ALTER TABLE MTS_ENVIRONMENT_REPORT
 ADD CONSTRAINT MTS_ENVIRONMENT_REPORT_R02 
 FOREIGN KEY (CREATOR_ID) 
 REFERENCES PER_PERSON (PERSON_ID);

ALTER TABLE MTS_ENVIRONMENT_REPORT
 ADD CONSTRAINT MTS_ENVIRONMENT_REPORT_R01 
 FOREIGN KEY (TABLE_METADATA_ID) 
 REFERENCES APP_TABLE_METADATA (ID);

ALTER TABLE MTS_MOUSE_HEALTH
 ADD CONSTRAINT MTS_MOUSE_HEALTH_R03 
 FOREIGN KEY (BODY_SYSTEM_DICT_ID) 
 REFERENCES MTS_BODY_SYSTEM_DICT (ID);

ALTER TABLE MTS_MOUSE_HEALTH
 ADD CONSTRAINT MTS_MOUSE_HEALTH_R04 
 FOREIGN KEY (HEALTH_CONCERN_DICT_ID) 
 REFERENCES MTS_HEALTH_CONCERN_DICT (ID);





ALTER TABLE MTS_MOUSE
 ADD CONSTRAINT MTS_MOUSE_R08 
 FOREIGN KEY (CURRENT_OWNER_ID) 
 REFERENCES PER_PERSON (PERSON_ID);

ALTER TABLE MTS_RESERVED_MOUSE
 ADD CONSTRAINT MTS_RESERVED_MOUSE_R02 
 FOREIGN KEY (CREATOR_ID) 
 REFERENCES PER_PERSON (PERSON_ID);

ALTER TABLE MTS_MOUSE_ALLELE
 ADD CONSTRAINT MTS_MOUSE_ALLELE_R03 
 FOREIGN KEY (GENOTYPE_DICT_ID) 
 REFERENCES MTS_GENOTYPE_DICT (ID);

ALTER TABLE MIR_CELL_LINE
 ADD CONSTRAINT MIR_CELL_LINE_R07 
 FOREIGN KEY (CELL_LINE_PROVIDER_ID) 
 REFERENCES PER_PERSON (PERSON_ID);

ALTER TABLE MIR_SCHEDULED_MI_TASK
 ADD FOREIGN KEY (CREATOR_ID) 
 REFERENCES PER_PERSON (PERSON_ID);



ALTER TABLE MTS_MOUSE
 ADD CONSTRAINT MTS_MOUSE_R03 
 FOREIGN KEY (EYE_COLOUR_DICT_ID) 
 REFERENCES MTS_EYE_COLOUR_DICT (ID);



ALTER TABLE MTS_MOUSE_ALLELE
 ADD CONSTRAINT MTS_MOUSE_ALLELE_R02 
 FOREIGN KEY (ALLELE_ID) 
 REFERENCES TYP_MODIFIED_ALLELE (ID);

ALTER TABLE MIR_SCHEDULED_MICRO_INJECTION
 ADD FOREIGN KEY (CELL_LINE_PROVIDER_ID) 
 REFERENCES PER_PERSON (PERSON_ID);

ALTER TABLE ARQ_DESIGN_2_DESIGN_REQUEST
 ADD CONSTRAINT ARQ_DES_2_DES_REQUEST_R01 
 FOREIGN KEY (DESIGN_ID) 
 REFERENCES EUCOMM_VECTOR.DESIGN (DESIGN_ID);

ALTER TABLE MTS_BREEDING
 ADD CONSTRAINT MTS_BREEDING_R02 
 FOREIGN KEY (FEMALE_ID) 
 REFERENCES MTS_MOUSE (ID);

ALTER TABLE MTS_MOUSE_ALLELE
 ADD CONSTRAINT MTS_MOUSE_ALLELE_R04 
 FOREIGN KEY (CREATOR_ID) 
 REFERENCES PER_PERSON (PERSON_ID);

ALTER TABLE MTS_AIR_HANDLING_DATA
 ADD CONSTRAINT MTS_AIR_HANDLING_DATA_MTS_FK1 
 FOREIGN KEY (AIR_HANDLING_UNIT_ID) 
 REFERENCES MTS_AIR_HANDLING_UNIT (ID);

ALTER TABLE MTS_TISSUE_SAMPLE
 ADD CONSTRAINT MTS_TISSUE_SAMPLE_PK
 PRIMARY KEY
 (ID);

ALTER TABLE MTS_LITTER
 ADD CONSTRAINT MTS_LITTER_R01 
 FOREIGN KEY (BREEDING_ID) 
 REFERENCES MTS_BREEDING (ID);

ALTER TABLE MTS_MOUSE
 ADD CONSTRAINT MTS_MOUSE_R17 
 FOREIGN KEY (MOTHER_ID) 
 REFERENCES MTS_MOUSE (ID);

ALTER TABLE MIR_SCHEDULED_MICRO_INJECTION
 ADD FOREIGN KEY (DONOR_ANIMAL_REQUEST_ID) 
 REFERENCES REQ_ANIMAL_REQUEST (ID);


ALTER TABLE MIR_SCHEDULED_MICRO_INJECTION
 ADD FOREIGN KEY (RECIPIENT_ANIMAL_REQUEST_ID) 
 REFERENCES REQ_ANIMAL_REQUEST (ID);

ALTER TABLE MIR_EMBRYO_TRANSFER_PROCEDURE
 ADD CONSTRAINT MIR_EMBRYO_TRANSFER_R09 
 FOREIGN KEY (STUFFER_STRAIN_ID) 
 REFERENCES TYP_STRAIN (ID);

ALTER TABLE MIR_EMBRYO_TRANSFER_PROCEDURE
 ADD CONSTRAINT MIR_EMBRYO_TRANSFER_R05 
 FOREIGN KEY (ANAESTHETIC_DICT_ID) 
 REFERENCES MIR_ANAESTHETIC_DICT (ID);

ALTER TABLE MIR_EMBRYO_TRANSFER_PROCEDURE
 ADD CONSTRAINT MIR_EMBRYO_TRANSFER_R06 
 FOREIGN KEY (ANALGESIA_DICT_ID) 
 REFERENCES MIR_ANALGESIA_DICT (ID);

ALTER TABLE MIR_EMBRYO_TRANSFER_PROCEDURE
 ADD FOREIGN KEY (CREATOR_ID) 
 REFERENCES PER_PERSON (PERSON_ID);

ALTER TABLE MIR_EMBRYO_TRANSFER_PROCEDURE
 ADD FOREIGN KEY (SCHEDULED_MICRO_INJECTION_ID) 
 REFERENCES MIR_SCHEDULED_MICRO_INJECTION (ID);

ALTER TABLE MIR_EMBRYO_TRANSFER_PROCEDURE
 ADD FOREIGN KEY (MOUSE_ID) 
 REFERENCES MTS_MOUSE (ID);

ALTER TABLE MIR_EMBRYO_TRANSFER_PROCEDURE
 ADD CONSTRAINT MIR_EMBRYO_TRANSFER_PROCED_R07 
 FOREIGN KEY (TRANSFER_TYPE_DICT_ID) 
 REFERENCES MIR_TRANSFER_TYPE_DICT (ID);

ALTER TABLE MIR_MICRO_INJECTION
 ADD CONSTRAINT MIR_MICRO_INJECTION_U01
 UNIQUE (SCHEDULED_MICRO_INJECTION_ID);

ALTER TABLE MIR_MICRO_INJECTION
 ADD CONSTRAINT MIR_MICRO_INJECTION_PROCED_R02 
 FOREIGN KEY (EMBRYO_STAGE_DICT_ID) 
 REFERENCES MIR_EMBRYO_STAGE_DICT (ID);

ALTER TABLE MIR_MICRO_INJECTION
 ADD CONSTRAINT MIR_MICRO_INJECTION_PROCED_R03 
 FOREIGN KEY (CELL_LINE_ID) 
 REFERENCES MIR_CELL_LINE (ID);

ALTER TABLE MIR_MICRO_INJECTION
 ADD CONSTRAINT MIR_MICRO_INJECTION_PROCED_R05 
 FOREIGN KEY (CREATOR_ID) 
 REFERENCES PER_PERSON (PERSON_ID);

ALTER TABLE MIR_MICRO_INJECTION
 ADD FOREIGN KEY (SCHEDULED_MICRO_INJECTION_ID) 
 REFERENCES MIR_SCHEDULED_MICRO_INJECTION (ID);

ALTER TABLE MIR_MICRO_INJECTION
 ADD FOREIGN KEY (EMBRYO_HARVEST_ID) 
 REFERENCES MIR_EMBRYO_HARVEST (ID);

ALTER TABLE MIR_EMBRYO_HARVEST
 ADD CONSTRAINT MIR_EMBRYO_HARVEST_PETRI_D_R01 
 FOREIGN KEY (CREATOR_ID) 
 REFERENCES PER_PERSON (PERSON_ID);

ALTER TABLE MTS_AIR_HANDLING_UNIT
 ADD CONSTRAINT MTS_AIR_HANDLING_UNIT_R01 
 FOREIGN KEY (ROOM_ID) 
 REFERENCES MTS_ROOM (ID);

ALTER TABLE MTS_RACK
 ADD CONSTRAINT MTS_RACK_R02 
 FOREIGN KEY (ROOM_ID) 
 REFERENCES MTS_ROOM (ID);

ALTER TABLE MTS_RACK
 ADD CONSTRAINT MTS_RACK_R01 
 FOREIGN KEY (AIR_HANDLING_UNIT_ID) 
 REFERENCES MTS_AIR_HANDLING_UNIT (ID);

ALTER TABLE MTS_RACK_ROOM_HISTORY
 ADD CONSTRAINT MTS_RACK_ROOM_HISTORY_R02 
 FOREIGN KEY (RACK_ID) 
 REFERENCES MTS_RACK (ID);

ALTER TABLE MTS_RACK_ROOM_HISTORY
 ADD CONSTRAINT MTS_RACK_ROOM_HISTORY_R01 
 FOREIGN KEY (ROOM_ID) 
 REFERENCES MTS_ROOM (ID);

ALTER TABLE MTS_BIOPSY_PLATE
 ADD CONSTRAINT MTS_BIOPSY_PLATE_U01
 UNIQUE (BARCODE);

ALTER TABLE MTS_MOUSE
 ADD CONSTRAINT MTS_MOUSE_R04 
 FOREIGN KEY (EARMARK_DICT_ID) 
 REFERENCES MTS_EARMARK_DICT (ID);

ALTER TABLE MTS_MOUSE
 ADD CONSTRAINT MTS_MOUSE_R12 
 FOREIGN KEY (SUPPLIER_DICT_ID) 
 REFERENCES MTS_MOUSE_SUPPLIER_DICT (ID);

ALTER TABLE LIC_PROCEDURE_2_PROTOCOL
 ADD CONSTRAINT LIC_PROCEDURE_2_PROTOCOL_R02 
 FOREIGN KEY (PROCEDURE_DICT_ID) 
 REFERENCES MTS_PROCEDURE_DICT (ID);

ALTER TABLE TYP_MODIFIED_ALLELE
 ADD CONSTRAINT TYP_MODIFIED_ALLELE 
 FOREIGN KEY (ALLELE_MAKER_ID) 
 REFERENCES PER_PERSON (PERSON_ID);

ALTER TABLE MTS_MOUSE
 ADD CONSTRAINT MTS_MOUSE_R13 
 FOREIGN KEY (COLONY_INFO_ID) 
 REFERENCES MTS_COLONY_INFO (ID);

ALTER TABLE MTS_ES_CLONE
 ADD CONSTRAINT MTS_ES_CLONE_R01 
 FOREIGN KEY (MODIFIED_ALLELE_ID) 
 REFERENCES TYP_MODIFIED_ALLELE (ID);

ALTER TABLE MIR_ANAESTHETIC_DICT
 ADD CONSTRAINT MIR_ANAESTHETIC_DICT_R01
 UNIQUE (NAME);

ALTER TABLE MIR_SCHEDULED_MICRO_INJECTION
 ADD CONSTRAINT MIR_SCHEDULED_MICRO_INJECT_R06 
 FOREIGN KEY (MICRO_INJECTION_REQUEST_ID) 
 REFERENCES MIR_MICRO_INJECTION_REQUEST (ID);

ALTER TABLE MTS_MOUSE
 ADD CONSTRAINT MTS_MOUSE_R07 
 FOREIGN KEY (CAGE_ID) 
 REFERENCES MTS_CAGE (ID);

ALTER TABLE MTS_MOUSE_PROCEDURE
 ADD CONSTRAINT MTS_MOUSE_PROCEDURE_R04 
 FOREIGN KEY (TABLE_METADATA_ID) 
 REFERENCES APP_TABLE_METADATA (ID);

ALTER TABLE MTS_MOUSE_ALLELE
 ADD CONSTRAINT MTS_MOUSE_ALLELE_R01 
 FOREIGN KEY (MOUSE_ID) 
 REFERENCES MTS_MOUSE (ID);

ALTER TABLE MTS_MOUSE_PROCEDURE
 ADD CONSTRAINT MTS_MOUSE_PROCEDURE_R05 
 FOREIGN KEY (CREATOR_ID) 
 REFERENCES PER_PERSON (PERSON_ID);

ALTER TABLE MIR_SCHEDULED_MI_TASK
 ADD CONSTRAINT MIR_SCHEDULED_MI_TASK_R02 
 FOREIGN KEY (SCHEDULED_MICRO_INJECTION_ID) 
 REFERENCES MIR_SCHEDULED_MICRO_INJECTION (ID);

ALTER TABLE MTS_BODY_SUBSYSTEM_DICT
 ADD CONSTRAINT MTS_BODY_SUBSYSTEM_DICT_R01 
 FOREIGN KEY (BODY_SYSTEM_DICT_ID) 
 REFERENCES MTS_BODY_SYSTEM_DICT (ID);

ALTER TABLE MTS_CHIMERIC_MOUSE_DATA
 ADD CONSTRAINT MTS_CHIMERIC_MOUSE_DATA_R02 
 FOREIGN KEY (CREATOR_ID) 
 REFERENCES PER_PERSON (PERSON_ID);

ALTER TABLE MTS_CAGE
 ADD CONSTRAINT MTS_CAGE_R01 
 FOREIGN KEY (RACK_ID) 
 REFERENCES MTS_RACK (ID);

ALTER TABLE APP_PRINTER
 ADD CONSTRAINT APP_PRINTER_MTS_ROOM_FK1 
 FOREIGN KEY (ROOM_ID) 
 REFERENCES MTS_ROOM (ID);

INSERT INTO MTS_EYE_COLOUR_DICT ( ID, NAME, ORDER_BY, DESCRIPTION,
ACTIVE ) VALUES ( 
1, 'Red', 2, 'Red', 1); 
INSERT INTO MTS_EYE_COLOUR_DICT ( ID, NAME, ORDER_BY, DESCRIPTION,
ACTIVE ) VALUES ( 
2, 'Black', 1, 'Black', 1); 
COMMIT;

INSERT INTO MTS_EARMARK_DICT ( ID, NAME, ORDER_BY, DESCRIPTION,
ACTIVE ) VALUES ( 
1, 'NM', 1, 'NM', 1); 
INSERT INTO MTS_EARMARK_DICT ( ID, NAME, ORDER_BY, DESCRIPTION,
ACTIVE ) VALUES ( 
2, '1L', 2, '1L', 1); 
INSERT INTO MTS_EARMARK_DICT ( ID, NAME, ORDER_BY, DESCRIPTION,
ACTIVE ) VALUES ( 
3, '1R', 3, '1R', 1); 
INSERT INTO MTS_EARMARK_DICT ( ID, NAME, ORDER_BY, DESCRIPTION,
ACTIVE ) VALUES ( 
4, '1L 1R', 4, '1L 1R', 1); 
INSERT INTO MTS_EARMARK_DICT ( ID, NAME, ORDER_BY, DESCRIPTION,
ACTIVE ) VALUES ( 
5, '2L', 5, '2L', 1); 
INSERT INTO MTS_EARMARK_DICT ( ID, NAME, ORDER_BY, DESCRIPTION,
ACTIVE ) VALUES ( 
6, '2R', 6, '2R', 1); 
INSERT INTO MTS_EARMARK_DICT ( ID, NAME, ORDER_BY, DESCRIPTION,
ACTIVE ) VALUES ( 
7, '1L 2R', 7, '1L 2R', 1); 
INSERT INTO MTS_EARMARK_DICT ( ID, NAME, ORDER_BY, DESCRIPTION,
ACTIVE ) VALUES ( 
8, '2L 1R', 8, '2L 1R', 1); 
INSERT INTO MTS_EARMARK_DICT ( ID, NAME, ORDER_BY, DESCRIPTION,
ACTIVE ) VALUES ( 
9, '2L 2R', 9, '2L 2R', 1); 
COMMIT;

INSERT INTO MTS_CAUSE_OF_DEATH_DICT ( ID, NAME, ORDER_BY, DESCRIPTION,
ACTIVE ) VALUES ( 
9, 'Found Dead', NULL, 'FDC', 1); 
INSERT INTO MTS_CAUSE_OF_DEATH_DICT ( ID, NAME, ORDER_BY, DESCRIPTION,
ACTIVE ) VALUES ( 
1, 'Unwanted Genotype', NULL, 'GENOTYPE', 1); 
INSERT INTO MTS_CAUSE_OF_DEATH_DICT ( ID, NAME, ORDER_BY, DESCRIPTION,
ACTIVE ) VALUES ( 
2, 'Schedule 1 Health Concern', NULL, 'HC', 1); 
INSERT INTO MTS_CAUSE_OF_DEATH_DICT ( ID, NAME, ORDER_BY, DESCRIPTION,
ACTIVE ) VALUES ( 
3, 'Age Related', NULL, 'AGE', 1); 
INSERT INTO MTS_CAUSE_OF_DEATH_DICT ( ID, NAME, ORDER_BY, DESCRIPTION,
ACTIVE ) VALUES ( 
4, 'Removed from RSF', NULL, 'REMOVED', 1); 
INSERT INTO MTS_CAUSE_OF_DEATH_DICT ( ID, NAME, ORDER_BY, DESCRIPTION,
ACTIVE ) VALUES ( 
5, 'Missing (presumed dead)', NULL, 'MISSING', 1); 
INSERT INTO MTS_CAUSE_OF_DEATH_DICT ( ID, NAME, ORDER_BY, DESCRIPTION,
ACTIVE ) VALUES ( 
6, 'End of study', NULL, 'EOS', 1); 
INSERT INTO MTS_CAUSE_OF_DEATH_DICT ( ID, NAME, ORDER_BY, DESCRIPTION,
ACTIVE ) VALUES ( 
7, 'Excess stock', NULL, 'XS', 1); 
INSERT INTO MTS_CAUSE_OF_DEATH_DICT ( ID, NAME, ORDER_BY, DESCRIPTION,
ACTIVE ) VALUES ( 
8, 'Taken for study', NULL, 'STUDY', 1); 
INSERT INTO MTS_CAUSE_OF_DEATH_DICT ( ID, NAME, ORDER_BY, DESCRIPTION,
ACTIVE ) VALUES ( 
10, 'Embyro Harvest', NULL, 'HARVEST', 1); 
COMMIT;

INSERT INTO MTS_PROCEDURE_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
1, 'Blood Sampling', NULL, 1, 3); 
INSERT INTO MTS_PROCEDURE_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
2, 'Opthalmic Measurements', NULL, 1, 11); 
INSERT INTO MTS_PROCEDURE_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
3, 'Open Field', NULL, 1, 10); 
INSERT INTO MTS_PROCEDURE_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
4, 'Modified SHIRPA', NULL, 1, 9); 
INSERT INTO MTS_PROCEDURE_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
5, 'Grip Strength', NULL, 1, 8); 
INSERT INTO MTS_PROCEDURE_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
6, 'Y-maze', NULL, 1, 17); 
INSERT INTO MTS_PROCEDURE_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
7, 'Elevated Platform', NULL, 1, 7); 
INSERT INTO MTS_PROCEDURE_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
8, 'Acoustic Startle', NULL, 1, 2); 
INSERT INTO MTS_PROCEDURE_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
9, 'Tail Flick', NULL, 1, 14); 
INSERT INTO MTS_PROCEDURE_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
10, 'Tail Suspension', NULL, 1, 15); 
INSERT INTO MTS_PROCEDURE_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
11, 'Dexa-scan', NULL, 1, 4); 
INSERT INTO MTS_PROCEDURE_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
12, 'X-ray', NULL, 1, 16); 
INSERT INTO MTS_PROCEDURE_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
13, 'Dysmorphology Assessment', NULL, 1, 5); 
INSERT INTO MTS_PROCEDURE_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
14, 'Simplified IPGTT', NULL, 1, 13); 
INSERT INTO MTS_PROCEDURE_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
15, 'Oxymax', NULL, 1, 12); 
INSERT INTO MTS_PROCEDURE_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
16, 'Echo Cardiography', NULL, 1, 6); 
INSERT INTO MTS_PROCEDURE_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
17, 'ANP', NULL, 1, 1); 
COMMIT;

INSERT INTO MTS_MOUSE_SUPPLIER_DICT ( ID, NAME, ORDER_BY, DESCRIPTION,
ACTIVE ) VALUES ( 
1, 'Charles Rivers', NULL, 'Charles Rivers', 1); 
INSERT INTO MTS_MOUSE_SUPPLIER_DICT ( ID, NAME, ORDER_BY, DESCRIPTION,
ACTIVE ) VALUES ( 
2, 'WTSI', NULL, 'WTSI', 1); 
COMMIT;

INSERT INTO MTS_GENDER_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE ) VALUES ( 
1, 'Female', 1, 'Female', 1); 
INSERT INTO MTS_GENDER_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE ) VALUES ( 
2, 'Male', 2, 'Male', 1); 
INSERT INTO MTS_GENDER_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE ) VALUES ( 
3, 'Undefined', 3, 'Undefined', 1); 
COMMIT;




INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
483, 'GB855', 3, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
485, 'GB860', 3, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
487, 'GB877', 3, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
489, 'GB828', 4, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
491, 'GB834', 4, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
493, 'GB845', 4, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
495, 'GB871', 4, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
497, 'GB885', 4, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
499, 'GB861', 5, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
501, 'GB866', 5, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
503, 'GB876', 5, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
505, 'GB881', 5, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
507, 'GB868', 6, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
509, 'GB869', 6, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
511, 'GB870', 6, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
513, 'GB874', 6, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
515, 'GB858', 7, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
517, 'GB864', 7, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
519, 'GB880', 7, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
521, 'GB883', 7, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
523, 'GB853', 9, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
525, 'GB862', 9, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
527, 'GB812', 10, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
529, 'GB842', 10, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
531, 'GB849', 10, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
533, 'GB865', 10, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
535, 'GB822', 11, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
537, 'GB841', 11, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
539, 'GB846', 11, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
541, 'GB875', 11, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
543, 'GB831', 16, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
545, 'GB847', 16, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
547, 'GB848', 16, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
549, 'GB813', 19, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
551, 'GB879', 19, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
553, 'GB882', 19, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
555, 'GB821', 22, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
557, 'GB835', 22, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
559, 'GB844', 22, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
561, 'GB857', 22, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
563, 'GB815', 23, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
565, 'GB825', 23, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
567, 'GB840', 23, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
569, 'GB851', 23, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
571, 'GB820', 24, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
573, 'GB826', 24, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
575, 'GB833', 24, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
577, 'GB884', 24, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
579, 'GB823', 25, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
581, 'GB829', 25, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
583, 'GB878', 25, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
585, 'GB887', 25, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
587, 'GB837', 28, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
589, 'GB843', 28, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
591, 'GB859', 28, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
593, 'GB817', 29, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
595, 'GB838', 30, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
597, 'GB886', 30, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
599, 'GB836', 33, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
601, 'GB873', 33, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
603, 'GB885', 33, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
605, 'GB888', 33, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
607, 'GB889', 33, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
609, 'GB839', 34, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
611, 'GB856', 34, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
613, 'GB863', 34, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
615, 'GB872', 34, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
617, 'GB814', 35, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
619, 'GB816', 35, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
621, 'GB818', 35, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
INSERT INTO MTS_AIR_HANDLING_UNIT ( ID, NAME, ROOM_ID, CHECK_NUMBER, RADIO_ADDRESS, EDITED_BY,
EDIT_DATE, CREATED_DATE ) VALUES ( 
623, 'GB819', 35, NULL, NULL, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')); 
COMMIT;

INSERT INTO MTS_BODY_SYSTEM_DICT ( ID, NAME, ORDER_BY, DESCRIPTION,
ACTIVE ) VALUES ( 
4, 'Limbs', NULL, 'Limbs', 1); 
INSERT INTO MTS_BODY_SYSTEM_DICT ( ID, NAME, ORDER_BY, DESCRIPTION,
ACTIVE ) VALUES ( 
3, 'Tail', NULL, 'Tail', 1); 
INSERT INTO MTS_BODY_SYSTEM_DICT ( ID, NAME, ORDER_BY, DESCRIPTION,
ACTIVE ) VALUES ( 
2, 'Body', NULL, 'Body', 1); 
INSERT INTO MTS_BODY_SYSTEM_DICT ( ID, NAME, ORDER_BY, DESCRIPTION,
ACTIVE ) VALUES ( 
1, 'Head', NULL, 'Head', 1); 
COMMIT;


INSERT INTO MTS_BODY_SUBSYSTEM_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SYSTEM_DICT_ID ) VALUES ( 
1, 'Mouth', NULL, 'Mouth', 1, 1); 
INSERT INTO MTS_BODY_SUBSYSTEM_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SYSTEM_DICT_ID ) VALUES ( 
2, 'Nose', NULL, 'Nose', 1, 1); 
INSERT INTO MTS_BODY_SUBSYSTEM_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SYSTEM_DICT_ID ) VALUES ( 
3, 'Ears', NULL, 'Ears', 1, 1); 
INSERT INTO MTS_BODY_SUBSYSTEM_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SYSTEM_DICT_ID ) VALUES ( 
4, 'Eyes', NULL, 'Eyes', 1, 1); 
INSERT INTO MTS_BODY_SUBSYSTEM_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SYSTEM_DICT_ID ) VALUES ( 
5, 'Whole Body', NULL, 'Whole Body', 1, 2); 
INSERT INTO MTS_BODY_SUBSYSTEM_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SYSTEM_DICT_ID ) VALUES ( 
6, 'Right FLank', NULL, 'Right Flank', 1, 2); 
INSERT INTO MTS_BODY_SUBSYSTEM_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SYSTEM_DICT_ID ) VALUES ( 
7, 'Left Flank', NULL, 'Left Flank', 1, 2); 
INSERT INTO MTS_BODY_SUBSYSTEM_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SYSTEM_DICT_ID ) VALUES ( 
8, 'Abdomen', NULL, 'Abdomen', 1, 2); 
INSERT INTO MTS_BODY_SUBSYSTEM_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SYSTEM_DICT_ID ) VALUES ( 
9, 'Back', NULL, 'Back', 1, 2); 
INSERT INTO MTS_BODY_SUBSYSTEM_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SYSTEM_DICT_ID ) VALUES ( 
10, 'Rectal/Gential', NULL, 'Rectal./Genital', 1, 2); 
INSERT INTO MTS_BODY_SUBSYSTEM_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SYSTEM_DICT_ID ) VALUES ( 
11, 'Root', NULL, 'Root', 1, 3); 
INSERT INTO MTS_BODY_SUBSYSTEM_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SYSTEM_DICT_ID ) VALUES ( 
12, 'Tip', NULL, 'Tip', 1, 3); 
INSERT INTO MTS_BODY_SUBSYSTEM_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SYSTEM_DICT_ID ) VALUES ( 
13, 'Back Leg Right', NULL, 'Back Leg Right', 1, 4); 
INSERT INTO MTS_BODY_SUBSYSTEM_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SYSTEM_DICT_ID ) VALUES ( 
14, 'Back Leg Left', NULL, 'Back Leg Left', 1, 4); 
INSERT INTO MTS_BODY_SUBSYSTEM_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SYSTEM_DICT_ID ) VALUES ( 
15, 'Front Leg Right', NULL, 'Front Leg Right', 1, 4); 
INSERT INTO MTS_BODY_SUBSYSTEM_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SYSTEM_DICT_ID ) VALUES ( 
16, 'Front Leg Left', NULL, 'Front Leg Left', 1, 4); 
COMMIT;


INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
1, 'Malocclusion', NULL, 'Malocclusion', 1, 1); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
2, 'Tumour', NULL, 'Tumour', 1, 1); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
3, 'Tumour', NULL, 'Tumour', 1, 2); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
4, 'Fight Wounds', NULL, 'Fight Wounds', 1, 2); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
5, 'Tumour', NULL, 'Tumour', 1, 3); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
6, 'Fight Wounds', NULL, 'Fight Wounds', 1, 3); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
7, 'Conjunctivitis', NULL, 'Conjunctivitis', 1, 4); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
8, 'Periocular Irritation', NULL, 'Periocular Irritation', 1, 4); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
9, 'Tumour', NULL, 'Tumour', 1, 4); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
10, 'Proptosis', NULL, 'Proptosis', 1, 4); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
11, 'Fight Wounds', NULL, 'Fight Wounds', 1, 4); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
12, 'Paralysis', NULL, 'Paralysis', 1, 5); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
13, 'Focal Alopecia (Hair Loss)', NULL, 'Focal Alopecia (Hair Loss)', 1, 5); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
14, 'Anemia', NULL, 'Anemia', 1, 5); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
15, 'Dehydration', NULL, 'Dehydration', 1, 5); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
16, 'Hypothermia', NULL, 'Hypothermia', 1, 5); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
17, 'Icterus (Yellowing)', NULL, 'Icterus (Yellowing)', 1, 5); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
18, 'Abnormal Breathing', NULL, 'Abnormal Breathing', 1, 5); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
19, 'Abnormal Locomotion', NULL, 'Abnormal Locomotion', 1, 5); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
20, 'Hyperactivity', NULL, 'Hyperactivity', 1, 5); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
21, 'Lethargy', NULL, 'Lethargy', 1, 5); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
22, 'Paresis (Weak, but able to move legs)', NULL, 'Paresis (Weak, but able to move legs)'
, 1, 5); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
23, 'Ruffled Fur', NULL, 'Ruffled Fur', 1, 5); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
24, 'Tremors', NULL, 'Tremors', 1, 5); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
25, 'Ulcerative Dermatitis', NULL, 'Ulcerative Dermatitis', 1, 5); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
26, 'Emaciation (Runty)', NULL, 'Emaciation (Runty)', 1, 5); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
27, 'Fight Wounds', NULL, 'Fight Wounds', 1, 6); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
28, 'Ulcerative Dermatitis', NULL, 'Ulcerative Dermatitis', 1, 6); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
29, 'Fight Wounds', NULL, 'Fight Wounds', 1, 7); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
30, 'Ulcerative Dermatitis', NULL, 'Ulcerative Dermatitis', 1, 7); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
31, 'Fight Wounds', NULL, 'Fight Wounds', 1, 8); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
32, 'Ulcerative Dermatitis', NULL, 'Ulcerative Dermatitis', 1, 8); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
33, 'Tumour', NULL, 'Tumour', 1, 8); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
34, 'Fight Wounds', NULL, 'Fight Wounds', 1, 9); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
35, 'Ulcerative Dermatitis', NULL, 'Ulcerative Dermatitis', 1, 9); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
36, 'Tumour', NULL, 'Tumour', 1, 9); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
37, 'Fight Wounds', NULL, 'Fight Wounds', 1, 10); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
38, 'Diarrhoea', NULL, 'Diarrhoea', 1, 10); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
39, 'Rectal Prolapse', NULL, 'Rectal Prolapse', 1, 10); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
40, 'Tumour', NULL, 'Tumour', 1, 10); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
41, 'Vaginal or Uterine Prolapse', NULL, 'Vaginal or Uterine Prolapse', 1, 10); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
42, 'Preputial or Vaginal Discharge', NULL, 'Preputial or Vaginal Discharge', 1, 10); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
43, 'Fight Wounds', NULL, 'Fight Wounds', 1, 11); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
44, 'Fight Wounds', NULL, 'Fight Wounds', 1, 12); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
45, 'Fight Wounds', NULL, 'Fight Wounds', 1, 13); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
46, 'Ulcerative Dermatitis', NULL, 'Ulcerative Dermatitis', 1, 13); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
47, 'Fight Wounds', NULL, 'Fight Wounds', 1, 14); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
48, 'Ulcerative Dermatitis', NULL, 'Ulcerative Dermatitis', 1, 14); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
49, 'Fight Wounds', NULL, 'Fight Wounds', 1, 15); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
50, 'Ulcerative Dermatitis', NULL, 'Ulcerative Dermatitis', 1, 15); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
51, 'Fight Wounds', NULL, 'Fight Wounds', 1, 16); 
INSERT INTO MTS_HEALTH_CONCERN_DICT ( ID, NAME, ORDER_BY, DESCRIPTION, ACTIVE,
BODY_SUBSYSTEM_DICT_ID ) VALUES ( 
52, 'Ulcerative Dermatitis', NULL, 'Ulcerative Dermatitis', 1, 16); 
COMMIT;

INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
12, 98, '1', 'Production of genetically modified animals', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
13, 98, '1a', 'Superovulation ', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
14, 98, '1b', 'Embryo recipients ', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
15, 98, '1c', 'Vasectomy', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
16, 98, '2a', 'Breeding and maintenance of genetically altered animals ', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
17, 98, '2b', 'Breeding and maintenance of genetically altered animals ', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
18, 98, '3a', 'Basic phenotypic characterisation of genetically altered animals '
, NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
19, 98, '3b', 'Basic phenotypic characterisation of genetically altered animals '
, NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
20, 82, '1', 'Production of genetically modified animals', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
21, 82, '1a', 'Ovariectomy', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
22, 82, '1b', 'Vasectomy', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
23, 82, '1c', 'Embryo transfer', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
24, 82, '1d', 'Superovulation', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
25, 82, '2', 'Breeding, molecular genotyping and analysis of genetically modified mice'
, NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
26, 82, '2a', 'Ovary transfer', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
27, 82, '2b', 'Artificial Insemination', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
28, 82, '2c', 'Tumour induction by injection of cells', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
29, 82, '2d', 'Tumour induction by irradiation', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
30, 82, '2e', 'Tumour induction by retrovirus', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
31, 82, '2f', 'Tumour induction by transposon', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
32, 82, '2g', 'Analysis of developmental defects', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
33, 84, '1', 'Breeding and maintenance of mutant and control mice', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
34, 84, '2', 'Tissue collection from young mice', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
35, 84, '3', 'Analysis of hearing and balance', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
36, 84, '4', 'Noise exposure', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
37, 84, '5', 'Analysis of vision and effects of light exposure', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
38, 84, '6', 'Superovulation', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
39, 84, '7', 'Embryo recipient', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
40, 84, '8', 'Vasectomy', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
41, 83, '1', 'Production of genetically modified animals', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
42, 83, '1a', 'Ovariectomy', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
43, 83, '1b', 'Vasectomy', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
44, 83, '1c', 'Embryo transfer', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
45, 83, '1d', 'Superovulation', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
46, 83, '2', 'Breeding and maintenance of genetically modified mice', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
47, 83, '2a', 'Ovary transfer', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
48, 83, '2b', 'Artificial insemination', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
49, 83, '2c', 'Immunisation of mice', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
50, 83, '2d', 'Inducible expression of transgene', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
51, 83, '3', 'Genetic interaction in cancer - ENU mutagenesis', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
52, 83, '4', 'Genetic interaction in cancer - irradiation', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
53, 83, '5', 'Genetic interaction in cancer - slow transforming retrovirus', NULL
,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
54, 83, '6a', 'Genetic interaction in cancer - foetal liver cell and bone marrow transplantation - donors'
, NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
55, 83, '6b', 'Genetic interaction in cancer - foetal liver cell and bone marrow transplantation - recipients'
, NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
56, 83, '7', 'Genetic interaction in cancer - tumour induction by injecting cells'
, NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
57, 100, '1', 'Production, maintenance and breeding of genetically modified and wildtype animals'
, NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
58, 100, '2', 'Induction of tumours by genetic alteration', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
59, 100, '3', 'Induction of tumours by carcinogens or ionising radiation, transposons or viruses'
, NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
60, 100, '4', 'Intranasal virus administration', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
61, 100, '5', 'Ectopic cell transplantation', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
62, 100, '6', 'Tumour induction by foetal liver cells and bone marrow transplantation - Donors.'
, NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
63, 100, '7', 'Tumour induction by foetal liver cell and bone marrow transplantation - recipients.'
, NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
64, 100, '8', 'Analysis of developmental defects', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
65, 90, '1', 'Challenge with pathogenic organisms', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
66, 90, '2', 'challenge with attenuated organisms', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
67, 90, '3', 'Immunisation and challenge with pathogenic organisms', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
68, 90, '4', 'role of maternally acquired immunity', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
69, 90, '5', 'role of cytokines on infection with pathogenic organisms', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
70, 90, '6', 'role of cytokines on infection with attenuated organisms', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
71, 90, '7', 'Tetanus toxin challenge', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
72, 90, '8', 'Epidermal immunisation of particulate proteins via a high pressure device'
, NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
73, 90, '9', 'Immunisation', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
74, 90, '10', 'Adoptive transfer of immunity induced by vaccination', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
75, 90, '11', 'Role of host immune cells on immunity and infection', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
76, 90, '12', 'Breeding and maintenance of genetically modified mice', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
77, 90, '13', 'Isolation of perotoneal macrophages', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
78, 88, '1', 'Production of genetically modified animals ', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
79, 88, '1a ', 'Vasectomy ', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
80, 88, '1b ', 'Embryo transfer ', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
81, 88, '2', 'Breeding and maintenance of genetically modified animals ', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
82, 88, '3', 'Analysis of developmental defects ', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
83, 87, '1', 'Superovulation', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
84, 87, '2', 'Embryo recipients', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
85, 87, '3', 'Vasectomy', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
86, 87, '4', 'Production of founder stock', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
87, 87, '5', 'Breeding and maintenance of genetically modified animals', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
INSERT INTO LIC_PROTOCOL_19B ( ID, PROJECT_LICENCE_ID, PROTOCOL_CODE, TITLE, CREATOR_ID,
CREATED_DATE, EDITED_BY, EDIT_DATE, CHECK_NUMBER ) VALUES ( 
88, 87, '6', 'Behavioural analysis', NULL,  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 'dg6',  TO_Date( '02/12/2007 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'), 0); 
COMMIT;

INSERT INTO APP_PRINTER ( PRINTER_MODEL, ID, LOADED_MEDIA, SYS_NAME, ROOM_ID,
DESCRIPTION ) VALUES ( 
'DYMO LabelWriter 400', 1, '99014', '\\evo16924\DYMOTest', NULL, 'Dave''s Label Printer'); 
INSERT INTO APP_PRINTER ( PRINTER_MODEL, ID, LOADED_MEDIA, SYS_NAME, ROOM_ID,
DESCRIPTION ) VALUES ( 
'DYMO LabelWriter 400', 21, '99014', '\\evo18508\DYMOPilot', NULL, 'Pilot Label Printer'); 
COMMIT;

INSERT INTO APP_SERVER_ALERT_DICT ( ID, NAME, DESCRIPTION, ORDER_BY,
ACTIVE ) VALUES ( 
1, 'Downtime notification', 'The WSTI Mouse Database will be unavailable this evening from 5:00pm to 5:30pm for rountine maintenance.<br> Please ensure your have saved your data and exited the application before that time.'
, NULL, 0);
COMMIT;

INSERT INTO APP_COLUMN_PREFS ( ID, TABLE_NAME, COLUMN_NAME, COLUMN_TITLE, GETTER_METHOD, ORDER_BY,
DATATYPE ) VALUES ( 
2, 'mts_mouse_list_vw', 'name', 'Name', 'getName', 1, NULL); 
INSERT INTO APP_COLUMN_PREFS ( ID, TABLE_NAME, COLUMN_NAME, COLUMN_TITLE, GETTER_METHOD, ORDER_BY,
DATATYPE ) VALUES ( 
3, 'mts_mouse_list_vw', 'coat_colour', 'Coat Colour', 'getCoatColour', 4, NULL); 
INSERT INTO APP_COLUMN_PREFS ( ID, TABLE_NAME, COLUMN_NAME, COLUMN_TITLE, GETTER_METHOD, ORDER_BY,
DATATYPE ) VALUES ( 
4, 'mts_mouse_list_vw', 'eye_colour', 'Eye Colour', 'getEyeColour', NULL, NULL); 
INSERT INTO APP_COLUMN_PREFS ( ID, TABLE_NAME, COLUMN_NAME, COLUMN_TITLE, GETTER_METHOD, ORDER_BY,
DATATYPE ) VALUES ( 
5, 'mts_mouse_list_vw', 'earmark', 'Earclip', 'getEarmark', 6, NULL); 
INSERT INTO APP_COLUMN_PREFS ( ID, TABLE_NAME, COLUMN_NAME, COLUMN_TITLE, GETTER_METHOD, ORDER_BY,
DATATYPE ) VALUES ( 
6, 'mts_mouse_list_vw', 'birth_date', 'Birth Date', 'getBirthDate', 8, 'date'); 
INSERT INTO APP_COLUMN_PREFS ( ID, TABLE_NAME, COLUMN_NAME, COLUMN_TITLE, GETTER_METHOD, ORDER_BY,
DATATYPE ) VALUES ( 
7, 'mts_mouse_list_vw', 'death_date', 'Death Date', 'getDeathDate', 10, 'date'); 
INSERT INTO APP_COLUMN_PREFS ( ID, TABLE_NAME, COLUMN_NAME, COLUMN_TITLE, GETTER_METHOD, ORDER_BY,
DATATYPE ) VALUES ( 
9, 'mts_mouse_list_vw', 'cause_of_death', 'Cause of Death', 'getCauseOfDeath', 9, NULL); 
INSERT INTO APP_COLUMN_PREFS ( ID, TABLE_NAME, COLUMN_NAME, COLUMN_TITLE, GETTER_METHOD, ORDER_BY,
DATATYPE ) VALUES ( 
10, 'mts_mouse_list_vw', 'wean_date', 'Wean Date', 'getWeanDate', 11, 'date'); 
INSERT INTO APP_COLUMN_PREFS ( ID, TABLE_NAME, COLUMN_NAME, COLUMN_TITLE, GETTER_METHOD, ORDER_BY,
DATATYPE ) VALUES ( 
11, 'mts_mouse_list_vw', 'cage_name', 'Cage', 'getCageName', 14, NULL); 
INSERT INTO APP_COLUMN_PREFS ( ID, TABLE_NAME, COLUMN_NAME, COLUMN_TITLE, GETTER_METHOD, ORDER_BY,
DATATYPE ) VALUES ( 
12, 'mts_mouse_list_vw', 'rack_name', 'Rack', 'getRackName', 13, NULL); 
INSERT INTO APP_COLUMN_PREFS ( ID, TABLE_NAME, COLUMN_NAME, COLUMN_TITLE, GETTER_METHOD, ORDER_BY,
DATATYPE ) VALUES ( 
13, 'mts_mouse_list_vw', 'room_name', 'Room', 'getRoomName', 12, NULL); 
INSERT INTO APP_COLUMN_PREFS ( ID, TABLE_NAME, COLUMN_NAME, COLUMN_TITLE, GETTER_METHOD, ORDER_BY,
DATATYPE ) VALUES ( 
14, 'mts_mouse_list_vw', 'current_owner', 'Owner', 'getCurrentOwner', 15, NULL); 
INSERT INTO APP_COLUMN_PREFS ( ID, TABLE_NAME, COLUMN_NAME, COLUMN_TITLE, GETTER_METHOD, ORDER_BY,
DATATYPE ) VALUES ( 
15, 'mts_mouse_list_vw', 'current_project_licence', 'PPL', 'getCurrentProjectLicence'
, 16, NULL); 
INSERT INTO APP_COLUMN_PREFS ( ID, TABLE_NAME, COLUMN_NAME, COLUMN_TITLE, GETTER_METHOD, ORDER_BY,
DATATYPE ) VALUES ( 
16, 'mts_mouse_list_vw', 'current_protocol_code', 'Protocol', 'getCurrentProtocolCode'
, 17, NULL); 
INSERT INTO APP_COLUMN_PREFS ( ID, TABLE_NAME, COLUMN_NAME, COLUMN_TITLE, GETTER_METHOD, ORDER_BY,
DATATYPE ) VALUES ( 
17, 'mts_mouse_list_vw', 'gender', 'Gender', 'getGender', 2, NULL); 
INSERT INTO APP_COLUMN_PREFS ( ID, TABLE_NAME, COLUMN_NAME, COLUMN_TITLE, GETTER_METHOD, ORDER_BY,
DATATYPE ) VALUES ( 
18, 'mts_mouse_list_vw', 'strain', 'Strain', 'getStrain', NULL, NULL); 
INSERT INTO APP_COLUMN_PREFS ( ID, TABLE_NAME, COLUMN_NAME, COLUMN_TITLE, GETTER_METHOD, ORDER_BY,
DATATYPE ) VALUES ( 
19, 'mts_mouse_list_vw', 'status', 'Status', 'getStatus', 5, NULL); 
INSERT INTO APP_COLUMN_PREFS ( ID, TABLE_NAME, COLUMN_NAME, COLUMN_TITLE, GETTER_METHOD, ORDER_BY,
DATATYPE ) VALUES ( 
20, 'mts_mouse_list_vw', 'barcode', 'Barcode', 'getBarcode', 18, NULL); 
INSERT INTO APP_COLUMN_PREFS ( ID, TABLE_NAME, COLUMN_NAME, COLUMN_TITLE, GETTER_METHOD, ORDER_BY,
DATATYPE ) VALUES ( 
22, 'mts_mouse_list_vw', 'supplier', 'Supplier', 'getSupplier', NULL, NULL); 
INSERT INTO APP_COLUMN_PREFS ( ID, TABLE_NAME, COLUMN_NAME, COLUMN_TITLE, GETTER_METHOD, ORDER_BY,
DATATYPE ) VALUES ( 
23, 'mts_mouse_list_vw', 'is_non_breeder', 'Non Breeder', 'isNonBreeder', NULL, 'boolean'); 
INSERT INTO APP_COLUMN_PREFS ( ID, TABLE_NAME, COLUMN_NAME, COLUMN_TITLE, GETTER_METHOD, ORDER_BY,
DATATYPE ) VALUES ( 
24, 'mts_mouse_list_vw', 'is_sentinel', 'Sentinel', 'isSentinel', NULL, 'boolean'); 
INSERT INTO APP_COLUMN_PREFS ( ID, TABLE_NAME, COLUMN_NAME, COLUMN_TITLE, GETTER_METHOD, ORDER_BY,
DATATYPE ) VALUES ( 
25, 'mts_mouse_list_vw', 'generation', 'Generation', 'getGeneration', 7, NULL); 
INSERT INTO APP_COLUMN_PREFS ( ID, TABLE_NAME, COLUMN_NAME, COLUMN_TITLE, GETTER_METHOD, ORDER_BY,
DATATYPE ) VALUES ( 
26, 'mts_mouse_list_vw', 'colony_name', 'Colony Name', 'getColonyName', 3, NULL); 
INSERT INTO APP_COLUMN_PREFS ( ID, TABLE_NAME, COLUMN_NAME, COLUMN_TITLE, GETTER_METHOD, ORDER_BY,
DATATYPE ) VALUES ( 
27, 'mts_mouse_list_vw', 'age_in_weeks', 'Age in Weeks', 'getAgeInWeeks', 27, NULL); 
INSERT INTO APP_COLUMN_PREFS ( ID, TABLE_NAME, COLUMN_NAME, COLUMN_TITLE, GETTER_METHOD, ORDER_BY,
DATATYPE ) VALUES ( 
28, 'mts_mouse_list_vw', 'age_at_death', 'Age At Death', 'getAgeAtDeath', 28, NULL); 

COMMIT;

INSERT INTO MIR_INTERNAL_STATUS_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
5, 'Embryonic Chimeras Flushed', 'Embryonic Chimera Endpoint', 1, 5); 
INSERT INTO MIR_INTERNAL_STATUS_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
3, 'Microinjection Complete', 'Donor embryos have been microinjected with ES cells.'
, 1, 3); 
INSERT INTO MIR_INTERNAL_STATUS_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
13, 'Completed', 'Endpoint has been reached and Technician has confirmed completed.'
, 1, 13); 
INSERT INTO MIR_INTERNAL_STATUS_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
4, 'Embryo Transfer Complete', 'Recipient wiltype females have had surgically imlpanted embryo/ES cells .'
, 1, 4); 
INSERT INTO MIR_INTERNAL_STATUS_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
6, 'F0 Pups Weaned', 'F0 Endpoint', 1, 6); 
INSERT INTO MIR_INTERNAL_STATUS_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
9, 'Failed', 'MI has failed for technical reasons. New MI may be created to fulfill request.'
, 1, 9); 
INSERT INTO MIR_INTERNAL_STATUS_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
10, 'Cancelled', 'MI has been cancelled by administration. New MI may be created to fulfill request.'
, 1, 10); 
INSERT INTO MIR_INTERNAL_STATUS_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
11, 'F1 Pups Weaned', 'F1 Pups Weaned', 1, 11); 
INSERT INTO MIR_INTERNAL_STATUS_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
12, 'F1 Pups Genotyped', 'F1 Endpoint', 1, 12); 
INSERT INTO MIR_INTERNAL_STATUS_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
1, 'Scheduled - Awaiting Work', 'MI has been scheduled but no work done on it yet.'
, 1, 1); 
COMMIT;

INSERT INTO MIR_MI_129_TASK_TEMPLATE ( ID, NAME, DESCRIPTION, SEQUENCE_NUMBER, TIME_OFFSET,
TIME_UNIT, IS_MILESTONE ) VALUES ( 
12, 'F1s Genotyped', 'F1 Weaned and genotyped', 8, 103, 'days', 1); 
INSERT INTO MIR_MI_129_TASK_TEMPLATE ( ID, NAME, DESCRIPTION, SEQUENCE_NUMBER, TIME_OFFSET,
TIME_UNIT, IS_MILESTONE ) VALUES ( 
4, 'Microinjection Completed', 'Microinjection Completed', 0, 0, 'days', 1); 
INSERT INTO MIR_MI_129_TASK_TEMPLATE ( ID, NAME, DESCRIPTION, SEQUENCE_NUMBER, TIME_OFFSET,
TIME_UNIT, IS_MILESTONE ) VALUES ( 
5, 'Embryo Transfer Completed', 'Embryo Transfer - Pseudo-breeding', 1, 0, 'days'
, 1); 
INSERT INTO MIR_MI_129_TASK_TEMPLATE ( ID, NAME, DESCRIPTION, SEQUENCE_NUMBER, TIME_OFFSET,
TIME_UNIT, IS_MILESTONE ) VALUES ( 
13, 'Email Requester F1 results', 'Email Requester F1 results', 9, 117, 'days', 0); 
INSERT INTO MIR_MI_129_TASK_TEMPLATE ( ID, NAME, DESCRIPTION, SEQUENCE_NUMBER, TIME_OFFSET,
TIME_UNIT, IS_MILESTONE ) VALUES ( 
6, 'Recipient Pregnancy Check', 'Recipient Pregnancy Check', 2, 10, 'days', 0); 
INSERT INTO MIR_MI_129_TASK_TEMPLATE ( ID, NAME, DESCRIPTION, SEQUENCE_NUMBER, TIME_OFFSET,
TIME_UNIT, IS_MILESTONE ) VALUES ( 
7, 'F0s Born', 'F0s Born', 3, 18, 'days', 0); 
INSERT INTO MIR_MI_129_TASK_TEMPLATE ( ID, NAME, DESCRIPTION, SEQUENCE_NUMBER, TIME_OFFSET,
TIME_UNIT, IS_MILESTONE ) VALUES ( 
9, 'F0s Weaned', 'F0s Weaned', 5, 40, 'days', 1); 
INSERT INTO MIR_MI_129_TASK_TEMPLATE ( ID, NAME, DESCRIPTION, SEQUENCE_NUMBER, TIME_OFFSET,
TIME_UNIT, IS_MILESTONE ) VALUES ( 
10, 'Breeding F0 to 129 Female', 'Breeding F0 to B6 Female', 6, 61, 'days', 0); 
INSERT INTO MIR_MI_129_TASK_TEMPLATE ( ID, NAME, DESCRIPTION, SEQUENCE_NUMBER, TIME_OFFSET,
TIME_UNIT, IS_MILESTONE ) VALUES ( 
11, 'F1s Born', 'F1s Born', 7, 82, 'days', 0); 
COMMIT;

INSERT INTO MIR_MI_B6_TASK_TEMPLATE ( ID, NAME, DESCRIPTION, SEQUENCE_NUMBER, TIME_OFFSET,
TIME_UNIT, IS_MILESTONE ) VALUES ( 
12, 'F1s Genotyped', 'Milestone - Earclip and genotyping', 10, 171, 'days', 1); 
INSERT INTO MIR_MI_B6_TASK_TEMPLATE ( ID, NAME, DESCRIPTION, SEQUENCE_NUMBER, TIME_OFFSET,
TIME_UNIT, IS_MILESTONE ) VALUES ( 
4, 'Microinjection Completed', 'Milestone -  MI Completed', 2, 0, 'days', 1); 
INSERT INTO MIR_MI_B6_TASK_TEMPLATE ( ID, NAME, DESCRIPTION, SEQUENCE_NUMBER, TIME_OFFSET,
TIME_UNIT, IS_MILESTONE ) VALUES ( 
5, 'Embryo Transfer Completed', 'Milestone - Embryo Transfer Procedure(s) Completed'
, 3, 0, 'days', 1); 
INSERT INTO MIR_MI_B6_TASK_TEMPLATE ( ID, NAME, DESCRIPTION, SEQUENCE_NUMBER, TIME_OFFSET,
TIME_UNIT, IS_MILESTONE ) VALUES ( 
13, 'Email Requester F1 results', 'Email Requester F1 results', 11, 131, 'days', 0); 
INSERT INTO MIR_MI_B6_TASK_TEMPLATE ( ID, NAME, DESCRIPTION, SEQUENCE_NUMBER, TIME_OFFSET,
TIME_UNIT, IS_MILESTONE ) VALUES ( 
6, 'Recipient Pregnancy Check', 'Check if surrogate female pregnant with F0s', 4, 10
, 'days', 0); 
INSERT INTO MIR_MI_B6_TASK_TEMPLATE ( ID, NAME, DESCRIPTION, SEQUENCE_NUMBER, TIME_OFFSET,
TIME_UNIT, IS_MILESTONE ) VALUES ( 
7, 'F0s Born', 'Chimeras Born', 5, 18, 'days', 0); 
INSERT INTO MIR_MI_B6_TASK_TEMPLATE ( ID, NAME, DESCRIPTION, SEQUENCE_NUMBER, TIME_OFFSET,
TIME_UNIT, IS_MILESTONE ) VALUES ( 
9, 'F0s Weaned', 'Milestone - Coat check for percent chimeric', 7, 40, 'days', 1); 
INSERT INTO MIR_MI_B6_TASK_TEMPLATE ( ID, NAME, DESCRIPTION, SEQUENCE_NUMBER, TIME_OFFSET,
TIME_UNIT, IS_MILESTONE ) VALUES ( 
10, 'Breeding F0 to B6 Female', 'Breeding Chimeras to B6 Female', 8, 75, 'days', 0); 
INSERT INTO MIR_MI_B6_TASK_TEMPLATE ( ID, NAME, DESCRIPTION, SEQUENCE_NUMBER, TIME_OFFSET,
TIME_UNIT, IS_MILESTONE ) VALUES ( 
11, 'F1s Born', 'F1 Generation Born', 9, 96, 'days', 0); 
COMMIT;

INSERT INTO MIR_MI_F0_EMBRYO_TASK_TEMPLATE ( ID, NAME, DESCRIPTION, SEQUENCE_NUMBER, TIME_OFFSET,
TIME_UNIT, IS_MILESTONE ) VALUES ( 
4, 'Microinjection Completed', 'Microinjection Completed', 0, 0, 'days', 1); 
INSERT INTO MIR_MI_F0_EMBRYO_TASK_TEMPLATE ( ID, NAME, DESCRIPTION, SEQUENCE_NUMBER, TIME_OFFSET,
TIME_UNIT, IS_MILESTONE ) VALUES ( 
5, 'Embryo Transfer Completed', 'Embryo Transfer Completed', 1, 0, 'days', 1); 
INSERT INTO MIR_MI_F0_EMBRYO_TASK_TEMPLATE ( ID, NAME, DESCRIPTION, SEQUENCE_NUMBER, TIME_OFFSET,
TIME_UNIT, IS_MILESTONE ) VALUES ( 
9, 'F0 Embryos Harvested', 'F0 Embryos Harvested', 2, 15, 'days', 1); 
COMMIT;

INSERT INTO MIR_TRANSFER_TYPE_DICT ( ID, NAME, DESCRIPTION, ORDER_BY,
ACTIVE ) VALUES ( 
1, 'Uterine', 'uterine', 1, 1); 
INSERT INTO MIR_TRANSFER_TYPE_DICT ( ID, NAME, DESCRIPTION, ORDER_BY,
ACTIVE ) VALUES ( 
2, 'Oviduct', 'oviduct', 2, 1); 
INSERT INTO MIR_TRANSFER_TYPE_DICT ( ID, NAME, DESCRIPTION, ORDER_BY,
ACTIVE ) VALUES ( 
3, 'Catheter', 'catheter', 3, 1); 
COMMIT;

delete mir_external_status_dict;

INSERT INTO MIR_EXTERNAL_STATUS_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
1, 'Micro injections requested', NULL, 1, 1); 
INSERT INTO MIR_EXTERNAL_STATUS_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
2, 'Micro injections scheduled', NULL, 1, 2); 
INSERT INTO MIR_EXTERNAL_STATUS_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
3, 'Micro injection delayed', NULL, 1, 4); 
INSERT INTO MIR_EXTERNAL_STATUS_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
4, 'Micro injected', NULL, 1, 5); 
INSERT INTO MIR_EXTERNAL_STATUS_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
5, 'Surrogate females pregnant', NULL, 1, 6); 
INSERT INTO MIR_EXTERNAL_STATUS_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
6, 'F0 Pups born', NULL, 1, 7); 
INSERT INTO MIR_EXTERNAL_STATUS_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
7, 'Male chimaeras', NULL, 1, 9); 
INSERT INTO MIR_EXTERNAL_STATUS_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
8, 'Chimaeras scheduled for breeding', NULL, 1, 10); 
INSERT INTO MIR_EXTERNAL_STATUS_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
9, 'Chimaeras bred', NULL, 1, 11); 
INSERT INTO MIR_EXTERNAL_STATUS_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
10, 'F1s born', NULL, 1, 12); 
INSERT INTO MIR_EXTERNAL_STATUS_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
11, 'Confirmed hets', NULL, 1, 13); 
INSERT INTO MIR_EXTERNAL_STATUS_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
15, 'No male chimeras', NULL, 1, 8); 
INSERT INTO MIR_EXTERNAL_STATUS_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
16, 'Partial Micro-Injection', NULL, 1, 16); 
INSERT INTO MIR_EXTERNAL_STATUS_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
12, 'Completed', NULL, 1, 14); 
INSERT INTO MIR_EXTERNAL_STATUS_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
13, 'Cancelled', NULL, 1, 15); 
INSERT INTO MIR_EXTERNAL_STATUS_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
14, 'awaiting MAP test result', NULL, 1, 3); 
INSERT INTO MIR_EXTERNAL_STATUS_DICT ( ID, NAME, DESCRIPTION, ACTIVE,
ORDER_BY ) VALUES ( 
17, 'In Process', NULL, 1, 17); 
COMMIT;


ALTER TABLE MTS_EARMARK_DICT
MODIFY(NAME  NOT NULL);


ALTER TABLE MIR_MI_F0_EMBRYO_TASK_TEMPLATE
MODIFY(SEQUENCE_NUMBER  NOT NULL);


ALTER TABLE MIR_MI_B6_TASK_TEMPLATE
MODIFY(NAME  NOT NULL);


ALTER TABLE MTS_PROCEDURE_DICT
MODIFY(ACTIVE  NOT NULL);


ALTER TABLE MIR_MI_B6_TASK_TEMPLATE
MODIFY(SEQUENCE_NUMBER  NOT NULL);


ALTER TABLE ARQ_DESIGN_REQUEST
MODIFY(GENE_BUILD_GENE_ID  DEFAULT null);

ALTER TABLE ARQ_DESIGN_REQUEST
MODIFY(START_EXON_ID  DEFAULT null);

ALTER TABLE ARQ_DESIGN_REQUEST
MODIFY(END_EXON_ID  DEFAULT null);

ALTER TABLE ARQ_DESIGN_REQUEST
MODIFY(TARGET_START  DEFAULT null);

ALTER TABLE ARQ_DESIGN_REQUEST
MODIFY(TARGET_END  DEFAULT null);

ALTER TABLE ARQ_DESIGN_REQUEST
MODIFY(MIN_5P_EXON_FLANKS  DEFAULT null);

ALTER TABLE ARQ_DESIGN_REQUEST
MODIFY(MIN_3P_EXON_FLANKS  DEFAULT null);

ALTER TABLE ARQ_DESIGN_REQUEST
MODIFY(SPLIT_TARGET_SEQ_LENGTH  DEFAULT null);

ALTER TABLE ARQ_DESIGN_REQUEST
MODIFY(MULTI_REGION_OFFSET_SHIM  DEFAULT null);

ALTER TABLE ARQ_DESIGN_REQUEST
MODIFY(PRIMER_LENGTH  DEFAULT null);

ALTER TABLE MIR_MI_B6_TASK_TEMPLATE
MODIFY(TIME_OFFSET  NOT NULL);


ALTER TABLE MIR_ANALGESIA_DICT
MODIFY(ACTIVE  NOT NULL);


ALTER TABLE MTS_BODY_SYSTEM_DICT
MODIFY(ACTIVE  NOT NULL);


ALTER TABLE MIR_MI_F0_EMBRYO_TASK_TEMPLATE
MODIFY(NAME  NOT NULL);


ALTER TABLE MIR_MI_129_TASK_TEMPLATE
MODIFY(NAME  NOT NULL);


ALTER TABLE MIR_MI_129_TASK_TEMPLATE
MODIFY(SEQUENCE_NUMBER  NOT NULL);


ALTER TABLE MIR_MI_129_TASK_TEMPLATE
MODIFY(TIME_OFFSET  NOT NULL);


ALTER TABLE MTS_BODY_SUBSYSTEM_DICT
MODIFY(NAME  NOT NULL);


ALTER TABLE MTS_BODY_SUBSYSTEM_DICT
MODIFY(ACTIVE  NOT NULL);


ALTER TABLE MIR_EMBRYO_HARVEST
MODIFY(FLUSH_DATE  NOT NULL);


ALTER TABLE ARQ_DESIGN_REQUEST
MODIFY(RETRIEVAL_PRIMER_OFFSET_5P  DEFAULT null);

ALTER TABLE ARQ_DESIGN_REQUEST
MODIFY(RETRIEVAL_PRIMER_LENGTH_5P  DEFAULT null);

ALTER TABLE LIC_PROCEDURE_2_PROTOCOL
MODIFY(PROCEDURE_DICT_ID  NOT NULL);


ALTER TABLE LIC_PROCEDURE_2_PROTOCOL
MODIFY(PROTOCOL_ID  NOT NULL);


ALTER TABLE MIR_MICRO_INJECTION_REQUEST
MODIFY(ENDPOINT_DICT_ID  NOT NULL);


ALTER TABLE MIR_EMBRYO_TRANSFER_PROCEDURE
MODIFY(SCHEDULED_MICRO_INJECTION_ID  NOT NULL);


ALTER TABLE MTS_CAGE
MODIFY(BARCODE  NOT NULL);


ALTER TABLE MIR_SCHEDULED_MICRO_INJECTION
MODIFY(TARGET_SCHEDULE_DATE  NOT NULL);


ALTER TABLE MIR_SCHEDULED_MICRO_INJECTION
MODIFY(MICRO_INJECTION_REQUEST_ID  NOT NULL);


ALTER TABLE MIR_SCHEDULED_MICRO_INJECTION
MODIFY(INTERNAL_STATUS_DICT_ID  NOT NULL);


ALTER TABLE MIR_MICRO_INJECTION
MODIFY(SCHEDULED_MICRO_INJECTION_ID  NOT NULL);


ALTER TABLE MTS_HEALTH_CONCERN_DICT
MODIFY(ACTIVE  NOT NULL);


ALTER TABLE MIR_TRANSFER_TYPE_DICT
MODIFY(ORDER_BY  NOT NULL);


ALTER TABLE MTS_EYE_COLOUR_DICT
MODIFY(ACTIVE  NOT NULL);


ALTER TABLE MTS_EARMARK_DICT
MODIFY(ACTIVE  NOT NULL);


ALTER TABLE MTS_PROCEDURE_DICT
MODIFY(NAME  NOT NULL);


ALTER TABLE MTS_HEALTH_CONCERN_DICT
MODIFY(NAME  NOT NULL);


ALTER TABLE MTS_BODY_SYSTEM_DICT
MODIFY(NAME  NOT NULL);


ALTER TABLE MTS_MOUSE_SUPPLIER_DICT
MODIFY(ACTIVE  NOT NULL);


ALTER TABLE MIR_TRANSFER_TYPE_DICT
MODIFY(ACTIVE  NOT NULL);


ALTER TABLE MIR_ANAESTHETIC_DICT
MODIFY(NAME  NOT NULL);


ALTER TABLE MIR_MI_F0_EMBRYO_TASK_TEMPLATE
MODIFY(TIME_OFFSET  NOT NULL);


ALTER TABLE MIR_ANALGESIA_DICT
MODIFY(NAME  NOT NULL);


ALTER TABLE MIR_ANAESTHETIC_DICT
MODIFY(ACTIVE  NOT NULL);


ALTER TABLE MTS_MOUSE_SUPPLIER_DICT
MODIFY(NAME  NOT NULL);


ALTER TABLE MTS_GENDER_DICT
MODIFY(ACTIVE  NOT NULL);


ALTER TABLE MIR_TRANSFER_TYPE_DICT
MODIFY(NAME  NOT NULL);


ALTER TABLE MTS_GENDER_DICT
MODIFY(NAME  NOT NULL);


ALTER TABLE MTS_CAUSE_OF_DEATH_DICT
MODIFY(ACTIVE  NOT NULL);


ALTER TABLE MIR_INTERNAL_STATUS_DICT
MODIFY(NAME  NOT NULL);


ALTER TABLE MIR_INTERNAL_STATUS_DICT
MODIFY(ACTIVE  NOT NULL);


ALTER TABLE MTS_EYE_COLOUR_DICT
MODIFY(NAME  NOT NULL);


ALTER TABLE MTS_CAUSE_OF_DEATH_DICT
MODIFY(NAME  NOT NULL);


update mir_micro_injection_request set funding_source = decode(requester_id,310,'Other','Sanger');

update mir_micro_injection_request set funding_source = 'Other' where workflow_pipeline_dict_id = 3;

commit;

INSERT INTO APP_TABLE_METADATA ( ID, TABLE_NAME, PRIMARY_KEY_COLUMN ) VALUES ( 
7, 'MTS_CAGE', 'ID'); 
INSERT INTO APP_TABLE_METADATA ( ID, TABLE_NAME, PRIMARY_KEY_COLUMN ) VALUES ( 
6, 'MTS_AIR_HANDLING_UNIT', 'ID'); 
INSERT INTO APP_TABLE_METADATA ( ID, TABLE_NAME, PRIMARY_KEY_COLUMN ) VALUES ( 
5, 'MTS_RACK', 'ID'); 
INSERT INTO APP_TABLE_METADATA ( ID, TABLE_NAME, PRIMARY_KEY_COLUMN ) VALUES ( 
4, 'MTS_ROOM', 'ID'); 
INSERT INTO APP_TABLE_METADATA ( ID, TABLE_NAME, PRIMARY_KEY_COLUMN ) VALUES ( 
1, 'MTS_MOUSE', 'ID'); 
INSERT INTO APP_TABLE_METADATA ( ID, TABLE_NAME, PRIMARY_KEY_COLUMN ) VALUES ( 
2, 'REQ_ANIMAL_REQUEST', 'ID'); 
INSERT INTO APP_TABLE_METADATA ( ID, TABLE_NAME, PRIMARY_KEY_COLUMN ) VALUES ( 
8, 'MIR_EMBRYO_HARVEST', 'ID'); 
INSERT INTO APP_TABLE_METADATA ( ID, TABLE_NAME, PRIMARY_KEY_COLUMN ) VALUES ( 
3, 'MIR_EMBRYO_TRANSFER_PROCEDURE', 'ID'); 
COMMIT;


