drop table temp_max_gene_build;

drop table temp_max_gene_build_duplicates;

update gnm_master_mgi_symbol_list set invalid=1 where ensembl_id in (
select ensembl_id
from gnm_master_mgi_symbol_list where ensembl_id is not null
group by ensembl_id having count(*) > 1
);

update gnm_master_mgi_symbol_list set invalid=1 where vega_id in (
select vega_id
from gnm_master_mgi_symbol_list where vega_id is not null
group by vega_id having count(*) > 1
);

-- gnm_gene_build_genes with no linker
insert into gnm_gene_2_gene_build_gene(gene_id, gene_build_gene_id, is_valid, reasoning)
select distinct
  linker.gene_id,
  missing.id gene_build_gene_id,
 1 is_valid,
 'dg6 19-01-09 linked by primary_name' reasoning
from 
  gnm_gene_build_gene missing,
  gnm_gene_2_gene_build_gene linker,
  gnm_gene_build_gene already_linked  
where 
  not exists (select null from gnm_gene_2_gene_build_gene linker2 where linker2.gene_build_gene_id = missing.id) and
  missing.primary_name = already_linked.primary_name and
  already_linked.id = linker.gene_build_gene_id and missing.build_id = &&build_id;
  
-- add mig genes for orphan vega build genes (ONLY RUN FOR VEGA)
--insert into gnm_gene(ncbi_taxon, primary_build_gene_id, is_valid, primary_vega_build_gene_id, in_current_vega, in_current_ensembl)
--select 10090,b.id,1,b.id,1,0
--from gnm_gene_build_gene b
--where not exists (select null from gnm_gene_2_gene_build_gene l where l.gene_build_gene_id = b.id)
--and b.build_id = &&build_id;

-- add mig genes for orphan ensembl build genes (ONLY RUN FOR ENSEMBLE)
insert into gnm_gene(ncbi_taxon, primary_build_gene_id, is_valid, primary_ensembl_build_gene_id, in_current_vega, in_current_ensembl)
select 10090,b.id,1,b.id,0,1
from gnm_gene_build_gene b
where not exists (select null from gnm_gene_2_gene_build_gene l where l.gene_build_gene_id = b.id)
and b.build_id = &&build_id;

-- gnm_genes with no linker records  
insert into gnm_gene_2_gene_build_gene(gene_id, gene_build_gene_id, is_valid, reasoning)
select  
 g.id,
 g.primary_build_gene_id,
 1 is_valid,
 'dg6 19-01-09 manual linker by primary_gene_build_gene' reasoning
from 
  gnm_gene g,
  gnm_gene_build_gene b 
where 
  not exists (select null from gnm_gene_2_gene_build_gene b where g.id = b.gene_id) and
  b.id = g.primary_build_gene_id and b.build_id = &&build_id;
  
-- add linker records for manually annotated havana requests  
insert into gnm_gene_2_gene_build_gene(gene_id,gene_build_gene_id,is_valid,reasoning)
select distinct
  a.gene_id,
  b.id gene_build_gene,
  1 is_valid,
  'dg6 19-01-09 linked by havana request'
from
  arq_havana_request h,
  arq_allele_request a,
  gnm_gene_build_gene b
where
  h.vega_id = b.primary_name and
  h.allele_request_id = a.id and
  not exists (select null from gnm_gene_2_gene_build_gene l where l.gene_id = a.gene_id and l.gene_build_gene_id = b.id)   ;

-- create table with max build for each mig gene
-- NOTE: Relies on gene_builds having linker records to the mig genes
create table temp_max_gene_build
as
select
  b.source,
  x.gene_id,
  b.id build_id,
  gbg.id gene_build_gene_id
from
  gnm_gene_build b,
  (   select
	  g2g.gene_id,
	  b.source,
	  max(b.order_by) order_by
	from
	  gnm_gene_build_gene gbg,
	  gnm_gene_build b,
	  gnm_gene_2_gene_build_gene g2g
	where
	  b.id = gbg.build_id and
	  gbg.id = g2g.gene_build_gene_id 
	group by
	  g2g.gene_id,
	  b.source
  ) x,
  gnm_gene_2_gene_build_gene g2gbg,
  gnm_gene_build_gene gbg
where
  x.source = b.source and
  x.order_by = b.order_by and
  b.id = gbg.build_id and
  gbg.id = g2gbg.gene_build_gene_id and
  x.gene_id = g2gbg.gene_id;
  
-- make table of mig genes that point to >1 build gene 
create table temp_max_gene_build_duplicates as  
select * from temp_max_gene_build where (source,gene_id) in ( 
select source,gene_id from temp_max_gene_build group by source,gene_id having count(*)>1);

-- list mig genes where primary gene cannot be automatically resolved
select distinct gene_id from temp_max_gene_build_duplicates;

-- remove duplicates from this table (can't arbitrarily choose one primary gene from a choice of two or more)
delete from temp_max_gene_build where (source,gene_id) in ( 
select source,gene_id from temp_max_gene_build group by source,gene_id having count(*)>1);

-- for efficiency
create index temp_max_gene_build_ind1 on temp_max_gene_build
(gene_id)
tablespace index_02;

drop table gnm_mgi_marker_2_vega_dups;
  
create table gnm_mgi_marker_2_vega_dups as select * from gnm_mgi_marker_2_vega where vega_id in (
select vega_id from gnm_mgi_marker_2_vega group by vega_id having count(*) > 1) order by vega_id;

delete from gnm_mgi_marker_2_vega where vega_id in (
select vega_id from gnm_mgi_marker_2_vega group by vega_id having count(*) > 1);

drop table gnm_mgi_marker_2_ensembl_dups;

create table gnm_mgi_marker_2_ensembl_dups as select * from gnm_mgi_marker_2_ensembl where ensembl_id in (
select ensembl_id from gnm_mgi_marker_2_ensembl group by ensembl_id having count(*) > 1) order by ensembl_id;

delete from gnm_mgi_marker_2_ensembl where ensembl_id in (
select ensembl_id from gnm_mgi_marker_2_ensembl group by ensembl_id having count(*) > 1);  
  
-- set primary ensembl and vega id for gnm_gene
update gnm_gene g set
  primary_ensembl_build_gene_id = (select gene_build_gene_id
  						  	 from temp_max_gene_build t
							 where source='Ensembl' and t.gene_id = g.id),
  primary_vega_build_gene_id = (select gene_build_gene_id
  						  	 from temp_max_gene_build t
							 where source='Vega' and t.gene_id = g.id);  
							 
-- set primary build gene for gnm_gene based on primary vega or ensembl	  
update gnm_gene u
set 
  primary_build_gene_id = nvl(primary_vega_build_gene_id, primary_ensembl_build_gene_id)
where
  primary_vega_build_gene_id is not null or 
  primary_ensembl_build_gene_id is not null;
	    
--set new name to null		
update
  gnm_gene set old_name = new_name, new_name = null;	
  
update gnm_gene set primary_name_source = null;
  
-- set primary name from mgi master list
update gnm_gene g1
set
  g1.new_name = (select m.mgi_symbol from gnm_master_mgi_symbol_list m, gnm_gene_build_gene b
  			  	where b.primary_name = m.vega_id and b.id = g1.primary_vega_build_gene_id and nvl(invalid,0) != 1),
  g1.primary_name_source = 'mgi-master-list-vega'
where g1.new_name is null;  

update gnm_gene set primary_name_source = null where new_name is null;
 
update gnm_gene g1
set
  g1.new_name = (select m.mgi_symbol from gnm_master_mgi_symbol_list m, gnm_gene_build_gene b
  			  	where b.primary_name = m.ensembl_id and b.id = g1.primary_ensembl_build_gene_id and nvl(invalid,0) != 1),
  g1.primary_name_source = 'mgi-master-list-ensembl'
where g1.new_name is null; 

update gnm_gene set primary_name_source = null where new_name is null;
 
-- set primary name from mgi-2-vega  
update gnm_gene g1
set
  g1.new_name = (select m.mgi_symbol from gnm_mgi_marker_2_vega m, gnm_gene_build_gene b
                 where b.primary_name = m.vega_id and b.id = g1.primary_vega_build_gene_id),
  g1.primary_name_source = 'mgi-2-vega'
where g1.new_name is null;

update gnm_gene set primary_name_source = null where new_name is null;

-- set primary name from mgi-2-ensembl  
update gnm_gene g1
set
  g1.new_name = (select m.mgi_symbol from gnm_mgi_marker_2_ensembl m, gnm_gene_build_gene b
                 where b.primary_name = m.ensembl_id and b.id = g1.primary_ensembl_build_gene_id),
  g1.primary_name_source = 'mgi-2-ensembl'
where g1.new_name is null;

update gnm_gene set primary_name_source = null where new_name is null;

-- set primary name from gnm_gene
update gnm_gene g1
set
  g1.primary_name_source = 'mgi from vega build',
  g1.new_name = (
	select
	  n.name
	from
	  gnm_gene_build_gene_name n,
	  gnm_gene g
	where
	  g.id = g1.id and
	  n.source = 'MarkerSymbol' and
	  n.gene_build_gene_id = g.primary_vega_build_gene_id and
	  not exists (
	    select 
		  null
		from 
		  gnm_gene_build_gene_name n1 
		where 
		  n1.source ='MarkerSymbol' and
		  n1.gene_build_gene_id = n.gene_build_gene_id	  
		group by 
		  n1.gene_build_gene_id
		  having count(distinct n1.name) > 1	  
	    )
	)
where g1.new_name is null;

update gnm_gene set primary_name_source = null where new_name is null;

update gnm_gene g1
set
  g1.primary_name_source = 'ottmus from vega build',
  g1.new_name = (select n.primary_name from gnm_gene_build_gene n where n.id = g1.primary_vega_build_gene_id)
where
  g1.new_name is null and g1.primary_vega_build_gene_id is not null;
  
update gnm_gene set primary_name_source = null where new_name is null;
  
update gnm_gene g1
set
  g1.primary_name_source = 'mgi from ensembl build',
  g1.new_name = (
	select
	  n.name
	from
	  gnm_gene_build_gene_name n,
	  gnm_gene g
	where
	  g.id = g1.id and
	  n.source = 'MarkerSymbol' and
	  n.gene_build_gene_id = g.primary_ensembl_build_gene_id and
	  not exists (
	    select 
		  null
		from 
		  gnm_gene_build_gene_name n1 
		where 
		  n1.source ='MarkerSymbol' and
		  n1.gene_build_gene_id = n.gene_build_gene_id	  
		group by 
		  n1.gene_build_gene_id
		  having count(distinct n1.name) > 1	  
	    )
	) 
where g1.new_name is null;   
	
update gnm_gene set primary_name_source = null where new_name is null;	
	
update gnm_gene g1
set
  g1.primary_name_source = 'ensmus from ensembl build',
  g1.new_name = (select n.primary_name from gnm_gene_build_gene n where n.id = g1.primary_ensembl_build_gene_id)
where
  g1.new_name is null; 
 
update gnm_gene set primary_name_source = null where new_name is null; 
 
select * from gnm_gene where new_name != primary_name;

update gnm_gene set primary_name = new_name where new_name is not null;

insert into gnm_gene_name(name,source,name_uc,gene_id)
select g.primary_name,g.primary_name_source,upper(g.primary_name),g.id from gnm_gene g where g.primary_name is not null and not exists 
(select null from gnm_gene_name n where g.id = n.gene_id and upper(g.primary_name) = upper(n.name));

insert into gnm_gene_name (name,source,name_uc,gene_id) 
select distinct
  gbgn.name,
  gbgn.source,
  upper(gbgn.name) uc_name,
  g.id gene_id
from
  gnm_gene g,
  gnm_gene_2_gene_build_gene g2gb,
  gnm_gene_build_gene_name gbgn
where
  g.id = g2gb.gene_id and
  g2gb.gene_build_gene_id = gbgn.gene_build_gene_id and
  not exists (select null from gnm_gene_name n where n.gene_id = g.id and gbgn.source = n.source and gbgn.name = n.name);
  
BEGIN
  DBMS_SNAPSHOT.REFRESH(
    LIST                 => 'MIG.GNM_GENE_ALIAS_MV'
   ,PUSH_DEFERRED_RPC    => TRUE
   ,REFRESH_AFTER_ERRORS => FALSE
   ,PURGE_OPTION         => 1
   ,PARALLELISM          => 0
   ,ATOMIC_REFRESH       => TRUE
   ,NESTED               => FALSE);
END;
/
