/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.gene;

import uk.ac.sanger.mig.common.PaginatedSearchBean;
import uk.ac.sanger.mig.geneevidence.MigCuratedStatus;

public class MigGeneListDataBean extends PaginatedSearchBean {
	
	MigGene migGene = null;
	MigGeneMetaData metaData = null;
	
	public MigGene getMigGene() {
		return migGene;
	}
	
	public int getMigGeneId() {
		return migGene.getId().intValue();
	}
	
	public void setMigGene(MigGene migGene) {
		this.migGene = migGene;
	}

	public MigCuratedStatus getMigCuratedStatus() {
		MigCuratedStatus curatedStatus = null;
		if(metaData != null)
			curatedStatus = metaData.getMigCuratedStatus();
		return curatedStatus;
	}

	public String getUserVote() {
		return metaData.getUserVote();
	}
	
	public MigGeneMetaData getMetaData() {
		return metaData;
	}
	
	public void setMetaData(MigGeneMetaData metatdata) {
		this.metaData = metatdata;
	}

	public String getEnsemblId() {
		return migGene.getPrimaryEnsemblBuildGene().getPrimaryName();
	}

	public long getId() {
		return migGene.getId();
	}

	public String getPrimaryName() {
		return migGene.getPrimaryName();
	}

	public String getVegaId() {
		return migGene.getPrimaryVegaBuildGene().getPrimaryName();
	}

	public int getSetMembershipCount() {
		return metaData.getSetMembershipCount();
	}

	public int getGlobalScore() {
		return metaData.getGlobalScore();
	}
	
	public Integer getIgtcHits() {
		return migGene.getMigGeneTargetingHits().getIgtcHitCount();
	}

	public Integer getOmniBankHits() {
		return migGene.getMigGeneTargetingHits().getOmnibankHitCount();
	}
	
	public int getTranscriptCount() {
		return migGene.getPrimaryBuildGene().getTranscriptCount();
	}
	
	public int getTotalExonCount() {
		return migGene.getPrimaryBuildGene().getTotalExonCount();
	}	
	
	public int getUniqueExonCount() {
		return migGene.getPrimaryBuildGene().getUniqueExonCount();
	}
	
	public String getChromosomeName() {
		return migGene.getPrimaryBuildGene().getLocus().getChromosomeName();
	}
}
