/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.gene;

import java.util.Collection;

import uk.ac.sanger.mig.geneevidence.MigCuratedStatus;

/**
 * A data structure used to communicate data associated with a Gene, for example the number of GeneSets that contain
 * the Gene. These are intended to be properties ascociated with the Gene rather than the actual
 * gene its self.
 * 
 * @author dgm
 *
 */

public class MigGeneMetaData {
	
	private int setMembershipCount = 0;
	private int globalScore = 0;
	private Collection supportingEvidenceRecords = null;
	private MigCuratedStatus migCuratedStatus;
	private String userVote;
	
	public void setSupportingEvidenceRecords(Collection supportingEvidenceRecords) {
		this.supportingEvidenceRecords = supportingEvidenceRecords;
	}
	public Collection getSupportingEvidenceRecords() {
		return supportingEvidenceRecords;
	}
	
	public String getUserVote() {
		return userVote;
	}
	
	public void setUserVote(String vote) {
		userVote = vote;
	}
	
	/**
	 * Get the currently assigned score value for the gene. This will be fetched from the
	 * summary table in the database.
	 * 
	 * @return the knockout scoring for this gene.
	 */
	public int getGlobalScore() {
		return globalScore;
	}

	/**
	 * Set the knockout score for this gene.
	 * @param globalscore
	 */
	public void setGlobalScore(int globalscore) {
		this.globalScore = globalscore;
	}
	

	/**
	 * Get the number of sets that the associated gene is a member of.
	 * 
	 * @return the count of sets that contain the associated gene.
	 */
	public int getSetMembershipCount() {
		return setMembershipCount;
	}

	/**
	 * Used to set the number of sets that the associated gene is a member of.
	 * 
	 * @param setMembershipCount is the number of sets to that the associated
	 *     gene is a member of.
	 */
	public void setSetMembershipCount(int setMembershipCount) {
		this.setMembershipCount = setMembershipCount;
	}
	
	public MigCuratedStatus getMigCuratedStatus() {
		return migCuratedStatus;
	}
	
	public void setMigCuratedStatus(MigCuratedStatus migCuratedStatus) {
		this.migCuratedStatus = migCuratedStatus;
	}
}
