/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.gene;

import uk.ac.sanger.mig.common.AuthenticatedDataObject;
import uk.ac.sanger.mig.common.ComponentEnum;

public class MigGeneName extends AuthenticatedDataObject {
	
	public enum Component implements ComponentEnum {
		ALL_COMPONENTS
	}

	private String name;
	private String source;
	private Long migGeneId;
	
	/**
	 * Get the name component of the pair. e.g. ENSMUSG00000001234
	 * @return the string containing the name component of the pair.
	 */
	public String getName() {
		return name;
	}
	
	/**
	 * Set the name component of the pair. e.g. ENSMUSG00000001234
	 * @param name is the string containing the name component of the pair.
	 */
	public void setName(String name) {
		this.name = name;
	}
	
	/**
	 * Get the source component of the pair. e.g. Ensembl_Id
	 * @return the string containing the source component of the pair.
	 */
	public String getSource() {
		return source;
	}
	
	/**
	 * Set the source component of the pair. e.g. Ensembl_Id
	 * @param source is the string containing the source component of the
	 *     pair.
	 */
	public void setSource(String source) {
		this.source = source;
	}
	
	/**
	 * Return a hashing string. This is the concatination of the name and source.
	 * @return a hashing string which is a concatination of name and source strings.
	 */
	public String getHash(){
		return name + source;
	}
	
	/**
	 * Make a hash code for use by HashMap's and HashSets that makes two GeneName
	 * objects identical IFF the source and name components are identical.
	 */
	public int hashCode(){
		return getHash().hashCode();
	}
	
	/**
	 * Allow two instances of GeneName to be compared for identity based on their
	 * source and names.
	 */
	public boolean equals(MigGeneName migGeneName){
		return migGeneName.getHash().equals(this.getHash());
	}

	public Long getMigGeneId() {
		return migGeneId;
	}

	public void setMigGeneId(Long migGeneId) {
		this.migGeneId = migGeneId;
	}
}
