/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.gene.controllers;

import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.ParameterizableViewController;

import uk.ac.sanger.mig.allelerequest.AlleleRequest;
import uk.ac.sanger.mig.allelerequest.AlleleRequestSearchBean;
import uk.ac.sanger.mig.allelerequest.services.AlleleRequestService;
import uk.ac.sanger.mig.allelerequest.views.AlleleRequestListView;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.services.ComponentMapService;
import uk.ac.sanger.mig.designrequest.services.DesignRequestService;
import uk.ac.sanger.mig.gene.BuildGene;
import uk.ac.sanger.mig.gene.MigGene;
import uk.ac.sanger.mig.gene.MigGeneMetaData;
import uk.ac.sanger.mig.gene.services.BuildGeneService;
import uk.ac.sanger.mig.gene.services.MigGeneService;
import uk.ac.sanger.mig.geneevidence.FacultyVote;
import uk.ac.sanger.mig.geneevidence.MigGeneArticleRef;
import uk.ac.sanger.mig.geneevidence.SupportEvidence;
import uk.ac.sanger.mig.geneevidence.services.FacultyVoteService;
import uk.ac.sanger.mig.geneevidence.services.MgiPhenotypeAlleleService;
import uk.ac.sanger.mig.geneevidence.services.MigGeneArticleRefService;
import uk.ac.sanger.mig.geneevidence.services.MigGeneSummaryScoreService;
import uk.ac.sanger.mig.geneevidence.services.MigGeneTargetingHitsService;
import uk.ac.sanger.mig.geneevidence.services.SupportEvidenceService;
import uk.ac.sanger.mig.geneevidence.view.EvidenceListDataBean;
import uk.ac.sanger.mig.geneevidence.view.PubmedEvidenceDataBean;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.reporting.RepPageOverview;
import uk.ac.sanger.mig.reporting.services.RepPageOverviewService;

public class ViewOneMigGeneController extends ParameterizableViewController {

	private MigGeneService migGeneService;
	private MigGeneSummaryScoreService migGeneSummaryScoreService;
	private MigGeneArticleRefService migGeneArticleRefService;
	private MigGeneTargetingHitsService migGeneTargetingHitsService;
	private SupportEvidenceService supportEvidenceService;
	private MgiPhenotypeAlleleService mgiPhenotypeAlleleService;
	private FacultyVoteService facultyVoteService;
	private BuildGeneService buildGeneService;
	private AlleleRequestService alleleRequestService;
	private DesignRequestService designRequestService;
	private ComponentMapService componentMapService;
	private RepPageOverviewService overviewService;

	public void setOverviewService(RepPageOverviewService overviewService) {
		this.overviewService = overviewService;
	}

	public void setComponentMapService(ComponentMapService componentMapService) {
		this.componentMapService = componentMapService;
	}

	public void setDesignRequestService(DesignRequestService designRequestService) {
		this.designRequestService = designRequestService;
	}

	public void setFacultyVoteService(FacultyVoteService facultyVoteService) {
		this.facultyVoteService = facultyVoteService;
	}

	public void setMigGeneArticleRefService(MigGeneArticleRefService migGeneArticleRefService) {
		this.migGeneArticleRefService = migGeneArticleRefService;
	}

	public void setMigGeneSummaryScoreService(MigGeneSummaryScoreService migGeneSummaryScoreService) {
		this.migGeneSummaryScoreService = migGeneSummaryScoreService;
	}

	public void setMgiPhenotypeAlleleService(MgiPhenotypeAlleleService mgiPhenotypeAlleleService) {
		this.mgiPhenotypeAlleleService = mgiPhenotypeAlleleService;
	}

	public void setSupportEvidenceService(SupportEvidenceService supportEvidenceService) {
		this.supportEvidenceService = supportEvidenceService;
	}

	public void setAlleleRequestService(AlleleRequestService alleleRequestService) {
		this.alleleRequestService = alleleRequestService;
	}

	public void setMigGeneService(MigGeneService migGeneService) {
		this.migGeneService = migGeneService;
	}

	public void setBuildGeneService(BuildGeneService buildGeneService) {
		this.buildGeneService = buildGeneService;
	}

	public void setMigGeneTargetingHitsService(
			MigGeneTargetingHitsService migGeneTargetingHitsService) {
		this.migGeneTargetingHitsService = migGeneTargetingHitsService;
	}

	protected ModelAndView handleRequestInternal(HttpServletRequest httpServletRequest, HttpServletResponse response) throws Exception {

		Map<String,Object> model = new HashMap<String,Object>();

		Long migGeneId = ServletRequestUtils.getRequiredLongParameter(httpServletRequest, "migGeneId");
		Person person = (Person)httpServletRequest.getSession().getAttribute("user");

		MigGene migGene = null;

		ComponentMap migGeneComponentMap = componentMapService.getComponentMap("viewOneMigGene");

		migGene = migGeneService.fetchById(migGeneId, migGeneComponentMap);

		migGene.setMigGeneTargetingHits(migGeneTargetingHitsService.fetchTargetingHitsByMigGeneId(migGeneId));

		if (httpServletRequest.getParameterMap().containsKey("vegaId")) {
			String vegaId = ServletRequestUtils.getRequiredStringParameter(httpServletRequest,
			"vegaId");
			if (vegaId != null && vegaId.length() != 0
					&& !vegaId.equalsIgnoreCase(" ")) {

				String[] importResults =
					designRequestService.syncGene("otter_06_09_21",
							vegaId, migGeneId.toString());
				String string = new String();
				int counter = 0;
				while(counter < importResults.length){
					string += importResults[counter];
					counter++;
				}
				logger.debug("Import from Otterlace results: " + string);
			}
		}

		//add historical buildGenes
		ComponentMap buildGeneComponentMap = componentMapService.getComponentMap("viewOneBuildGene");

		Collection<BuildGene> buildGenes = buildGeneService.fetchAllForMigGene(migGene, buildGeneComponentMap);

		model.put("migGene", migGene);
		model.put("buildGenes", buildGenes);


		MigGeneMetaData migGeneMetaData = new MigGeneMetaData();
		migGeneMetaData.setGlobalScore(migGeneSummaryScoreService.fetchCurrentScore(migGeneId));

		model.put("migGeneMetaData", migGeneMetaData);

		//add migGeneArticleRef information such as article, authors etc.
		ComponentMap migGeneArticleRefComponentMap =
			ComponentMap.putAll(
					new ComponentMap(MigGeneArticleRef.Component.ARTICLE, null)
			);

		Collection<MigGeneArticleRef> geneArticles = migGeneArticleRefService.fetchAllByMigGeneId(migGeneId, migGeneArticleRefComponentMap);
		Collection<PubmedEvidenceDataBean> pubmedBeanWrapperList = new ArrayList<PubmedEvidenceDataBean>();

		if(geneArticles != null){
			for(MigGeneArticleRef migGeneArticleRef: geneArticles) {
				PubmedEvidenceDataBean pubmedEvidenceDataBean = new PubmedEvidenceDataBean();
				pubmedEvidenceDataBean.setPubmedEvidence(migGeneArticleRef);
				pubmedBeanWrapperList.add(pubmedEvidenceDataBean);
			}
		}

		model.put("pubmedEvidence", pubmedBeanWrapperList);

		//Fetch and set supportevidence
		Collection evidence = supportEvidenceService.fetchAllSupportEvidenceByMigGeneId(migGeneId, new ComponentMap());
		Collection<EvidenceListDataBean> beanWrapperList
		= new ArrayList<EvidenceListDataBean>();
		for(Iterator i = evidence.iterator(); i.hasNext();) {
			EvidenceListDataBean eldb = new EvidenceListDataBean();
			eldb.setEvidence((SupportEvidence)i.next());
			beanWrapperList.add(eldb);
		}
		model.put("supportEvidence", beanWrapperList);

		Collection knockouts = mgiPhenotypeAlleleService.fetchAllMgiPhenotypeAllelesByMigGeneId(migGeneId, new ComponentMap());
		model.put("existingKO", knockouts);

		AlleleRequestSearchBean alleleRequestSearchBean = new AlleleRequestSearchBean();
		AlleleRequest alleleRequest = new AlleleRequest();
		alleleRequestSearchBean.setPaginated(false);
		alleleRequest.setMigGene(migGene);
		alleleRequestSearchBean.setAlleleRequest(alleleRequest);
		Collection<AlleleRequestListView> alleleRequests = alleleRequestService.search(alleleRequestSearchBean);
		model.put("requestedAlleles", alleleRequests);

		// If we are running in non-authenticated mode then no voting information is applicable.
		if(person != null) {
			FacultyVote facultyVote = facultyVoteService.fetchCurrentFacultyVoteWithMigGeneIdAndPersonId(migGeneId, person.getId(), new ComponentMap());
			model.put("facultyVote", facultyVote);
		}

		// Add data needed for displaying graphs.
		RepPageOverview overview = overviewService.fetchByGeneId(migGeneId, ComponentMap.of(RepPageOverview.Component.ALL_COMPONENTS));
		model.put("overview",overview);

		return new ModelAndView(getViewName(), model);
	}
}
