/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.gene.dao;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.common.PaginatedSearchUtils;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.gene.Assembly;
import uk.ac.sanger.mig.gene.AssemblySearchBean;

public class AssemblyDaoSpringImpl extends AbstractDaoSpringImpl<Assembly> implements AssemblyDao {

	private PaginatedSearchUtils<Assembly> paginator;
	
	public void setPaginator(PaginatedSearchUtils<Assembly> paginator) {
		this.paginator = paginator;
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, Assembly assembly) {
		sql.addIntParam(assembly.getNcbiTaxon(), "NCBI_TAXON");
		sql.addStringParam(assembly.getSpeciesName(), "SPECIES_NAME");
		sql.addStringParam(assembly.getName(), "NAME");
		sql.addLongParam(assembly.getCheckNumber(), "CHECK_NUMBER");
		sql.addStringParam(assembly.getEditedBy(), "EDITED_BY");
		sql.addDateParam(assembly.getEditDate(), "EDIT_DATE");
		sql.addDateParam(assembly.getCreatedDate(), "CREATED_DATE");
		sql.addLongParam(assembly.getCreatorId(), "CREATOR_ID");
		sql.addLongParam(assembly.getId(), "ID");
	}

		/* (non-Javadoc)
	 * @see uk.ac.sanger.mig.gene.dao.AssemblyDao#search(uk.ac.sanger.mig.gene.AssemblySearchBean)
	 */
	public Collection<Assembly> search(AssemblySearchBean assemblySearchBean) {
		Collection<Object> bindVariables = new ArrayList<Object>();

		String selectSql = "select a.* ";
		String fromSql = " from " + getTableName() + " a ";

		String whereSql = " where 1=1 ";

		if (assemblySearchBean.getCreatedDateFrom() != null) {
			whereSql += " and a.created_date >= ? ";
			bindVariables.add(defaultDateFormat.format(assemblySearchBean.getCreatedDateFrom()));
		}

		if (assemblySearchBean.getCreatedDateTo() != null) {
			whereSql += " and a.created_date <= ? ";
			bindVariables.add(defaultDateFormat.format(assemblySearchBean.getCreatedDateTo()));
		}

		if (assemblySearchBean.getSpeciesName() != null) {
			whereSql += " and a.species_name = ? ";
			bindVariables.add(assemblySearchBean.getSpeciesName());
		}

		if (assemblySearchBean.getName() != null) {
			whereSql += " and a.name = ? ";
			bindVariables.add(assemblySearchBean.getName());
		}

		String orderBySql = "";

		if (assemblySearchBean.getOrderBy() != null && assemblySearchBean.getOrderBy().length() > 0) {
			orderBySql += " order by " + assemblySearchBean.getOrderBy();
			if (assemblySearchBean.isOrderDesc()) {
				orderBySql += " desc ";
			}
		}

		String sql = selectSql + fromSql + whereSql + orderBySql;

		return paginator.fetchSearchResults(sql, bindVariables,
				assemblySearchBean, getRowMapper());
	}
}