/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.gene.dao;

import java.util.Collection;
import java.util.LinkedList;
import java.util.List;

import org.springframework.dao.IncorrectResultSizeDataAccessException;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.common.PaginatedSearchUtils;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.gene.Bac;
import uk.ac.sanger.mig.gene.BacSearchBean;

public class BacDaoSpringImpl extends AbstractDaoSpringImpl<Bac> implements BacDao {

  private PaginatedSearchUtils<Bac> paginator;

	public void setPaginator(PaginatedSearchUtils<Bac> paginator) {
    this.paginator = paginator;
  }

  @Override
	protected void bindVariables(ParameterizedSqlUpdate sql, Bac bac) {
		sql.addStringParam(bac.getName(), "NAME");
		sql.addLongParam(bac.getTypeId(), "TYPE_ID");
		sql.addLongParam(bac.getCreatorId(), "CREATOR_ID");
		sql.addDateParam(bac.getCreatedDate(), "CREATED_DATE");
		sql.addStringParam(bac.getEditedBy(), "EDITED_BY");
		sql.addDateParam(bac.getEditDate(), "EDIT_DATE");
		sql.addLongParam(bac.getCheckNumber(), "CHECK_NUMBER");
		sql.addLongParam(bac.getId(), "ID");
	}

  public Collection<Bac> search(BacSearchBean bacSearchBean) {
    String sql = "select b.* from "+getTableName()+ " b where 1=1";
    List<Object> bindVariables = new LinkedList<Object>();
    
    if (bacSearchBean.getBacType() != null) {
      sql += " and type_id = ?";
      bindVariables.add(bacSearchBean.getBacType());
    }
    
    if (bacSearchBean.getBacName() != null) {
      sql += " and name = ?";
      bindVariables.add(bacSearchBean.getBacName());
    }
    
    return paginator.fetchSearchResults(sql, bindVariables, bacSearchBean, getRowMapper());
  }

  public Bac fetchByNameAndType(String name, Long bacTypeId) {
    String sql = "select * from "+getTableName()+" where name = ? and type_id = ?";
    
    Bac bac = null;
    try {
      bac = getSimpleJdbcTemplate().queryForObject(sql, getRowMapper(), name,bacTypeId);
    }
    catch (IncorrectResultSizeDataAccessException e) {
      if (e.getActualSize() > 1) {
        throw new RuntimeException(e);
      }      
    }
    return bac;
  }
	
}