/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.gene.dao;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.common.PaginatedSearchUtils;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.gene.Build;
import uk.ac.sanger.mig.gene.BuildSearchBean;

public class BuildDaoSpringImpl extends AbstractDaoSpringImpl<Build> implements BuildDao {

	private PaginatedSearchUtils<Build> paginator;

	public void setPaginator(PaginatedSearchUtils<Build> paginator) {
		this.paginator = paginator;
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, Build build) {
		sql.addLongParam(build.getAssemblyId(), "ASSEMBLY_ID");
		sql.addStringParam(build.getName(), "NAME");
		sql.addStringParam(build.getVersion(), "VERSION");
		sql.addStringParam(build.getSource(), "SOURCE");
		sql.addIntParam(build.getOrderBy(), "ORDER_BY");
		sql.addLongParam(build.getCheckNumber(), "CHECK_NUMBER");
		sql.addStringParam(build.getEditedBy(), "EDITED_BY");
		sql.addDateParam(build.getEditDate(), "EDIT_DATE");
		sql.addDateParam(build.getCreatedDate(), "CREATED_DATE");
		sql.addLongParam(build.getCreatorId(), "CREATOR_ID");
		sql.addLongParam(build.getId(), "ID");
	}
	
	public Collection<Build> fetchAll(){
		String sql = "SELECT * FROM gnm_gene_build";		

		Collection<Build> geneBuilds = getSimpleJdbcTemplate().query(sql, getRowMapper());
		
		return (geneBuilds == null) ? new ArrayList<Build>() : geneBuilds;
	}
	
		/* (non-Javadoc)
		 * @see uk.ac.sanger.mig.gene.dao.BuildDao#search(uk.ac.sanger.mig.gene.BuildSearchBean)
		 */
		public Collection<Build> search(BuildSearchBean buildSearchBean) {
			Collection<Object> bindVariables = new ArrayList<Object>();
			
			String selectSql  = "select b.* ";
			String fromSql = " from " + getTableName() + " b ";
			
			String whereSql = " where 1=1 ";
			
			if(buildSearchBean.getCreatedDateFrom() != null) {
				whereSql += " and b.created_date >= ? ";
				bindVariables.add(defaultDateFormat.format(buildSearchBean.getCreatedDateFrom()));
			}
			
			if(buildSearchBean.getCreatedDateTo() != null) {
				whereSql += " and b.created_date <= ? ";
				bindVariables.add(defaultDateFormat.format(buildSearchBean.getCreatedDateTo()));
			}
			
			if(buildSearchBean.getCreatedDateFrom() != null) {
				whereSql += " and b.created_date >= ? ";
				bindVariables.add(defaultDateFormat.format(buildSearchBean.getCreatedDateFrom()));
			}
			
			if(buildSearchBean.getCreatedDateTo() != null) {
				whereSql += " and b.created_date <= ? ";
				bindVariables.add(defaultDateFormat.format(buildSearchBean.getCreatedDateTo()));
			}
			
			if(buildSearchBean.getSource() != null) {
				whereSql += " and b.source = ? ";
				bindVariables.add(defaultDateFormat.format(buildSearchBean.getSource()));
			}
			
			if(buildSearchBean.getVersion() != null) {
				whereSql += " and b.version = ? ";
				bindVariables.add(defaultDateFormat.format(buildSearchBean.getVersion()));
			}
			
			if(buildSearchBean.getName() != null) {
				whereSql += " and b.name = ? ";
				bindVariables.add(defaultDateFormat.format(buildSearchBean.getName()));
			}
			
			String orderBySql = "";
			
			if(buildSearchBean.getOrderBy() != null && buildSearchBean.getOrderBy().length() > 0) {
				orderBySql += " order by " + buildSearchBean.getOrderBy();
				if(buildSearchBean.isOrderDesc()) {
					orderBySql += " desc ";
				}
			}
			
			String sql = selectSql + fromSql + whereSql + orderBySql;	
			
			return paginator.fetchSearchResults(sql, bindVariables, buildSearchBean, getRowMapper());
		}
	
}