/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.gene.dao;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.gene.BuildGeneLink;

public class BuildGeneLinkDaoSpringImpl extends AbstractDaoSpringImpl<BuildGeneLink> implements BuildGeneLinkDao {

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, BuildGeneLink buildGeneLink) {
		sql.addLongParam(buildGeneLink.getMigGeneId(), "GENE_ID");
		sql.addLongParam(buildGeneLink.getMigGeneBuildGeneId(), "GENE_BUILD_GENE_ID");
		sql.addDateParam(buildGeneLink.getEditDate(), "EDIT_DATE");
		sql.addStringParam(buildGeneLink.getReasoning(), "REASONING");
		sql.addBooleanParam(buildGeneLink.isValid(), "IS_VALID");
		sql.addLongParam(buildGeneLink.getCheckNumber(), "CHECK_NUMBER");
		sql.addStringParam(buildGeneLink.getEditedBy(), "EDITED_BY");
		sql.addDateParam(buildGeneLink.getCreatedDate(), "CREATED_DATE");
		sql.addLongParam(buildGeneLink.getCreatorId(), "CREATOR_ID");
		sql.addLongParam(buildGeneLink.getId(), "ID");
	}

	/* (non-Javadoc)
	 * @see uk.ac.sanger.mig.gene.dao.BuildGeneLinkDao#fetchAllBuildGeneLinksByMigGeneId(java.lang.Long)
	 */
	public Collection<BuildGeneLink> fetchAllBuildGeneLinksByMigGeneId(Long id) {
		String sql = " SELECT * from GNM_GENE_2_GENE_BUILD_GENE gbgl where gbgl.gene_id=?";
		
		Collection<BuildGeneLink> links = getSimpleJdbcTemplate().query(sql, getRowMapper(), id);
		
		return (links == null) ? new ArrayList<BuildGeneLink>() : links;
	}
	
}