/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.gene.dao;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.common.PaginatedSearchUtils;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.gene.Exon;
import uk.ac.sanger.mig.gene.ExonSearchBean;

public class ExonDaoSpringImpl extends AbstractDaoSpringImpl<Exon> implements ExonDao {

	private PaginatedSearchUtils<Exon> paginator;
	
	public void setPaginator(PaginatedSearchUtils<Exon> paginator) {
		this.paginator = paginator;
	}

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, Exon exon) {
		sql.addLongParam(exon.getLocusId(), "LOCUS_ID");
		sql.addIntParam(exon.getPhase(), "PHASE");
		sql.addStringParam(exon.getPrimaryName(), "PRIMARY_NAME");
		sql.addLongParam(exon.getCheckNumber(), "CHECK_NUMBER");
		sql.addStringParam(exon.getEditedBy(), "EDITED_BY");
		sql.addDateParam(exon.getEditDate(), "EDIT_DATE");
		sql.addDateParam(exon.getCreatedDate(), "CREATED_DATE");
		sql.addLongParam(exon.getCreatorId(), "CREATOR_ID");
		sql.addLongParam(exon.getId(), "ID");
	}
	
	/* (non-Javadoc)
	 * @see uk.ac.sanger.mig.gene.dao.ExonDao#search(uk.ac.sanger.mig.gene.ExonSearchBean)
	 */
	public Collection<Exon> search(ExonSearchBean exonSearchBean) {
		Collection<Object> bindVariables = new ArrayList<Object>();
			
		String selectSql  = "select e.* ";
		String fromSql = " from " + getTableName() + " e ";
			
		String whereSql = " where 1=1 ";
			
		if(exonSearchBean.getCreatedDateFrom() != null) {
			whereSql += " and e.created_date >= ? ";
			bindVariables.add(defaultDateFormat.format(exonSearchBean.getCreatedDateFrom()));
		}
			
		if(exonSearchBean.getCreatedDateTo() != null) {
			whereSql += " and e.created_date <= ? ";
			bindVariables.add(defaultDateFormat.format(exonSearchBean.getCreatedDateTo()));
		}
			
		if(exonSearchBean.getPrimaryName() != null) {
			whereSql += " and e.primary_name = ? ";
			bindVariables.add(exonSearchBean.getPrimaryName());
		}
			
		String orderBySql = "";
			
		if(exonSearchBean.getOrderBy() != null && exonSearchBean.getOrderBy().length() > 0) {
			orderBySql += " order by " + exonSearchBean.getOrderBy();
			if(exonSearchBean.isOrderDesc()) {
				orderBySql += " desc ";
			}
		}
			
		String sql = selectSql + fromSql + whereSql + orderBySql;	
			
		return paginator.fetchSearchResults(sql, bindVariables, exonSearchBean, getRowMapper());
	}
	
	 public Collection<Exon> fetchAllByBuildGeneId(Long buildGeneId){
		    String sql = "select gnm_exon.id exon_id, gnm_exon.*, gnm_locus.* from gnm_gene_build_gene, gnm_transcript, gnm_exon, gnm_locus " +
		        " where gnm_gene_build_gene.id = gnm_transcript.build_gene_id and " +
		        " gnm_transcript.id = gnm_exon.transcript_id and gnm_exon.locus_id = gnm_locus.id and gnm_gene_build_gene.id = ? order by gnm_locus.chr_start asc";
		    
		    Collection<Exon> exons = getSimpleJdbcTemplate().query(sql, getRowMapper(), buildGeneId);
		    
		    return exons == null ? new ArrayList<Exon>() : exons;
	}
}