/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.gene.dao;

import java.util.ArrayList;
import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractDaoSpringImpl;
import uk.ac.sanger.mig.database.ParameterizedSqlUpdate;
import uk.ac.sanger.mig.gene.Transcript;

public class TranscriptDaoSpringImpl extends AbstractDaoSpringImpl<Transcript>
		implements TranscriptDao {

	@Override
	protected void bindVariables(ParameterizedSqlUpdate sql, Transcript transcript) {
		sql.addLongParam(transcript.getLocusId(), "LOCUS_ID");
		sql.addLongParam(transcript.getBuildGeneId(), "BUILD_GENE_ID");
		sql.addIntParam(transcript.getExonCount(), "EXON_COUNT");
		sql.addStringParam(transcript.getPrimaryName(), "PRIMARY_NAME");
		sql.addLongParam(transcript.getCheckNumber(), "CHECK_NUMBER");
		sql.addStringParam(transcript.getEditedBy(), "EDITED_BY");
		sql.addDateParam(transcript.getEditDate(), "EDIT_DATE");
		sql.addDateParam(transcript.getCreatedDate(), "CREATED_DATE");
		sql.addLongParam(transcript.getCreatorId(), "CREATOR_ID");
		sql.addLongParam(transcript.getId(), "ID");
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see uk.ac.sanger.mig.gene.dao.TranscriptDao#fetchAllTranscriptsForBuildGeneId(java.lang.Long)
	 */
	public Collection<Transcript> fetchAllTranscriptsForBuildGeneId(Long id) {
		String sql = " select t.* from gnm_transcript t where t.build_gene_id = ? ";
		
		Collection<Transcript> transcripts = getSimpleJdbcTemplate().query(sql, getRowMapper(), id);
			
		return (transcripts == null) ? new ArrayList<Transcript>() : transcripts;
	}

	/* (non-Javadoc)
	 * @see uk.ac.sanger.mig.gene.dao.TranscriptDao#fetchAllTranscriptsForExonId(java.lang.Long)
	 */
	public Collection<Transcript> fetchAllTranscriptsForExonId(Long id) {
		String sql = " select t.* from gnm_transcript t, gnm_transcript_2_exon te where t.id = te.transcript_id and te.exon_id = ? ";
		
		Collection<Transcript> transcripts = getSimpleJdbcTemplate().query(sql, getRowMapper(), id);
			
		return (transcripts == null) ? new ArrayList<Transcript>() : transcripts;
	}

}