/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.gene.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.gene.Assembly;

public class AssemblyRowMapper implements ParameterizedRowMapper<Assembly> {

	public Assembly mapRow(ResultSet rs, int rowNum) throws SQLException {
		
		Assembly assembly = new Assembly();
		

		assembly.setId(rs.getLong("ID"));

		assembly.setNcbiTaxon(rs.getInt("NCBI_TAXON"));

		assembly.setSpeciesName(rs.getString("SPECIES_NAME"));

		assembly.setName(rs.getString("NAME"));

		assembly.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) assembly.setCheckNumber(null);		

		assembly.setEditedBy(rs.getString("EDITED_BY"));

		assembly.setEditDate(rs.getDate("EDIT_DATE"));

		assembly.setCreatedDate(rs.getDate("CREATED_DATE"));
		
		assembly.setCreatorId(rs.getLong("CREATOR_ID"));
		if(rs.wasNull()) assembly.setCreatorId(null);
		
		
		return assembly;
		
	}
}