/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.gene.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.database.DictionaryEnum;
import uk.ac.sanger.mig.database.DictionaryService;
import uk.ac.sanger.mig.gene.Bac;

public class BacRowMapper implements ParameterizedRowMapper<Bac> {
  private DictionaryService dictionaryService;
  
	public void setDictionaryService(DictionaryService dictionaryService) {
    this.dictionaryService = dictionaryService;
  }
	
  public Bac mapRow(ResultSet rs, int rowNum) throws SQLException {
		
		Bac bac = new Bac();
		

		bac.setId(rs.getLong("ID"));

		bac.setName(rs.getString("NAME"));

		bac.setTypeId(rs.getLong("TYPE_ID"));
		if(rs.wasNull()) {
		  bac.setTypeId(null);		
		}
		else {
		  bac.setBacType(
		      dictionaryService.fetchEntry(DictionaryEnum.BAC_TYPE,bac.getTypeId())
		  );
		}

		bac.setCreatorId(rs.getLong("CREATOR_ID"));

		bac.setCreatedDate(rs.getTimestamp("CREATED_DATE"));

		bac.setEditedBy(rs.getString("EDITED_BY"));

		bac.setEditDate(rs.getTimestamp("EDIT_DATE"));

		bac.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) bac.setCheckNumber(null);		
		
		return bac;
		
	}
}