/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.gene.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.gene.views.MigGeneListView;

public class MigGeneListViewRowMapper implements ParameterizedRowMapper<MigGeneListView> {
	
	protected Log logger = LogFactory.getLog(this.getClass());

	public MigGeneListView mapRow(ResultSet rs, int rowNum) throws SQLException {
		
		MigGeneListView migGeneListView = new MigGeneListView();

		migGeneListView.setId(rs.getLong("ID"));
		migGeneListView.setNcbiTaxon(rs.getInt("NCBI_TAXON"));
		migGeneListView.setPrimaryGeneBuildGeneId(rs.getLong("PRIMARY_BUILD_GENE_ID"));
		if(rs.wasNull()) migGeneListView.setPrimaryGeneBuildGeneId(null);		
		migGeneListView.setPrimaryVegaBuildGeneId(rs.getLong("PRIMARY_VEGA_BUILD_GENE_ID"));
		if(rs.wasNull()) migGeneListView.setPrimaryVegaBuildGeneId(null);
		migGeneListView.setInCurrentVega(rs.getBoolean("IN_CURRENT_VEGA"));
		migGeneListView.setPrimaryEnsemblBuildGeneId(rs.getLong("PRIMARY_ENSEMBL_BUILD_GENE_ID"));
		if(rs.wasNull()) migGeneListView.setPrimaryEnsemblBuildGeneId(null);
		migGeneListView.setInCurrentEnsembl(rs.getBoolean("IN_CURRENT_ENSEMBL"));
		migGeneListView.setValid(rs.getBoolean("IS_VALID"));
		migGeneListView.setPrimaryName(rs.getString("PRIMARY_NAME"));
		migGeneListView.setEnsemblIdString(rs.getString("ENSEMBL_ID"));
		migGeneListView.setVegaIdString(rs.getString("VEGA_ID"));
		migGeneListView.setBuildId(rs.getLong("BUILD_ID"));
		if(rs.wasNull()) migGeneListView.setBuildId(null);
		migGeneListView.setLocusId(rs.getLong("LOCUS_ID"));
		if(rs.wasNull()) migGeneListView.setLocusId(null);
		migGeneListView.setFinished(rs.getString("IS_FINISHED"));
		migGeneListView.setTranscriptCount(rs.getInt("TRANSCRIPT_COUNT"));
		migGeneListView.setTotalExonCount(rs.getInt("TOTAL_EXON_COUNT"));
		migGeneListView.setUniqueExonCount(rs.getInt("UNIQUE_EXON_COUNT"));
		migGeneListView.setBuildGenePrimaryName(rs.getString("GENE_BUILD_GENE_PRIMARY_NAME"));
		migGeneListView.setChromosomeName(rs.getString("CHROMOSOME_NAME"));
		migGeneListView.setChromosomeStart(rs.getInt("CHROMOSOME_START"));
		migGeneListView.setChromosomeEnd(rs.getInt("CHROMOSOME_END"));
		migGeneListView.setChromosomeStrand(rs.getInt("CHROMOSOME_STRAND"));
		migGeneListView.setBuildName(rs.getString("BUILD_NAME"));
		migGeneListView.setBuildVersion(rs.getString("BUILD_VERSION"));
		migGeneListView.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) migGeneListView.setCheckNumber(null);		
		migGeneListView.setEditedBy(rs.getString("EDITED_BY"));
		migGeneListView.setEditDate(rs.getDate("EDIT_DATE"));
		migGeneListView.setCreatedDate(rs.getDate("CREATED_DATE"));
		migGeneListView.setCreatorId(rs.getLong("CREATOR_ID"));
		migGeneListView.setPrimaryNameSource(rs.getString("PRIMARY_NAME_SOURCE"));
		migGeneListView.setCuratedStatus(rs.getString("STATUS"));
		migGeneListView.setSummaryScore(rs.getInt("SCORE"));
		migGeneListView.setIgtcHits(rs.getInt("IGTC_HITS"));
		migGeneListView.setOmnibankHits(rs.getInt("OMNIBANK_HITS"));
		
		return migGeneListView;
		
	}
}