/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.gene.dao.rowmappers;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.simple.ParameterizedRowMapper;

import uk.ac.sanger.mig.gene.MigGene;

public class MigGeneRowMapper implements ParameterizedRowMapper<MigGene> {

	public MigGene mapRow(ResultSet rs, int rowNum) throws SQLException {
		
		MigGene migGene = new MigGene();

		migGene.setId(rs.getLong("ID"));

		migGene.setNcbiTaxon(rs.getInt("NCBI_TAXON"));

		migGene.setPrimaryBuildGeneId(rs.getLong("PRIMARY_BUILD_GENE_ID"));
		if(rs.wasNull()) migGene.setPrimaryBuildGeneId(null);		

		migGene.setValid(rs.getBoolean("IS_VALID"));

		migGene.setPrimaryName(rs.getString("PRIMARY_NAME"));
		migGene.setPrimaryNameSource(rs.getString("PRIMARY_NAME_SOURCE"));
		
		migGene.setPrimaryVegaBuildGeneId(rs.getLong("PRIMARY_VEGA_BUILD_GENE_ID"));
		if(rs.wasNull()) migGene.setPrimaryVegaBuildGeneId(null);
		migGene.setInCurrentVega(rs.getBoolean("IN_CURRENT_VEGA"));

		migGene.setPrimaryEnsemblBuildGeneId(rs.getLong("PRIMARY_ENSEMBL_BUILD_GENE_ID"));
		if(rs.wasNull()) migGene.setPrimaryEnsemblBuildGeneId(null);
		migGene.setInCurrentEnsembl(rs.getBoolean("IN_CURRENT_ENSEMBL"));
		
		migGene.setCheckNumber(rs.getLong("CHECK_NUMBER"));
		if(rs.wasNull()) migGene.setCheckNumber(null);		

		migGene.setEditedBy(rs.getString("EDITED_BY"));
		migGene.setEditDate(rs.getDate("EDIT_DATE"));

		migGene.setCreatedDate(rs.getDate("CREATED_DATE"));
		
		migGene.setCreatorId(rs.getLong("CREATOR_ID"));
		if(rs.wasNull()) migGene.setCreatorId(null);		
		
		return migGene;
		
	}
}