/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.gene.services;

import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.gene.Assembly;
import uk.ac.sanger.mig.gene.AssemblySearchBean;
import uk.ac.sanger.mig.gene.dao.AssemblyDao;
import uk.ac.sanger.mig.personnel.Person;

public class AssemblyServiceImpl extends AbstractServiceImpl<Assembly> implements AssemblyService {
	
	private AssemblyDao assemblyDao;
	
	public void setAssemblyDao(AssemblyDao assemblyDao) {
		this.assemblyDao = assemblyDao;
	}

	public Long storeAuthenticated(Assembly assembly, Person user) {
		if(assembly == null) {
			throw new RuntimeException("Cannot save a null assembly");
		}
		
		return assemblyDao.store(assembly, user);
	}
	
	public Assembly fetchById(Long assemblyId, ComponentMap requiredComponents) {
		Assembly assembly = assemblyDao.fetchById(assemblyId);
		
		if(assembly != null)
			attachComponents(assembly, requiredComponents);
		
		return assembly;
	}

	@Override
	protected void attachComponents(Assembly assembly, ComponentMap requiredComponents) {
		if(assembly == null) {
			throw new RuntimeException("Cannot attach components to null assembly");
		}		
	}


	/* (non-Javadoc)
	 * @see uk.ac.sanger.mig.gene.services.AssemblyService#search(uk.ac.sanger.mig.gene.AssemblySearchBean)
	 */
	public Collection<Assembly> search(AssemblySearchBean assemblySearchBean) {
		return assemblyDao.search(assemblySearchBean);
	}
}
								