/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.gene.services;

import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.gene.BuildGeneLink;
import uk.ac.sanger.mig.gene.dao.BuildGeneLinkDao;
import uk.ac.sanger.mig.personnel.Person;

public class BuildGeneLinkServiceImpl extends AbstractServiceImpl<BuildGeneLink> implements BuildGeneLinkService {
	
	private BuildGeneLinkDao buildGeneLinkDao;
	
	public void setBuildGeneLinkDao(BuildGeneLinkDao buildGeneLinkDao) {
		this.buildGeneLinkDao = buildGeneLinkDao;
	}

	public Long storeAuthenticated(BuildGeneLink buildGeneLink, Person user) {
		if(buildGeneLink == null) {
			throw new RuntimeException("Cannot save a null buildGeneLink");
		}
		
		return buildGeneLinkDao.store(buildGeneLink, user);
	}
	
	public BuildGeneLink fetchById(Long buildGeneLinkId, ComponentMap requiredComponents) {
		BuildGeneLink buildGeneLink = buildGeneLinkDao.fetchById(buildGeneLinkId);
		
		if(buildGeneLink != null)
			attachComponents(buildGeneLink, requiredComponents);
		
		return buildGeneLink;
	}

	@Override
	protected void attachComponents(BuildGeneLink buildGeneLink, ComponentMap requiredComponents) {
		if(buildGeneLink == null) {
			throw new RuntimeException("Cannot attach components to null buildGeneLink");
		}		
	}

	/* (non-Javadoc)
	 * @see uk.ac.sanger.mig.gene.services.BuildGeneLinkService#fetchAllBuildGeneLinksByMigGeneId(java.lang.Long, uk.ac.sanger.mig.common.ComponentMap)
	 */
	public Collection<BuildGeneLink> fetchAllBuildGeneLinksByMigGeneId(Long id, ComponentMap map) {
		Collection<BuildGeneLink> buildGeneLinks = buildGeneLinkDao.fetchAllBuildGeneLinksByMigGeneId(id);
		
		attachComponents(buildGeneLinks, map);
		
		return buildGeneLinks;
	}
	
}
								