/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.gene.services;

import java.util.Collection;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.gene.Exon;
import uk.ac.sanger.mig.gene.ExonSearchBean;
import uk.ac.sanger.mig.gene.Locus;
import uk.ac.sanger.mig.gene.Transcript;
import uk.ac.sanger.mig.gene.dao.ExonDao;
import uk.ac.sanger.mig.personnel.Person;

public class ExonServiceImpl extends AbstractServiceImpl<Exon> implements ExonService {
	
	private ExonDao exonDao;
	
	private LocusService locusService;
	private TranscriptService transcriptService;
	
	public void setLocusService(LocusService locusService) {
		this.locusService = locusService;
	}

	public void setTranscriptService(TranscriptService transcriptService) {
		this.transcriptService = transcriptService;
	}

	public void setExonDao(ExonDao exonDao) {
		this.exonDao = exonDao;
	}

	public Long storeAuthenticated(Exon exon, Person user) {
		if(exon == null) {
			throw new RuntimeException("Cannot save a null exon");
		}
		
		return exonDao.store(exon, user);
	}
	
	public Exon fetchById(Long exonId, ComponentMap requiredComponents) {
		Exon exon = exonDao.fetchById(exonId);
		
		if(exon != null)
			attachComponents(exon, requiredComponents);
		
		return exon;
	}

	@Override
	protected void attachComponents(Exon exon, ComponentMap requiredComponents) {
		if(exon == null) {
			throw new RuntimeException("Cannot attach components to null exon");
		}		
		
		boolean fetchAll = false;
		
		if(requiredComponents != null) {
			
			if(requiredComponents.containsKey(Exon.Component.ALL_COMPONENTS)) {
				fetchAll = true;
			}
			
			if(fetchAll || requiredComponents.containsKey(Exon.Component.LOCUS)) {
				exon.setLocus(fetchLocus(exon, requiredComponents.get(Exon.Component.LOCUS)));
			}
			
			if(fetchAll || requiredComponents.containsKey(Exon.Component.TRANSCRIPTS)) {
				exon.setTranscripts(fetchTranscripts(exon, requiredComponents.get(Exon.Component.TRANSCRIPTS)));
			}
			
		}
	}
	
	/* (non-Javadoc)
	 * @see uk.ac.sanger.mig.gene.services.ExonService#search(uk.ac.sanger.mig.gene.ExonSearchBean)
	 */
	public Collection<Exon> search(ExonSearchBean exonSearchBean) {
		return exonDao.search(exonSearchBean);
	}


	/* (non-Javadoc)
	 * @see uk.ac.sanger.mig.gene.services.ExonService#fetchAllExonsByTranscriptId(java.lang.Long, uk.ac.sanger.mig.common.ComponentMap)
	 */
	public Collection<Exon> fetchAllExonsByTranscriptId(Long id, ComponentMap map) {
		// TODO Auto-generated method stub
		return null;
	}

	/**
	 * @param exon
	 * @param map
	 * @return
	 */
	private Collection<Transcript> fetchTranscripts(Exon exon, ComponentMap map) {
		return transcriptService.fetchAllTranscriptsForExonId(exon.getId(), map);
	}


	/**
	 * @param exon
	 * @param map
	 * @return
	 */
	private Locus fetchLocus(Exon exon, ComponentMap map) {
		return locusService.fetchById(exon.getLocusId(), map);
	}
	
	 public Collection<Exon> fetchAllByBuildGeneId(Long buildGeneId, ComponentMap requiredComponents){
		    
		 Collection<Exon> exons = exonDao.fetchAllByBuildGeneId(buildGeneId);
		    
		 if(exons != null)
				for(Exon exon : exons){
					attachComponents(exon, requiredComponents);
				}

			return exons;
	}
}
								