/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.gene.services;

import java.util.Collection;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

import uk.ac.sanger.mig.common.AbstractServiceImpl;
import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.gene.MigGeneName;
import uk.ac.sanger.mig.gene.dao.MigGeneNameDao;
import uk.ac.sanger.mig.personnel.Person;

public class MigGeneNameServiceImpl extends AbstractServiceImpl<MigGeneName> implements MigGeneNameService {
	
	private MigGeneNameDao migGeneNameDao;

	public void setMigGeneNameDao(MigGeneNameDao migGeneNameDao) {
		this.migGeneNameDao = migGeneNameDao;
	}

	@Override
	protected void attachComponents(MigGeneName migGeneName, ComponentMap requiredComponents) {
		if(migGeneName == null) {
			throw new RuntimeException("Cannot attach components to null migGeneName");
		}		
	}

	public Map<String, Set<MigGeneName>> fetchNamesAndSourcesByMigGeneId(Long migGeneId, ComponentMap componentMap) {
		Map<String, Set<MigGeneName>> sources = new HashMap<String, Set<MigGeneName>>();
		Collection<MigGeneName> migGeneNames = migGeneNameDao.fetchNamesAndSourcesByMigGeneId(migGeneId, componentMap);
		if(migGeneNames != null)
			for(MigGeneName migGeneName : migGeneNames){
				//If the source has already been added then get the list of names associated with the source
				//and add the new name to it...
				if(sources.get(migGeneName.getSource()) != null){
					Set<MigGeneName> names = sources.get(migGeneName.getSource());
					names.add(migGeneName);
					sources.put(migGeneName.getSource(), names);
				}
				//...else, if the source is new set up a new HashSet for the names and add this to the Map
				else{
					Set<MigGeneName> names = new HashSet<MigGeneName>();
					names.add(migGeneName);
					sources.put(migGeneName.getSource(), names);
				}
			}
		
		return sources;
	}

	public MigGeneName fetchById(Long id, ComponentMap componentMap) {
		// TODO Auto-generated method stub
		return null;
	}

	public Long storeAuthenticated(MigGeneName migGeneName, Person user) {
		if(migGeneName == null) {
			throw new RuntimeException("Cannot save a null migGeneName");
		}
		
		return migGeneNameDao.store(migGeneName, user);
	}

}
