/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.testing.gene.dao;

import java.text.SimpleDateFormat;
import java.util.Date;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.test.AbstractTransactionalSpringContextTests;

import uk.ac.sanger.mig.common.OperationNotSupported;
import uk.ac.sanger.mig.gene.Build;
import uk.ac.sanger.mig.gene.dao.BuildDao;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.personnel.dao.PersonDao;


public class BuildDaoSpringImplTest extends AbstractTransactionalSpringContextTests {
	
	private static final SimpleDateFormat simpleDateFormat = new SimpleDateFormat("dd-MMM-yyyy hh:mm:ss");

	public static final Log logger = LogFactory.getLog(BuildDaoSpringImplTest.class);

	private BuildDao buildDao;
	public void setBuildDaoSpringImpl(BuildDao buildDao ) {
		this.buildDao = buildDao;
	}
	
	private PersonDao personDao;
	public void setPersonDao(PersonDao personDao) {
		this.personDao = personDao;
	}

	public void testFetchById() {
		Build build = buildDao.fetchById(1L);
		
		assertTrue(build != null);
		logger.info("FetchById:" + build);
	}

	/**
	 * Attempt to perform a full round-trip of a POJO. Create a new one, write it to the database and retrieve
	 * its contents using its primary key.
	 *
	 */
	public void testStoreAuthenticated() {
		
		
		Build build = new Build();
		
		Date timestamp = new Date();
		
		build.setName("test-build-name");
		build.setEditDate(timestamp);
		build.setVersion("test-build-version");
		build.setSource("test-build-source");
		build.setOrderBy(10);
		build.setCreatorId(1L);
		build.setCreatedDate(timestamp);
		
		Long id = null;
		try {
			
			Person person = personDao.fetchById(1L);
			logger.info("Got Person:" + person.getFullName());
			
			build.setCreator(person);
			id = buildDao.store(build, person);
			
			Build res = buildDao.fetchById(id);
			
			assertTrue("test-build-name".equals(res.getName()));
			assertTrue("test-build-version".equals(res.getVersion()));
			assertTrue("test-build-source".equals(res.getSource()));
			assertTrue(build.getOrderBy() == 10);
			
			assertTrue(res.getCreatorId() == 1L);
			assertTrue(res.getCreatedDate() != null);
			
			String timestampStr = simpleDateFormat.format(timestamp);
			
			assertTrue(res.getEditDate() != null);
			assertTrue(timestampStr.equals(simpleDateFormat.format(res.getEditDate())));
			
			assertTrue(res.getCreatedDate() != null);
			assertTrue(timestampStr.equals(simpleDateFormat.format(res.getCreatedDate())));
			
		} catch (OperationNotSupported e) {
			id = -1L;
		}

		assertTrue(id != null);
		logger.info("StoreAuthenticated:" + build);
	}

	protected String[] getConfigLocations() {
		return new String[] {
				"file:WebRoot/WEB-INF/conf/licensing.xml",
				"file:WebRoot/WEB-INF/conf/common.xml",
				"file:WebRoot/WEB-INF/conf/junit-common.xml",
				"file:WebRoot/WEB-INF/conf/personnel.xml",
				"file:WebRoot/WEB-INF/conf/debug-database.xml",
				"file:WebRoot/WEB-INF/conf/gene.xml" };
	}
}
