/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**
 * Copyright (c) 2007 Genome Research Ltd
 */
package uk.ac.sanger.mig.testing.gene.dao;

import java.text.SimpleDateFormat;
import java.util.Date;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.test.AbstractTransactionalSpringContextTests;

import uk.ac.sanger.mig.common.OperationNotSupported;
import uk.ac.sanger.mig.gene.BuildGene;
import uk.ac.sanger.mig.gene.dao.BuildGeneDao;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.personnel.dao.PersonDao;

public class BuildGeneDaoSpringImplTest extends
		AbstractTransactionalSpringContextTests {

	private static final SimpleDateFormat simpleDateFormat = new SimpleDateFormat("dd-MMM-yyyy hh:mm:ss");

	public static final Log logger = LogFactory.getLog(BuildGeneDaoSpringImplTest.class);

	private BuildGeneDao buildGeneDao;

	public void setBuildGeneDaoSpringImpl(BuildGeneDao buildGeneDao) {
		this.buildGeneDao = buildGeneDao;
	}

	private PersonDao personDao;

	public void setPersonDao(PersonDao personDao) {
		this.personDao = personDao;
	}

	public void testFetchById() {
		BuildGene buildGene = buildGeneDao.fetchById(1L);

		assertTrue(buildGene != null);
		logger.info("FetchById:" + buildGene);
	}

	/**
	 * Attempt to perform a full round-trip of a POJO. Create a new one,
	 * write it to the database and retrieve its contents using its primary
	 * key.
	 * 
	 */
	public void testStoreAuthenticated() {

		BuildGene buildGene = new BuildGene();

		Date timestamp = new Date();

		buildGene.setEditDate(timestamp);
		buildGene.setBuildId(1L);
		//buildGene.setExonCount(1234);
		buildGene.setFinishingStatus("n/a");
		buildGene.setLocusId(2345L);
		buildGene.setPrimaryName("test-primary-name");
		buildGene.setTranscriptCount(12);
		buildGene.setCreatorId(1L);
		buildGene.setCreatedDate(timestamp);

		Long id = null;
		try {

			Person person = personDao.fetchById(1L);
			logger.info("Got Person:" + person.getFullName());

			buildGene.setCreator(person);
			id = buildGeneDao.store(buildGene, person);

			BuildGene res = buildGeneDao.fetchById(id);

			assertTrue(res.getBuildId() == 1L);

			//assertTrue(res.getExonCount() == 1234);
			assertTrue("n/a".equals(res.getFinishingStatus()));
			assertTrue(res.getLocusId() == 2345L);
			assertTrue("test-primary-name".equals(res.getPrimaryName()));
			assertTrue(res.getTranscriptCount() == 12);

			assertTrue(res.getCreatorId() == 1L);
			assertTrue(res.getCreatedDate() != null);

			String timestampStr = simpleDateFormat.format(timestamp);

			assertTrue(res.getEditDate() != null);
			assertTrue(timestampStr.equals(simpleDateFormat.format(res.getEditDate())));

			assertTrue(res.getCreatedDate() != null);
			assertTrue(timestampStr.equals(simpleDateFormat.format(res.getCreatedDate())));

		} catch (OperationNotSupported e) {
			id = -1L;
		}

		assertTrue(id != null);
		logger.info("StoreAuthenticated:" + buildGene);
	}

	protected String[] getConfigLocations() {
		return new String[] { "file:WebRoot/WEB-INF/conf/licensing.xml",
				"file:WebRoot/WEB-INF/conf/common.xml",
				"file:WebRoot/WEB-INF/conf/junit-common.xml",
				"file:WebRoot/WEB-INF/conf/personnel.xml",
				"file:WebRoot/WEB-INF/conf/debug-database.xml",
				"file:WebRoot/WEB-INF/conf/gene.xml" };
	}
}
