/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**
 * Copyright (c) 2007 Genome Research Ltd
 */
package uk.ac.sanger.mig.testing.gene.services;

import java.text.SimpleDateFormat;
import java.util.Date;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.test.AbstractTransactionalSpringContextTests;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.common.OperationNotSupported;
import uk.ac.sanger.mig.gene.BuildGeneLink;
import uk.ac.sanger.mig.gene.services.BuildGeneLinkService;
import uk.ac.sanger.mig.personnel.Person;
import uk.ac.sanger.mig.personnel.dao.PersonDao;

public class BuildGeneLinkServiceSpringImplTest extends
		AbstractTransactionalSpringContextTests {

	private static final SimpleDateFormat simpleDateFormat = new SimpleDateFormat("dd-MMM-yyyy hh:mm:ss");

	public static final Log logger = LogFactory.getLog(BuildGeneLinkServiceSpringImplTest.class);

	private BuildGeneLinkService buildGeneLinkService;

	public void setBuildGeneLinkServiceSpringImpl(BuildGeneLinkService buildGeneLinkService) {
		this.buildGeneLinkService = buildGeneLinkService;
	}

	private PersonDao personDao;

	public void setPersonDao(PersonDao personDao) {
		this.personDao = personDao;
	}

	public void testFetchById() {
		
		ComponentMap linkComponents = new ComponentMap();
		linkComponents.put(BuildGeneLink.Component.ALL_COMPONENTS, null);
		
		BuildGeneLink link = buildGeneLinkService.fetchById(650L, linkComponents);

		assertTrue(link != null);
		logger.info("FetchById:" + link);
	}

	/**
	 * Attempt to perform a full round-trip of a POJO. Create a new one,
	 * write it to the database and retrieve its contents using its primary
	 * key.
	 * 
	 */
	public void testStoreAuthenticated() {

		BuildGeneLink link = new BuildGeneLink();

		Date timestamp = new Date();

		link.setEditDate(timestamp);
		link.setCreatorId(1L);
		link.setCreatedDate(timestamp);
		//link.setGeneId(1L);
		//link.setGeneBuildGeneId(2L);
		link.setReasoning("test-reasoning");
		link.setValid(true);

		Long id = null;
		try {

			Person person = personDao.fetchById(1L);
			logger.info("Got Person:" + person.getFullName());

			link.setCreator(person);
			id = buildGeneLinkService.storeAuthenticated(link, person);

			
			ComponentMap linkComponents = new ComponentMap();
			linkComponents.put(BuildGeneLink.Component.ALL_COMPONENTS, null);
			BuildGeneLink res = buildGeneLinkService.fetchById(id, linkComponents);

			assertTrue("test-reasoning".equals(res.getReasoning()));
			//assertTrue(res.getGeneId() == 1L);
			//assertTrue(res.getGeneBuildGeneId() == 2L);
			assertTrue(res.isValid());
			
			assertTrue(res.getCreatorId() == 1L);
			assertTrue(res.getCreatedDate() != null);

			String timestampStr = simpleDateFormat.format(timestamp);

			assertTrue(res.getEditDate() != null);
			assertTrue(timestampStr.equals(simpleDateFormat.format(res.getEditDate())));

			assertTrue(res.getCreatedDate() != null);
			assertTrue(timestampStr.equals(simpleDateFormat.format(res.getCreatedDate())));

		} catch (OperationNotSupported e) {
			id = -1L;
		}

		assertTrue(id != null);
		logger.info("StoreAuthenticated:" + link);
	}

	protected String[] getConfigLocations() {
		return new String[] { "file:WebRoot/WEB-INF/conf/licensing.xml",
				"file:WebRoot/WEB-INF/conf/common.xml",
				"file:WebRoot/WEB-INF/conf/junit-common.xml",
				"file:WebRoot/WEB-INF/conf/personnel.xml",
				"file:WebRoot/WEB-INF/conf/debug-database.xml",
				"file:WebRoot/WEB-INF/conf/gene.xml" };
	}
}
