/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of conditions
 *     and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list of
 *     conditions and the following disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *  3. The name of the author may not be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.gene.services;

import java.util.Collection;
import java.util.HashSet;

import junit.framework.TestCase;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import uk.ac.sanger.mig.gene.BacImport;
import uk.ac.sanger.mig.gene.dao.BacImportDaoDasImpl;

public class BacImportDaoDasImplTest extends TestCase {

  protected Log logger = LogFactory.getLog(this.getClass());
  private BacImportDaoDasImpl bacImportDao;

  private static final Long assemblyId = 11L;
  private static final Long bacTypeId = 2L;

  @Override
  public void setUp() {
    // make sure we use the Xerces XML parser..
    System.setProperty("javax.xml.parsers.DocumentBuilderFactory","org.apache.xerces.jaxp.DocumentBuilderFactoryImpl");
    System.setProperty("javax.xml.parsers.SAXParserFactory","org.apache.xerces.jaxp.SAXParserFactoryImpl");

    // if you are behind a proxy, please uncomment the following lines
    System.setProperty("proxySet","true");
    System.setProperty("proxyHost","wwwcache.sanger.ac.uk");
    System.setProperty("proxyPort","3128");

    bacImportDao = new BacImportDaoDasImpl();
    bacImportDao.setSrcUrl("http://das.sanger.ac.uk/das/ens_m37_bacmap");

    Collection<String> types = new HashSet<String>();
    types.add("ssaha2:clone");
    types.add("map2gp:clone");
    bacImportDao.setRequiredTypes(types);
    bacImportDao.setTimeLimit(20d);
    bacImportDao.setAssemblyId(assemblyId);
    bacImportDao.setBacTypeId(bacTypeId);
  }

  public void testBacsOnOneSmallChromosome() {
    String chr = "Y";

    Collection<BacImport> bacs = bacImportDao.fetchByChromosome(chr);
    assertNotNull(bacs);
    assertEquals(39,bacs.size());

    for (BacImport bac : bacs) {
      assertEquals(chr,bac.getChromosome());
      assertEquals(assemblyId,bac.getAssemblyId());
      assertEquals(bacTypeId, bac.getBacTypeId());

      assertNotNull(bac.getChromosomeStrand());
      assertTrue(bac.getChromosomeStrand() == 1 || bac.getChromosomeStrand() == -1);

      assertNotNull(bac.getLabel());

      assertNotNull(bac.getStart());
      assertNotNull(bac.getStop());

      assertTrue(bac.getStart() > 0);
      assertTrue(bac.getStop() > 0);

      assertTrue(bac.getStop() > bac.getStart());

      logger.info(bac);
    }
  }


}
