/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package uk.ac.sanger.mig.gene.services;

import java.util.Collection;

import uk.ac.sanger.mig.common.ComponentMap;
import uk.ac.sanger.mig.gene.Bac;
import uk.ac.sanger.mig.gene.Locus;
import uk.ac.sanger.mig.gene.LocusSearchBean;
import uk.ac.sanger.mig.testsupport.AbstractGenericServiceTest;

public class BacServiceTest extends AbstractGenericServiceTest {
	private LocusService locusService;
	private BacService bacService;
	
  public void setBacService(BacService service) {
		this.bacService = service;
    this.service = service;
	}
	public void setLocusService(LocusService locusService){
	  this.locusService = locusService;
	}
	
	
	public void testCreateAttachAndDetach() {
	  Bac bac = new Bac();
	  bac.setName("Test bac");
	  bac.setTypeId(1L);

	  Long bacId = bacService.store(bac, getFakeUser());
	  
	  LocusSearchBean locusSearchBean = new LocusSearchBean();
	  locusSearchBean.setPaginated(false);
	  locusSearchBean.setChromosomeName("Y");
	  Collection<Locus> loci = locusService.search(locusSearchBean);
	  
	  assertFalse("Require some loci to proceed with test",loci.isEmpty());
	  
	  Locus locus = loci.iterator().next();
	  
	  bacService.addLocusToBac(locus, bac, getFakeUser());
	  
	  Bac retrievedBac = bacService.fetchById(bacId, ComponentMap.of(Bac.Component.LOCI));

	  assertNotNull("Should have retrieved BAC",retrievedBac);
	  assertNotNull("Should have some loci",retrievedBac.getLoci());
	  assertTrue("Should have one locus", retrievedBac.getLoci().size() == 1);
	  assertEquals("Different references to the same locus should be equal", locus, retrievedBac.getLoci().iterator().next());
	  
	  bacService.removeLocusFromBac(locus, retrievedBac, getFakeUser());
	  retrievedBac  = bacService.fetchById(bacId, ComponentMap.of(Bac.Component.LOCI));

	  assertNotNull("Should have retrieved BAC",retrievedBac);
    assertTrue("Should have no loci", retrievedBac.getLoci().isEmpty());
	}

}