/*
 * Copyright (c) 2007 Genome Research Ltd.
 *
 * Author: Mouse Informatics Group <team110g@sanger.ac.uk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE)ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package uk.ac.sanger.mig.gene.services;

import java.lang.reflect.Method;
import java.util.List;

import uk.ac.sanger.mig.gene.MigGene;
import uk.ac.sanger.mig.testsupport.AbstractGenericServiceTest;

public class MigGeneServiceTest extends AbstractGenericServiceTest {

	public void setMigGeneService(MigGeneService service) {
		this.service = service;
	}

	public MigGeneService getMigGeneService(){
		return (MigGeneService)service;
	}

	public void testInflateMigGeneComponents(){
		MigGene migGene = new MigGene();
		getMigGeneService().inflateMigGeneComponents(migGene);
		assertTrue("MigGene should now have a primaryBuildGene inflated.", migGene.getPrimaryBuildGene() != null);
		assertTrue("MigGene should now have a primaryVegaBuildGene inflated.", migGene.getPrimaryVegaBuildGene() != null);
		assertTrue("MigGene should now have a primaryEnsemblBuildGene inflated.", migGene.getPrimaryEnsemblBuildGene() != null);
		assertTrue("MigGene should now have buildGeneLinks inflated.", migGene.getBuildGeneLinks() != null);
		assertTrue("MigGene should now have a creator inflated.", migGene.getCreator() != null);
	}

	public void testFetchPubmedKeywords(){
		//Naughtily hard-coded!  But should be a stable identifier.
		String ensemblId = "ENSMUSG00000000001";
		List<String> pubmedKeywords = getMigGeneService().fetchPubmedKeywords(ensemblId);
		assertTrue("Method returns a list of pubmed keywords.", pubmedKeywords.size() > 0);
	}

  @Override
  protected boolean testFetchMethod(Method method) {
    return !method.getName().equals("fetchByName");
  }


}
